/*
FORM: BalticOI 1996 day 1
PROB: expr
KEYW: full exhaustion, reverse polish notation (RPN, revrse polish signature)
*/

#include <cstdio>
#include <cctype>
#include <cassert>
#include <utility>
#include <vector>
#include <string>
#include <algorithm>

unsigned char rpn[5][256];
unsigned int rp[5];
unsigned int val[5][8];

void to_rpn (int id, const char *line) {
	static unsigned char buf[256];
	int p1 = 0, p2 = 0;

	int i;
	for (i = 0; line[i]; ++i) {
//		printf ("%c -- \n", line[i]);
		if (isalpha (line[i])) {
			rpn[id][p1++] = line[i] - 'a';
//			printf ("put var %d\n", line[i] - 'a');
		} else if (line[i] != ')') {
			switch (line[i]) {
				case '#': buf[p2++] = 8; break;
				case '&': buf[p2++] = 9; break;
				case '+': buf[p2++] = 10; break;
				case '(': buf[p2++] = 11; break;
				default : assert (0);
			}
			if (line[i] == '(') continue;//no flushing
			while (p2 >= 2 && buf[p2-2] <= buf[p2-1]) {
//				printf ("flush sgn %d\n", buf[p2-2]);
				rpn[id][p1++] = buf[p2-2];
				buf[p2-2] = buf[p2-1];
				--p2;
			}
		} else
			for (--p2; buf[p2] != 11; --p2) {
//				printf ("flush sgn %d\n", buf[p2]);
				rpn[id][p1++] = buf[p2];
			}
	}

	for (--p2; p2 >= 0; --p2) {
//		printf ("flush sgn %d\n", buf[p2]);
		rpn[id][p1++] = buf[p2];
	}
/*
	static char ref[] = "#&+";
	for (i = 0; i < p1; ++i)
		if (rpn[id][i] >= 8)
			putchar (ref[rpn[id][i] - 8]);
		else
			putchar (rpn[id][i] + 'a');
*/
	rp[id] = (unsigned)p1;
//	puts ("");puts ("");
}

bool calc_rpn (int id, int val) {
	static bool buf[256];
	int bp = 0;

	unsigned i;
	for (i = 0; i < rp[id]; ++i)
		if (rpn[id][i] < 8) {
			buf[bp++] = val & (1 << rpn[id][i]);
		} else {
			switch (rpn[id][i]) {
				case 8: buf[bp-1] = !buf[bp-1]; break;// #
				case 9: --bp; buf[bp-1] = buf[bp-1] && buf[bp]; break;// &
				case 10: --bp; buf[bp-1] = buf[bp-1] || buf[bp]; break;// + , |
				default: assert (0);
			}
		}

	assert (bp == 1);
	return buf[0];
}

bool cmp (const std::string &a, const std::string &b) {
	if (a.size () == 2 && b.size () == 2)
		return a < b;
	else if (a.size () == 2 || b.size () == 2)
		return a.size () < b.size ();
	else
		return a < b;
}

int main () {
	unsigned i, j;
	unsigned k, kk, l;
	static char line[512];
	for (i = 0; i < 5; ++i) {
		gets (line);
		to_rpn (i, line);
	}

//	#warning fix 8 to 256, and swap cycles
	for (i = 0; i < 256; ++i)
		for (j = 0; j < 5; ++j) {
//			printf ("%d (%d) --- %d\n", j, i, calc_rpn (j, i));
			val[j][i >> 5] |= (!!calc_rpn (j, i)) << (i & 0x1f);
//			printf ("i == %d -- to cell %d, shifted %d\n", i, i >> 5, i & 0x1f);
		}

	int s1[8], s2[8];
	unsigned s1p, s2p;
	std::pair <std::pair <int, int>, int> ca[8];//current assignment
	unsigned ban = 5;
	std::pair <std::pair <int, int>, int> ba[8];//best assignment
	std::pair <std::pair <int, int>, int> nill (std::pair <int, int> (-1, -1), -1);
	for (j = 0; j < 5; ++j) ba[j] = nill;

	for (i = 0; i < 32; ++i) {
//	i = 11;
//	{
//		printf ("i == %d\n", i);
		s1p = s2p = 0;
		for (j = 0; j < 5; ++j)
			if ((1 << j) & i) s1[s1p++] = j;
			else s2[s2p++] = j;

//		for (j = 0; j < s1p; ++j) printf ("%d ", s1[j]); printf ("\n");
//		for (j = 0; j < s2p; ++j) printf ("%d ", s2[j]); printf ("\n");

		for (j = 0; j < s2p; ++j) {
//			printf ("j == %d\n", j);
			///try =
//			printf ("trying =\n");
			for (k = 0; k < s1p; ++k) {
				for (l = 0; l < 8; ++l)
					if (val[s2[j]][l] != val[s1[k]][l])
						break;
				if (l == 8) {
					ca[s2[j]] = std::make_pair (std::make_pair (s1[k], s1[k]), 0);
					goto nextj;
				} else {
//					printf ("k == %d, broken on %d\n", k, l);
				}
			}

			///try #
//			printf ("trying #\n");
			for (k = 0; k < s1p; ++k) {
				for (l = 0; l < 8; ++l)
					if (val[s2[j]][l] != ~val[s1[k]][l])
						break;

				if (l == 8) {
					ca[s2[j]] = std::make_pair (std::make_pair (s1[k], s1[k]), 1);
					goto nextj;
				} else {
//					printf ("k == %d, broken on %d\n", k, l);
				}
			}

			///try &
//			printf ("trying &\n");
			for (k = 0; k < s1p; ++k)
				for (kk = k + 1; kk < s1p; ++kk) {
					for (l = 0; l < 8 && (val[s2[j]][l] == (val[s1[k]][l] & val[s1[kk]][l])); ++l);

					if (l == 8) {
						ca[s2[j]] = std::make_pair (std::make_pair (s1[k], s1[kk]), 2);
//						printf ("%x %x (%x  &) -- %x\n", val[s1[k]][0], val[s1[kk]][0], val[s1[k]][0] & val[s1[kk]][0], val[s2[j]][0]);
						goto nextj;
					} else {
//						printf ("k, kk %d %d, broken on %d\n", k, kk, l);
					}
				}

			///try +
//			printf ("trying +\n");
			for (k = 0; k < s1p; ++k)
				for (kk = k + 1; kk < s1p; ++kk) {
					for (l = 0; l < 8 && (val[s2[j]][l] == (val[s1[k]][l] | val[s1[kk]][l])); ++l);

					if (l == 8) {
						ca[s2[j]] = std::make_pair (std::make_pair (s1[k], s1[kk]), 3);
//						printf ("%x %x (%x  |) -- %x\n", val[s1[k]][0], val[s1[kk]][0], val[s1[k]][0] | val[s1[kk]][0], val[s2[j]][0]);
						goto nextj;
					} else {
//						printf ("k, kk %d %d, broken on %d\n", k, kk, l);
					}
				}
			///no way to do it
			break;
			nextj:;
//			printf ("worked for %d (%d %d %d)\n", s2[j], ca[s2[j]].first.first, ca[s2[j]].first.second, ca[s2[j]].second);
		}
		if (j == s2p) {//found a solution
			if (s1p < ban) {
				ban = s1p;
				for (j = 0; j < 5; ++j) ba[j] = nill;
				for (j = 0; j < s2p; ++j) ba[s2[j]] = ca[s2[j]];
			}
		}
	}

//	printf ("ban == %d\n", ban);

	std::vector <std::string> res;
	for (i = 0; i < 5; ++i) {

		if (ba[i] == nill)
			sprintf (line, "R%d", i + 1);
		else {
			sprintf (line, "R%d=", i + 1);
			switch (ba[i].second) {
				case 0: sprintf (line + 3, "R%d", ba[i].first.first + 1); break;
				case 1: sprintf (line + 3, "#R%d", ba[i].first.first + 1); break;
				case 2: sprintf (line + 3, "R%d&R%d", ba[i].first.first + 1, ba[i].first.second + 1); break;
				case 3: sprintf (line + 3, "R%d+R%d", ba[i].first.first + 1, ba[i].first.second + 1); break;
				default: assert (0);
			}
		}
//		printf ("%s\n", line);
		res.push_back (std::string (line));
	}
//	puts ("");

	std::sort (res.begin (), res.end (), cmp);
	for (i = 0; i < 5; ++i)
		printf ("%s\n", res[i].c_str ());

	return 0;
}
