/*
FROM: BalticOI 2000 day 1
PROB: elect (electronical plate)
KEYW: max flow, dinitz
*/

#include <cstdio>
#include <vector>
#include <utility>

const int MAXn = 1 << 4;
const int MAXN = 1 << 9;
const int MAXM = MAXN << 4;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, 1, 0, -1};

const char dirs[3][3] = 
{	{'?', 'N', '?'},
	{'W', '?', 'E'},
	{'?', 'S', '?'}
};

struct el {
	int to;
	bool cap;
	int next;
	el () {}
	el (int _to, bool _cap, int _next) : to (_to), cap (_cap), next (_next) {}
};

inline int op (int a) {return a ^ 1;}

int n;
bool grid[MAXn][MAXn];

int N, M;
int source, sink;
int vec[MAXN];
el buf[MAXM];
std::pair <int, int> exit_top[MAXn][MAXn];
bool exited[MAXn][MAXn];

int _N2;

int D[MAXN];
bool used[MAXN];

bool bfs () {
	static int queue[MAXN];
	static int p3, i, j, c;
	for (i = 0; i < N; ++i) {
		used[i] = 0;
		D[i] = -1;
	}
	used[source] = 1;

	p3 = 0;
	queue[p3++] = sink;
	D[sink] = 0;

//	printf ("here!\n");

	for (i = 0; i < p3; ++i) {
		c = queue[i];
//		printf ("popped %d (%d)\n", c, D[c]);
		for (j = vec[c]; j != -1; j = buf[j].next) {
			if (buf[op (j)].cap && D[buf[j].to] == -1) {
//				printf ("push %d\n", buf[j].to);
				D[buf[j].to] = D[c] + 1;
				queue[p3++] = buf[j].to;
			}
		}
	}

	return D[source] != -1;
}

int vp, vis[MAXN];

bool dfs (int a) {
//	printf ("dfs %d\n", a);
	if (a == sink) {
		used[sink] = 0;
//		printf ("!!\n");
		return 1;
	}

	for (int i = vec[a]; i != -1; i = buf[i].next) {
		if (buf[i].cap && D[a] == D[buf[i].to] + 1 && !used[buf[i].to]) {
			used[buf[i].to] = 1;
			vis[vp++] = i;
			if (dfs (buf[i].to)) return 1;
			--vp;
		}
	}
//	printf ("<-\n");
	return 0;
}

int dinitz () {
	int max_flow = 0;
	while (bfs ()) {
		while (vp = 0, dfs (source)) {
			++max_flow;
			for (int i = 0; i < vp; ++i) {	
				buf[vis[i]].cap = 0;
				buf[op (vis[i])].cap = 1;
			}
		}
	}
	return max_flow;
}

void prnt_dir (int x, int y, int xx, int yy) {
	xx -= x;
	yy -= y;
	putchar (dirs[xx + 1][yy + 1]);
}

void dfs_prnt (int a) {
	for (int i = vec[a + 16]; i != -1; i = buf[i].next)
		if (!buf[i].cap) {
			if (buf[i].to != sink) {
				prnt_dir (a / (n - 2), a % (n - 2), buf[i].to / (n - 2), buf[i].to % (n - 2));
				return dfs_prnt (buf[i].to);
			} else {
				prnt_dir (a / (n - 2) + 1, a % (n - 2) + 1
				, exit_top[a / (n - 2) + 1][a % (n - 2) + 1].first
				, exit_top[a / (n - 2) + 1][a % (n - 2) + 1].second);
				printf ("\n");
			}
		}
}

inline int to_id (int x, int y, int s) {
//	printf ("to id %d %d %d --> %d\n", x, y, s, ((x - 1) * (n - 2) + (y - 1)) + (_N2 * s));
	return ((x - 1) * (n - 2) + (y - 1)) + (_N2 * s);
}

void add (int id1, int id2) {
//	printf ("add %d %d\n", id1, id2);
	buf[M] = el (id2, 1, vec[id1]);
	vec[id1] = M++;

	buf[M] = el (id1, 0, vec[id2]);
	vec[id2] = M++;
}

int main () {
	scanf ("%d", &n);

	int i, j = 0, k;
	for (i = 0; i < n; ++i)
		for (j = 0; j < n; ++j) {
			int tmp;
			scanf ("%d", &tmp);
			grid[i][j] = tmp;
		}
/*
	for (i = 0; i < n; ++i) {
		for (j = 0; j < n; ++j)
			printf ("%d ", grid[i][j]);
		printf ("\n");
	}
*/
	_N2 = (n - 2) * (n - 2);
	source = 2 * (n - 2) * (n - 2);
	sink = source + 1;
	N = sink + 1;
	static std::vector <std::pair <int, int> > pins;
	static std::vector <std::pair <int, int> > exitp;
	int ii, jj;

	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 1; i < n - 1; ++i)
		for (j = 1; j < n - 1; ++j) {
			add (to_id (i, j, 0), to_id (i, j, 1));
			if (grid[i][j])
				pins.push_back (std::make_pair (i, j));

			for (k = 0; k < 4; ++k) {
				ii = i + dx[k];
				jj = j + dy[k];
//				printf ("(%d %d) -> (%d %d)\n", i, j, ii, jj);
				if (grid[ii][jj]) {
//					printf ("grid!\n");
					continue;
				}
				if (ii == 0 || ii == n - 1
				 || jj == 0 || jj == n - 1) {
				 	if (exited[i][j]) continue;
					exitp.push_back (std::make_pair (i, j));
					exit_top[i][j] = std::make_pair (ii, jj);
					exited[i][j] = 1;
//					printf ("bound!\n");
				} else {
//					printf ("ADD\n");
					add (to_id (i, j, 1), to_id (ii, jj, 0));
				}
			}
		}

//	printf ("\nFROM SOURCE!\n\n");
	for (i = 0; i < (int)pins.size (); ++i)
		add (source, to_id (pins[i].first, pins[i].second, 0));

//	printf ("\nTO SINK\n\n");
	for (i = 0; i < (int)exitp.size (); ++i)
		add (to_id (exitp[i].first, exitp[i].second, 1), sink);

	int max = dinitz ();
	printf ("%d\n", max);

	for (i = vec[source]; i != -1; i = buf[i].next)
		if (!buf[i].cap) {
			printf ("%d ", (buf[i].to / (n - 2) + 1) * n + buf[i].to % (n - 2) + 2);
			dfs_prnt (buf[i].to);
		}

	return 0;
}
