/*
FROM: BalticOI (BaOI) 2002 day 2
PROB: lgame
KEYW: game theory, hardcoding, draw positions
*/

#include <cstdio>
#include <algorithm>

const int MAXN = 1 << 16;
const int MAXM = 1 << 24;
const int ROW = 4;
const int COL = 4;
const int CODES = 64512;
const int LCODE = 48;

int lo[8][4][2] =
{
	{{0, 0}, {1, 0}, {0, 1}, {0, 2}},
	{{0, 0}, {1, 0}, {2, 0}, {2, 1}},
	{{1, 0}, {1, 1}, {1, 2}, {0, 2}},
	{{0, 0}, {0, 1}, {1, 1}, {2, 1}},

	{{0, 0}, {1, 0}, {1, 1}, {1, 2}},
	{{0, 1}, {1, 1}, {2, 1}, {2, 0}},
	{{0, 0}, {0, 1}, {0, 2}, {1, 2}},
	{{0, 0}, {0, 1}, {1, 0}, {2, 0}}
};

int bnd[2][2] = {{3, 2}, {2, 3}};

struct el {
	int to;
	int next;
	el () {}
	el (int _to, int _next) : to (_to), next (_next) {}
};

char brd[ROW][COL];
char inp[ROW][COL+1];

const int _COEF_L2 = 28, _COEF_L1 = _COEF_L2 * 48;
void __decode (int c, int &l1p, int &l2p, int &sp) {
	l1p = c / _COEF_L1; c %= _COEF_L1;
	l2p = c / _COEF_L2; c %= _COEF_L2;
	sp = c;
}

void _dec_l (int lp, int &lid, int &lbx, int &lby) {
	lid = lp / 6; lp %= 6;
	lbx = lp / 2; lby = lp % 2;
	if (lid & 1) std::swap (lbx, lby);
}

int _dec_s[28][2];
int _en_s[8][8];

bool write_l (int lp, char c, char banned = '*') {
	static int i, lid, lbx, lby;
	_dec_l (lp, lid, lbx, lby);
//	printf ("\t%d %d %d (%d)\n", lid, lbx, lby, lid);
	for (i = 0; i < 4; ++i) {
		if (brd[lo[lid][i][0] + lbx][lo[lid][i][1] + lby] == banned
		 || brd[lo[lid][i][0] + lbx][lo[lid][i][1] + lby] == 'x') return 0;
		brd[lo[lid][i][0] + lbx][lo[lid][i][1] + lby] = c;
	}
	return 1;
}

int sq_p[2][2], sq_pp;
void write_sq (int sp, char c) {
	static int i, j, cnt, sp1, sp2;
	sp1 = _dec_s[sp][0];
	sp2 = _dec_s[sp][1];
//	printf ("\t%d %d (%d)\n", sp1, sp2, sp);
	for (i = cnt = sq_pp = 0; i < ROW; ++i)
		for (j = 0; j < COL; ++j)
			if (brd[i][j] == '.') {
				if (cnt == sp1 || cnt == sp2) {
					brd[i][j] = c;
					sq_p[sq_pp][0] = i;
					sq_p[sq_pp][1] = j;
					++sq_pp;
				}
				++cnt;
			}
}

bool decode (int c, int &l1p, int &l2p) {//returns 0 if impossible position given
	static int sp;
	__decode (c, l1p, l2p, sp);
//	printf ("%d %d %d\n", l1p, l2p, sp);
	memset (brd, '.', sizeof (brd));
	write_l (l1p, '#');
	if (!write_l (l2p, '*', '#')) return 0;
	write_sq (sp, 'x');
	return 1;
}

void fill_dec_s () {
	int i, j, p = 0;
	for (i = 0; i < 8; ++i)
		for (j = i + 1; j < 8; ++j) {
			_dec_s[p][0] = i;
			_dec_s[p][1] = j;
			_en_s[i][j] = _en_s[j][i] = p++;
		}
}

int N, M;
int vec[MAXN];
el buf[MAXM];
int bp;

void prnt () {
	for (int i = 0; i < 4; ++i) {
		for (int j = 0; j < 4; ++j)
			printf ("%c", brd[i][j]);
		printf ("\n");
	}
}

int q[MAXN], p3;
int in[MAXN];
int type[MAXN];//0 -> uninitialised, 1 -> losing, 2 -> wining, 3 -> bad
int prev[MAXN];

void _pb (int a, int b, int c, int id) {
	int toid = a * _COEF_L1 + b * _COEF_L2 + c;
	buf[bp] = el (id, vec[toid]);
	vec[toid] = bp++;
	++in[id];
}

void clr_brd () {
	for (int i = 0; i < 4; ++i) for (int j = 0; j < 4; ++j) if (brd[i][j] == '#') brd[i][j] = '.';
}

void put_all (int l1p, int l2p, int cid) {
	static int i, j, cnt;
	int sh[2], shp = 0;
	clr_brd ();
	write_l (l2p, '#');
	for (i = cnt = 0; i < 4; ++i)
		for (j = 0; j < 4; ++j)
			if (brd[i][j] != '#'
			 && brd[i][j] != '*') {
				if (brd[i][j] == 'x') {
					sh[shp++] = cnt;
				}
				++cnt;
			}
//	printf ("\t going to (%d %d) %d %d\n", sh[0], sh[1], l1p, l2p);
//	prnt ();
	_pb (l1p, l2p, _en_s[sh[0]][sh[1]], cid);
	for (i = 0; i < 8; ++i) {
		if (sh[0] == i || sh[1] == i) continue;

		_pb (l1p, l2p, _en_s[i][sh[0]], cid);
		_pb (l1p, l2p, _en_s[i][sh[1]], cid);
	}
}

int _cntr;
int BEG;
void build_graph () {
	int i, j;
	int l1p, l2p;
	memset (vec, -1, sizeof (vec));
	for (int id = 0; id < CODES; ++id) {
		if (!decode (id, l1p, l2p)) {
			type[id] = 3;
			continue;
		}
	
		for (i = 0; i < 4; ++i)
			for (j = 0; j < 4; ++j)
				if (inp[i][j] != brd[i][j]) goto end;
		end:; if (i == 4 && j == 4) BEG = id;
	
//		printf ("\n\n___NOW IN %d___\n", id);
//		prnt ();
		for (int lp = 0; lp < LCODE; ++lp) {
			if (lp == l1p || !write_l (lp, '#')) continue;
			put_all (l2p, lp, id);
		}
		if (!in[id]) {
//			printf ("TERMINAL\n");
			q[p3++] = id;
			type[id] = 1;//losing
			prev[id] = -1;//no prev
		}
		++_cntr;
	}
}

void bfs () {
	int i, j;
	for (i = 0; i < p3; ++i) {
		if (type[q[i]] == 1) {//we are losing
			for (j = vec[q[i]]; j != -1; j = buf[j].next) {
				if (type[buf[j].to] == 0) {//untouched
					q[p3++] = buf[j].to;
					type[buf[j].to] = 2;//winning
					prev[buf[j].to] = q[i];
				}
			}
		} else {
			for (j = vec[q[i]]; j != -1; j = buf[j].next) {
				if (type[buf[j].to] == 0 && !(--in[buf[j].to])) {
					q[p3++] = buf[j].to;
					type[buf[j].to] = 1;//losing
					prev[buf[j].to] = q[i];
				}
			}
		}
	}
}

int main () {
	for (int i = 0; i < 4; ++i) gets (inp[i]);
	fill_dec_s ();
/*
	int bid;
	scanf ("%d", &bid);

	int a, b, rval;
	rval = decode (bid, a, b);
	printf ("%d\n", rval);
	prnt ();*/
/*	for (int i = 0; i < 48; ++i) {
		memset (brd, '.', sizeof (brd));
		write_l (i, '#');
		printf ("--%d--\n", i);
		prnt ();
	}*/
	build_graph ();
//	printf ("%d %d %d\n", p3, _cntr, BEG);
	bfs ();

	if (type[BEG] == 0)
		printf ("No winning move\nDraw\n");
	else if (type[BEG] == 1)
		printf ("No winning move\nLosing\n");
	else {
		int a, b;
		decode (prev[BEG], a, b);
		for (int i = 0; i < 4; ++i) for (int j = 0; j < 4; ++j) if (brd[i][j] == '#') brd[i][j] = '*'; else if (brd[i][j] == '*') brd[i][j] = '#';
		prnt ();
	}
//	for (int i = 0; i < CODES; ++i) printf ("%d -> %d %d\n", i, type[i], prev[i]);

	return 0;
}
