/*
FROM: BalticOI 2002 day 1
PROB: speed
KEYW: graph expansion, dijkstra with stl heap maintaining prev
*/

#include <cstdio>
#include <vector>
#include <utility>
#include <queue>

using std::make_pair;

const int MAXN = 1 << 8;
const int MAXM = MAXN * MAXN;
const int MAXV = 1 << 9;
const double INF = 1e20;
const double EPS = 1e-6;

struct el {
	int to;
	int dst;
	int lim;
	int next;
	el () {}
	el (int _to, int _dst, int _lim, int _next) : to (_to), dst (_dst), lim (_lim), 	next (_next) {}
};

int N, M, D;
int vec[MAXN];
el buf[MAXM];

double in_q[MAXN][MAXV];
std::pair <int, int> prev[MAXN][MAXV];

std::pair <int, int> dijkstra () {
	static std::priority_queue <std::pair <double, std::pair <int, int> > > q;
	q.push (make_pair (0, make_pair (0, 70)));
	for (int i = 0; i < MAXN; ++i) 
		for (int j = 0; j < MAXV; ++j)
			in_q[i][j] = INF;
	in_q[0][70] = 0;
	prev[0][70] = make_pair (-1, -1);
	std::pair <double, std::pair <int, int> > crnt;
	int np, nv;
	double nt;
	while (!q.empty ()) {
		crnt = q.top (); q.pop ();
		crnt.first *= -1.;//it was pushed negative
//		printf ("popped %d %d (%lf)\n", crnt.second.first, crnt.second.second, crnt.first);
		if (crnt.second.first == D) return crnt.second;
		if (crnt.first != in_q[crnt.second.first][crnt.second.second]) continue;
		for (int i = vec[crnt.second.first]; i != -1; i = buf[i].next) {
			np = buf[i].to;
			nv = buf[i].lim ? buf[i].lim : crnt.second.second;
			nt = crnt.first + (double)buf[i].dst / (double)nv;
			if (in_q[np][nv] > nt + EPS) {
				in_q[np][nv] = nt;
				prev[np][nv] = crnt.second;
				q.push (make_pair (-nt, make_pair (np, nv)));//push negative to pop the least
//				printf ("\tpush %d %d (%lf)\n", np, nv, nt);
			}
		}
	}

	return make_pair (-1, -1);
}

int main () {
	scanf ("%d %d %d", &N, &M, &D);

	int i;
	int a, b, v, l;
	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d %d", &a, &b, &v, &l);

		buf[i] = el (b, l, v, vec[a]);
		vec[a] = i;
	}

//	printf ("here!\n");
	std::pair <int, int> fin = dijkstra ();

	static std::vector <int> ans;
	for (; fin != std::make_pair (-1, -1); fin = prev[fin.first][fin.second])
		ans.push_back (fin.first);

	printf ("0");
	for (i = ans.size () - 2; i >= 0; --i)
		printf (" %d", ans[i]);
	printf ("\n");

	return 0;
}
