/*
FROM: Baltic Olympiad in Informatics (BaOI) 2004 day 2
PROB: car park (carpark)
KEYW: bfs, hash_set <vector <int> >
*/

#include <cstdio>
#include <queue>
#include <vector>
#include <ext/hash_set>

struct car {
	bool o;
	int rc;
	int len;
	car () {}
	car (bool _o, int _rc, int _len) : o (_o), rc (_rc), len (_len) {}
};

const int MAXC = 16;
const size_t MOD = 223092869;
const int MAXX = 6, MAXY = 6;

int N;
car data[MAXC];
std::vector <int> istate;

namespace __gnu_cxx {
	template <>
	class hash <std::vector <int> > {
		public:
		size_t operator () (const std::vector <int> &v) const {
			size_t res = 0;
			for (size_t i = 0; i < v.size (); ++i) {
				res *= 5;
				res += v[i];
				res %= MOD;
			}

			return res;
		}
	};
}

char map[MAXX][MAXY];

void build_map (const std::vector <int> &a) {
	memset (map, 0, sizeof (map));
	for (int i = 0; i < N; ++i) {
		if (data[i].o) {//horizontal
			for (int j = 0; j < data[i].len; ++j)
				map[data[i].rc][a[i] + j] = i + 1;
		} else {//vertical
			for (int j = 0; j < data[i].len; ++j)
				map[a[i] + j][data[i].rc] = i + 1;
		}
	}
}

int bfs (const std::vector <int> &istate) {
	std::queue <__gnu_cxx::hash_set <std::vector <int> > :: const_iterator > q1, q2, *old_q, *new_q;
	__gnu_cxx::hash_set <std::vector <int> > used;
	__gnu_cxx::hash_set <std::vector <int> > :: const_iterator crnt;
	std::vector <int> a;
	int i, lvl = 0;

	old_q = &q1;
	new_q = &q2;

	old_q -> push (used.insert (istate).first);

	for (;;) {
//		printf ("popping level %d\n", lvl);
		while (!old_q -> empty ()) {
			crnt = old_q -> front (); old_q -> pop ();
			a = *crnt;
			if (a[0] == 4) return lvl + 2;

//			for (i = 0; i < N; ++i) printf (" %d", a[i]);
//			printf ("__ set size %u\n", used . size ());


			build_map (*crnt);
			for (i = 0; i < N; ++i) {
//				printf ("i == %d\n", i);
				if (data[i].o) {//horizontal
					//--a[i]
					if (a[i] == 0
					 || map[data[i].rc][a[i] - 1]) goto nxt_hor;
					
					--a[i];
//					printf ("%d hor --\n", i);
					if (used.find (a) == used.end ())
						new_q -> push (used.insert (a).first);
					++a[i];
	
					//++a[i]
					nxt_hor:;
					if (a[i] == 6 - data[i].len
					 || map[data[i].rc][a[i] + data[i].len]) continue;
	
					++a[i];
//					printf ("%d hor ++\n", i);
					if (used.find (a) == used.end ())
						new_q -> push (used.insert (a).first);
					--a[i];
				} else {//vertical
					//--a[i]
					if (a[i] == 0
					 || map[a[i] - 1][data[i].rc]) goto nxt_ver;
					
					--a[i];
//					printf ("%d vec --\n", i);
					if (used.find (a) == used.end ())
						new_q -> push (used.insert (a).first);
					++a[i];
	
					//++a[i]
					nxt_ver:;
					if (a[i] == 6 - data[i].len
					 || map[a[i] + data[i].len][data[i].rc]) continue;

					++a[i];
//					printf ("%d vec ++\n", i);
					if (used.find (a) == used.end ())
						new_q -> push (used.insert (a).first);
					--a[i];
				}
			}
		}
		++lvl;
		if (new_q -> empty ()) break;
		std::swap (old_q, new_q);
	}
	return -1;
}

int main () {
	scanf ("%d", &N);
	istate.resize (N);

	int i;
	int o, col, row, len;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d %d %d", &len, &o, &col, &row);
		--col; --row;

		if (o) {//horizontal
			data[i] = car (o, row, len);
			istate[i] = col;
		} else {//vertical
			data[i] = car (o, col, len);
			istate[i] = row;
		}
	}

	if (data[0].o != 1 || data[0].rc != 2) {
		printf ("-1\n");
		return 0;
	}

	printf ("%d\n", bfs (istate));

	return 0;
}
