/*
FROM: Baltic Olympiad in Informatics (BaOI) 2004 day 2
PROB: rectangles (rect)
KEWY: geometry, binary search
*/

#include <cstdio>
#include <algorithm>
#include <utility>
#include <ext/numeric>

//#warning check with 0 rectangles
//#warning check with rectangles laying on the boundaries

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	bool operator == (const pnt &a) const {return x == a.x && y == a.y;}
	bool operator != (const pnt &a) const {return x != a.x || y != a.y;}
	long long sq () const {return (long long)x * x + (long long)y * y;}
};

const int MAXN = 1 << 14;
const pnt _no_point (-1, -1);

int N, N2;
pnt beg (0, 0), cor;
pnt rect[MAXN * 2];
int idx[MAXN * 2], ip;

long long S (const pnt &a, const pnt &b, const pnt &c) {
	return (long long)(b.x - a.x) * (c.y - a.y) - (long long)(b.y - a.y) * (c.x - a.x);
}

bool cmp (int a, int b) {
	static long long tmp;
	return (tmp = S (beg, rect[a], rect[b])) ? tmp > 0 : rect[a].sq () < rect[b].sq ();
}

pnt findb (const pnt &p1, const pnt &p2) {
	static long long s1, s2;
	static int l, r, m;
	static pnt ret;
	s1 = S (beg, p1, cor);
	s2 = S (beg, p2, cor);
	if (s1 > 0 && s2 < 0 || s1 == 0 && s2 == 0)
		return cor;

	if (s1 > 0) {
		l = 0, r = cor.y;
		while (l + 1 != r) {
			m = (l + r) / 2;
			if (S (beg, p1, pnt (cor.x, m)) <= 0)
				l = m;
			else
				r = m;
		}
		ret = pnt (cor.x, r - (p1 == p2));
	} else {
		l = -1, r = cor.x;
		while (l + 1 != r) {
			m = (l + r) / 2;
			if (S (beg, p1, pnt (m, cor.y)) <= 0)
				r = m;
			else
				l = m;
		}
		ret = pnt (l + (p1 == p2), cor.y);
	}
	s1 = S (beg, p2, ret);
//	printf ("findb %d %d  %d %d --> %d %d?\n", p1.x, p1.y, p2.x, p2.y, ret.x, ret.y);
	if (p1 != p2 && s1 < 0
	 || p1 == p2 && !s1)
		return ret;
	return _no_point;
}

void upd (std::pair <int, int> &p, int id) {
	if (id & 1)
		--p.second;
	else {
		++p.first;
		++p.second;
	}
}

std::pair <int, int> eat (int ic) {
	std::pair <int, int> ret (ic, ic);
	upd (ret, idx[ip]);
//	printf ("\t%d %d\n", rect[idx[ip]].x, rect[idx[ip]].y);
	for (++ip; ip < N2 && !S (beg, rect[idx[ip-1]], rect[idx[ip]]); ++ip) {
//		printf ("\t%d %d\n", rect[idx[ip]].x, rect[idx[ip]].y);
		upd (ret, idx[ip]);
	}
	return ret;
}

int main () {
	scanf ("%d %d %d", &cor.x, &cor.y, &N);
	N2 = N * 2;
	if (!N) {
		printf ("%d %d %d\n", 0, cor.x, cor.y);
		return 0;
	}

	int i;
	int x1, y1, x2, y2, rp = 0;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d %d %d", &x1, &y1, &x2, &y2);

		rect[rp++] = pnt (x2, y1);
		rect[rp++] = pnt (x1, y2);
	}

	__gnu_cxx::iota (idx, idx + N2, 0);

	std::sort (idx, idx + N2, cmp);
/*
	for (i = 0; i < N2; ++i)
		printf ("%d %d\n", rect[idx[i]].x, rect[idx[i]].y);
*/
	int best = 0;
	pnt bestp = _no_point;
	int ip_save = 0;
	int inter_cnt = 0;
	pnt x;
	std::pair <int, int> cnts;
	for (;;) {
		cnts = eat (inter_cnt);
//		printf ("eaten %d %d -- %d %d\n", ip_save, ip, cnts.first, cnts.second);

		x = findb (rect[idx[ip_save]], rect[idx[ip_save]]);
//		printf ("sharp %d %d\n", x.x, x.y);
		if (x != _no_point && best < cnts.first) {
			best = cnts.first;
			bestp = x;
		}

		if (ip == N2) break;
		x = findb (rect[idx[ip_save]], rect[idx[ip]]);
//		printf ("float %d %d\n", x.x, x.y);
		if (x != _no_point && best < cnts.second) {
			best = cnts.second;
			bestp = x;
		}
		ip_save = ip;
		inter_cnt = cnts.second;;
	}

	printf ("%d %d %d\n", best, bestp.x, bestp.y);

	return 0;
}
