/*
FROM: Baltic Olympiad in Informatics (BaOI) 2004 day 2
PROB: repeats
KEYW: string comparison using hashes, full exhaustion
*/

#include <cstdio>
#include <cassert>
#include <utility>

typedef long long LLi;
typedef std::pair <int, int> PI;
typedef std::pair <LLi, LLi> PL;

PL operator * (const PI &a, const PI &b) {return PL ((LLi)a.first * b.first, (LLi)a.second * b.second);}
PL operator + (const PL &a, const PL &b) {return PL (a.first + b.first, a.second + b.second);}
PL operator - (const PI &a, const PL &b) {return PL ((LLi)a.first - b.first, (LLi)a.second - b.second);}
PI operator % (const PL &a, const PI &b) {return PI (a.first % b.first, a.second % b.second);}
inline PI dup (int a) {return PI (a, a);}
inline PL dup (LLi a) {return PL (a, a);}


const int MAXN = 1 << 16;
const PI MOD = PI (1115464349, 1115464351);
const PL MOD_SQ = MOD * MOD;

int N;
PI _hash[MAXN];
PI _base[MAXN];
int row[MAXN];

int dp[MAXN];
PI hash_mem[MAXN];

void init_hash () {
	_hash[0] = dup (0);
	_base[0] = dup (1);
	for (int i = 1; i <= N; ++i) {
		_hash[i] = (_hash[i-1] * dup (2) + dup ((LLi)row[i])) % MOD;
		_base[i] = (_base[i-1] * dup (2)) % MOD;
		assert (_hash[i].first >= 0 && _hash[i].first < MOD.first);
		assert (_hash[i].second >= 0 && _hash[i].second < MOD.second);
		assert (_base[i].first >= 0 && _base[i].first < MOD.first);
		assert (_base[i].second >= 0 && _base[i].second < MOD.second);
	}
}

inline PI hash (int end, int len) {
	return (_hash[end] - _hash[end-len] * _base[len] + MOD_SQ) % MOD;
}

int main () {
	scanf ("%d\n", &N);
	int i;
	char t;
	for (i = 1; i <= N; ++i) {
		t = getchar (); getchar ();
		row[i] = (t == 'a');
	}

	init_hash ();

	int len, end;
	int best_k = 1;
	int best_len = 1, best_end = 1;
	for (len = 2; len * (best_k + 1) <= N; ++len) {
//		fprintf (stderr, "%d\r", len);
		assert (2 * len <= N);
		for (end = len; end < 2 * len; ++end) {
			hash_mem[end] = hash (end, len);
			dp[end] = 1;
		}
		for (end = 2 * len; end <= N; ++end) {
			hash_mem[end] = hash (end, len);
			if (hash_mem[end] == hash_mem[end-len])
				dp[end] = dp[end-len] + 1;
			else
				dp[end] = 1;

			if (best_k < dp[end]) {
				best_k = dp[end];
				best_end = end;
				best_len = len;
			}
		}
	}

	printf ("%d\n%d\n%d\n", best_k, best_len, best_end - best_k * best_len + 1);

/*
	int end1, end2, len1, len2;
	scanf ("%d %d %d %d", &end1, &len1, &end2, &len2);
	printf ("%d\n", hash (end1, len1) == hash (end2, len2));
*/
	return 0;
}
