/*
FROM: Baltic Olympiad in Informatics (BaOI) 2004 day 1
PROB: scales
KEWY: long numbers, symmetric ternary system (base 3 with the digits -1 0 and 1)
*/

#include <cstdio>
#include <cstdlib>
#include <cassert>
#include <cstring>

const int BASE = 100000000;
int N_DIG = 8;
const int MAX = 1 << 4;
const int MAXL = 1 << 7;//pow 10
const int MAXP = 1 << 8;//pow 3

struct big {
	int m[MAX];
	big () {}
	big (int a) {memset (m, 0, sizeof (m)); m[0] = a;}
	big (const big &a) {memcpy (m, a.m, sizeof (m));}
	big& operator = (const big &a) {memcpy (m, a.m, sizeof (m)); return *this;}
	big& mul3 () {
		int pr = 0;
		div_t dres;
		for (int i = 0; i < MAX; ++i) {
			m[i] *= 3;
			m[i] += pr;
			dres = div (m[i], BASE);
			pr = dres.quot;
			m[i] = dres.rem;
/*			pr = m[i] / BASE;
			m[i] %= BASE;
*/
		}
		assert (!pr);
		return *this;
	}
	big& div2 () {
		int prev = 0;//, new_prev;
		div_t dres;
		for (int i = MAX - 1; i >= 0; --i) {
			dres = div (prev * BASE + m[i], 2);
			/*new_*/prev = dres.rem;//(prev * BASE + m[i]) % 2;
			m[i] = dres.quot;//(prev * BASE + m[i]) / 2;
			//prev = new_prev;
		}
		assert (prev == 1);//we will divide only powers of 3 here
		return *this;
	}
	big& operator -= (const big &a) {
		int take = 0;
/*		printf ("operator -=:\n");
		prnt ();
		a.prnt ();*/
		for (int i = 0; i < MAX; ++i) {
			m[i] -= a.m[i] + take;
			if (m[i] < 0) {
				m[i] += BASE;
				take = 1;
			} else
				take = 0;
		}
		assert (!take);
		return *this;
	}
	bool operator < (const big &a) const {
		int i;
		for (i = MAX - 1; i && m[i] == a.m[i]; --i);
		return m[i] < a.m[i];
	}
	bool operator == (const big &a) const {
		int i;
		for (i = MAX - 1; i && m[i] == a.m[i]; --i);
		return m[i] == a.m[i];	
	}
	void prnt (char end = '\n') const {
		int i;
		for (i = MAX - 1; i && !m[i]; --i);
		printf ("%d", m[i]);
		for (--i; i >= 0; --i) printf ("%0*d", N_DIG, m[i]);
		putchar (end);
	}
	void scan () {
		static char line[MAXL];
		gets (line);
		int len = strlen (line);
		memset (m, 0, sizeof (m));
		int cdig, pos;
//		printf ("%d %s\n", len, line);
		for (int i = 0; i * N_DIG < len; ++i) {
//			printf ("i == %d\n", i);
			cdig = 0;
			for (int j = N_DIG - 1; j >= 0; --j) {
//				printf ("\tj == %d\n", j);
				pos = len - 1 - (i * N_DIG + j);
//				printf ("%d %d --> %d\n", i, j, pos);
				if (pos < 0) continue;
				cdig *= 10;
//				printf ("add %d\n", line[pos] - '0');
				cdig += line[pos] - '0';
			}
//			printf ("cdig -- %d\n", cdig);
			m[i] = cdig;
		}
//		printf ("we are out %d %d %d\n", m[2], m[1], m[0]);
	}
};

big pow3[MAXP];

struct base3 {
	int m[MAXP];
	base3 () {}
	base3 (int) {memset (m, 0, sizeof (m));}
	base3 (const base3 &a) {memcpy (m, a.m, sizeof (m));}
	base3& operator = (const base3 &a) {memcpy (m, a.m, sizeof (m)); return *this;}
	base3& inv () {for (int i = 0; i < MAXP; ++i) m[i] = -m[i]; return *this;}
	void prnt () {
		int i;
		for (i = MAXP - 1; i && !m[i]; --i);
		printf ("%d", m[i]);
		for (--i; i >= 0; --i) printf (" %d", m[i]);
		puts ("");
	}
};

big big0 (0);
base3 result (0);
void convert (const big &a) {
	if (a == big0) return;

	int l = 0, r = MAXP, m;
	while (l + 1 < r) {//3 ^ (r-1) <= a < 3 ^ r
		m = (l + r) / 2;
		if (a < pow3[m])
			r = m;
		else
			l = m;
	}
//	printf ("in convert after bsrch: %d\n", r);
//	a.prnt ();
	//r;// 3 ^ r <= a < 3 ^ (r + 1);
	big mid = pow3[r];
	mid.div2 ();
//	mid.prnt ();
	if (mid < a) {
//		printf ("case 2 -- ");
//		pow3[r].prnt ();
		big tmp (pow3[r]);
		tmp -= a;
		convert (tmp);
		result.inv ();
		result.m[r] = 1;
	} else {
//		printf ("case 1\n");
		--r;
		big tmp (a);
		tmp -= pow3[r];
		convert (tmp);
		result.m[r] = 1;
	}
}

void init () {
	pow3[0] = big (1); 
	for (int i = 1; i < MAXP; ++i) {
		pow3[i] = pow3[i-1];
		pow3[i].mul3 ();
	}
}

int main () {
	init ();
	big initial;
	initial.scan ();
//	initial.prnt ();

//	base3 result (0);
	convert (initial);
//	result.prnt ();

	int left = 0, right = 0;
	int i;
	for (i = MAXP - 1; i >= 0; --i)
		if (result.m[i] == -1)
			++left;
		else if (result.m[i] == 1)
			++right;

	printf ("%d", left);
	for (i = 0; i < MAXP; ++i)
		if (result.m[i] == -1) {
			putchar (' ');
			pow3[i].prnt ('\0');
		}
	puts ("");

	printf ("%d", right);
	for (i = 0; i < MAXP; ++i)
		if (result.m[i] == 1) {
			putchar (' ');
			pow3[i].prnt ('\0');
		}
	puts ("");
/*
	for (i = 0; i < 30; ++i)
		printf ("%d ->", i), pow3[i].prnt ();
*/
}
