#include <cstdio>
//#include <cassert>
#include <cstring>
#include <cmath>
#include <algorithm>

void assert(bool b) {
	while(!b) ;
}

const int MAXN = 300;

struct pnt {
	int x, y, z;
	pnt() {}
	pnt(int _x, int _y, int _z) : x(_x), y(_y), z(_z) {}

	pnt operator % (const pnt &p) const {
		return pnt(y * p.z - z * p.y, z * p.x - x * p.z, x * p.y - y * p.x);
	}

	pnt operator - (const pnt &p) const {
		return pnt(x - p.x, y - p.y, z - p.z);
	}

	bool is_null() const {
		return x == 0 && y == 0 && z == 0;
	}
};

struct plane {
	int A, B, C, D;
	plane() {}
	plane(pnt base, pnt norm) {
		A = norm.x;
		B = norm.y;
		C = norm.z;
		D = -(A * base.x + B * base.y + C * base.z);
	}

	int operator * (pnt p) const {
		return A * p.x + B * p.y + C * p.z + D;
	}
};

typedef double fract_t;
struct pnt_f {
	fract_t x, y;
	pnt_f() {}
	pnt_f(fract_t _x, fract_t _y) : x(_x), y(_y) {}

	fract_t len() const {return x * x + y * y;}

	pnt_f operator - (const pnt_f &p) const {
		return pnt_f(x - p.x, y - p.y);
	}

};

fract_t S(pnt_f p1, pnt_f p2, pnt_f p3) {
	return (p2.x - p1.x) * (p3.y - p1.y) - (p2.y - p1.y) * (p3.x - p1.x);
}

const double EPS = 1e-7;

bool __coords(int a1_, int b1_, int c1_, int a2_, int b2_, int c2_, fract_t &x, fract_t &y) {
	double det = a1_ * b2_ - a2_ * b1_;
	if (fabs(det) < EPS) return false;
	x = (c1_ * b2_ - c2_ * b1_) / det;
	y = (a1_ * c2_ - a2_ * c1_) / det;
	return true;
}

pnt_f coords(pnt b1, pnt b2, pnt v) {
	fract_t a, b;

	if (!__coords(b1.x, b2.x, v.x, b1.y, b2.y, v.y, a, b))
  		if (!__coords(b1.x, b2.x, v.x, b1.z, b2.z, v.z, a, b))
  			assert(__coords(b1.y, b2.y, v.y, b1.z, b2.z, v.z, a, b));

//	printf("%d %d %d  %d %d %d  %d %d %d | %lf %lf\n", b1.x, b1.y, b1.z, b2.x, b2.y, b2.z, v.x, v.y, v.z, a, b);
/*	assert(fabs(b1.x * a + b2.x * b - v.x) < EPS);
	assert(fabs(b1.y * a + b2.y * b - v.y) < EPS);
	assert(fabs(b1.z * a + b2.z * b - v.z) < EPS);*/
	return pnt_f(a, b);
}

int N;
pnt vec[MAXN];
int planesp;
plane planes[MAXN];
int h2dp;
pnt_f h2d[MAXN];

int ans[MAXN];

pnt_f _base;
bool cmp(int a, int b) {
	static fract_t tmp;
	return fabs(tmp = S(_base, h2d[a], h2d[b])) < EPS ?
		 (h2d[a] - _base).len() < (h2d[b] - _base).len() :
		 tmp > 0;
}

int hull() {
	static int idx[MAXN];
	for (int i = 0; i < h2dp; ++i) idx[i] = i;

	int _bid = 0;
	for (int i = 1; i < h2dp; ++i) {
		if (h2d[i].y < h2d[_bid].y
		 || (h2d[i].y == h2d[_bid].y && h2d[i].x > h2d[_bid].y)) {
			_bid = i;
		}
	}

	idx[0] = _bid;
	idx[_bid] = 0;

	/*
	printf("---hull1---:\n");
	for (int i = 0; i < h2dp; ++i) {
		printf("%lf %lf\n", h2d[idx[i]].x, h2d[idx[i]].y);
	}
*/
	_base = h2d[idx[0]];
	std::sort(idx + 1, idx + h2dp, cmp);
/*
	printf("---hull2---:\n");
	for (int i = 0; i < h2dp; ++i) {
		printf("%lf %lf\n", h2d[idx[i]].x, h2d[idx[i]].y);
	}*/

	int hpi = 2;
	for (int i = 2; i < h2dp; ++i) {
		while (hpi >= 2 && S(h2d[idx[hpi-2]], h2d[idx[hpi-1]], h2d[idx[i]]) < EPS) {
//			printf("%lf %lf  %lf %lf  %lf %lf --> popping second\n"\
				, h2d[idx[hpi-2]].x, h2d[idx[hpi-2]].y\
				, h2d[idx[hpi-1]].x, h2d[idx[hpi-1]].y\
				, h2d[idx[i]].x, h2d[idx[i]].y);
			--hpi;
		}
		idx[hpi++] = idx[i];
	}
/*
	for (int i = 0; i < hpi; ++i)
		printf("\t%lf %lf\n", h2d[idx[i]].x, h2d[idx[i]].y);
	printf("%d\n", hpi);*/
	return hpi;
}


int main() {
	int tc;
	scanf("%d", &tc);

	for (int ctc = 0; ctc < tc; ++ctc) {
		scanf("%d", &N);

		for (int i = 0; i < N; ++i) {
			scanf("%d %d %d", &vec[i].x, &vec[i].y, &vec[i].z);
		}

		memset(ans, 0, sizeof(ans));
		planesp = 0;
		for (int i1 = 0; i1 < N; ++i1) {
			//printf("%d  %d %d %d\n", i1, vec[i1].x, vec[i1].y, vec[i1].z);
			for (int i2 = i1 + 1; i2 < N; ++i2) {
				//printf("\t%d  %d %d %d\n", i2, vec[i2].x, vec[i2].y, vec[i2].z);
				pnt v1 = vec[i2] - vec[i1];
				for (int i3 = i2 + 1; i3 < N; ++i3) {
					//printf("\t\t%d  %d %d %d\n", i3, vec[i3].x, vec[i3].y, vec[i3].z);
					pnt v2 = vec[i3] - vec[i1];
					//printf("v1 = %d %d %d\n", v1.x, v1.y, v1.z);
					//printf("v2 = %d %d %d\n", v2.x, v2.y, v2.z);
					pnt vp = v1 % v2;
					if (vp.is_null()) continue;
					int p;
					for (p = 0; p < planesp; ++p) {
						if (planes[p] * vec[i1] == 0
						 && planes[p] * vec[i2] == 0
						 && planes[p] * vec[i3] == 0) {
							break;
						}
					}

					if (p != planesp) {
//						printf("\t\t\texisting plane!\n");
						continue;
					}
					plane cp = plane(vec[i1], vp);
//					printf("\t\t\t-----%d %d %d----found plane %d %d %d %d\n", i1, i2, i3, cp.A, cp.B, cp.C, cp.D);
//					printf("v1 = %d %d %d\n", v1.x, v1.y, v1.z);
//					printf("v2 = %d %d %d\n", v2.x, v2.y, v2.z);
					planes[planesp] = cp;
					h2dp = 0;
/*					h2d[h2dp++] = coords(v1, v2, pnt(0, 0, 0));
					h2d[h2dp++] = coords(v1, v2, v1);
					h2d[h2dp++] = coords(v1, v2, v2);*/
					int pos = 0, neg = 0;
					int i;
					for (i = 0; i < N; ++i) {
						pnt v3 = vec[i] - vec[i1];
						int r = cp * vec[i];
						if (r == 0) {
//							printf("adding point %d  %d %d %d (vector %d %d %d)\n", i, vec[i].x, vec[i].y, vec[i].z, v3.x, v3.y, v3.z);
							h2d[h2dp++] = coords(v1, v2, v3);
						}
						if (r > 0) ++pos;
						if (r < 0) ++neg;
						if (pos * neg != 0)
							break;
					}
					if (i == N) {
						++planesp;
						++ans[hull()];
					}
				}
			}
		}
		printf("Case #%d:\n", ctc + 1);
		for (int i = 3; i < MAXN; ++i)
			if (ans[i])
				printf("%d: %d\n", i, ans[i]);
	}

	return 0;
}
