#include <cstdio>
#include <cassert>
#include <vector>
#include <algorithm>

using namespace std;

template <typename T>
struct pnt {
	T x, y;
	pnt() {}
	pnt(T _x, T _y) : x(_x), y(_y) {}
	//template <typename U> pnt<T>(U _x, U _y) : x(_x), y(_y) {}

	pnt operator - (const pnt &p) const {return pnt(x - p.x, y - p.y);}
	pnt operator + (const pnt &p) const {return pnt(x + p.x, y + p.y);}

	T operator * (const pnt &p) const {return x * p.x + y * p.y;}
	T len2() const {return *this * *this;}

	pnt operator * (T coef) const {return pnt(x * coef, y * coef);}
	pnt operator / (T coef) const {return pnt(x / coef, y / coef);}
};

template <typename T>
T S(pnt<T> p1, pnt<T> p2, pnt<T> p3) {
	return (p2.x - p1.x) * (p3.y - p1.y) - (p2.y - p1.y) * (p3.x - p1.x);
}

pnt<double> toD(pnt<int> p) {
	return pnt<double>(p.x, p.y);
}

pnt<int> p1, q1;
pnt<int> p2, q2;
pnt<int> v1, v2, v;
pnt<double> n;

pnt<double> inter(pnt<int> a, pnt<int> b, pnt<int> c, pnt<int> d) {
	int s1 = S(a, c, d);
	int s2 = S(d, c, b);
	assert (s1 + s2);
	double t = s1 / (s1 + s2);
	return toD(a) + toD(b - a) * t;
}

int main() {
	int tc = 1;
	scanf("%d", &tc);

	for (int ctc = 0; ctc < tc; ++ctc) {
		scanf("%d %d %d %d", &p1.x, &p1.y, &q1.x, &q1.y);
		scanf("%d %d %d %d", &p2.x, &p2.y, &q2.x, &q2.y);

		scanf("%d %d", &v1.x, &v1.y);
		scanf("%d %d", &v2.x, &v2.y);

		vector<double> cand;
		v = v1 - v2;
		if (v.x == 0 && v.y == 0) {
			printf("-1\n");
			continue;
		}
		n = pnt<double>((q1 - p1).x, (q1 - p1).y);
		n = pnt<double>(-n.y, n.x);
		//printf("mid n %lf %lf\n", n.x, n.y);
		n = n * (n * pnt<double>(v.x, v.y)) / n.len2();

		//printf("%d %d\n", v.x, v.y);
		//printf("%lf %lf\n", n.x, n.y);

		int s1, s2;
		//p2 inside?
		s1 = S(p1, p1+v, p2);
		s2 = S(q1, q1+v, p2);
		if (s1 * s2 <= 0) {
			double dst = n * toD(p2 - p1);
			if (dst >= 0)
				cand.push_back(dst);
		}

		//q2 inside?
		s1 = S(p1, p1+v, q2);
		s2 = S(p2, p2+v, q2);
		if (s1 * s2 <= 0) {
			double dst = n * toD(q2 - p1);
			if (dst >= 0)
				cand.push_back(dst);
		}

		//p2 q2 cross p1, p1+v?
		s1 = S(p1, p1+v, p2);
		s2 = S(p1, p1+v, q2);
		if (s1 * s2 < 0) {
			double dst = n * (inter(p1, p1+v, p2, q2) - toD(p1));
			if (dst >= 0)
				cand.push_back(dst);
		}

		//p2 q2 cross q1, q1+v?
		s1 = S(p2, p2+v, p2);
		s2 = S(p2, p2+v, q2);
		if (s1 * s2 < 0) {
			double dst = n * (inter(p2, p2+v, p2, q2) - toD(p1));
			if (dst >= 0)
				cand.push_back(dst);
		}

		sort(cand.begin(), cand.end());
		if (!cand.empty())
			printf("%.6lf\n", cand.front() / n.len2());
		else
			printf("-1\n");
	}

	return 0;
}
