/*
FROM: acm.timus.ru
PROB: 1037 (Memory management)
KEYW: heap (hand made & stl)
*/

#include <cstdio>
//#include <cassert>
#include <cstring>
#include <queue>

#define DEEBUG

#ifndef assert
void assert (bool a) {
#ifdef DEEBUG
	while (!a);
#endif
}
#endif
	
const int MAXL = 1 << 7;
const int MAXN = 1 << 15;
const int MAXT = 1 << 20;
const int N = 30000;
const int T = 600;


//BEGIN exp heap (hand made)
const int MAXEL = MAXN;
const int MAXHS = MAXEL * 2;

struct exp_el {
	int id;
	int exp_t;
	exp_el () {}
	exp_el (int _id, int _exp_t) : id (_id), exp_t (_exp_t) {}

	bool operator < (const exp_el &a) const {
		return exp_t < a.exp_t;
	}
};

exp_el exp[MAXHS];
int idx[MAXEL];
int hsz;

void init () {
	exp[0] = exp_el (-1, -1);//expires early (too early)
	for (int i = 1; i < MAXHS; ++i)
		exp[i] = exp_el (-1, MAXT);//expires late (too late)
	hsz = 1;
	memset (idx, -1, sizeof (idx));
}

exp_el top () {
//	printf ("returning %d %d\n", exp[1].id, exp[1].exp_t);
	return exp[1];//if hsz == 1 i.e there aren't any elements this will return exp_el (-1, MAXT);
}

void dump ();

void sift_down (int id) {
//	printf ("sifting down %d\n", id);\
	dump ();
	exp_el tomove = exp[idx[id]];

	int p1 = idx[id], p2 = p1 * 2;
	for (;;) {
		
		if (exp[p2+1] < exp[p2])
			++p2;
//		printf ("%d %d -- %d (%d)\n", p1, p2, exp[p2].exp_t, tomove.exp_t);
		if (exp[p2] < tomove) {
			idx[exp[p2].id] = p1;
			exp[p1] = exp[p2];
			p1 = p2;
			p2 *= 2;
		} else
			break;
	}
	exp[p1] = tomove;
	idx[id] = p1;
//	printf ("after shit!\n");\
	dump ();
}

void pop () {
//	printf ("POP --- dumping:\n");\
	dump ();
	assert (hsz > 1);
	idx[exp[1].id] = -1;
	exp[1] = exp[--hsz];
	assert (exp[1].id != -1);
	exp[hsz] = exp_el (-1, MAXT);
	if (hsz == 1) return;
	idx[exp[1].id] = 1;
	sift_down (exp[1].id);
//	printf ("after pop:\n");\
	dump ();
}


void sift_up (int id) {
//	printf ("sift up %d\n", id);\
	dump ();
	assert (idx[id] != -1);
	exp_el tomove = exp[idx[id]];
	int p1 = idx[id], p2 = p1 / 2;

	while (tomove < exp[p2]) {
		idx[exp[p2].id] = p1;
		exp[p1] = exp[p2];
		p1 = p2;
		p2 /= 2;
	}
	exp[p1] = tomove;
	idx[tomove.id] = p1;
//	printf ("after sift_up\n");\
	dump ();
}

void add (const exp_el &to_add) {
	assert (idx[to_add.id] == -1);

	exp[hsz] = to_add;
	idx[to_add.id] = hsz++;
	sift_up (to_add.id);
}

void dump () {
	printf ("hsz == %d\n", hsz);
	int i = 1;
	for (int brd = 2;; brd *= 2) {
		for (; i < brd && exp[i].id != -1; ++i)
			printf ("(%d %d)<%d %d>", exp[i].id, exp[i].exp_t, idx[exp[i].id], i);
		puts ("");
		if (i != brd) break;
	}
}
//END

std::priority_queue <int, std::vector <int>, std::greater <int> > fr;


int main () {
	for (int i = 0; i < N; ++i)
		fr.push (i);

	init ();
//	dump ();
	char line[MAXL];
	int pt = -1;
	while (gets (line)) {
		int tm, rd;
		char op;
		int id;
		exp_el xx;
		sscanf (line, "%d %c%n", &tm, &op, &rd);
		assert (tm >= pt);
		pt = tm;
//		printf ("%d %c\ndumping\n", tm, op);\
		dump ();
		while ((xx = top ()).exp_t <= tm) {
			fr.push (xx.id);
			pop ();
		}
//		printf ("after pops\n");\
		dump ();
		if (op == '+') {
//			printf ("SIGN WAS +");
			assert (!fr.empty ());
			id = fr.top (); fr.pop ();
			add (exp_el (id, tm + T));
			printf ("%d\n", id + 1);
		} else {
//			printf ("SIGN WAS .\n");
			sscanf (line + rd, " %d", &id);
			--id;
//			printf ("got id %d\n", id);
			if (idx[id] == -1) {
				printf ("-\n");
			} else {
				printf ("+\n");
//				printf ("setting exp_t of exp[idx[%d]] -- exp[%d] --> %d\n", id, idx[id], tm + T);
				exp[idx[id]].exp_t = tm + T;
				sift_down (id);
			}
		}
//		printf ("after op!\n");\
		dump ();
	}

	return 0;
}
