/*
FROM: acm.timus.ru
PROB: 1043 (Cover an Arc)
KEYW: computational geometry
*/

#include <cstdio>
#include <cmath>
#include <cassert>
#include <algorithm>

const double EPS = 1e-9;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}
	
	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator * (double a) const {return pnt (x * a, y * a);}
	pnt operator / (double a) const {return pnt (x / a, y / a);}

	double operator * (const pnt &a) const {return x * a.x + y * a.y;}
	double dst (const pnt &a) const {return hypot (x - a.x, y - a.y);}
	double dst2 (const pnt &a) const {return (a - *this) * (a - *this);}
	double cross (const pnt &a) const {return x * a.y - y * a.x;}
	pnt rot () const {return pnt (-y, x);}
};

bool between (double beg, double end, double w) {
	return beg < end ? beg < w && w < end : beg < w || w < end;
}

int myceil (double x) {
	return (int)ceil (x);
//	return (int)(x > EPS ? ceil (x) : x < -EPS ? floor (x) : 0);
}

int myfloor (double x) {
	return (int)floor (x);
//	return (int)(x < -EPS ? ceil (x) : x > EPS ? floor (x) : 0);
}

int main () {
	pnt a, b, c, x;
	scanf ("%lf %lf  %lf %lf  %lf %lf", &a.x, &a.y, &b.x, &b.y, &c.x, &c.y);
	pnt cen = (b + c) / 2. + (c - b).rot () * (((b - a) * (c - a)) / (b - a).cross (c - a)) / 2.;
	double R = a.dst (cen);

	double 
	  ang1 = atan2 (a.y - cen.y, a.x - cen.x)
	, ang2 = atan2 (b.y - cen.y, b.x - cen.x)
	, ang3 = atan2 (c.y - cen.y, c.x - cen.x)
	, ang;

	if (!between (ang1, ang2, ang3))
		std::swap (ang1, ang2);

	assert (between (ang1, ang2, ang3));

	double u, d, l, r;
	u = std::max (a.y, b.y);
	d = std::min (a.y, b.y);
	l = std::min (a.x, b.x);
	r = std::max (a.x, b.x);
	//upper point
	x = cen + pnt (0, R);
	ang = atan2 (x.y - cen.y, x.x - cen.x);
	if (between (ang1, ang2, ang))
		u = x.y;

	//down point
	x = cen + pnt (0, -R);
	ang = atan2 (x.y - cen.y, x.x - cen.x);
	if (between (ang1, ang2, ang))
		d = x.y;

	//left point
	x = cen + pnt (-R, 0);
	ang = atan2 (x.y - cen.y, x.x - cen.x);
	if (between (ang1, ang2, ang))
		l = x.x;
	
	//right point
	x = cen + pnt (R, 0);
	ang = atan2 (x.y - cen.y, x.x - cen.x);
	if (between (ang1, ang2, ang))
		r = x.x;

//	fprintf (stderr, "%lf %lf\n", cen.x, cen.y);
//	fprintf (stderr, "%lf %lf %lf %lf\n", u, d, l, r);
//	fprintf (stderr, "%d %d %d %d\n", myceil (u), myfloor (d), myceil (r), myfloor (l));
	assert (myceil (u) <= 1000 && myfloor (d) >= -1000);
	assert (myceil (r) <= 1000 && myfloor (l) >= -1000);
	int area = (myceil (u-EPS) - myfloor (d+EPS)) * (myceil (r-EPS) - myfloor (l+EPS));
	printf ("%d\n", area);

	return 0;
}
