/*
FROM: acm.timus.ru
PROB: 1046 (Geometrical dreams)
KEYW: multiplying rotations, using matrices
*/

#include <cstdio>
#include <cstring>
#include <cmath>
#include <complex>

#ifdef ONLINE_JUDGE
#define PI 3.14159265358979323846264338327950288419
#else
#define PI M_PI
#endif

const int MAXN = 1 << 6;

double _tmp[2][2];
struct ma3x {
	double m[2][2];
	ma3x () {memset (m, 0, sizeof (m)); m[0][0] = m[1][1] = 1;}
	ma3x (const ma3x &a) {memcpy (m, a.m, sizeof (m));}
	ma3x (double ang) {
		m[0][0] = cos (ang); m[0][1] = -sin (ang);
		m[1][0] = sin (ang); m[1][1] =  cos (ang);
	}
	ma3x & operator = (const ma3x &a) {
		memcpy (m, a.m, sizeof (m));
		return *this;
	}
	ma3x operator * (const ma3x &a) const {
		ma3x ret;
		memset (ret.m, 0, sizeof (ret.m));
		int i, j, k;
		for (i = 0; i < 2; ++i)
			for (j = 0; j < 2; ++j)
				for (k = 0; k < 2; ++k)
					ret.m[i][j] += m[i][k] * a.m[k][j];
		return ret;
	}
};

struct pnt {
	double x, y;
	pnt () {}
	pnt (const pnt &a) : x (a.x), y (a.y) {}
	pnt (double _x, double _y) : x (_x), y (_y) {}

	pnt & operator += (const pnt &a) {x += a.x; y += a.y; return *this;}
	pnt & operator -= (const pnt &a) {x -= a.x; y -= a.y; return *this;}

	pnt operator + (const pnt &a) const {pnt ret (*this); ret += a; return ret;}
	pnt operator - (const pnt &a) const {pnt ret (*this); ret -= a; return ret;}
};

pnt operator * (const ma3x &a, const pnt &b) {
	return pnt (  b.x * a.m[0][0] + b.y * a.m[0][1]
				, b.x * a.m[1][0] + b.y * a.m[1][1]);
}
/*
int N;
pnt vec[MAXN];
double ang[MAXN];
*/

int N;
std::complex <double> vec[MAXN];
double ang[MAXN];

int main () {
	scanf ("%d", &N);

	int i;
	double x, y;
	for (i = 0; i < N; ++i) {
		scanf ("%lf %lf", &x, &y);
		vec[i] = std::complex <double> (x, y);
	}

	for (i = 0; i < N; ++i) {
		scanf ("%lf", ang + i);
		ang[i] = ang[i] / 180. * PI;
	}

/*	ma3x P1;
	pnt P0 (0, 0);

	for (i = 0; i < N; ++i) {
		ma3x R (ang[i]);
		P1 = R * P1;
		P0 = R * P0 + vec[i] - R * vec[i];
	}

	printf ("%lf %lf\n%lf %lf\n", P1.m[0][0], P1.m[0][1], P1.m[1][0], P1.m[1][1]);
	printf ("%lf %lf\n", P0.x, P0.y);
*/
	std::complex <double> P1 (cos (0.), sin (0.)), P0, R;
	for (i = 0; i < N; ++i) {
		R = std::complex <double> (cos (ang[i]), sin (ang[i]));
		P1 = R * P1;
		P0 = R * P0 + vec[i] - R * vec[i];
//		printf ("%lf %lf\n%lf %lf\n", P0.real (), P0.imag (), P1.real (), P1.imag ());
	}

	std::complex <double> res = P0 / (std::complex <double> (1) - P1);
//	printf ("%lf %lf\n%lf %lf\n", P0.real (), P0.imag (), P1.real (), P1.imag ());
//	printf ("%lf %lf\n", res.real (), res.imag ());

	for (i = 0; i < N; ++i) {
		R = std::complex <double> (cos (ang[i]), sin (ang[i]));
		printf ("%lf %lf\n", res.real (), res.imag ());
		res = R * res + vec[i] - R * vec[i];
	}

	return 0;
}
