/*
FROM: acm.timus.ru
PROB: 1075 (A thread in a space)
KEYW: computational geometry 3D, find a shortest path between 2 points with a spherical obstacle, good example of precision tuning
*/

#include <cstdio>
#include <cassert>
#include <cmath>

#ifdef ONLINE_JUDGE
#define PI 3.14159265358979323846264338327950288419
#else
#define PI M_PI
#endif

#define GOOD_VER1
#define GOOD_VER2
//#define GOOD_VER3
//#define GOOD_VER4

const double EPS = 1e-7;

double sq (double a) {return a * a;}

struct pnt3d {
	double x, y, z;
	double dst (const pnt3d &a) const {
		return sqrt (sq (x - a.x) + sq (y - a.y) + sq (z - a.z));
	}
	double dst2 (const pnt3d &a) const {
		return sq (x - a.x) + sq (y - a.y) + sq (z - a.z);
	}
};

struct pnt2d {
	double x, y;
	pnt2d () {}
	pnt2d (double _x, double _y) : x (_x), y (_y) {}
	double dst (const pnt2d &a) const {
		return hypot (x - a.x, y - a.y);
	}
};

typedef pnt2d pnt;
double S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}


pnt3d A3d, B3d, C3d;
double r;
pnt2d a, b, c;

double rad2grad (double ang) {
	return ang / PI * 180.;
}

double myacos (double a) {
#ifdef GOOD_VER4
	if (a > 1)
		a = 1;
	else if (a < -1)
		a = -1;
#endif
	return acos (a);
}
double myasin (double a) {
#ifdef GOOD_VER4
	if (a > 1)
		a = 1;
	else if (a < -1)
		a = -1;
#endif
	return asin (a);
}
int main () {
	scanf ("%lf %lf %lf", &A3d.x, &A3d.y, &A3d.z);
	scanf ("%lf %lf %lf", &B3d.x, &B3d.y, &B3d.z);
	scanf ("%lf %lf %lf", &C3d.x, &C3d.y, &C3d.z);
	scanf ("%lf", &r);

	double ab = A3d.dst (B3d), absq = A3d.dst2 (B3d);
	double ac = A3d.dst (C3d), acsq = A3d.dst2 (C3d);
	double bc = B3d.dst (C3d), bcsq = B3d.dst2 (C3d);

#ifdef GOOD_VER2
	if (acsq + EPS > absq + bcsq
	 || bcsq + EPS > absq + acsq) {
		printf ("%.10lf\n", ab);
		return 0;
	}
#endif
	

	a = pnt (0, 0);
	b = pnt (ab, 0);

#ifdef GOOD_VER1
	double cang = (absq + acsq - bcsq) / sqrt (4. * absq * acsq);
//	double ang = myacos (cang);
	double sang = sqrt (1. - cang * cang);
//	assert (fabs (sin (ang) - sang) < EPS);

	c = pnt (cang * ac, sang * ac);
#else
	double cang = (absq + acsq - bcsq) / (2. * ab * ac);
	double ang = myacos (cang);
//	double sang = sqrt (1. - cang * cang);
//	assert (fabs (sin (ang) - sang) < EPS);

	c = pnt (cang * ac, sin (ang) * ac);
#endif

//	printf ("%.10lf %.10lf %.10lf\n", ab, ac, bc);
//	printf ("%lf %lf\n%lf %lf\n%lf %lf\n", a.x, a.y, b.x, b.y, c.x, c.y);\
	printf ("%lf %lf\n", a.dst (c), b.dst (c));
#ifdef GOOD_VER2
	if (c.y + EPS > r) {
		printf ("%.10lf\n", ab);
		return 0;
	}
#else
	if (c.y + EPS > r || c.x < EPS || c.x > b.x - EPS) {
		printf ("%.10lf\n", ab);
		return 0;
	}
#endif

//	printf ("%lf %lf\n%lf %lf\n%lf %lf\n", a.x, a.y, b.x, b.y, c.x, c.y);\
	printf ("%lf %lf\n", a.dst (c), b.dst (c));

	double sac = r / ac;
	double aac = -myasin (sac);
	double acba = atan2 (c.y, c.x);//c.y - a.y, c.x - a.x
	double acfa = acba + aac;

	double sbc = r / bc;
	double abc = myasin (sbc);
	double bcba = atan2 (- c.y, b.x - c.x);//b.y - c.y, b.x - c.x
	double bcfa = bcba + abc;

#ifdef GOOD_VER3
	if (bcfa < EPS) bcfa = 0.;//should be positive
	if (acfa > -EPS) acfa = 0.;//should be negative
#endif
//	printf ("%lf %lf\n", acfa, rad2grad (acfa));\
	printf ("%lf %lf\n", bcfa, rad2grad (bcfa));
	printf ("%.10lf\n", sqrt (acsq - sq (r)) + sqrt (bcsq - sq (r)) + (bcfa - acfa) * r);

	return 0;
}
