/*
FROM: acm.timus.ru
PROB: 1101 (Robot In The Field)
KEYW: simulation, reverse polish notation (RPN)
*/

#include <cstdio>
#include <cctype>
#include <cstring>

const int MAXE = 1 << 8;
const int MAXLINE = 1 << 8;
const int MAXN = 1 << 7;
const int MAXK = 1 << 7;

enum token {TRUE, FALSE, NOT, OR, AND, LB, NLB, RB, REG, END_OF_INPUT};

#ifdef ONLINE_JUDGE
void assert (int a) {
	while (!a);
}
#else
#include <cassert>
#endif

int ep;
char expr[MAXE];
int lcp;
char line[MAXLINE];

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, 1, 0, -1};

token ctok;
char reg;
token next_tok () {
	while (isspace (line[lcp])) ++lcp;
	if (line[lcp] == '\0') return ctok = END_OF_INPUT;

	if (line[lcp] == '(') {
		++lcp;
		return ctok = LB;
	} else if (line[lcp] == ')') {
		++lcp;
		return ctok = RB;
	}

	if (isalpha (line[lcp+1])) {
		if 		  (strncmp (line + lcp, "AN", 2) == 0) {
			lcp += 3;
			return ctok = AND;
		} else if (strncmp (line + lcp, "OR", 2) == 0) {
			lcp += 2;
			return ctok = OR;
		} else if (strncmp (line + lcp, "NO", 2) == 0) {
			lcp += 3;
			return ctok = NOT;
		} else if (strncmp (line + lcp, "TR", 2) == 0) {
			lcp += 4;
			return ctok = TRUE;
		} else if (strncmp (line + lcp, "FA", 2) == 0) {
			lcp += 5;
			return ctok = FALSE;
		} else {
//			assert (0);
		}
	}

//	printf ("this character is _%c_ %d\n", line[lcp], isspace (lcp));
	
	reg = line[lcp++];
	return ctok = REG;
}

void read_expr () {
	gets (line);
	token tok_buf[MAXE];
	int tbp = 0;

	while (next_tok () != END_OF_INPUT) {
//		printf ("%d _%c_ %.10s\n", ctok, reg, line + lcp);
		switch (ctok) {
			case AND:
				while (tbp && tok_buf[tbp-1] == AND) {expr[ep++] = tok_buf[--tbp];}
				tok_buf[tbp++] = AND;
				break;
			case OR:
				while (tbp && (tok_buf[tbp-1] == OR || tok_buf[tbp-1] == AND)) {expr[ep++] = tok_buf[--tbp];}
				tok_buf[tbp++] = OR;
				break;
			case TRUE: case FALSE:
				expr[ep++] = ctok;
				break;
			case LB:
				tok_buf[tbp++] = LB;
				break;
			case RB:
				while (tbp && tok_buf[tbp-1] != LB && tok_buf[tbp-1] != NLB) {expr[ep++] = tok_buf[--tbp];}
				if (tok_buf[tbp-1] == NLB)
					expr[ep++] = NOT;

				--tbp;
				break;
			case REG:
				expr[ep++] = tolower (reg);
				break;
			case NOT:
				next_tok ();
//				printf ("got %d _%c_ %.10s\n", ctok, reg, line + lcp);
//				assert (ctok != END_OF_INPUT);
				if (ctok == TRUE)
					expr[ep++] = FALSE;
				else if (ctok == FALSE)
					expr[ep++] = TRUE;
				else if (ctok == LB)
					tok_buf[tbp++] = NLB;
				else if (ctok != NOT) {
					assert (ctok == REG);
					expr[ep++] = toupper (reg);//negated
				}
				break;
			default:
				;
//				assert (0);
		}
	}
	while (tbp > 0)
		expr[ep++] = tok_buf[--tbp];
}

int N, M, K;
char brd[MAXN * 2][MAXN * 2];
bool regs[MAXK];

bool eval () {
	bool stk[MAXE];
	int sp = 0;
	int i;
	for (i = 0; i < ep; ++i) {
		switch (expr[i]) {
			case NOT: stk[sp-1] = !stk[sp-1]; break;
			case AND: stk[sp-2] = stk[sp-2] && stk[sp-1]; --sp; break;
			case OR:  stk[sp-2] = stk[sp-2] || stk[sp-1]; --sp; break;
			case TRUE: stk[sp++] = true; break;
			case FALSE: stk[sp++] = false; break;
			default:
//				assert (isalpha (expr[i]));
				stk[sp++] = islower (expr[i]) ? regs[expr[i] - 'a'] : !regs[expr[i] - 'A'];
		}
	}
//	assert (sp == 1);
//	printf ("EVAL %d\n", stk[0]);
	return stk[0];
}

int main () {
	read_expr ();

	scanf ("%d %d %d", &N, &M, &K);

	int i;
/*
	for (i = 0; i < ep; ++i) {
		if (isalpha (expr[i]))
			printf (" %c", expr[i]);
		else switch ((token)expr[i]) {
			case TRUE: printf (" TRUE"); break;
			case FALSE: printf (" FALSE"); break;
			case AND: printf (" AND"); break;
			case OR: printf (" OR"); break;
			case NOT: printf (" NOT"); break;
			default:
				fprintf (stderr, "\ngot %d\n", (int)expr[i]);
				assert (0);
		}
//			printf (" %d", expr[i]);
	}
	*/
	int x, y;
	char c;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &x, &y);
		x += N; y += N;
		brd[x][y] = 1;
	}

	for (i = 0; i < K; ++i) {
		scanf ("%d %d %c", &x, &y, &c);
		x += N; y += N;
		brd[x][y] = tolower (c);
	}

	x = y = N;
	int dir = 2;
	while (x >= 0 && x <= 2 * N
		&& y >= 0 && y <= 2 * N) {
		printf ("%d %d\n", x - N, y - N);
		if (brd[x][y] == 1) {
			dir += eval () ? 1 : 3;
			dir %= 4;
//			printf ("NEW DIR %d\n", dir);
		} else if (isalpha (brd[x][y])) {
			regs[brd[x][y] - 'a'] = !regs[brd[x][y] - 'a'];
//			printf ("INV %d\n", (int)(brd[x][y] - 'a'));
		}
		x += dx[dir];
		y += dy[dir];
	}

	return 0;
}
