/*
NAME: SCUD Busters
ID: 109
SITE: acm.uva.es
*/

#include <cstdio>
#include <algorithm>

const int MAXN = 1 << 7;
const int MAXK = 1 << 5;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	pnt (const pnt &a) : x (a.x), y (a.y) {}
};

int K;
pnt data[MAXK][MAXN];
int ds[MAXK];

inline int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

pnt base;
bool cmp (const pnt &a, const pnt &b) {
	static int tmp;
	return 	(tmp = S (base, a, b)) ?
				tmp > 0 :
				a.y != b.y ?
					a.y < b.y :
					a.x > b.x;
}

void hull (int N, pnt *vec) {
	int lpid = 0;
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y < vec[lpid].y || vec[i].y == vec[lpid].y && vec[i].x > vec[lpid].x)
			lpid = i;
	base = vec[lpid];
	vec[lpid] = vec[0];
	vec[0] = base;
	std::sort (vec + 1, vec + N, cmp);

	int hsz = 0;
	for (i = 0; i < N; ++i) {
		data[K][hsz++] = vec[i];
		while (hsz > 2 && S (data[K][hsz-3], data[K][hsz-2], data[K][hsz-1]) <= 0) {
			data[K][hsz-2] = data[K][hsz-1];
			--hsz;
		}
	}
	if (hsz > 2)
		ds[K++] = hsz;

//	for (i = 0; i < hsz; ++i) printf ("(%d %d) ", data[K-1][i].x, data[K-1][i].y); printf ("\n");
}

int calc_S (int);
void input () {
	static int N;
	static pnt buf[MAXN];
	while (scanf ("%d", &N), N != -1) {
		for (int i = 0; i < N; ++i) scanf ("%d %d", &buf[i].x, &buf[i].y);
		hull (N, buf);
	}
/*
	int k, i;
	for (k = 0; k < K; ++k) {
		for (i = 0; i < ds[k]; ++i) printf ("(%d %d) ", data[k][i].x, data[k][i].y); printf ("\n");
		printf ("%d\n", calc_S (k));
	}
*/
}

int calc_S (int id) {
	int S = 0;
	data[id][ds[id]] = data[id][0];
	for (int i = 0; i < ds[id]; ++i)
		S += data[id][i].x * data[id][i+1].y - data[id][i+1].x * data[id][i].y;
	return S;
}

pnt boom;
bool bsrch (int id) {
	int l = 1, r = ds[id]-1, m;
//	printf ("bsrch %d %d  %d\n", boom.x, boom.y, id);

	int tmp;
	tmp = S (data[id][0], data[id][l], boom);
//	printf ("t1 %d(%d %d  %d %d  %d %d)\n", tmp, data[id][0].x, data[id][0].y, data[id][l].x, data[id][l].y, boom.x, boom.y);
	if (tmp < 0) return 0;
	if (!tmp) return boom.y <= data[id][l].y;

	tmp = S (data[id][0], data[id][r], boom);
//	printf ("t2 %d(%d %d  %d %d  %d %d)\n", tmp, data[id][0].x, data[id][0].y, data[id][r].x, data[id][r].y, boom.x, boom.y);
	if (tmp > 0) return 0;
	if (!tmp) {
		if (boom.y == data[id][0].y && boom.x < data[id][r].x) return 0;
		if (boom.y != data[id][0].y && boom.y > data[id][r].y) return 0;
		return 1;
	}

	while (l + 1 < r) {
		m = (l + r) / 2;
		tmp = S (data[id][0], data[id][m], boom);
		if (tmp > 0)
			l = m;
		else if (tmp < 0)
			r = m;
		else if (boom.y > data[id][m].y) return 0;
		else return 1;
	}
//	printf ("%d %d -- %d %d %d\n", boom.x, boom.y, id, l, r);
//	printf ("%d\n", S (data[id][l], data[id][r], boom) >= 0);
	return S (data[id][l], data[id][r], boom) >= 0;
}

bool hitted[MAXK];
int total_S;
void do_all () {
	for (int i = 0; i < K; ++i)
		if (!hitted[i] && bsrch (i)) {
			hitted[i] = 1;
			total_S += calc_S (i);
		}
}

int main () {
	input ();

	while (scanf ("%d %d", &boom.x, &boom.y) == 2)
		do_all ();

	printf ("%.2lf\n", total_S / 2.0);

	return 0;
}
