#include <cstdio>
#include <vector>
#include <queue>
#include <utility>
#include <algorithm>

using std::make_pair;

const int MAXR = 1 << 7;
const int MAXC = 1 << 7;
const int MAXN = MAXR * MAXC;

const int difx[] = {0, 1, 0, -1, 1, 1, -1, -1};
const int dify[] = {1, 0, -1, 0, 1, -1, -1, 1};

struct edge {
	int a;
	int b;
	int d;
};

int R, C;
bool map[MAXR][MAXC];
int N;
int comp[MAXR][MAXC];

std::vector <edge> edges;

void constr_edges () {
	int i, j;
	int beg;
	int bgr, egr;
	edges.clear ();

	for (i = 0; i < R - 1; ++i) {
		beg = 0;
		for (j = 1; j < C; ++j)
			if (beg) {
				if (!(comp[i][j] == -1 && comp[i+1][j] == -1)) {
					egr = comp[i][j] != -1 ? comp[i][j] : comp[i+1][j];
					if (bgr != egr)
						edges.push_back ((edge) {bgr, egr, beg});

					beg = 0;
				} else
					++beg;
			} else {
				if (comp[i][j] == -1 && comp[i+1][j] == -1 &&
				!(comp[i][j-1] == -1 && comp[i+1][j-1] == -1)) {
					beg = 1;
					bgr = comp[i][j-1] != -1 ? comp[i][j-1] : comp[i+1][j-1];
					}
			}
	}

	for (j = 1; j < C; ++j) {
		beg = 0;
		for (i = 1; i < R; ++i)
			if (beg) {
				if (!(comp[i][j] == -1 && comp[i][j-1] == -1)) {
					egr = comp[i][j] != -1 ? comp[i][j] : comp[i][j-1];
					if (bgr != egr)
						edges.push_back ((edge) {bgr, egr, beg});
					beg = 0;
				} else
					++beg;
			} else {
				if (comp[i][j] == -1 && comp[i][j-1] == -1 &&
				!(comp[i-1][j-1] == -1 && comp[i-1][j] == -1)) {
					bgr = comp[i-1][j-1] != -1 ? comp[i-1][j-1] : comp[i-1][j];
					beg = 1;
				}
			}
	}
}

void bfs (int a, int b) {
	std::queue <std::pair <int, int> > q;
	q.push (std::make_pair (a, b));
	comp[a][b] = N;

	std::pair <int, int> crnt;
	int ni, nj, k;
	while (!q.empty ()) {
		crnt = q.front (); q.pop ();

		for (k = 0; k < 8; ++k) {
			ni = crnt.first + difx[k];
			nj = crnt.second + dify[k];

			if (ni >= 0 && nj >= 0 && ni < R && nj < C && comp[ni][nj] == -1 && map[ni][nj]) {
				comp[ni][nj] = N;
				q.push (make_pair (ni, nj));
			}
		}
	}
}

void make_comp () {
	int i, j;
	for (i = 0; i < R; ++i) for (j = 0; j < C; ++j) comp[i][j] = -1;

	N = 0;
	for (i = 0; i < R; ++i)
		for (j = 0; j < C; ++j)
			if (comp[i][j] == -1 && map[i][j]) {
				bfs (i, j);
				++N;
			}
/*
	for (i = 0; i < R; ++i) {
		for (j = 0; j < C; ++j)
			printf ("%3d", comp[i][j]);
		printf ("\n");
	}
	printf ("\n");
*/
}

bool cmp (const edge &a, const edge &b) {
	return a.d < b.d;
}

int main () {
	int i, j;
	char tmp;
	int A[MAXN], sz[MAXN];
	int p, q;
	int tc = 0;
	int alllen = 0;
	int edgecnt = 0;
	while (scanf ("%d %d\n", &R, &C), ++tc, (R && C)) {
		for (i = 0; i < R; ++i) {
			for (j = 0; j < C; ++j) {
				scanf ("%c", &tmp);
				map[i][j] = (tmp == '#');
			}
			scanf ("\n");
		}

		make_comp ();
		constr_edges ();
		if (N < 2) {if (tc != 1) printf ("\n"); printf ("City %d\nNo bridges are needed.\n", tc); continue;}
		std::sort (edges.begin (), edges.end (), cmp);
		for (i = 0; i < N; ++i) {A[i] = i; sz[i] = 1;}

		edgecnt = 0; alllen = 0;
		for (i = 0; i < (int)edges.size (); ++i) {
//			printf ("edge %d %d %d\n", edges[i].a, edges[i].b, edges[i].d);
			for (p = edges[i].a; p != A[p]; p = A[p]) A[p] = A[A[p]];
			for (q = edges[i].b; q != A[q]; q = A[q]) A[q] = A[A[q]];
			if (p != q) {
				if (sz[p] > sz[q]) {
					A[q] = p;
					sz[p] += sz[q];
				} else {
					A[p] = q;
					sz[p] += sz[q];
				}
				alllen += edges[i].d;
//				printf ("add -- %d\n", alllen);
				++edgecnt;
			}
		}
//		printf ("--\n");
		if (tc != 1) printf ("\n");
		printf ("City %d\n", tc);
		if (edgecnt)
			printf ("%d %s of total length %d\n", edgecnt, edgecnt == 1 ? "bridge" : "bridges" ,alllen);
		else
			printf ("No bridges are possible.\n");

		if (N - edgecnt != 1) {
			printf ("%d disconnected groups\n", N-edgecnt);
		}
	}
	return 0;
}
