/*
KEYW: Dinitz implemented with list  of neighbours
*/

#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <limits>

using std::min;

const int MAXN = 1 << 10;
const int MAXM = MAXN * MAXN;

const int MAXFLOW = std::numeric_limits <int>::max ();

struct el {
	int to;
	int rd;
	int next;
	el () {}
	el (int tt, int rr, int nn) : to (tt), rd (rr), next (nn) {}
};

int op (int id) {
	return id + (id & 1 ? -1 : 1);
}

int N, M;
int source, sink;

int vec[MAXN];
el buf[MAXM];

int maxflow;

int D[MAXN];
bool used[MAXN];

bool bfs () {
	int i, j, crnt;
	for (i = 0; i < N; ++i) {
		D[i] = -1;
		used[i] = 0;
	}

	int queue[MAXN];
	int p1 =0, p2 =1, p3 =0, lvl =0;
	queue[p3++] = sink;
	D[sink] = lvl++;
	
	while (p1 != p2) {
		for (i = p1; i < p2; ++i) {
			crnt = queue[i];
//			printf ("pop %d\n", crnt);
			for (j = vec[crnt]; j != -1; j = buf[j].next) {
				if (D[buf[j].to] == -1 && buf[op (j)].rd) {
//					printf ("\t push %d\n", buf[j].to);
					D[buf[j].to] = lvl;
					queue[p3++] = buf[j].to;
				}
			}
		}
		p1 = p2;
		p2 = p3;
		++lvl;
	}
	used[source] = 1;//prevent returning to the source in the dfs
//	printf ("end bfs!\n");
	return D[source] != -1;
}

int vis[MAXN];
int vp;

int dfs (int v) {
//	printf ("%d\n", v);
	if (v == sink) {
		used[v] = 0;//unuse the sink for further use
		return MAXFLOW;
	}
	int i, tmp;
	for (i = vec[v]; i != -1; i = buf[i].next) {
		if (buf[i].rd < 0) exit (0);
		if (D[buf[i].to] == D[v] - 1 && !used[buf[i].to] && buf[i].rd) {
//			printf ("%d (from %d)\n", buf[i].to, v);
			used[buf[i].to] = 1;
			vis[vp++] = i;//the number of the edge
			if ((tmp = dfs (buf[i].to)))
				return min (tmp, buf[i].rd);
			--vp;
			used[buf[i].to] = 0;
		}
	}
//	printf ("%d <-\n", v);
	return 0;//didn't find a path to the sink
}

void prntused () {
	for (int i = 0; i < N; ++i)
		printf ("%d ", used[i]);
	printf ("\n");
}

void dinitz () {
	int cflow, i;
	while (bfs ()) {
		while (vp =0, (cflow = dfs (source))) {
//			printf ("****\n");
			maxflow += cflow;
			for (i = 0; i < vp; ++i) {
				buf[vis[i]].rd -= cflow;
//				printf ("%d -> now %d\n", vis[i], buf[vis[i]].rd);
				buf[op (vis[i])].rd += cflow;
//				printf ("%d -> now %d\n", op (vis[i]), buf[op (vis[i])].rd);
			}
		}
	}
}

void input () {
	scanf ("%d %d", &N, &M);
	scanf ("%d %d", &source, &sink);
	--source; --sink;

	int i;
	int bp =0;
	int a, b, c;
	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d", &a, &b, &c);
		--a; --b;
		
		buf[bp] = el (b, c, vec[a]);
		vec[a] = bp++;
		
		buf[bp] = el (a, 0, vec[b]);
		vec[b] = bp++;
	}
	M = bp;
}

void output () {
	printf ("%d\n", maxflow);
}

int main () {
	input ();
	dinitz ();
	output ();
	return 0;
}
