 #include <iostream>
#include <list>
#include <vector>
using namespace std;
 
#define ZEROARR(a) memset(a, 0, sizeof(a))
#define REP(i, n) for (int i = 0; i < n; ++i)
#define ONEREP(i, n) for (int i = 1; i <= n; i++)
 
const int MAXN = 201;
const int INF = 10100;
 
struct Node {
 int height, excess;
 vector<int>::iterator cur;
 vector<int> neib;
};
 
Node node[MAXN];
int n, n2, maxCops, sour, dist;
int limit[MAXN][MAXN], flow[MAXN][MAXN];
 
void Init() {
 int m;
 
 cin >> maxCops;
 cin >> n >> m >> sour >> dist;
 dist += n;
 n2 = n * 2;
 
 ZEROARR(flow);
 ZEROARR(limit);
//double nodes
 ONEREP(i, n) {
  int nodeLimit;
  cin >> nodeLimit;
 
  limit[i][n + i] = nodeLimit;
  node[i].neib.push_back(n + i);
  node[n + i].neib.push_back(i);
 }
 limit[sour][n + sour] = INF;
 limit[dist - n][dist] = INF;
//edges
 REP(k, m) {
  int i, j;
  cin >> i >> j;
  if (n + i != dist && j != sour) {
   limit[n + i][j] = INF;
   node[n + i].neib.push_back(j);
   node[j].neib.push_back(n + i);
  }
  if (n + j != dist && i != sour) {
   limit[n + j][i] = INF;
   node[n + j].neib.push_back(i);
   node[i].neib.push_back(n + j);
  }
 }
//heights - excess - current position in the neib vector
 ONEREP(i, n2) {
  node[i].cur = node[i].neib.begin();
  node[i].height = 0;
  node[i].excess = 0;
 }
 node[sour].height = n2;
//preflow to source's neighbours
 for (vector<int>::iterator it = node[sour].neib.begin(); it != node[sour].neib.end(); ++it) {
  int i = *it;
  flow[sour][i] = limit[sour][i];
  flow[i][sour] = -limit[sour][i];
  node[i].excess = limit[sour][i];
  node[sour].excess -= limit[sour][i];
 }
}
 
void Relabel(int i) {
 int heightNew = 2 * MAXN;
 for (vector<int>::iterator it = node[i].neib.begin(); it != node[i].neib.end(); ++it) {
  int j = *it;
  if (limit[i][j] - flow[i][j] > 0 && node[j].height < heightNew) {
   heightNew = node[j].height;
  }
 }
 node[i].height = 1 + heightNew;
}
 
void Push(int i, int j) {
 //dif = min (node[i].excess, edge(i,j)->residual_capacity)
 int dif;
 if (limit[i][j] - flow[i][j] < node[i].excess) {
  dif = limit[i][j] - flow[i][j];
 }
 else {
  dif = node[i].excess;
 }
 flow[i][j] += dif;
 flow[j][i] = -flow[i][j];
 node[i].excess -= dif;
 node[j].excess += dif;
}
 
void Discharge(int i) {
 while (node[i].excess > 0) {
  if (node[i].cur == node[i].neib.end()) {
   Relabel(i);
   node[i].cur = node[i].neib.begin();
  }
  else {
   int j = *(node[i].cur);
   if (limit[i][j] - flow[i][j] > 0 && node[i].height == node[j].height + 1) {
    Push(i, j);
   }
   else {
    ++node[i].cur;
   }
  }
 }//while
}
 
int Solve() {
//make the lsit L = V[G] - {s,t} in any order
 list<int> nodes;
 ONEREP(i, n2) {
  if (i != sour && i != dist) {
   nodes.push_back(i);
  }
 }
//relabel-to-fron
 list<int>::iterator it = nodes.begin();
 while (it != nodes.end()) {
  int i = *it;
  int heightOld = node[i].height;
//DisplayInfo(i);
  Discharge(i);
  if (node[i].height > heightOld) {
   nodes.erase(it);
   nodes.push_front(i);
   it = nodes.begin();
  }
  ++it;
 }
 return node[dist].excess;
}
 
int main() {
 Init();
 int maxFlow = Solve();
 
//cout << endl << maxFlow << endl;
 
 if (maxFlow <= maxCops) {
  cout << "YES";
 }
 else {
  cout << "NO";
 }
 return 0;
}
	