/*
FROM: BaOI 2001
PROB: kni
KEYW: bipartite matching
*/

#include <cstdio>
#include <limits>

const int MAXN = 1 << 16;
const int MAXM = MAXN << 3;

const int MAXFLOW = std::numeric_limits <int> :: max ();

const int difx[] = {-1, -2, -2, -1, 1, 2,  2,  1};
const int dify[] = {-2, -1,  1,  2, 2, 1, -1, -2};
const int MVCNT = 1 << 3;

struct el {
	int to;
	int rd;
	int next;
	el () {}
	el (int tt, int rr, int nn) : to (tt), rd (rr), next (nn) {}
};

int N, M;
int rN;//the N we will use in dinitz
int source, sink;

int vec[MAXN];
el buf[MAXM];

int to_n (int a, int b) {
	return a * N + b;
}

const int MAXn = 1 << 8;//256
bool forb[MAXn][MAXn];

int D[MAXN];
int used[MAXN];

int op (int a) {
	return a + (a & 1 ? -1 : +1);
}

bool bfs () {
	int i, j;
	for (i = 0; i < rN; ++i) {
		D[i] = -1;
		used[i] = 0;
	}
	used[source] = 1;//needed for the corectness of dfs ()

	int p1 =0, p2 =1, p3 =0, lvl =0;
	int crnt;
	int queue[MAXN];
	queue[p3++] = sink;
	D[sink] = lvl++;
	
	while (p1 != p2) {
		for (i = p1; i < p2; ++i) {
			crnt = queue[i];
//			printf ("popped %d\n", crnt);
			for (j = vec[crnt]; j != -1; j = buf[j].next) {
				if (D[buf[j].to] == -1 && buf[op (j)].rd) {
//					printf ("\tpush %d\n", buf[j].to);
					D[buf[j].to] = lvl;
					queue[p3++] = buf[j].to;
				}
			}
		}
		p1 = p2;
		p2 = p3;
		++lvl;
	}

	return D[source] != -1;
}

int vis[MAXN];
int vp;

int dfs (int v) {
	printf ("dfs %d\n", v);
	if (v == sink) {
		used[sink] = 0;
		return MAXFLOW;
	}
	
	int i;
	int tmp;
	for (i = vec[v]; i  != -1; i = buf[i].next) {
		printf ("->%d(%d) ((%d))\n", buf[i].to, buf[i].rd, used[buf[i].to]);	
		if (D[buf[i].to] == D[v] - 1 && !used[buf[i].to] && buf[i].rd) {
			used[buf[i].to] = 1;
			vis[vp++] = i;//the number of the edge
			if ((tmp = dfs (buf[i].to)))
				return (tmp < buf[i].rd ? tmp : buf[i].rd);
			--vp;
		}
	}
	printf ("dfs %d <-\n", v);
	return 0;//no path to sink found
}

int maxflow;
void dinitz () {
 	int cflow, i;
	while (bfs ()) {
		while (vp = 0, (cflow = dfs (source))) {
			maxflow += cflow;
			printf ("******\n");
			for (i = 0; i < vp; ++i) {
				buf[vis[i]].rd -= cflow;
				buf[op (vis[i])].rd += cflow;
			}
		}
	}
}

void input () {
	scanf ("%d %d", &N, &M);
	
	int i, j, k, a, b;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &a, &b);
		forb[--a][--b] = 1;
	}

	rN = N * N + 2;//real N (number of vetrices) inlude the source and the sink
	int bp =0;
	int p1, p2;
	int n1 = N * N;
	n1 = (n1 & 1 ? 1 : 0) + n1 >> 1;
	for (i = 0; i < rN; ++i) vec[i] = -1;
	for (i = 0; i < N; ++i)//add arcs from 1st group to 2nd group
		for (j = 0; j < N; ++j) {
			if ((i + j) & 1) continue;//we will observe only the BLACK positions ((0,0) is BLACK)
			p1 = to_n (i, j) / 2;
			for (k = 0; k < MVCNT; ++k)
				if (!forb[i][j] && (a = i + difx[k]) >= 0 && a < N && (b = j + dify[k]) >= 0 && b < N && !forb[a][b]) {
					p2 = (to_n (a, b) >> 1) + n1;
					printf ("adding %d %d(%d)\n", p1, p2, p2 - n1);

					buf[bp] = el (p1, 0, vec[p2]);
					vec[p2] = bp++;

					buf[bp] = el (p2, 1, vec[p1]);
					vec[p1] = bp++;
				}
		}
	source = N * N;
	sink = source + 1;
	for (i = 0; i < n1; ++i) {//add arcs from source to first group
		if (forb[(i * 2) / N][(i * 2) % N]) continue;
		buf[bp] = el (i, 1, vec[source]);
		vec[source] = bp++;
		
		buf[bp] = el (source, 0, vec[i]);
		vec[i] = bp++;
	}

	for (i = n1; i < source; ++i) {//add arcs from 2nd group to sink
		if (forb[((i - n1) * 2 + 1) / N][((i - n1) * 2 + 1) % N]) continue;
		buf[bp] = el (sink, 1, vec[i]);
		vec[i] = bp++;

		buf[bp] = el (i, 0, vec[sink]);
		vec[sink] = bp++;
	}
	
	for (i = 0; i < rN; ++i) {
		printf ("%d ->", i);
		for (j = vec[i]; j != -1; j = buf[j].next)
			printf (" (%d %d)", buf[j].to, buf[j].rd);
		printf ("\n");
	}
}

void output () {
	printf ("%d\n", N * N - M - maxflow);//not yet :)
}

int main () {
	input ();
	dinitz ();
	output ();

	return 0;
}
