/*
FROM: Balkan Olimpiad in Informatics (BOI) 1997 day 1
PROB: the running man
KEYW: artic points
*/

#include <cstdio>
#include <utility>
#include <algorithm>

#define x first
#define y second

const int MAXN = 1 << 6;
const int MAX = MAXN * MAXN;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, 1, 0, -1};

int N;
int rx, ry;
int ex, ey;
char map[MAXN][MAXN];

int lowest[MAXN][MAXN], prenum[MAXN][MAXN], size[MAXN][MAXN];

std::pair <int, int> dvec[MAX];
int dvp;
std::pair <int, int> ans[MAX];
int ap;

void tc2nc (int &x, int &y) {
	y = N - y;
	--x;
	std::swap (x, y);
}

void nc2tc (int &x, int &y) {
	++y;
	x = N-x;
	std::swap (x, y);
}

void dfs (int x, int y) {
	static int cpn = 0;
	prenum[x][y] = lowest[x][y] = ++cpn;
	size[x][y] = 1;

	int i, nx, ny;
	for (i = 0; i < 4; ++i) {
		nx = x + dx[i];
		ny = y + dy[i];
		if (nx < 0 || nx >= N
		 || ny < 0 || ny >= N
		 || map[nx][ny] == 'W') continue;//cannot go there

		if (prenum[nx][ny] == 0) {
			dfs (nx, ny);
			size[x][y] += size[nx][ny];
			lowest[x][y] <?= lowest[nx][ny];
		} else
			lowest[x][y] <?= prenum[nx][ny];
	}
}

bool in_sub_tree (int ax, int ay, int bx, int by) {
	return prenum[ax][ay] > prenum[bx][by]
		&& prenum[ax][ay] < prenum[bx][by] + size[bx][by];
}

bool is_separated (int ax, int ay, int bx, int by) {
	return lowest[ax][ay] <= prenum[bx][by];
}

int main () {
	scanf ("%d", &N);
	scanf ("%d %d", &rx, &ry);
	tc2nc (rx, ry);

	int i, j;
	for (i = 0; i < N; ++i)
		for (j = 0; j < N; ++j) {
			scanf (" %c", &map[i][j]);
			if (map[i][j] == 'D')
				dvec[dvp++] = std::make_pair (i, j);
			else if (map[i][j] == 'E') {
				ex = i;
				ey = j;
			}
		}

	if (dvp == 0) {
		printf ("NO\n");
		return 0;
	}

	dfs (ex, ey);

	for (i = 0; i < dvp; ++i) {
		if (in_sub_tree (rx, ry, dvec[i].x, dvec[i].y)
		 && is_separated (rx, ry, dvec[i].x, dvec[i].y))
			ans[ap++] = std::make_pair (dvec[i].x, dvec[i].y);
	}

	if (ap == 0) {
		printf ("NO\n");
		return 0;
	}

	printf ("YES\n");
	printf ("%d\n", ap);
	for (i = 0; i < ap; ++i) {
		nc2tc (ans[i].x, ans[i].y);
		printf ("%d %d\n", ans[i].x, ans[i].y);
	}

/*	for (i = 0; i < N; ++i) {
		for (j = 0; j < N; ++j)
			printf ("(%d %d %d)", prenum[i][j], size[i][j], lowest[i][j]);
		puts ("");
	}
*/
	return 0;
}
