/*
FROM: Balkan Olympiad in Informatics (BOI) 1998 day 2
PROB: conference call (conf)
KEYW: dijkstra with stl heap with optimizations, maintaining path (prev)
*/

#include <cstdio>
#include <cstdlib>
#include <utility>
#include <queue>

const int MAXN = 1 << 7;
const int MAXM = 1 << 14;
const int INF = 1 << 30;
const int PRT = 4;

struct el {
	int to;
	int dist;
	int next;
	el () {}
	el (int _to, int _dist, int _next) : to (_to), dist (_dist), next (_next) {}
};

int N, M;

int vec[MAXN];
el buf[MAXM * 2];

int stp[PRT], dst[PRT][MAXN], prev[PRT][MAXN];

void dijkstra (int id) {
	static std::priority_queue <std::pair <int, int> > q;
	static std::pair <int, int> crnt;
	memset (dst[id], 0x7f, sizeof (dst) / PRT);//fill it with sth close to infinity

	q.push (std::make_pair (0, stp[id]));
	dst[id][stp[id]] = 0;
	prev[id][stp[id]] = -1;

	while (!q.empty ()) {
		crnt = q.top (); q.pop ();
		crnt.first *= -1;
	
		if (crnt.first > dst[id][crnt.second]) continue;
	
		for (int i = vec[crnt.second]; i != -1; i = buf[i].next) {
			if (dst[id][buf[i].to] > crnt.first + buf[i].dist) {
				dst[id][buf[i].to] = crnt.first + buf[i].dist;
				prev[id][buf[i].to] = crnt.second;
				q.push (std::make_pair (-dst[id][buf[i].to], buf[i].to));
			}
		}
	}
}

int main () {
	scanf ("%d %d", &N, &M);

	int i;
	int a, b, c;
	int bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d", &a, &b, &c);
		--a; --b;
		
		buf[bp] = el (b, c, vec[a]);
		vec[a] = bp++;

		buf[bp] = el (a, c, vec[b]);
		vec[b] = bp++;
	}

	scanf ("%d %d %d", stp, stp + 1, stp + 2);
	--stp[0]; --stp[1]; --stp[2];

	for (i = 0; i < 3; ++i) dijkstra (i);

	int best = INF, bsep = -1;
	for (i = 0; i < N; ++i)
		if (best > dst[0][i] + dst[1][i] + dst[2][i]) {
			best = dst[0][i] + dst[1][i] + dst[2][i];
			bsep = i;
		}

//	printf ("%d  %d %d %d\n", bsep, dst[0][bsep], dst[1][bsep], dst[2][bsep]);

	static std::pair <int, int> ans[MAXN];
	int ap = 0;

	for (i = 0; i < 3; ++i) {
		int c = bsep;
		while (prev[i][c] != -1) {
			ans[ap++] = std::make_pair (c, prev[i][c]);
			c = prev[i][c];
		}
	}

	printf ("%d %d\n", best, ap);
	for (i = 0; i < ap; ++i)
		printf ("%d %d\n", ans[i].first + 1, ans[i].second + 1);

	return 0;
}
