/*
FROM: Balkan Olympiad in Informatics (BOI) 1999 day 1
PROB: guarding a gallery
KEYW: geometry, pointer to function
*/

#include <cstdio>
#include <cassert>
#include <algorithm>

const int INF = 2000;
const int MAXN = 1 << 10;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	bool operator == (const pnt &a) const {return x == a.x && y == a.y;}
	pnt simplify () const {return pnt (x > 0 ? 1 : x < 0 ? -1 : 0, y > 0 ? 1 : y < 0 ? -1 : 0);}
};

int minx = INF, miny = INF;
int maxx = -INF, maxy = -INF;

void upd_maxx (int x) {
//	printf ("upd maxx %d\n", x);
	maxx >?= x;
}
void upd_maxy (int y) {
//	printf ("upd maxy %d\n", y);
	maxy >?= y;
}
void upd_minx (int x) {
//	printf ("upd minx %d\n", x);
	minx <?= x;
}
void upd_miny (int y) {
//	printf ("upd miny %d\n", y);
	miny <?= y;
}

typedef void (*upd_fun) (int);

upd_fun updx[4] = {&upd_maxx, &upd_minx, &upd_minx, &upd_maxx};
upd_fun updy[4] = {&upd_miny, &upd_miny, &upd_maxy, &upd_maxy};

int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int N;
pnt vec[MAXN];

int find_id (const pnt &a) {
	if (a == pnt (1, 0)) return 0;
	else if (a == pnt (0, 1)) return 3;
	else if (a == pnt (-1, 0)) return 2;
	else return 1;
}

int main () {
	scanf ("%d", &N);
	int i;
	int overall_minx = INF;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d", &vec[i].x, &vec[i].y);
		overall_minx <?= vec[i].x;
	}

	vec[N] = vec[0];
	for (i = 0; i < N && vec[i].x != overall_minx; ++i);

	assert (vec[i+1].x == overall_minx);
	if (vec[i+1].y > vec[i].y)
		std::reverse (vec, vec + N);

	vec[N] = vec[0];
	vec[N+1] = vec[1];

	int id;
	for (i = 1; i <= N; ++i) {
		if (S (vec[i-1], vec[i], vec[i + 1]) <= 0) continue;
//		printf ("%d %d  %d %d  %d %d\n", vec[i-1].x, vec[i-1].y, vec[i].x, vec[i].y, vec[i+1].x, vec[i+1].y);
	
		id = find_id ((vec[i-1] - vec[i]).simplify ());
//		printf ("%d %d  %d\n", (vec[i-1] - vec[i]).x, (vec[i-1] - vec[i]).y, id);
		updx[id] (vec[i].x);
		updy[id] (vec[i].y);
	}

//	printf ("minx %d\nminy %d\nmaxx %d\nmaxy %d\n", minx, miny, maxx, maxy);
	std::swap (minx, maxx);
	std::swap (miny, maxy);
	if (minx > maxx) {printf ("NO POINT\n"); return 0;}
	if (miny > maxy) {printf ("NO POINT\n"); return 0;}
	printf ("%d %d\n", minx, miny);

	return 0;
}
