/*
FROM: Balkan Olympiad in Informatics (BOI) 1999 day 2
PROB: river highwater
KEYW: dijkstra, late computing of neighbours, A* (a star)
*/

#include <cstdio>
#include <cmath>
#include <queue>
#include <algorithm>

const int MAXN = 1 << 11;
const double INF = 1e10;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	double len (const pnt &a) const {return hypot (x - a.x, y - a.y);}
};

double dst_end[MAXN * 2];
struct q_el {
	int to;
	double dst;
	q_el () {}
	q_el (int _to, double _dst) : to (_to), dst (_dst) {}
	bool operator < (const q_el &a) const {return dst + dst_end[to] > a.dst + dst_end[a.to];}//inverted
};

int N, M, NM;
pnt vec[MAXN * 2];
int idx[MAXN * 2];

int prev[MAXN * 2];
double dst[MAXN * 2];

bool cmp1 (int a, int b) {
	return vec[a].y != vec[b].y ? vec[a].y < vec[b].y : vec[a].x < vec[b].x;
}

bool cmp2 (int a, int b) {
	return vec[a].y < vec[b].y;
}

int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

void dijkstra () {
	static std::priority_queue <q_el> q;
	q_el c;
	int i;
	for (i = 0; i < NM; ++i) dst[i] = INF;

	q.push (q_el (0, 0));
	prev[0] = -1;
	dst[0] = 0;

	while (!q.empty ()) {
		c = q.top (); q.pop ();

		if (c.to == NM-1) break;//we are done
		if (c.dst != dst[c.to]) continue;//we have popped sth old

		pnt lb = pnt (vec[c.to].x - 10, vec[c.to].y),
			rb = pnt (vec[c.to].x + 10, vec[c.to].y);
	
		i = std::upper_bound (idx, idx + NM, c.to, cmp2) - idx;
		for (; i < NM; ++i) {
			if (idx[i] < N) {
				if (S (vec[c.to], rb, vec[idx[i]]) < 0) break;
				if (S (vec[c.to], lb, vec[idx[i]]) > 0) continue;
				lb = vec[idx[i]];
			} else {
				if (S (vec[c.to], lb, vec[idx[i]]) > 0) break;
				if (S (vec[c.to], rb, vec[idx[i]]) < 0) continue;
				rb = vec[idx[i]];
			}
			if (dst[idx[i]] > c.dst + vec[c.to].len (vec[idx[i]])) {
				dst[idx[i]] = c.dst + vec[c.to].len (vec[idx[i]]);
				prev[idx[i]] = c.to;
				q.push (q_el (idx[i], dst[idx[i]]));
			}
		}
	}
}

int main () {
	scanf ("%d %d", &N, &M);
	NM = N + M;

	int i;
	for (i = 0; i < NM; ++i) {
		scanf ("%d %d", &vec[i].x, &vec[i].y);
		idx[i] = i;
	}

	std::sort (idx, idx + NM, cmp1);

	for (i = 0; i < NM; ++i)
		dst_end[i] = vec[NM-1].len (vec[i]);

	dijkstra ();

	static int ans[MAXN * 2], ap;
	int crnt = NM - 1;
	while (crnt != -1) {
		ans[ap++] = crnt;
		crnt = prev[crnt];
	}

	for (i = ap-1; i >= 0; --i)
		printf ("%d %d\n", vec[ans[i]].x, vec[ans[i]].y);

	return 0;
}
