/*
FROM: Balkan Olympiad in Informatics (BOI) 2000 day 2
PROB: bridge
KEYW: dijkstra with stl heap, full exhaustion
*/

#include <cstdio>
#include <cstring>
#include <cmath>
#include <queue>

const int MAXN = 1 << 11;
const int MAXM = 1 << 13;
const int STARTS = 3;
const double INF = 1e10;
const double EPS = 1e-8;

struct el {
	int to;
	double dst;
	int next;
	el () {}
	el (int _to, double _dst, int _next) : to (_to), dst (_dst), next (_next) {}
};

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	double len (const pnt &a) {return hypot (x - a.x, y - a.y);}
};

int N, M;
double Lmax;
pnt coor[MAXN];
int vec[MAXN];
el buf[MAXM * 2];

double dst[STARTS][MAXN];

void dijkstra (int id) {
	static std::priority_queue <std::pair <double, int> > q;
	std::pair <double, int> c;
	int i;
	for (i = 0; i < N; ++i) dst[id][i] = INF;
	q.push (std::make_pair (0.0, id));
	dst[id][id] = 0.0;
	while (!q.empty ()) {
		c = q.top (); q.pop ();
		c.first *= -1;
		if (dst[id][c.second] != c.first) continue;
	
		for (i = vec[c.second]; i != -1; i = buf[i].next) {
			if (dst[id][buf[i].to] > c.first + buf[i].dst + EPS) {
				dst[id][buf[i].to] = c.first + buf[i].dst;
				q.push (std::make_pair (-dst[id][buf[i].to], buf[i].to));
			}
		}
	}
}

int main () {
	scanf ("%d %d %lf", &N, &M, &Lmax);

	int i, j;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &coor[i].x, &coor[i].y);

	int a, b, bp = 0;
	double d;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &a, &b);
		--a; --b;
		d = coor[a].len (coor[b]);

		buf[bp] = el (b, d, vec[a]);
		vec[a] = bp++;
		buf[bp] = el (a, d, vec[b]);
		vec[b] = bp++;
	}

	for (i = 0; i < 3; ++i)
		dijkstra (i);

	double best_sum = dst[0][1] + dst[0][2];//too much
	int bi = -1, bj = -1;
	int ii, jj;
	for (i = 0; i < N; ++i)
		for (j = i + 1; j < N; ++j) {
			d = coor[i].len (coor[j]);
			if (d > Lmax + EPS || fabs (dst[0][i] - dst[0][j]) <= d) continue;
			if (dst[0][i] < dst[0][j]) {
				ii = i;
				jj = j;
			} else {
				ii = j;
				jj = i;
			}

			if (dst[0][ii] + d + dst[1][jj] > dst[0][1] - EPS) continue;
			if (dst[0][ii] + d + dst[2][jj] > dst[0][2] - EPS) continue;
			if (best_sum > (dst[0][ii] + d) * 2 + dst[1][jj] + dst[2][jj]) {
				best_sum = (dst[0][ii] + d) * 2 + dst[1][jj] + dst[2][jj];
				bi = i;
				bj = j;
			}
		}

	if (best_sum == dst[0][1] + dst[0][2])
		printf ("0 0\n%lf %lf\n", dst[0][1], dst[0][2]);
	else
		printf ("%d %d\n", bi + 1, bj + 1);

	return 0;
}
