/*
FROM: Balkan Olympiad in Informatics (BOI) 2002 day 1
PROB: tour
KEYW: strongly connected components (SCC), complete directed graph, building all cycles in a SCC
NOTE: It seems that in a SCC of size P of a complete directed graph there can be built cycles with every length <= P
*/

#include <cstdio>
#include <cassert>
#include <list>
#include <utility>
#include <ext/hash_map>

const int MAXN = 1 << 10;

int N, K;
bool ma3x[MAXN][MAXN];

int postnum[MAXN], pnref[MAXN];
int group[MAXN], grc, _cgs;

std::list <int> cycle;
bool to_cycle[MAXN], from_cycle[MAXN], in_cycle[MAXN];

void dfs1 (int a) {
	static int cpn = 0;
	postnum[a] = -2;
	for (int i = 0; i < N; ++i)
		if (ma3x[a][i] && postnum[i] == -1)
			dfs1 (i);
	pnref[cpn] = a;
	postnum[a] = cpn++;
}

void dfs2 (int a) {
	group[a] = grc;
	++_cgs;
	for (int i = 0; i < N; ++i)
		if (ma3x[i][a] && !group[i])
			dfs2 (i);
}

typedef std::pair <long long, long long> _16b_t;
typedef __gnu_cxx::hash_multimap <int, _16b_t> map_t;
typedef map_t::iterator it_map_t;

map_t map_fr, map_to;

template <typename RES, typename SRC>
RES crack_type (const SRC &x) {return *((RES*)&x);}

void remove_edges (map_t &cmap, int key, map_t &omap) {
	std::pair <it_map_t, it_map_t> range = cmap.equal_range (key);

	for (it_map_t it = range.first; it != range.second;) {
		omap.erase (crack_type <it_map_t, _16b_t> (it->second));
		it_map_t tmp = it++;
		cmap.erase (tmp);
	}
}

void add_edge (int fr, int to) {
	it_map_t fr_it = map_fr.insert (std::make_pair (fr, _16b_t ()));
	it_map_t to_it = map_to.insert (std::make_pair (to, _16b_t ()));
	fr_it -> second = crack_type <_16b_t, it_map_t> (to_it);
	to_it -> second = crack_type <_16b_t, it_map_t> (fr_it);
}

void print_all_edges () {
	for (it_map_t it = map_fr.begin (); it != map_fr.end (); ++it)
		printf ("%d -> %d\n", it->first, (crack_type <it_map_t, _16b_t> (it->second))->first);
}

std::pair <int, int> take_one_edge () {
	return std::make_pair (map_fr.begin () -> first, (crack_type <it_map_t, _16b_t> (map_fr.begin () -> second))->first);
}

void add_to_cycle (int a) {
	//this function updates information ONLY in from_cycle, to_cycle, in_cycle BUT NOT in cycle
	in_cycle[a] = 1;
	for (int i = 0; i < N; ++i)
		if (group[i] == grc && !in_cycle[i])
			if (ma3x[a][i]) {
				from_cycle[i] = 1;
				if (to_cycle[i] == 1)
					remove_edges (map_to, i, map_fr);
			} else {
				to_cycle[i] = 1;
				if (from_cycle[i] == 1)
					remove_edges (map_fr, i, map_to);
			}

	from_cycle[a] = 0;
	to_cycle[a] = 0;
}

int main () {
	scanf ("%d %d", &N, &K);

	int i, j = -1;
	int a, b;
	for (i = 0; i < N * (N-1) / 2; ++i) {
		scanf ("%d %d", &a, &b);
		ma3x[--a][--b] = 1;
	}

	memset (postnum, -1, sizeof (postnum));
	for (i = 0; i < N; ++i)
		if (postnum[i] == -1)
			dfs1 (i);

	for (i = N-1; i >= 0; --i)
		if (!group[pnref[i]]) {
			++grc;
			_cgs = 0;
			dfs2 (pnref[i]);
			if (_cgs >= K)
				break;//we have found the SCC we need
		}

	if (i == -1) {//there is no solution coz every SCC has size < K
		printf ("0\n");
		return 0;
	}

//	for (i = 0; i < N; ++i) if (group[i] == grc) printf (" %d", i); puts ("");

	//find a starting triangle
	a = pnref[i];//this is from the CSS

	//build the two sets
	cycle.push_back (a); add_to_cycle (a);

	//find all edges from set from_cycle to set to_cycle
	for (i = 0; i < N; ++i) {
		if (!from_cycle[i]) continue;
		for (j = 0; j < N; ++j)
			if (ma3x[i][j] && to_cycle[j])
				add_edge (i, j);
	}

//	print_all_edges ();
	std::pair <int, int> edge = take_one_edge ();

	remove_edges (map_fr, edge.first, map_to);
	remove_edges (map_to, edge.second, map_fr);
	cycle.push_back (edge.first); add_to_cycle (edge.first);
	cycle.push_back (edge.second); add_to_cycle (edge.second);

	std::list <int> :: iterator ii;
	int _bad_cnt = 0;
	for (int l = 4; l <= K; ++l) {
		for (i = 0; i < N; ++i)
			if (from_cycle[i] && to_cycle[i])
				break;

		if (i != N) {//simple case -> only add
			a = i;
			bool prev_from = ma3x[*cycle.begin ()][a];
			for (ii = ++cycle.begin (); ii != cycle.end (); ++ii)
				if (ma3x[a][*ii] && prev_from) break;
				else prev_from = ma3x[*ii][a];

			if (ii != cycle.end ()) {
				cycle.insert (ii, a); add_to_cycle (a);
			} else {
				assert (ma3x[*(--cycle.end ())][a] && ma3x[a][*cycle.begin ()]);
				cycle.insert (cycle.end (), a); add_to_cycle (a);
			}
		} else {//bad case -> add 2 and remove 1
			++_bad_cnt;
			edge = take_one_edge ();
			b = *cycle.begin ();//this is going to be removed -> it should not be in the maps coz it will be added shortly in a simple case
			in_cycle[b] = 0;
			from_cycle[b] = to_cycle[b] = 1;
			
			cycle.erase (cycle.begin ());
			cycle.insert (cycle.begin (), edge.second); add_to_cycle (edge.second);
			cycle.insert (cycle.begin (), edge.first); add_to_cycle (edge.first);
		}
	}

	for (std::list <int> :: iterator ii = cycle.begin (); ii != cycle.end (); ++ii)
		printf (" %d", *ii);
	puts ("");
	fprintf (stderr, "%d\n", _bad_cnt);

	return 0;
}
