/*
FROM: Balkan Olympiad in Informatics
PROB: company (comp)
KEYW: tree, conversions, hardcoding
*/

#include <cstdio>
#include <cassert>
#include <vector>
#include <algorithm>

const int MAXN = 1 << 14;

struct perm;
struct state;

struct perm {
	int t[3];
	perm () {t[0] = 0; t[1] = 1; t[2] = 2;}
	perm (int _a, int _b, int _c) {t[0] = _a, t[1] = _b; t[2] = _c;}
	perm (const state &s1, const state &s2, const perm &p);
	perm apply (const perm &p) const {
		perm ret;
		ret.t[0] = t[p.t[0]];
		ret.t[1] = t[p.t[1]];
		ret.t[2] = t[p.t[2]];
//		printf ("%d %d %d  %d %d %d apply %d %d %d\n", t[0], t[1], t[2], p.t[0], p.t[1], p.t[2], ret.t[0], ret.t[1], ret.t[2]);
		return ret;
	}
	perm& operator = (const perm &p) {memcpy (t, p.t, sizeof (t)); return *this;}
};

struct state {
	int a[4];
	state () {a[0] = 0; a[1] = 1; a[2] = a[3] = 2;}
	state& operator = (const state &s) {memcpy (a, s.a, sizeof (a)); return *this;}
	state (const state &s, const perm &p); 
	int& cnt () {return a[3];}
	const int& cnt () const {return a[3];}
};

perm::perm (const state &s1, const state &s2, const perm &p) {
//	printf ("(%d %d)%d %d %d  %d %d %d  %d %d %d -->", s1.cnt (), s2.cnt (), s1.a[0], s1.a[1], s1.a[2], s2.a[0], s2.a[1], s2.a[2], p.t[0], p.t[1], p.t[2]);
	t[s2.a[0]] = s1.a[p.t[0]];
	t[s2.a[1]] = s1.a[p.t[1]];
	t[s2.a[2]] = s1.a[p.t[2]];
//	printf ("%d %d %d\n", t[0], t[1], t[2]);
}

state::state (const state &s, const perm &p) {
	a[0] = s.a[p.t[0]];
	a[1] = s.a[p.t[1]];
	a[2] = s.a[p.t[2]];
//	printf ("st %d %d %d  %d %d %d >>> %d %d %d\n", s.a[0], s.a[1], s.a[2], p.t[0], p.t[1], p.t[2], a[0], a[1], a[2]);
}

int N;
int prev[MAXN];
std::vector <int> kids[MAXN];
perm change[MAXN];
state states[MAXN];
int _c[3];
int col[MAXN];

void set_prev (int a, int b = -1) {
//	printf ("set prev %d %d\n", a, b);
	static int r;
	static int ac, bc;
	static perm cc;
	r = prev[a];
	if (b == -1) {//one child
		//change is normal (no change)
		states[r].a[0] = states[a].a[2];
		states[r].a[1] = states[a].a[0];
		states[r].a[2] = states[a].a[1];
		states[r].cnt () = (states[a].cnt () + 2) % 3;
	} else {//two children
		ac = states[a].cnt ();
		bc = states[b].cnt ();
		bool flip = ac < bc;
		if (flip) std::swap (ac, bc), std::swap (a, b);

		if 		  (ac == 0 && bc == 0) {
			cc = perm (states[a], states[b], perm (1, 0, 2));
			states[r] = state (states[a], perm (2, 0, 1));
		} else if (ac == 1 && bc == 0) {
			cc = perm (states[a], states[b], perm (1, 0, 2));
			states[r] = state (states[a], perm (2, 0, 1));
		} else if (ac == 2 && bc == 0) {
			cc = perm (states[a], states[b], perm (2, 0, 1));
			states[r] = state (states[a], perm (1, 0, 2));
		} else if (ac == 1 && bc == 1) {
			cc = perm (states[a], states[b], perm (2, 0, 1));
			states[r] = state (states[a], perm (1, 0, 2));
		} else if (ac == 2 && bc == 1) {
			cc = perm (states[a], states[b], perm (1, 2, 0));
			states[r] = state (states[a], perm (2, 0, 1));
		} else if (ac == 2 && bc == 2) {
			cc = perm (states[a], states[b], perm (1, 0, 2));
			states[r] = state (states[a], perm (2, 0, 1));
		} else {
			assert (0);
		}
		change[b] = cc;
		states[r].cnt () = (ac + bc + 2) % 3;
//		printf ("%d %d %d <-- %d %d %d  %d\n", cc.t[0], cc.t[1], cc.t[2],\
		states[r].a[0], states[r].a[1], states[r].a[2], states[r].a[3]);
	}
}

void solve (int v) {
	if (kids[v].size () == 0) return;
	solve (kids[v][0]);
	if (kids[v].size () == 2) {
		solve (kids[v][1]);
		set_prev (kids[v][0], kids[v][1]);
	} else
		set_prev (kids[v][0]);
}

void calc_col (int v, perm p = perm ()) {
	p = p.apply (change[v]);
	col[v] = p.t[states[v].a[0]];
	++_c[col[v]];
	if (kids[v].size () == 1) {
		calc_col (kids[v][0], p);
		assert (col[v] != col[kids[v][0]]);
	} else if (kids[v].size () == 2) {
		calc_col (kids[v][0], p);
		calc_col (kids[v][1], p);
		assert (col[v] != col[kids[v][0]]);
		assert (col[v] != col[kids[v][1]]);
	}
}

int main () {
	scanf ("%d", &N);

	int i;
	int a, b;
	for (i = 1; i < N; ++i) {
		scanf ("%d %d", &a, &b);
		--a; --b;
		prev[a] = b;
		kids[b].push_back (a);
	}

	solve (0);
/*	for (i = 0; i < N; ++i) {
		printf ("%d -- %d %d %d _ %d %d %d _ %d\n", i
		, change[i].t[0], change[i].t[1], change[i].t[2]
		, states[i].a[0], states[i].a[1], states[i].a[2]
		, states[i].a[3]);
	}
*/
/*
	for (i = 0; i < N; ++i) {
		_c[0] = _c[1] = _c[2] = 0;
		calc_col (i);
		assert ((_c[0] >? _c[1] >? _c[2]) - (_c[0] <? _c[1] <? _c[2]) < 3);
	}
*/
	calc_col (0);
	for (i = 1, printf ("%d", col[0] + 1); i < N; ++i) printf (" %d", col[i] + 1); puts ("");

	return 0;
}
