/*
FROM: Balkan Olympiad in Informatics (BOI) 2004 day 1
PROB: path
KEYW: A*, A-star, dijkstra with stl heap, with module
*/

#include "path_mod.h"

#include <cstdio>
#include <cassert>
#include <cmath>
#include <queue>

struct pos {
	int x, y;
	pos () {}
	pos (int _x, int _y) : x (_x), y (_y) {}
};

struct heap {
	int to;
	double to_dist;
	heap (int _to, double _to_dist) : to (_to), to_dist (_to_dist) {}
	bool operator < (const heap &a) const;
};

const int MAXN = 1 << 13;
const double INF = 1e10;
const double EPS = 1e-6;

int N, S, F;
int ks[MAXN];
double dst[MAXN];
double dst_to_end[MAXN];
int prev[MAXN];
pos coor[MAXN];

bool heap::operator < (const heap &a) const {
	return to_dist + dst_to_end[to] > a.to_dist + dst_to_end[a.to];//inverted
}

double calc_dst (int id1, int id2) {
	return hypot (coor[id1].x - coor[id2].x, coor[id1].y - coor[id2].y);
}

int ans[MAXN], ap;

void dijkstra () {
	static std::priority_queue <heap> q;
	static heap crnt (-1, -1.);
	int i, go;
	double tmp;

	getXYM (S + 1, &coor[S].x, &coor[S].y, ks + S);
	dst_to_end[S] = calc_dst (S, F);
	
	prev[S] = -1;
	dst[S] = 0;

	q.push (heap (S, 0));

	while (!q.empty ()) {
		crnt = q.top (); q.pop ();
		if (crnt.to == F)
			break;
		if (dst[crnt.to] != crnt.to_dist) continue;
//		printf ("popped %d %lf\n", crnt.to, crnt.to_dist);
		for (i = 0; i < ks[crnt.to]; ++i) {
			go = getAdj (crnt.to + 1) - 1;
			if (prev[go] == -1 && go != F) {//not in queue
				getXYM (go + 1, &coor[go].x, &coor[go].y, ks + go);
				dst_to_end[go] = calc_dst (go, F);
//				printf ("\t!!! dst_to_end[%d] -- %lf\n", go, dst_to_end[go]);
			}

			if (dst[go] > (tmp = (crnt.to_dist + calc_dst (crnt.to, go))) + EPS) {
				dst[go] = tmp;
//				printf ("\tpush %d %lf (%lf)\n", go, dst[go], dst[go] + dst_to_end[go]);
				prev[go] = crnt.to;
				q.push (heap (go, dst[go]));
			} else {
//				printf ("\tfailed to push %d\n", go);
			}
		}
	}

	assert (crnt.to == F);
	for (int crnt = F; crnt != -1; crnt = prev[crnt])
		ans[ap++] = crnt;

	done (ap);
	for (i = ap-1; i >= 0; --i)
		report (ans[i] + 1);
}

int main () {
	start (&N, &S, &F);
	--S; --F;

	int i;
	memset (prev, -1, sizeof (prev));
	for (i = 0; i < N; ++i) dst[i] = INF;

	getXYM (F + 1, &coor[F].x, &coor[F].y, ks + F);

	dijkstra ();

	return 0;
}
