/*
FROM: Central European Olympiad in Informatics (CEOI) 2000 day 1
PROB: falling
KEYW: map, dynamical programming
*/

#include <cstdio>
#include <cassert>

#include <map>
#include <algorithm>
#include <ext/numeric>

const int MAXN = 1 << 10;
const int INF = 1 << 20;

struct val {
	int t;
	int pl;
	val (int _t, int _pl) : t (_t), pl (_pl) {}
};

typedef std::map <int, val> tree_type;
typedef tree_type::iterator tree_iter;

int N;
//int bH, bX;
int MF;

int H[MAXN];
int X[MAXN][2];
int prev[MAXN * 2];

bool cmp (int a, int b) {
	return H[a] > H[b];//higher first
}

int main () {
	scanf ("%d", &N);
	scanf ("%d %d %d", &X[N][0], &H[N], &MF);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d %d %d", &X[i][0], &X[i][1], &H[i]);
/*
	X[N][0] = -INF; X[N][1] = INF; H[N][0] = 0;
	++N;//add the bottom platform
*/
	static int idx[MAXN];
	__gnu_cxx::iota (idx, idx + N, 0);
	std::sort (idx, idx + N, cmp);

	tree_type falls;
	tree_iter lb, rb;
	falls.insert (std::make_pair (X[N][0], val (0, N * 2)));

	int t1, t2;
	int fall_id, fall_h, fall_x;
	int c, tmp;
	for (i = 0; i < N; ++i) {
		c = idx[i];

		t1 = INF, t2 = INF;
		lb = falls.lower_bound (X[c][0]);
		rb = falls.upper_bound (X[c][1]);

		for (tree_iter it = lb; it != rb; ++it) {
			fall_id = it->second.pl / 2;
			fall_h = H[fall_id];
			fall_x = X[fall_id][it->second.pl % 2];
//			printf ("platform %d caught %d %d %d (%d)\n", c, fall_id, fall_h, fall_x, it->second.t);
			if (fall_h > H[c] + MF) continue;//it will break
			assert (fall_x >= X[c][0]);
			assert (fall_x <= X[c][1]);
			if (t1 > (tmp = it->second.t + fall_h - H[c] + fall_x - X[c][0])) {
				t1 = tmp;
				prev[c * 2] = it->second.pl;
			}
			if (t2 > (tmp = it->second.t + fall_h - H[c] + X[c][1] - fall_x)) {
				t2 = tmp;
				prev[c * 2 + 1] = it->second.pl;
			}
		}
		falls.erase (lb, rb);
		if (t1 == INF || t2 == INF)
			assert (t1 == INF && t2 == INF);
		else {
//			printf ("push %d %d %d\npush %d %d %d\n", X[c][0], t1, c * 2, X[c][1], t2, c * 2 + 1);
			//falls[X[c][0]] = val (t1, c * 2);
			falls.insert (std::make_pair (X[c][0], val (t1, c * 2)));
			//falls[X[c][1]] = val (t2, c * 2 + 1);
			falls.insert (std::make_pair (X[c][1], val (t2, c * 2 + 1)));
		}
	}

	t1 = INF;
	int best_id = -1;
	for (tree_iter it = falls.begin (); it != falls.end (); ++it) {
//		printf ("final caught %d %d %d (xht)\n", it->first, H[it->second.pl / 2], it->second.t);
		if (H[it->second.pl / 2] <= MF
		 && t1 > (tmp = it->second.t + H[it->second.pl / 2])) {
			t1 = tmp;
			best_id = it->second.pl;
		}
	}

	assert (best_id != -1);

	static int ans[MAXN], ap;
	int id = best_id;
	while (id != 2 * N) {
//		printf (" %d", id);
		ans[ap++] = id;
		id = prev[id];
	}

	printf ("%d\n", t1);
	int fall_t = 0;
	fall_h = H[N];
	fall_x = X[N][0];
	for (i = ap - 1; i >= 0; --i) {
		fall_t += fall_h - H[ans[i] / 2];
		printf ("%d %d %d\n", ans[i] / 2 + 1, fall_t, ans[i] % 2);
		fall_t += abs (fall_x - X[ans[i] / 2][ans[i] % 2]);
		fall_x = X[ans[i] / 2][ans[i] % 2];
		fall_h = H[ans[i] / 2];
	}

	return 0;
}
