/*
FROM: Central European Olympiad in Informatics (CEOI) 2000 day 2
PROB: landscape (landsc)
KEYW: dynamical programming, geometry, hard
*/

#include <cstdio>

const int MAXP = 1 << 8;
const int MAXB = 1 << 8;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
};

int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

struct frac {
	int nom, den;
	frac (int _nom = 0, int _den = 1) : nom (_nom), den (_den) {}
	frac (const pnt &base, const pnt &hrz, const pnt &p1, const pnt &p2)
	 : nom (S (p1, hrz, base)), den (S (p2, base, hrz) + nom) {}

	bool is_one () const {return nom == den;}
	bool is_zero () const {return !nom;}
	bool operator < (const frac &a) {
		return (long long)nom * a.den < (long long)den * a.nom;
	}
	bool check (const frac &a) {
		long long nnom = (long long)nom * a.den + (long long)den * a.nom;
		long long nden = (long long)den * a.den;
		return nnom > nden;
	}
};


int P, B;
pnt peaks[MAXP];
pnt bulbs[MAXB];

frac lt[MAXB][MAXP];
frac rt[MAXB][MAXP];
int lti[MAXB], rti[MAXB];
int dp[MAXB];

bool see_everything (int id1, int id2) {
	int i;
	for (i = rti[id1] + 1; i < lti[id2]; ++i) {
		if (rt[id1][i].is_zero ()
		 || lt[id2][i].is_one ()) continue;

		printf ("check %d %d %d\n", id1, id2, i);
		if (rt[id1][i] < lt[id2][i])
			continue;
		printf ("BAD\n");
		break;
	}
	printf ("check %d %d (%d)---> %d\n", id1, id2, i, i == lti[id2]);
	return i == lti[id2];
}

int main () {
	scanf ("%d", &P);

	int i, j;
	for (i = 0; i < P; ++i)
		scanf ("%d %d", &peaks[i].x, &peaks[i].y);

	scanf ("%d %d", &B, &bulbs[1].y);
	for (i = 1; i <= B; ++i) {
		scanf ("%d", &bulbs[i].x);
		bulbs[i].y = bulbs[1].y;
	}

	//right
	pnt hrz;//horizon
	for (i = 1; i <= B; ++i) {
		for (j = 0; j < P - 1 && peaks[j].x <= bulbs[i].x; ++j)
			rt[i][j] = frac (1);//nothing

		rti[i] = j-1; rt[i][j-1] = frac ();//everything but useless
//		printf ("i j %d %d\n", i, j - 1);
		if (j == P - 1) continue;

		hrz = peaks[j];
		for (++j; j < P; ++j) {
			int s = S (bulbs[i], hrz, peaks[j]);
			if (s <= 0)
				rt[i][j-1] = frac (1);//nothing is seen
			else {
				rt[i][j-1] = frac (bulbs[i], hrz, peaks[j - 1], peaks[j]);
				hrz = peaks[j];
			}
		}
	}
//	printf ("--------\n");

	//left
	for (i = 1; i <= B; ++i) {
		for (j = P - 2; j >= 0 && peaks[j].x >= bulbs[i].x; --j)
			lt[i][j] = frac ();//nothing

		lti[i] = j;
		printf ("i j %d %d\n", i, j);
		if (j == -1) continue;

		hrz = peaks[j];
		lt[i][j] = frac (1);//everything
		for (--j; j >= 0; --j) {
			int s = S (bulbs[i], hrz, peaks[j]);
			printf ("j, s %d %d (%d %d  %d %d  %d %d)\n", j, s, bulbs[i].x, bulbs[i].y, hrz.x, hrz.y, peaks[j].x, peaks[j].y);
			if (s >= 0)
				lt[i][j] = frac ();//nothing is seen
			else {
				lt[i][j] = frac (bulbs[i], hrz, peaks[j], peaks[j + 1]);
				printf ("\t%d %d\n", lt[i][j].nom, lt[i][j].den);
				hrz = peaks[j];
			}
		}
	}

	for (i = 1; i <= B; ++i)
		for (j = 0; j <= P-2; ++j)
			printf ("%d %d -- %d/%d(%d)  %d/%d(%d)\n", i, j, rt[i][j].nom, rt[i][j].den, rti[i], lt[i][j].nom, lt[i][j].den, lti[i]);

	rti[0] = -1;
	lti[B+1] = P - 1;
	for (i = 0; i < P-1; ++i) {
		rt[0][i] = frac (1);
		lt[B+1][i] = frac (0); 
	}

	for (i = 0; i <= B+1; ++i)
		dp[i] = B;

	int l, r, m;
	dp[0] = 0;
	for (i = 0; i <= B; ++i) {
		l = i+1, r = B+2;
		while (l + 1 < r) {
			printf ("lr %d %d\n", l, r);
			m = (l + r) / 2;
			if (see_everything (i, m))
				l = m;
			else
				r = m;
		}
		printf ("lr %d %d\n", l, r);
		printf ("%d --> %d\n", i, l);
		for (j = i + 1; j <= l; ++j)
			dp[j] <?= dp[i] + 1;
	}

	printf ("%d\n", dp[B+1] - 1);

	return 0;
}
