/*
FROM: Central European Olympiad in Informatics (CEOI) 2001 day 2
PROB: bitmap
KEYW: bfs, memory optimizations, DAMN
*/

#include <cstdio>
#include <cstdlib>
#include <cstring>

const int MAXN = 10010;
const int MAXM = 1 << 10;//1024
const int MAX_CIR_Q_LEN = 5000000;//5 M
const int MAX_NORM_Q_LEN = 1 << 14;

typedef unsigned short ushort;
typedef unsigned uint;

const ushort MASK_Y = 0x3ff;
const ushort MASK_D = 0xc00;
const ushort MASK_YD = MASK_Y | MASK_D;
const ushort BITS_Y = 10;
const ushort ONE_D = 0x400;
const ushort TRE_D = 0xc00;

struct pos {
	ushort x, y;
	pos () {}
	pos (const pos &a) : x (a.x), y (a.y) {}
	pos (ushort _x, ushort _y) : x (_x), y (_y) {}
	bool operator == (const pos &a) const {return x == a.x && y == a.y;}
	void operator += (const pos &a) {x += a.x; y += a.y;}
};

const pos dnxt[4] = {pos (0, 1), pos (-1, 0), pos (0, -1), pos (1, 0)};
const pos dnxt2[4] = {pos (1, 1), pos (-1, 1), pos (-1, -1), pos (1, -1)};
const pos ddir[4] = {pos (1, 0), pos (0, 1), pos (-1, 0), pos (0, -1)};

struct q_el {
	ushort _x, _y_d;
	q_el () {}
	q_el (const pos &a, ushort d) : _x (a.x), _y_d (a.y | (d << BITS_Y)) {}
	q_el (const q_el &a) : _x (a._x), _y_d (a._y_d) {}

	bool operator == (const q_el &a) const {return _x == a._x && _y_d == a._y_d;}
	void set_x (ushort x) {_x = x;}
	void set_y (ushort y) {_y_d &= ~MASK_Y; _y_d |= y;}
	void set_xy (const pos &a) {set_x (a.x); set_y (a.y);}
	void set_d (ushort d) {_y_d &= ~MASK_D; _y_d |= d;}

	ushort x () const {return _x;}
	ushort y () const {return _y_d & MASK_Y;}
	ushort d () const {return (_y_d & MASK_D) >> BITS_Y;}

	void inc_d () {_y_d += ONE_D; _y_d &= MASK_YD;}
	void dec_d () {_y_d += TRE_D; _y_d &= MASK_YD;}

	pos to_pos () const {return pos (x (), y ());}
};

int N, M;
struct bitmap {
	uint m[MAXN * MAXM / 32];
	bitmap () {memset (m, 0, sizeof (m));}
	void reset () {memset (m, 0, sizeof (m));}

	void set (const pos &a) {m[((int)a.x * MAXM + (int)a.y) >> 5] |= 1 << (((int)a.x * MAXM + (int)a.y) & 0x1f);}
	bool get (const pos &a) {return a.x >= N || a.y >= M ? 0 : (m[((int)a.x * MAXM + (int)a.y) >> 5] >> (((int)a.x * MAXM + (int)a.y) & 0x1f)) & 1;}
};

bitmap used;
bitmap brd;
bitmap bad;
int _tot_c, _bad_c;

void bfs_norm (const pos &start) {
	static pos q[MAX_NORM_Q_LEN];
	static int p2, p3, i;
	static pos go;
	bool is_bad = 0;
	p2 = p3 = 0;

	q[p3++] = start;
	used.set (start);

	while (p2 != p3) {
//		printf ("popped %hu %hu\n", q[p2].x, q[p2].y);
		if (bad.get (q[p2])) is_bad = 1;
		for (i = 0; i < 4; ++i) {
			go = pos (q[p2]);
			go += ddir[i];
//			printf ("\t!!to push %hu %hu\n", go.x, go.y);
			if (go.x < N && go.y < M
			 && brd.get (go)
			 && !used.get (go)) {
//				printf ("\tpush %hu %hu\n", go.x, go.y);
				used.set (go);
				q[p3++] = go;
				p3 &= MAX_NORM_Q_LEN - 1;
			}
		}
		++p2;
		p2 &= MAX_NORM_Q_LEN - 1;
	}

	++_tot_c;
	_bad_c += is_bad;
}

void bfs_cir (const pos &start) {
	static q_el q[MAX_CIR_Q_LEN];
	static int i, p3;
	static pos t1, t2;
	static q_el go;
	q_el start_el (start, 0);
	q[p3 = 0, p3++] = q_el (start, 0);

	int _gtc = 0, _btc = 0;
	for (i = 0;; ++i) {
//		printf ("crnt %hd %hd -- %hd\n", q[i].x (), q[i].y (), q[i].d ());
		t1 = q[i].to_pos ();
		t1 += dnxt[q[i].d ()];
		if (brd.get (t1)) {
			t2 = q[i].to_pos ();
			t2 += dnxt2[q[i].d ()];
//			printf ("t1 t2 %hd %hd, %hd %hd\n", t1.x, t1.y, t2.x, t2.y);
			if (brd.get (t2)) {
				go = q[i];
				go.dec_d ();
				go.set_x (t2.x);
				go.set_y (t2.y);
				++_btc;
			} else {
				go = q[i];
				go.set_x (t1.x);
				go.set_y (t1.y);
			}
		} else {
			++_gtc;
			go = q[i];
			go.inc_d ();
		}
//		printf ("\t go %hd %hd %hd\n", go.x (), go.y (), go.d ());
		if (go == start_el) break;
		q[p3++] = go;
//		if (i == 10) break;
	}
//	printf ("BREAK!!!!!!!!!\n");
//	exit (-1);
	_gtc -= _btc;
	if (_gtc > 0) return;//it is good;
	for (i = 0; i < p3; ++i)
		bad.set (q[i].to_pos ());
}

int main () {
	scanf ("%d %d", &N, &M);

	ushort i, j;
	int w, b;
	int cpos;
	for (i = 0; i < N; ++i) {
		cpos = 0;
		scanf ("%d", &w);
		while (w != -1) {
			scanf ("%d", &b);
			for (b += cpos += w; cpos < b; ++cpos)
				brd.set (pos (i, cpos));

			scanf ("%d", &w);
		}
	}
/*
	for (i = 0; i < N; ++i) {
		for (j = 0; j < M; ++j)
			putchar (brd.get (pos (i, j)) ? '#' : '.');
		putchar ('\n');
	}
	putchar ('\n');
*/
	for (i = 0; i < N - 1; ++i)
		for (j = 0; j < M; ++j)
			if (!used.get (pos (i, j))
			 && brd.get (pos (i, j))
			 && !brd.get (pos (i + 1, j)))
				bfs_cir (pos (i, j));

	used.reset ();
	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j)
			if (brd.get (pos (i, j))
			 && !used.get (pos (i, j))) {
				bfs_norm (pos (i, j));
/*				for (int ii = 0; ii < N; ++ii) {
					for (int jj = 0; jj < M; ++jj)
						putchar (used.get (pos (ii, jj)) ? '#' : '.');
					putchar ('\n');
				}
				putchar ('\n');*/
			}

	printf ("%d\n%d\n", _tot_c, _tot_c - _bad_c);

	return 0;
}
