/*
FROM: Central European Olympiad in Informatics (CEOI) 2002 day 2
PROB: dwarfs
KEYW: bynary search with 2 lookup (m, m+1)
*/

#include <cstdio>
#include <cmath>
#include <algorithm>

const int MAXN = 1 << 17;
const double EPS = 1e-6;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}
	pnt operator - (const pnt &a) {return pnt (x - a.x, y - a.y);}
	double sq () {return x * x + y * y;}
};

int N;
pnt vec[MAXN];
int hid[MAXN], hsz;
pnt a, b;

double S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

double D (int id) {
	return S (a, b, vec[hid[id]]);
}

int find_slope (int id1, int id2) {
	return (D (id2) - D (id1) >= 0) * 2 - 1;
}

double bsrch (int coef) {
//	printf ("bsrch %d\n", coef);
	int l = 0, r = hsz - 1, m;
	int bslope = find_slope (0, 1), cslope, tslope;
	while (l + 1 < r) {
		m = (l + r) / 2;
		cslope = find_slope (m, m + 1);
		tslope = find_slope (0, m);
		if (cslope == bslope && cslope == tslope)
			l = m;
		else if (cslope == bslope && cslope != tslope)
			r = m;
		else if (cslope * coef > 0)
			l = m;
		else
			r = m;
	}

/*	printf ("%e ", D (0));
	for (int i = 1; i < hsz; ++i) printf ("%c %e ", find_slope (i-1, i) > 0 ? '/' : '\\', D (i));
	puts ("");
	printf ("%e %e(%d) %e\n", D (0), D (r), r, D (hsz-1));
	if (coef > 0)//maxinum
		printf ("%e ---\n", D (0) >? D (r) >? D (hsz-1));
	else//minimum
		printf ("%e ---\n", D (0) <? D (r) <? D (hsz-1));
*/
	if (coef > 0)//maxinum
		return D (0) >? D (r) >? D (hsz-1);
	else//minimum
		return D (0) <? D (r) <? D (hsz-1);
}

int _fpi;
bool cmp (int id1, int id2) {
	static double tmp;
	return fabs (tmp = S (vec[_fpi], vec[id1], vec[id2])) > EPS ?
			tmp > 0:
			(vec[id1] - vec[_fpi]).sq ()
				<
			(vec[id2] - vec[_fpi]).sq ();
}

void hull () {
	int i;
	for (i = 1; i < N; ++i) {
		hid[i] = i;
		if (vec[i].y < vec[_fpi].y
		 || vec[i].y == vec[_fpi].y && vec[i].x > vec[_fpi].x) {
			_fpi = i;
		}
	}
	
	hid[_fpi] = 0;
	hid[0] = _fpi;

	std::sort (hid + 1, hid + N, cmp);

	hsz = 2;
	for (i = 2; i < N; ++i) {
		while (hsz > 1 && S (vec[hid[hsz-2]], vec[hid[hsz-1]], vec[hid[i]]) < EPS)
			--hsz;
		hid[hsz++] = hid[i];
	}
}

int main () {
	scanf ("%d", &N);

	if (N == 0)
		goto nxt;

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	hull ();
/*	for (i = 0; i < hsz; ++i) {
		printf ("%lf %lf\n", vec[hid[i]].x, vec[hid[i]].y);
	}
*/
	nxt:;
	while (scanf (" %lf %lf %lf %lf", &a.x, &a.y, &b.x, &b.y) == 4) {
		if (N == 0) printf ("GOOD\n");
		else
//		printf ("-----\n");
		printf ("%s\n", (bsrch (-1) * bsrch (1) < 0) ? "BAD" : "GOOD");
	}

	return 0;
}
