/*
FROM: Central European Olympiad in Informatics (CEOI) 2002 day 
PROB: guards
KEYW: dinitz max flow
*/

#include <cstdio>
#include <cstring>

const int MAXC = 1 << 8;
const int MAXE = 1 << 16;

typedef unsigned short ushort;

struct el {
	int to;
	bool rd;
	int next;
	el () {}
	el (int _to, bool _rd, int _next) : to (_to), rd (_rd), next (_next) {}
};

int N, M;
ushort hor_s[MAXC][MAXC];
ushort ver_s[MAXC][MAXC];
int edge_id[MAXC][MAXC];

int E;//vertical + horizontal stripes + source + sink
int vec[MAXE];//MAX_HOR + MAX_VER + source + sink == MAXE
el buf[MAXE * 4];//(MAX_HOR + MAX_VER) * 2 + MAX_INTERNAL_EDGE * 2 == MAXE * 2 * 2
int D[MAXE];
int source, sink;

char brd[MAXC][MAXC];
int _back_D_source;
int edge_l[MAXE], elp;

bool bfs () {
	static int q[MAXE], p3, i, j;
	memset (D, -1, sizeof (D));

	q[p3 = 0, p3++] = sink;
	D[sink] = 0;
	for (i = 0; i < p3; ++i) {
//		printf ("popped %d\n", q[i]);
		for (j = vec[q[i]]; j != -1; j = buf[j].next) {
			if (D[buf[j].to] == -1 && !buf[j].rd) {
//				printf ("\tpush %d\n", buf[j].to);
				D[buf[j].to] = D[q[i]] + 1;
				q[p3++] = buf[j].to;
			}
		}
	}

	return (_back_D_source = D[source]) != -1;
}

bool dfs (int v) {
//	printf ("dfs %d\n", v);
	if (v == sink) {
//		printf ("<-!\n");
		return 1;
	}

	for (int i = vec[v]; i != -1; i = buf[i].next) {
		if (D[buf[i].to] + 1 == D[v] && buf[i].rd) {
			edge_l[elp++] = i;
			if (dfs (buf[i].to)) return 1;
			--elp;
		}
	}

	D[v] = -2;//unusable
//	printf ("<-\n");
	return 0;
}

int dinitz () {
	int maxflow = 0, i;
	while (bfs ()) {
		while (D[source] = _back_D_source, elp = 0, dfs (source)) {//dfs is either 0 or 1
			++maxflow;//cflow is 1
			for (i = 0; i < elp; ++i) {
				buf[edge_l[i]].rd = 0;
				buf[edge_l[i] ^ 1].rd = 1;
			}
		}
	}

	return maxflow;
}

int main () {
	scanf ("%d %d", &N, &M);

	int i, j;
	int c;
	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j) {
			scanf ("%d", &c);
			brd[i][j] = c;
		}
/*
	for (i = 0; i < N; ++i) {
		for (j = 0; j < M; ++j)
			printf ("%d", (int)brd[i][j]);
		puts ("");
	}
*/
	source = 0;
	sink = 1;
	E = 2;
	int bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < N; ++i) {
		for (j = 0; j < M; ++j) {
			if (brd[i][j] != 2
			 && (j == 0 || brd[i][j-1] == 2)) {
				hor_s[i][j] = E;

				buf[bp] = el (E, 1, vec[source]);
				vec[source] = bp++;
				buf[bp] = el (source, 0, vec[E]);
				vec[E] = bp++;
			} else if (brd[i][j] != 2 && brd[i][j-1] != 2) {
				hor_s[i][j] = E;
			} else if (brd[i][j] == 2 && j && brd[i][j-1] != 2) {
				++E;
			}
		}
		if (brd[i][M-1] != 2) ++E;
	}

	memset (edge_id, -1, sizeof (edge_id));
	for (j = 0; j < M; ++j) {
		for (i = 0; i < N; ++i) {
			if (brd[i][j] != 2
			 && (i == 0 || brd[i-1][j] == 2)) {
				ver_s[i][j] = E;

				buf[bp] = el (sink, 1, vec[E]);
				vec[E] = bp++;
				buf[bp] = el (E, 0, vec[sink]);
				vec[sink] = bp++;

				if (brd[i][j] == 1) continue;//no edge here

				edge_id[i][j] = bp;
				buf[bp] = el (E, 1, vec[hor_s[i][j]]);
				vec[hor_s[i][j]] = bp++;
				buf[bp] = el (hor_s[i][j], 0, vec[E]);
				vec[E] = bp++;				
			} else if (brd[i][j] != 2 && brd[i-1][j] != 2) {
				ver_s[i][j] = E;
			} else if (brd[i][j] == 2 && i && brd[i-1][j] != 2) {
				++E;
			}
		}
		if (brd[N-1][j] != 2) ++E;
	}
/*
	for (i = 0; i < N; ++i) {
		for (j = 0; j < M; ++j)
			printf ("(%d %d %d)", hor_s[i][j], ver_s[i][j], edge_id[i][j]);
		puts ("");
	}

	for (i = 0; i < E; ++i) {
		printf ("%d ->", i);
		for (j = vec[i]; j != -1; j = buf[j].next)
			printf ("(%d %d)", buf[j].to, buf[j].rd);
		puts ("");
	}
*/
	int maxflow = dinitz ();
	printf ("%d\n", maxflow);

	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j)
			if (!buf[edge_id[i][j]].rd)
				printf ("%d %d\n", i + 1, j + 1);

	return 0;
}
