/*
FROM: CEOI 2004 0 day
PROB: clo
KEYW: computational geometry, long numbers
*/

#include <cstdio>
#include <cstdlib>

#include <algorithm>

const int MAXN = 1 << 10;
const int MAXCROSS = 1 << 18;
const long long BASE = 1000000000;
long long Vx, Vy;
int Vxs, Vys;

inline long long trf (long long a) {
	if (a > 0) return 1;
	if (a < 0) return -1;
	return 0;
}
/*
long long myabs (long long a) {
	if (a < 0)
		return -a;
	else
		return a;
}
*/
struct el {
	int cid;

	long long S1;
	long long S2;
	bool is_point_on;
	bool side;

	el () {}
	el (int _cid, long long _S1, long long _S2, bool _is_point_on, bool _side =0) : cid (_cid), S1 (llabs (_S1)), S2 (llabs (_S2)), is_point_on (_is_point_on), side (_side) {}
};

struct point {
	long long x, y;
	point () {}
	point (long long _x, long long _y) : x (_x), y (_y) {}
};

int N;
el m[MAXCROSS];
int mc;//m cnt

inline long long S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int _nod (int a, int b) {
	return (b ? _nod (b, a % b) : a);
}

inline int nod (int a, int b) {
	return (a > b ? _nod (a, b) : _nod (b, a));
}

void fixV () {
	Vx *= -1;
	Vy *= -1;
	int k = nod (abs (Vx), abs (Vy));
//	printf ("k = %d\n", k);
	Vxs = Vx / k;
	Vys = Vy / k;
	while (abs (Vx) < 1000000000 && abs (Vy) < 1000000000) {Vx *= 2; Vy *= 2;}
//	printf ("%d %d %d %d\n", Vxs, Vys, Vx, Vy);
//	printf ("vs %d %d\n", Vxs, Vys);
}


inline bool __cmp (long long *a, long long *b) {
	int i;
	for (i = 3; i >= 0 && a[i] == b[i]; --i);
	return (i == -1 ? 0 : a[i] < b[i]);
}

inline bool _cmp (const long long &a1, const long long &a2, const long long &b1, const long long &b2) {
	long long A1[] = {a1 % BASE, a1 / BASE}; if (a1 / BASE >= BASE) printf ("wow!\n");
	long long A2[] = {a2 % BASE, a2 / BASE}; if (a2 / BASE >= BASE) printf ("wow!\n");
	long long B1[] = {b1 % BASE, b1 / BASE}; if (b1 / BASE >= BASE) printf ("wow!\n");
	long long B2[] = {b2 % BASE, b2 / BASE}; if (b2 / BASE >= BASE) printf ("wow!\n");
	long long res1[4] = {0};
	long long res2[4] = {0};

	long long ost;
	int i, j;
	for (i = 0; i < 2; ++i) {
		ost = 0;
		for (j = 0; j < 2; ++j) {
			res1[i + j] += A1[i] * B2[j] + ost;
			ost = res1[i + j] / BASE;
			res1[i + j] %= BASE;
		}

		res1[i + j] += ost;
		ost = res1[i + j] / BASE;
		res1[i + j] %= BASE;
	}

	for (i = 0; i < 2; ++i) {
		ost = 0;
		for (j = 0; j < 2; ++j) {
			res2[i + j] += A2[i] * B1[j] + ost;
			ost = res2[i + j] / BASE;
			res2[i + j] %= BASE;
		}

		res2[i + j] += ost;
		ost = res2[i + j] / BASE;
		res2[i + j] %= BASE;
	}
	return __cmp (res1, res2);
}

inline bool in_line (const point &a) {
	return (trf (a.x) == trf (Vxs) && trf (a.y) == trf (Vys) && !S (point (0, 0), point (Vxs, Vys), a));
}

bool side (const point &a) {
	return (trf (S (point (0, 0), point (Vx, Vy), a)) > 0);
}

bool intersect (const point &a, const point &b) {
	long long _a = S (point (0, 0), point (Vx, Vy), a);
	long long _b = S (point (0, 0), point (Vx, Vy), b);
	if (trf (_a) == trf (_b)) {/*printf ("0\n");*/ return 0;}
	_a = S (a, b, point (0, 0));
	_b = S (a, b, point (Vx, Vy));
	return trf (_a) != trf (_b);
}

void fill_m (int n, point *vec, int id) {
	int i;
	vec[n] = vec[0];
	for (i = 0; i < n; ++i) {
//		printf ("(%d)%d %d  ", i,  vec[i].x, vec[i].y);
		if (in_line (vec[i])) {
			if (in_line (vec[i+1])) {
				continue;//the 2 points are on the line
			} else {
//				printf ("add (%d) %d -> %d %d\n", i, i + 1, 1, side (vec[i+1]));
				m[mc++] = el (id, S (point (0, 0), vec[i], vec[i+1]), S (vec[i+1], vec[i], point (Vx, Vy)), 1, side (vec[i+1]));
//				m[mc-1].n = __cnt__++;
			}
		} else {
			if (in_line (vec[i+1])) {
//				printf ("add %d (%d) -> %d %d\n", i, i + 1, 1, side (vec[i]));
				m[mc++] = el (id, S (point (0, 0), vec[i], vec[i+1]), S (vec[i+1], vec[i], point (Vx, Vy)), 1, side (vec[i]));
//				m[mc-1].n = __cnt__++;
			} else {
				if (intersect (vec[i], vec[i+1])) {
//					printf ("add %d %d\n", i, i + 1);
					m[mc++] = el (id, S (point (0, 0), vec[i], vec[i+1]), S (vec[i+1], vec[i], point (Vx, Vy)), 0);
//					m[mc-1].n = __cnt__++;
				}
			}
		}
	}
//	printf ("*****\n");
}

bool cmp_el (const el &a, const el &b) {
	return _cmp (a.S1, a.S2, b.S1, b.S2);
}

bool cmp_el_ (int a, int b) {
	printf ("cmp %d %d ->", a, b);
	bool ret = cmp_el (m[a], m[b]);
	printf ("%d\n", ret);
	return ret;
//	return m[a].S1 * m[b].S2 > m[a].S2 * m[b].S1;
}

int res;
int last_status;
int crnt_status;
bool norm[MAXN];
bool spec[MAXN];
bool sside[MAXN];
int in_cnt;
bool flag;
bool flag2;

void get_ready () {
}

void f1 (int a) {
	if (cmp_el (m[a-1], m[a])) {//yes if m[a-1] is smaller than m[a] (we need differnt)
		if ((!last_status && crnt_status) || flag2) ++res;
		last_status = crnt_status;
		flag2 = 0;
		flag = 0;
	}
}

void f2 (int a) {
	if (!m[a].is_point_on) {
		norm[m[a].cid] = !norm[m[a].cid];
		if (norm[m[a].cid])
			++in_cnt;
		else
			--in_cnt;
	} else {
		if (!spec[m[a].cid]) {
			spec[m[a].cid] = 1;
			sside[m[a].cid] = m[a].side;
			if (!norm[m[a].cid]) ++in_cnt;
		} else {
			spec[m[a].cid] = 0;
			if (sside[m[a].cid] != m[a].side) {
				if (norm[m[a].cid]) {
					norm[m[a].cid] = 0;
					--in_cnt;
				} else {
					norm[m[a].cid] = 1;
					//do NOT change in_cnt!! (it was changed when the other point appeared)
				}
			} else {
				if (!norm[m[a].cid]) {
					--in_cnt;
				}
			}
		}
	}
	if (in_cnt == 0) {
		if (crnt_status == 1) flag2 = 1;
		crnt_status = 0;//out
	} else {
		if (crnt_status == 0) flag = 1;
		crnt_status = 1;
	}
//	printf ("%d -> %d\n", a, crnt_status);
}

int main () {
	scanf ("%d %Ld %Ld", &N, &Vx, &Vy);
	fixV ();

	int n;
	point vec[MAXN];
	for (int i = 0; i < N; ++i) {
		scanf ("%d", &n);
		for (int j = 0; j < n; ++j)
			scanf ("%Ld %Ld", &vec[j].x, &vec[j].y);
		fill_m (n, vec, i);
	}
/*
	for (int i = 0; i < mc; ++i)
		printf ("%Ld\t%Ld\t\t\t%.12Lf\n", m[i].S1, m[i].S2, ((long double)(m[i].S1)) / m[i].S2);
*/

	std::sort (m, m + mc, cmp_el);

	std::swap (m[5], m[6]);

/*
	for (int i = 0; i < mc; ++i)
		printf ("%d\n", m[i].cid);
*/
	get_ready ();

	f2 (0);

	for (int i = 1; i < mc; ++i) {
		f1 (i);
		f2 (i);
	}

	printf ("%d\n", res + 1);

	return 0;
}
