/*
FROM: CEOI 2006 day 1
PROB: antenna
KEYW: binary search, computational geometry
*/

#include <cstdio>
#include <cassert>
#include <cmath>

#include <algorithm>

const int MAXN = 1 << 9;
const double EPS = 1e-12;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	double ang (const pnt &a) const {return atan2 (a.y - y, a.x - x);}
};

int N, K;
double d[MAXN][MAXN];
pnt vec[MAXN];

double R, _2R;
double _ox, _oy;

int cp;
double crp[MAXN << 1];
bool crpa[MAXN << 1];
int idx[MAXN << 1];

inline double ang (int i, int j) {return acos (d[i][j] / _2R);}

bool cmp (int a, int b) {
	return crp[a] < crp[b];
}

inline double tr_plus (double a) {while (a < -M_PI) a += 2. * M_PI; return a;}
inline double tr_min (double a) {while (a > M_PI) a -= 2. * M_PI; return a;}
inline double grad (double a) {return a / M_PI * 180;}

void add (double a, double b) {
	crp[cp] = tr_plus (a-b);
	crpa[cp] = 1;
	idx[cp] = cp;
	++cp;
	crp[cp] = tr_min (a+b);
	crpa[cp] = 0;
	idx[cp] = cp;
	++cp;
}

bool can () {
	_2R = 2. * R;

//	printf ("---------- R == %lf -------\n", R);

	int i, ii, j, inc;
	double alpha, beta;
	for (i = 0; i < N; ++i) {
		cp = 0;
		inc = 1;
		for (j = 0; j < N; ++j) {
			if (j == i || d[i][j] > _2R + EPS) continue;
			alpha = vec[i].ang (vec[j]);
			beta = ang (i, j);
			add (alpha, beta);
			if (hypot (vec[i].x - R - vec[j].x, vec[i].y - vec[j].y) < R) ++inc;
		}

//		printf ("i == %d (%d):\n", i, inc);
//		for (j = 0; j < cp; ++j) printf ("(%lf(%lf) %d)", crp[j], grad (crp[j]), crpa[j]); puts ("");

		if (inc >= K) {
			_ox = vec[i].x - R;
			_oy = vec[i].y;
//			printf ("-->> %lf %lf\n", _ox, _oy);
			return 1;
		}

		std::sort (idx, idx + cp, cmp);
//		for (j = 0; j < cp; ++j) printf ("[%lf(%lf) %d]", crp[idx[j]], grad (crp[idx[j]]), crpa[idx[j]]); puts ("");
		for (j = 0; j < cp; ++j) {
			ii = idx[j];
			if (crpa[ii]) ++inc;
			else --inc;
//			printf ("-- %lf(%lf) --> %d\n", crp[ii], grad (crp[ii]), inc);
			if (inc >= K) {
				_ox = vec[i].x + cosl (crp[ii]) * R;
				_oy = vec[i].y + sinl (crp[ii]) * R;
//				printf ("-->> %lf %lf\n", _ox, _oy);
				return 1;
			}
		}
	}

	return 0;
}

int main () {
	scanf ("%d %d", &N, &K);

	int i, j;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &vec[i].x, &vec[i].y);

	for (i = 0; i < N; ++i)
		for (j = i + 1; j < N; ++j)
			d[i][j] = d[j][i] = hypot (vec[i].x - vec[j].x, vec[i].y - vec[j].y);

	double l = 0., r = 15000.;

	while (fabs (l - r) > EPS) {
		R = (l + r) / 2.;
//		printf ("l,r,R %lf %lf %lf\n", l, r, R);
		if (can ())
			r = R;
		else
			l = R;
	}

	R = r;
	assert (can ());
	printf ("%.10lf\n", R);
	printf ("%.6lf %.6lf\n", _ox, _oy);

	return 0;
}
