/*
FROM: Central European Olympiad in Informatics (CEOI) 2007 day 1
PROB: ministry
KEWY: map (hash-map), tree
*/

#include <cstdio>
#include <cassert>
#include <utility>

#include <vector>
#include <algorithm>
#include <ext/hash_map>
//#include <map>

const int MAXN = 1 << 20;
const int MAXLEN = 1 << 21;

int N;
std::vector <int> nxt[MAXN];

char *cp;
char line[MAXLEN];

int _crnt_lvl;
int lvl[MAXN];
int id[MAXN];
int depth[MAXN];

int read () {
	int cid = N++;
	lvl[cid] = _crnt_lvl++;
	assert (*cp == '(');
	++cp;
	while (*cp != ')')
		nxt[cid].push_back (read ());	
	++cp;//ignore the ')'
	--_crnt_lvl;
	return cid;
}

bool cmp_lvl (int a, int b) {
	return lvl[a] > lvl[b];
}

bool cmp_depth (int a, int b) {
	return depth[a] < depth[b];
}

std::pair <int, int> mp (int el_id) {
	return std::pair <int, int> (depth[el_id], id[el_id]);
}

int idx2[MAXN], idx2p;

bool cmp_chld_in_vec (int a, int b) {
	return mp (a) < mp (b);
}

bool cmp_chld_vecs (int a, int b) {
	return
		std::lexicographical_compare (
			  nxt[a].begin (), nxt[a].end ()
			, nxt[b].begin (), nxt[b].end ()
			, cmp_chld_in_vec
		);
}

struct hash_chld_vec {
	size_t operator () (int a) const {
		size_t res = 0;
		for (size_t i = 0; i < nxt[a].size (); ++i) {
			res <<= 20;
			res |= depth[nxt[a][i]] ^ id[nxt[a][i]];
		}
		return res;
		return 0;
	}
};

struct hash_chld_vec_eq {
	bool operator () (int a, int b) const {
		if (nxt[a].size () != nxt[b].size ()) return 0;
		for (size_t i = 0; i < nxt[a].size (); ++i)
			if (depth[nxt[a][i]] != depth[nxt[b][i]]
			 || id[nxt[a][i]] != id[nxt[b][i]])
				return 0;
		return 1;
	}
};

void do_job_hash () {
	int i;
	int cid = 0;
	__gnu_cxx::hash_map <int, int, hash_chld_vec, hash_chld_vec_eq> :: iterator it;
	__gnu_cxx::hash_map <int, int, hash_chld_vec, hash_chld_vec_eq> db (idx2p / 4);
	for (i = 0; i < idx2p; ++i)
		if ((it = db.find (idx2[i])) != db.end ()) {
			id[idx2[i]] = it->second;
		} else {
			db[idx2[i]] = cid;
			id[idx2[i]] = cid++;
		}

	printf ("%u\n", (int)cid);
}

void do_job () {
	int i;
//	for (i = 0; i < idx2p; ++i) printf (" %d", idx2[i]); printf (" <-- do_job\n");
	std::sort (idx2, idx2 + idx2p, cmp_chld_vecs);
//	for (i = 0; i < idx2p; ++i) printf (" %d", idx2[i]); printf (" <-- after sort do_job\n");
	id[idx2[0]] = 0;
	int cid = 0;
	for (i = 1; i < idx2p; ++i) {
		if (cmp_chld_vecs (idx2[i-1], idx2[i])) {
//			printf ("%d %d -- new!\n", i, idx2[i]);
			id[idx2[i]] = ++cid;//new value
		} else {
//			printf ("%d %d -- old\n", i, idx2[i]);
			id[idx2[i]] = cid;//old value
		}
	}
	printf ("%d\n", cid + 1);
}

int main () {
	gets (line);
	cp = line;
	read ();

	int i, j;
/*	for (i = 0; i < N; ++i) {
		printf ("%d (%d)->", i, lvl[i]);
		for (j = 0; j < (int)nxt[i].size (); ++j)
			printf (" %d", nxt[i][j]);
		puts ("");
	}
*/
	static int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	std::sort (idx, idx + N, cmp_lvl);

	for (i = 0; i < N; ++i) {
//		printf ("i -> idx i %d %d\n", i, idx[i]);
		depth[idx[i]] = 1;
		for (j = 0; j < (int)nxt[idx[i]].size (); ++j)
			depth[idx[i]] >?= depth[nxt[idx[i]][j]] + 1;
	}

	std::sort (idx, idx + N, cmp_depth);

	idx2p = 0;
	idx2[idx2p++] = idx[0];
	for (i = 1; i < N; ++i) {
		if (depth[idx[i-1]] < depth[idx[i]]) {
			do_job_hash ();
			idx2p = 0;
		}
		idx2[idx2p++] = idx[i];
		std::sort (nxt[idx[i]].begin (), nxt[idx[i]].end (), cmp_chld_in_vec);
	}
	do_job_hash ();

	return 0;
}
