/*
FROM: CEOI 2003
PROB: hanoi
KEYW: separate and control (razdelqi i vladei)
*/
/*Idea: fullmove (int n) returns the number of moves MOD 1'000'000 needed
 *to move a COMPLETE pyramid size n from one place to another
 *from the formula (fullmove(n) = 2 * fullmove (n-1) + 1)
 *
 *make_pyramid (int where, int n) calculates the moves needed to make a
 *COMPLETE pyramid in place 'where' with 'n' disks
 *if the 'n'-th dist is not at place 'where' then we should make a COMPLETE pyramid
 *at place different from the place of the 'n'-th disk and different from place 'where',
 *move disk 'n' on position 'where' and move the COMPLETE pyramid to place 'where' (fullmove(n-1))
 */


#include <cstdio>

const int MOD = 1000000;
const int MAXN = 100000;

int N;
int place [MAXN];

int fullmoves (int n) {
//    printf ("fm - %d", n);
    int ans = 0;
    for (int i = 0; i < n; ++i) {
        ans *= 2;
        ++ans;
        ans %= MOD;
    }
//    printf (" - %d\n", ans);
    return ans;
}

int moves = 0;

void make_pyramid (int where, int n) {
//    printf ("mp - %d %d\n", where, n);
    if (n == 1) {
        if (where != place[n])
            moves++;
        return;
    }
    
    if (where == place[n]) {
        make_pyramid (where, n-1);
        return;
    }
    
    if (where != 0 && place[n] != 0)
        make_pyramid (0, n-1);
    else if (where != 1 && place[n] != 1)
        make_pyramid (1, n-1);
    else
        make_pyramid (2, n-1);
        
    moves++;

    moves += fullmoves (n-1);
    moves %= MOD;
}

int main () {
    scanf ("%d", &N);

    int br1, br2, br3;
    scanf ("%d%d%d", &br1, &br2, &br3);
    
    int i, tmp;
    for (i = 0; i < br1; ++i) {
        scanf ("%d", &tmp);
        place[tmp] = 0;
    }

    for (i = 0; i < br2; ++i) {
        scanf ("%d", &tmp);
        place[tmp] = 1;
    }

    for (i = 0; i < br3; ++i) {
        scanf ("%d", &tmp);
        place[tmp] = 2;
    }

    make_pyramid (place[N], N);

    printf ("%d\n%d\n", place[N] + 1, moves);

    return 0;
}

