/*
FROM: Campion 2005/2006 round 6 Large
PROB: grazing
KEYW: dynamical programming, large numbers, multiplication, combinatorics - combinations, permutations
NOTE: The graphs we are counting consist only of paths and cycles (length NON devisible by 3), which DO NOT have common points
*/

#include <cstdio>
#include <cassert>
#include <cstdlib>

const int MAXN = 310;
const long long MOD = 1000000000ll;

struct big {
	long long a;
	big (int b = 0) : a (b % MOD) {}
	big (const big &b) : a (b.a) {}

	big& operator = (int b) {a = b % MOD; return *this;}
	big& operator = (const big &b) {a = b.a; return *this;}

	big& operator += (const big &b) {a += b.a; a %= MOD; return *this;}
	big operator + (const big &b) const {big res (*this); res += b; return res;}

	big& operator -= (const big &b) {a -= b.a; a %= MOD; return *this;}
	big operator - (const big &b) const {big res (*this); res -= b; return res;}

	big& operator *= (const big &b) {a *= b.a; a %= MOD; return *this;}
	big operator * (const big &b) const {big res (*this); res *= b; return res;}

	big pow (int p) const {big res (1); while (p) {res *= *this; --p;} return res;}

	big d2 () const {return big (a / 2);}
	big d21 () const {assert ((a & 1) == 0); return big (a / 2);}
	big d22 () const {assert ((a & 1) == 0); return big (a / 2);}

	void prnt () {printf ("%Ld", a);}
};

int N;
big dp_cycle[MAXN][MAXN];
big dp_path[MAXN][MAXN];
big comb[MAXN][MAXN];
big fact[MAXN];
big part[MAXN][MAXN];

void init_comb () {
	comb[0][0] = 1;
	for (int i = 1; i <= N; ++i) {
		comb[i][0] = 1;
		for (int j = 1; j <= i; ++j) {
			comb[i][j] = comb[i-1][j-1];
			comb[i][j] += comb[i-1][j];
//			printf ("comb[%d][%d] == ", i, j); comb[i][j].prnt (); puts ("");
		}
	}
}

void init_fact () {
	fact[0] = 1;
	for (int i = 1; i <= N; ++i) {
		fact[i] = fact[i-1];
		fact[i] *= big (i);
//		printf ("fact[%d] == %Ld\n", i, fact[i].a);
	}
}

void init_part () {
	part[0][0] = 1;
	for (int j = 1; j <= N; ++j) {
		part[0][j] = 1;
		for (int i = j; i <= N; i += j) {
			part[i][j] = part[i-j][j] * comb[i-1][j-1];
//			printf ("part[%d][%d] == ", i, j); part[i][j].prnt (); puts ("");
		}
	}
}

big perm_path (int id) {
//	assert (id < 3 || (fact[id].a & 1) == 0);
	return (id < 3 ? 1 : fact[id].d2 ());
}

void init_dp_path () {
	for (int j = 0; j <= N; ++j) dp_path[0][j] = 1;
	for (int i = 1; i <= N; ++i) {
		dp_path[i][0] = 0;
		for (int j = 1; j <= N; ++j) {
			for (int k = 0; k * j <= i; ++k) {
				dp_path[i][j] += dp_path[i - j*k][j-1] * comb[i][j*k] * part[j*k][k] * perm_path (j).pow (k);
				printf ("dpp[%d][%d] <-- dpp[%d][%d] <%Ld> * comb[%d][%d] <%Ld> * part[%d][%d] <%Ld> * perm_path (%d).pow (%d) <%Ld>\n"\
							, i, j\
							, i-j*k, j-1, dp_path[i-j*k][j-1].a\
							, i, j*k, comb[i][j*k].a\
							, j*k, k, part[j*k][k].a\
							, j, k, perm_path (j).pow (k).a\
				);
			}
			printf ("dp_path[%d][%d] == ", i, j); dp_path[i][j].prnt (); puts ("");
		}
	}
}

big perm_cycle (int id) {
//	assert (id >= 4);
	return fact[id-1].d2 ();
}

void init_dp_cycle () {
	for (int j = 0; j <= N; ++j) dp_cycle[0][j] = 1;
	for (int i = 1; i <= N; ++i) {
		dp_cycle[i][0] = 0;
		for (int j = 1; j <= N; ++j) {
			if (!(j % 3)) continue;
			if (j <= 3) {
				dp_cycle[i][j] = 0;
				continue;//cannot have cycles with length 1 2 3
			}
			for (int k = 0; k * j <= i; ++k) {
/*				printf ("dpc %d %d <-- dpc[%d][%d] * comb[%d][%d] * part[%d][%d] * perm_c (%d).pow (%d)\n", i, j,
				i-j*k,j-1,i,j*k, j*k, k, j, k);*/
//				printf ("dpc[%d][%d] <-- dpc[%d][%d] <%Ld> * comb[%d][%d] <%Ld> * part[%d][%d] <%Ld> * perm_c (%d).pow (%d) <%Ld>\n"\
							, i, j\
							, i-j*k, j-1, dp_cycle[i-j*k][j-1].a\
							, i, j*k, comb[i][j*k].a\
							, j*k, k, part[j*k][k].a\
							, j, k, perm_cycle (j).pow (k).a\
				);
				dp_cycle[i][j] += dp_cycle[i - j*k][j-1] * comb[i][j*k] * part[j*k][k] * perm_cycle (j).pow (k);
			}
//			printf ("dp_cycle[%d][%d] == ", i, j); dp_cycle[i][j].prnt (); puts ("");
		}
	}
}

int main () {
	scanf ("%d", &N);

	init_comb ();
	init_fact ();
	init_part ();
	init_dp_cycle ();
	init_dp_path ();

	big res;
	for (int i = 0; i <= N; ++i) {
		if (i == 1 || i == 2) continue;
		printf ("%d -- dpc[%d][%d] <%Ld> * dpp[%d][%d] <%Ld> * comb[%d][%d] <%Ld>\n"\
			, i\
			, i, i, dp_cycle[i][i].a\
			, N-i, N-i, dp_path[N-i][N-i].a\
			, N, i, comb[N][i].a\
		);
		res += dp_cycle[i][i] * dp_path[N-i][N-i] * comb[N][i];
	}

	res.prnt (); puts ("");

	return 0;
}
