/*
FROM: Campion 2005/2006 round 8 Large
PROB: joc
KEYW: dynamical programming, string hashing, binary search
*/

#include <cstdio>
#include <cstring>

const int MAXN = 1 << 8;
const int BAD = MAXN * MAXN;
const int BASE = 11;
const int MOD = 9699689;

int N;
char row[MAXN];

int fnz[MAXN];
int prev[MAXN][MAXN];
int hash[MAXN][MAXN];

int dp[MAXN][MAXN];
int rlen[MAXN][MAXN];

void init_fnz () {
	static int i;
//	printf ("fnz\n");
	fnz[N] = N;
	for (i = N - 1; i >= 0; --i)
		fnz[i] = (row[i] != '0' ? i : fnz[i+1]);
}

void init_hash () {
	static int i, j;
	static int chash;
//	printf ("hash\n");
	for (i = N-1; i >= 0; --i) {
		chash = 0;
		for (j = 0; i + j < N; ++j) {
			chash *= BASE;
			chash += row[i+j] - '0';
			chash %= MOD;
			hash[i][j+1] = chash;
//			printf ("%d %d -- %d\n", i, j + 1, hash[i][j+1]);
		}
	}
}

int find_prev (int beg, int len, int beg2) {
	static int l, r, m;
//	printf ("fprev %d %d %d\n", beg, len, beg2);
	l = 0, r = len + 1;
	if (beg2 + len > N) {
//		printf ("returning bad!\n");
		return BAD;//inpossible
	}
	while (l + 1 != r) {
		m = (l + r) / 2;
//		printf ("%d %d %d\n", m, hash[beg][m], hash[beg2][m]);
		if (hash[beg][m] == hash[beg2][m])
			l = m;
		else
			r = m;
	}
	if (l == len || row[beg + l] > row[beg2 + l])
		return beg2 + len + 1 > N ? BAD : beg2 + len + 1;
	else
		return beg2 + len;
}

void init_prev () {
	static int i, j;
//	printf ("prev\n");
	for (i = N-1; i >= 0; --i) {
		if (row[i] == '0') {
			prev[i][1] = BAD;
			memcpy (prev[i] + 2, prev[i+1] + 1, sizeof (int) * (N - i - 1));
			continue;
		}
		for (j = 1; i + j <= N; ++j)
			prev[i][j] = find_prev (i, j, fnz[i+j]);
	}
/*	printf ("!!!\n");
	for (i = 0; i < N; ++i) {
		for (j = 1; i + j <= N; ++j)
			printf ("%d %d -- %d\n", i, j, prev[i][j]);
		puts ("");
	}*/
}

#define try_end(A,B) (fnz[N-(A)] < fnz[N-(B)])
/*inline bool try_end (int oldl, int newl) {
	return fnz[N-oldl] < fnz[N-newl];
}*/
/*
int alternative_prev (int pos, int len) {
}*/

void init_dp () {
	static int i, j;
	for (i = N-1; i >= 0; --i) {
		dp[i][N-i] = N-i;
		rlen[i][N-i] = N-i;
		if (row[i] == '0' && i != N-1) {
			for (j = 2; j < N - i; ++j) {
				dp[i][j] = dp[i+1][j-1];
				rlen[i][j] = rlen[i+1][j-1] + 1;
			}
			dp[i][1] = dp[i][2];
			rlen[i][1] = rlen[i][2];
			continue;
		}
		for (j = N-i-1; j; --j) {
			dp[i][j] = dp[i][j+1];
			rlen[i][j] = rlen[i][j+1];
//			printf ("dp[%d][%d] <- dp[%d][%d] (%d %d)\n", i, j, i, j +  1, dp[i][j], rlen[i][j]);
			if (prev[i][j] != BAD
			 && try_end (dp[i][j], dp[i+j][prev[i][j] - i - j])
//			 && fnz[N-dp[i][j]] < fnz[ N-dp[i+j][prev[i][j]-i-j] ])
			 /*dp[i][j] > dp[i+j][prev[i][j] - i - j]*/) {
				dp[i][j] = dp[i+j][prev[i][j] - i - j];
				rlen[i][j] = j;
//			 	printf ("!!writen %d from %d %d\n", dp[i][j], i + j, prev[i][j] - i - j);
			}
		}
	}
}

int main () {
	while (gets (row), N = strlen (row), N > 1 || row[0] != '0') {
//		puts (row);
//		printf ("N == %d\n", N);
		init_fnz ();
		init_hash ();
		init_prev ();
		init_dp ();
		int cbeg = 0, clen = rlen[0][1], nlen;
		for (;;) {
//			printf ("%d %d\n", cbeg, clen);
			for (int i = cbeg; i != cbeg + clen; ++i)
				putchar (row[i]);
			if (cbeg + clen == N) break;//we are done
			putchar (',');
			nlen = prev[cbeg][clen];
			cbeg += clen;
			nlen = rlen[cbeg][nlen - cbeg];
			clen = nlen;
		}
		puts ("");
	}

	return 0;
}
