/*
FROM: Campion 2005/2006 round 8 Large
PROG: trafic (traffic damn stupid romanians)
KEYW: graph, dijkstra with stl heap, max flow min cut theorem
*/

#include <cstdio>
#include <cstdlib>
#include <cstring>

#include <queue>
#include <utility>

const int MAXN = 160;
const int MAXM = 5100;
const int INF_DIST = 0x7f7f7f7f;
const int INF_RD = 5000;//more than the maximal number of soldiers

struct el {
	short to;
	short dist;
	short rd;
	short next;
	el () {}
	el (short _to, short _dist, short _next) : to (_to), dist (_dist), next (_next) {}
};

int N, M, G;
int vec[MAXN];
el buf[MAXM * 2];

int d[2][MAXN];//minumum distance from the two capitols to the current city

int source, sink;
int D[MAXN];
bool used[MAXN];

bool bfs () {
	static short q[MAXN], p3, c, i, j;
	memset (D, -1, sizeof (D));
	memset (used, 0, sizeof (used));
	used[source] = 1;

	D[sink] = 0;
	q[p3 = 0, p3++] = sink;
	for (i = 0; i < p3; ++i) {
		c = q[i];
		for (j = vec[c]; j != -1; j = buf[j].next) {
			if (D[buf[j].to] == -1 && buf[j^1].rd) {
				D[buf[j].to] = D[c] + 1;
				q[p3++] = buf[j].to;
			}	
		}
	}
	return D[source] != -1;
}

int edge[MAXN], edgep;

short dfs (short a) {
	if (a == sink) {
		used[sink] = 0;
		return INF_RD;
	}
	short tmp;
	for (int i = vec[a]; i != -1; i = buf[i].next) {
		if (D[buf[i].to] == D[a] - 1 && buf[i].rd && !used[buf[i].to]) {
			used[buf[i].to] = 1;
			edge[edgep++] = i;
			if ((tmp = dfs (buf[i].to))) {return buf[i].rd <? tmp;}
			--edgep;	
		}
	}
	return 0;
}

int dinitz () {
	source = 0, sink = N-1;
	int maxflow = 0, cflow;
	while (bfs ()) {
		while (edgep = 0, cflow = dfs (source)) {
			maxflow += cflow;
			for (int i = 0; i < edgep; ++i) {
				buf[edge[i]].rd -= cflow;
				buf[edge[i]^1].rd += cflow;
			}
		}
	}
	return maxflow;
}

void dijkstra (int start, int *cd) {
	static std::priority_queue <std::pair <int, short> > q;
	static std::pair <int, short> c;
	memset (cd, INF_DIST, sizeof (int) * MAXN);//fills it with a pretty big number
	cd[start] = 0;
	q.push (std::make_pair (0, start));
	while (!q.empty ()) {
		c = q.top (); q.pop ();
		c.first *= -1;
		if (c.first > cd[c.second]) continue;
		for (int i = vec[c.second]; i != -1; i = buf[i].next)
			if (cd[buf[i].to] > cd[c.second] + buf[i].dist) {
				cd[buf[i].to] = cd[c.second] + buf[i].dist;
				q.push (std::make_pair (-cd[buf[i].to], buf[i].to));
			}
	}
}

bool test (int tdist) {
	int i;
	int res01, res02, res11, res12;
	for (i = 0; i < M * 2; i += 2) {
		res01 = tdist - d[0][buf[i].to];
		res02 = tdist - d[1][buf[i].to];
		if (res01 >= 0 && res02 >= 0) {buf[i].rd = buf[i^1].rd = 1; continue;}

		res11 = tdist - d[0][buf[i^1].to];
		res12 = tdist - d[1][buf[i^1].to];
		if (res11 >= 0 && res12 >= 0) {buf[i].rd = buf[i^1].rd = 1; continue;}

		if (res01 >= 0 && res12 >= 0 && res01 + res12 >= buf[i].dist
		 || res11 >= 0 && res02 >= 0 && res11 + res02 >= buf[i].dist) {
			buf[i].rd = buf[i^1].rd = 1; continue;
		}
		buf[i].rd = buf[i^1].rd = INF_RD;
	}
//	for (i = 0; i < M * 2; ++i) printf ("%d %d\n", buf[i].to, buf[i].rd);
	return dinitz () <= G;
}

int main () {
	scanf ("%d %d %d", &N, &M, &G);

	int i;
	int a, b, c, bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d", &a, &b, &c);
		--a; --b; c *= 2;//we are using twice as big edges to avoid real numbers

		buf[bp] = el (b, c, vec[a]);
		vec[a] = bp++;

		buf[bp] = el (a, c, vec[b]);
		vec[b] = bp++;
	}

	dijkstra (0, d[0]);
	dijkstra (N-1, d[1]);
//	for (i = 0; i < N; ++i) printf (" %d", d[0][i]); puts ("");
//	for (i = 0; i < N; ++i) printf (" %d", d[1][i]); puts ("");


	int l = 0, r = INF_DIST, m;
	if (!test (r)) {printf ("-1\n"); return 0;}//the min cut of a graph constructed only with rd == 1 is more than the available soldiers
	while (l + 1 < r) {
		m = (l + r) / 2;
		if (test (m))
			r = m;
		else
			l = m;
	}

	printf ("%.1lf\n", r / 2.);

	return 0;
}
