/*
FROM: Champion 2006 round 1 (training)
PROB: robot
KEYW: computational geometry
*/

#include <cstdio>
#include <cassert>
#include <cstdlib>
#include <cmath>

const int MAXN = 1 << 14;
const long double EPS = 1e-9;

struct pnt {
	long double x, y;
	pnt () {}
	pnt (long double _x, long double _y) : x (_x), y (_y) {}

	pnt operator * (long double a) const {return pnt (x * a, y * a);}
	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator / (long double a) const {return pnt (x / a, y / a);}
	long double operator * (const pnt &a) const {return x * a.x + y * a.y;}
	long double len () const {return hypotl (x, y);}
};

int N;
int l[MAXN];
int m[MAXN];
int s[MAXN];
pnt dest;
pnt dest_1;

void init_check (int tx, int ty) {
	long long sqd = (long long)tx * tx + (long long)ty * ty;
	long long lb = (long long)m[N-1] * 2 - (long long)s[N-1]; if (lb < 0) lb = 0;
	long long ub = (long long)s[N-1];

//	printf ("%Ld %Ld %Ld\n", sqd, lb, ub);

	lb *= lb;
	ub *= ub;
//	printf ("---%Ld %Ld %Ld\n", sqd, lb, ub);
	if (sqd < lb || sqd > ub) {
		printf ("0\n");
		exit (0);
	}
}

pnt rotate (const pnt &a, long double msin, long double mcos) {
	pnt ret;
	ret.x = mcos * a.x - msin * a.y;
	ret.y = msin * a.x + mcos * a.y;
	return ret;
}
long double grad (long double);
pnt crnt;
pnt _interp;
bool intersect (const pnt &a, int r1, const pnt &b, int r2) {
	long double lb = abs (r1 - r2);
	long double ub = r1 + r2;
	long double d = (b - a).len ();

	if (d > lb - EPS && d < ub + EPS) {
		long double mycos = (d * d + (long double)r2 * (long double)r2 - (long double)r1 * (long double)r1)
		 / ((long double)2 * (long double)r2 * d);
		if (mycos > 1) mycos = 1;
		if (mycos < -1) mycos = -1;
//		long double mysin = sqrtl (1 - mycos * mycos);
		long double mysin = sin (acos (mycos));
		_interp = rotate (crnt, mysin, mycos);
		_interp = _interp * ((long double)r2 / _interp.len ());
//		printf ("--%Lf %Lf %Lf\n", lb, ub, d);
//		printf ("%Lf\n", (_interp - crnt).len ());
//		printf ("(((%Lf %Lf)))  %Lf %Lf -- %Lf %Lf(%Lf) %d\n", _interp.x, _interp.y, crnt.x, crnt.y, mycos, mysin, grad (acos (mycos)), r1);
		return 1;
	} else
		return 0;
}

pnt p1, p2;
int id;

long double grad (long double rad) {
//	printf ("-->%Lf -- ", rad);
	rad = rad * 180. / M_PI;
//	printf ("(%.15Lf)\n", rad);
	while (rad < 0) rad += 360.;
	if (fabsl (rad - 360.) < 1e-9) rad = 0;//prevent printing 360.00000(0001)
	while (rad > 360.) rad -= 360.;
//	printf ("((%.15Lf))\n", rad);
	return rad;
}

long double find_ang (const pnt &a, const pnt &b, const pnt &c) {
//	printf ("--%Lf %Lf   %Lf %Lf   %Lf %Lf\n", a.x, a.y, b.x, b.y, c.x, c.y);
//	printf ("--pure ang -- %Lf (%Lf)\n", grad (acosl ((a - b) * (c - b) / ((a - b).len () * (c - b).len ()))), grad (acosl ((a - b) * (c - b) / ((a - b).len () * (c - b).len ())) + M_PI));
	return acosl ((a - b) * (c - b) / ((a - b).len () * (c - b).len ())) + M_PI;
}

void prnt () {
//	printf ("%Lf %Lf (%Lf)\n%Lf %Lf\n%d\n", p1.x, p1.y, p1.len (), p2.x, p2.y, id);
	printf ("%.15Lf\n", grad (atan2l (p1.y, p1.x)));
	int i;
	for (i = 1; i < id; ++i) printf ("0\n");
	long double alpha = find_ang (pnt (0, 0), p1, p2);
	printf ("%.15Lf\n", grad (alpha));
	if (id == N-1) return;
	alpha = find_ang (p1, p2, dest);
	printf ("%.15Lf\n", grad (alpha));
	for (i = id + 1; i < N; ++i) printf ("0\n");
//	printf ("----%Lf %Lf   %Lf %Lf   %Lf %Lf (%Lf %Lf %Lf) %d\n", p1.x, p1.y, p2.x, p2.y, dest.x, dest.y,\
	grad (atan2l (p1.y, p1.x)), grad (find_ang (pnt (0, 0), p1, p2)), grad (find_ang (p1, p2, dest)), id);
}

int main () {
	freopen ("robot.in", "r", stdin);
	freopen ("robot.out", "w", stdout);
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d", l + i);
	m[0] = s[0] = l[0];
	for (i = 1; i < N; ++i) {
		m[i] = m[i-1] >? l[i];
		s[i] = s[i-1] + l[i];
	}

	int tx, ty;
	scanf ("%d %d", &tx, &ty);
	init_check (tx, ty);
	dest = pnt (tx, ty);

	if (dest.len () > EPS)
		dest_1 = dest / dest.len ();
	else
		dest_1 = pnt (0, 1);
	crnt = dest;

	for (i = N - 1; i; --i) {
//		printf ("%Lf %Lf (%d)\n", crnt.x, crnt.y, i);
		if (intersect (crnt, l[i], pnt (0, 0), s[i-1])) {
			p1 = _interp;
			p2 = crnt;
			id = i;
			prnt ();
			break;
		} else {
			crnt = crnt + dest_1 * l[i];
		}
	}

	return 0;
}
