/*
FROM: Champion 2006 round 5 Large
PROB: dragon
KEYW: convex hull
*/

#include <cstdio>
#include <algorithm>

const int MAXN = 1 << 10;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}

	pnt& operator -= (const pnt &a) {x -= a.x; y -= a.y; return *this;}
	pnt operator - (const pnt &a) const {pnt ret (x, y); return ret -= a;}

	int operator * (const pnt &a) const {return x * a.x + y * a.y;}
	int sq () const {return x * x + y * y;}
};

int N;
pnt cg;
pnt vec[MAXN];

int hsz;
int hid[MAXN];

inline int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int _base;
bool cmp (int a, int b) {
	static int tmp;
	return (tmp = S (vec[_base], vec[a], vec[b])) > 0 ?
			1 :
			tmp < 0 ?
				0 :
				(vec[a] - vec[_base]).sq () < (vec[b] - vec[_base]).sq ();
}

void hull () {
	static int ord[MAXN];
	int fid = 0;
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y < vec[fid].y
		 || vec[i].y == vec[fid].y
		 && vec[i].x > vec[fid].x)
			fid = i;

	for (i = 0; i < N; ++i) ord[i] = i;
	ord[fid] = 0;
	ord[0] = fid;
	_base = fid;
	std::sort (ord + 1, ord + N, cmp);

	//for (i = 0; i < N; ++i) printf ("(%d %d) ", vec[ord[i]].x, vec[ord[i]].y); printf ("\n");
	for (i = 0; i < N; ++i) {
		hid[hsz++] = ord[i];
	
		while (hsz > 2 && S (vec[hid[hsz-3]], vec[hid[hsz-2]], vec[hid[hsz-1]]) <= 0) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}
	//for (i = 0; i < hsz; ++i) printf ("(%d %d)", vec[hid[i]].x, vec[hid[i]].y); printf ("\n");
}

int main () {
	FILE *in = fopen ("dragon.in", "r");
	FILE *out = fopen ("dragon.out", "w");
//	FILE *in = stdin;
//	FILE *out = stdout;

	fscanf (in, "%d %d %d", &N, &cg.x, &cg.y);

	int i;
	for (i = 0; i < N; ++i)
		fscanf (in, "%d %d", &vec[i].x, &vec[i].y);
	fclose (in);


	hull ();

	hid[hsz] = hid[0];
	int cnt = 0;
	for (i = 0; i < hsz; ++i)
		if ((vec[hid[i+1]] - vec[hid[i]]) * (cg - vec[hid[i]]) > 0
		 && (vec[hid[i]] - vec[hid[i+1]]) * (cg - vec[hid[i+1]]) > 0)
			++cnt;

	fprintf (out, "%d\n", cnt);
	fclose (out);

	return 0;
}
