/*
FROM: Champion 2006 round 8 Large
PROB: kimberley
KEYW: dinitz max flow with graph expansion
*/

#include <cstdio>
#include <cassert>
#include <cstring>
#include <utility>

using std::make_pair;

const int MAXN = 51;
const int MAXG = 101;
const int MAXT = 102;
const int INF = 1 << 20;
const int T = MAXT - 1;
const int MAXM = 4 * MAXT * (MAXG + MAXN);/*(MAXN + MAXG) * MAXT * 2 * 2-- (64 + 128) * 256 * 4*/

struct el {
	int to_pos, to_time;
	int rd;
	int next;
	el () {}
	el (int _to_pos, int _to_time, int _rd, int _next) : to_pos (_to_pos), to_time (_to_time), rd (_rd), next (_next) {}
};

int op (int a) {return a ^ 1;}

int N, G;
int SRC, DST, PC;
int vec[MAXN][MAXT];
el buf[MAXM];

int edgel[MAXN * MAXT], edgelp;
int D[MAXN][T+1];

bool bfs () {
	static std::pair <int, int> q[MAXN * MAXT], crnt;
	static int i, j, p3;
	memset (D, -1, sizeof (D));
	q[p3 = 0, p3++] = make_pair (DST, T);
	D[DST][T] = 0;

	for (i = 0; i < p3; ++i) {
		crnt = q[i];
//		printf ("popped %d %d (%d)\n", crnt.first, crnt.second, D[crnt.first][crnt.second]);
		for (j = vec[crnt.first][crnt.second]; j != -1; j = buf[j].next) {
//			printf ("\ttry %d %d (%d %d)\n", buf[j].to_pos, buf[j].to_time, buf[op (j)].rd, D[buf[j].to_pos][buf[j].to_time]);
			if (buf[op (j)].rd && D[buf[j].to_pos][buf[j].to_time] == -1) {
//				printf ("\tpush %d %d\n", buf[j].to_pos, buf[j].to_time);
				q[p3++] = make_pair (buf[j].to_pos, buf[j].to_time);
				D[buf[j].to_pos][buf[j].to_time] = D[crnt.first][crnt.second] + 1;
			}
		}
	}
	return D[SRC][0] != -1;
}

int dfs (int pos, int time) {
//	printf ("dfs %d %d\n", pos, time);
	if (pos == DST && time == T) {
		return INF;
	}

	for (int i = vec[pos][time], tmp; i != -1; i = buf[i].next)
		if (D[buf[i].to_pos][buf[i].to_time] == D[pos][time] - 1 && buf[i].rd) {
			edgel[edgelp++] = i;
			if ((tmp = dfs (buf[i].to_pos, buf[i].to_time))) {return D[pos][time] = -2, (buf[i].rd <? tmp);}
			--edgelp;
		}

	return D[pos][time] = -2, 0;
}

void dinitz () {
	static int i, cflow, _dsrc;
	while (bfs ()) {
		_dsrc = D[SRC][0];
		while (edgelp = 0, D[SRC][0] = _dsrc, cflow = dfs (SRC, 0))
			for (i = 0; i < edgelp; ++i) {
				buf[    edgel[i] ].rd -= cflow;
				buf[op (edgel[i])].rd += cflow;
			}
	}
}

int fnd (int n, int t) {
	static int i;
	for (i = vec[n][t]; i != -1 && !(buf[i].to_pos == n && buf[i].to_time == t + 1); i = buf[i].next);
	return buf[op(i)].rd;
}

int main () {
	scanf ("%d %d", &N, &G);
	scanf ("%d %d %d", &SRC, &DST, &PC);
	--SRC; --DST;

	int i, t;
	int a, b, bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < G; ++i) {
//		printf ("i == %d\n", i);
		scanf ("%d %d", &a, &b);
		--a; --b;

//		if (a == DST) continue;//no need to put vertices from the sink
		for (t = 0; t < T; ++t) {
//			printf ("add %d %d -1-> %d %d\n", a, t, b, t + 1);
			if (a != DST) {
				buf[bp] = el (b, t + 1, 1, vec[a][t]);
				vec[a][t] = bp++;
				buf[bp] = el (a, t, 0, vec[b][t+1]);
				vec[b][t+1] = bp++;
			}

//			printf ("add %d %d -1-> %d %d\n", b, t, a, t + 1);
			if (b != DST) {
				buf[bp] = el (a, t + 1, 1, vec[b][t]);
				vec[b][t] = bp++;
				buf[bp] = el (b, t, 0, vec[a][t+1]);
				vec[a][t+1] = bp++;
			}
//			assert (bp < MAXM);
		}
	}
	for (i = 0; i < N; ++i)
		for (t = 0; t < T; ++t) {
//			printf ("add %d %d -INF-> %d %d\n", i, t, i, t + 1);
			buf[bp] = el (i, t + 1, INF, vec[i][t]);
			vec[i][t] = bp++;

			buf[bp] = el (i, t, 0, vec[i][t+1]);
			vec[i][t+1] = bp++;
//			assert (bp < MAXM);
		}
/*
	for (i = 0; i < N; ++i)
		for (t = 0; t < T; ++t) {
			printf ("%d %d --> ", i, t);
			for (int j = vec[i][t]; j != -1; j = buf[j].next)
				printf ("(%d %d %d)", buf[j].to_pos, buf[j].to_time, buf[j].rd);
			printf ("\n");
		}
*/
//	printf ("hay!\n");
//	assert (0);

	dinitz ();
	for (t = 1; t < T && fnd (DST, t) < PC; ++t);
	printf ("%d\n", t == T ? -1 : t);

	return 0;
}
