/*
FROM: Campion 2006/2007 round 9 Large
PROB: sol
KEYW: matroid theory, bfs, dfs, graph, generalised matching, minimum spanning tree, rainbow spanning tree
*/

#include <cstdio>
#include <cstring>

const int MAXN = 1 << 8;//max vertices
const int MAXE = 1 << 8;//max edges
const int MAXC = 1 << 8;//number of colors

int N, E, C;//vertex count, edge count, color count
int edge[MAXE][2];//list of all edges
int col[MAXE];//the color of a given edge

int inM[MAXE];//which edges construct our current solution

int col_used[MAXC];//which colors are used in the current configuration (set M)

int ma3x[MAXN][MAXN];//current graph (set M)
int used[MAXN];
int prenum[MAXN], _pn;//number given by pre-num numbering of the current graph
int stsz[MAXN];//sub tree size
int master_root[MAXN], _cmr;//which is the 'oldest' ancestor of a given element, current master root

int ma3xV2[MAXE][MAXE];//the new graph itself (V')
int start[MAXE], sp;//from which vertices in new graph (V') we can start the paht
int finish[MAXE], fp;//which vertices in new graph (V') can finish the path
int prev[MAXE];//from which vertex we are comming (V') (used later to recover the path)

int bfs () {
	static int q[MAXE], p3, c;
	static int i, j;
	memset (prev, -1, sizeof (prev));
	p3 = 0;
	for (i = 0; i < E; ++i) if (start[i]) q[p3++] = i;

	for (i = 0; i < p3; ++i) {
		c = q[i];
//		printf ("popped %d\n", c);
		if (finish[c]) {
//			for (int j = 0; j < E; ++j) printf ("prev[%d] = %d\n", j, prev[j]);
//			printf ("FINISH!\n");
			return c;
		}
		for (j = 0; j < E; ++j)
			if (ma3xV2[c][j] && prev[j] == -1 && !start[j]) {
//				printf ("\tadd %d\n", j);
				prev[j] = c;
				q[p3++] = j;
			}
	}
	return -1;//no path found
}

void dfs (int crnt) {
	prenum[crnt] = _pn++;
	master_root[crnt] = _cmr;
	stsz[crnt] = 1;
	for (int i = 0; i < N; ++i)
		if (ma3x[crnt][i] && !used[i]) {
			used[i] = 1;
			dfs (i);
			stsz[crnt] += stsz[i];
		}
}

void init_q1 () {
	memset (ma3x, 0, sizeof (ma3x));
	memset (used, 0, sizeof (used));

	for (int i = 0; i < E; ++i)
		if (inM[i]) {
			ma3x[edge[i][0]][edge[i][1]] = 1;
			ma3x[edge[i][1]][edge[i][0]] = 1;
		}	

	_pn = 0;
	for (int i = 0; i < N; ++i) {
		if (!used[i]) {
			used[i] = 1;
			_cmr = i;
			dfs (_cmr);
		}
	}
//	for (int i = 0; i < N; ++i) printf ("%d --> %d %d\n", i, prenum[i], stsz[i]);
}

void init_q2 () {
	for (int i = 0; i < E; ++i) if (inM[i]) col_used[col[i]] = 1;
}

int q01 (int add) {
	return master_root[edge[add][0]] != master_root[edge[add][1]];
}

int q02 (int add) {
	return !col_used[col[add]];
}

int dec (int a, int b) {
	return prenum[a] >= prenum[b]//a is traversed after b (probably it is in b's subtree)
		&& prenum[a] < prenum[b] + stsz[b];//a is in the subtree with root b
}

int q1 (int remove, int add) {
	int i = edge[add][0], j = edge[add][1], p = edge[remove][0], q = edge[remove][1];
//	printf ("q1 %d %d , %d %d  %d %d (%d %d %d %d) --> %d\n", remove, add, i, j, p, q, dec (i, p), dec (i, q), dec (j, p), dec (j, q),\
			q01 (add)\
		|| dec (j, p) && dec (j, q) && !(dec (i, p) && dec (i, q))\
		|| dec (i, p) && dec (i, q) && !(dec (j, p) && dec (j, q)));

	return q01 (add)
		|| dec (j, p) && dec (j, q) && !(dec (i, p) && dec (i, q))
		|| dec (i, p) && dec (i, q) && !(dec (j, p) && dec (j, q));
}

int q2 (int remove, int add) {
	return q02 (add) || col[remove] == col[add];
}

int main () {
	scanf ("%d %d %d", &N, &E, &C);

	int i, j;
	int a, b;
	for (i = 0; i < E; ++i) {
		scanf ("%d %d", &a, &b);
		edge[i][0] = --a;
		edge[i][1] = --b;
	}

	for (i = 0; i < C; ++i)
		for (scanf ("%d", &j); j; --j) {
			scanf ("%d", &a);
			col[--a] = i;
		}

	if (E == 0) {printf ("-1\n"); return 0;}

//	for (i = 0; i < E; ++i) printf ("%d - %d\n", i, col[i]);

	inM[0] = 1;//add the first edge to M
	for (int tec = 2; tec < N; ++tec) {//target edge count
		init_q1 ();
		init_q2 ();

		memset (ma3xV2, 0, sizeof (ma3xV2));
		memset (start, 0, sizeof (start));
		memset (finish, 0, sizeof (finish));
		for (i = 0; i < E; ++i) {
			if (!inM[i]) {
				start[i] = q01 (i);
				finish[i] = q02 (i);
//				printf ("%d - sf %d %d\n", i, start[i], finish[i]);
			}
			for (j = 0; j < E; ++j) {
				if (i == j) continue;
				if (inM[i] && !inM[j] && q1 (i, j)
				 || inM[j] && !inM[i] && q2 (j, i)) {
					ma3xV2[i][j] = 1;
//					printf ("add edgeV2 %d %d\n", i, j);
				}
			}
		}
		int fin = bfs ();
		if (fin == -1) {printf ("-1"); return 0;}//there is no path
		for (i = fin; i != -1; i = prev[i]) {
//			printf ("change status %d\n", i);
			inM[i] = !inM[i];//change status
		}
//		for (i = 0; i < E; ++i) if (inM[i]) printf (" %d", i); puts ("<---");
//		printf ("--%d--\n", tec);
	}
	for (i = 0; i < E && !inM[i]; ++i);
	printf ("%d\n%d", N-1, i + 1);
	for (++i; i < E; ++i) if (inM[i]) printf (" %d", i + 1); puts ("");

	return 0;
}
