/*
TASK:dwarfs
LANG:C++

FROM: CEOI 2002 day 2
PROB: dwarfs
KEYW: convex hull, binary search
NOTE: Velin's warmup : Theme 1 (convex hull, binary search)
*/

#include <cstdio>
#include <cmath>
#include <algorithm>

const int MAXN = 1 << 17;
const double epsilon = 1e-6;

struct point {
	double x, y;
	point () {}
	point (double _x, double _y) : x (_x), y (_y) {}
};

int N;
point vec[MAXN];
point p, q;

inline double S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int hid[MAXN], hsz;
int fid;

bool cmp (int a, int b) {
	static double tmp;
	return	fabs (tmp = S (vec[fid], vec[a], vec[b])) > epsilon ?
				tmp > 0 :
				fabs (vec[a].y - vec[b].y) < epsilon ?
					vec[a].x < vec[b].x :
					vec[a].y < vec[b].y;
}

void hull () {
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y - vec[fid].y < -epsilon || fabs (vec[i].y - vec[fid].y) < epsilon && vec[i].x > vec[fid].x)
			fid = i;

	static int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	idx[fid] = 0;
	idx[0] = fid;

	std::sort (idx + 1, idx + N, cmp);
	idx[N] = idx[0];//copy the base point at the end
	for (i = 0; i <= N; ++i) {
		hid[hsz++] = idx[i];
		while (hsz > 2 && S (vec[hid[hsz-3]], vec[hid[hsz-2]], vec[hid[hsz-1]]) < epsilon) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}
	--hsz;//eat the base point at the end but it remains at hid[hsz]
//	for (i = 0; i < hsz; ++i) printf ("%d(%lf %lf) ", hid[i], vec[hid[i]].x, vec[hid[i]].y); printf ("\n");
}

double min (int a, int b) {
//	printf ("min %d %d (%lf)\n", hid[a], hid[b], S (p, q, vec[hid[a]]) - S (p, q, vec[hid[b]]));
	return (S (p, q, vec[hid[a]])) - (S (p, q, vec[hid[b]]));
}
double max (int a, int b) {return (S (p, q, vec[hid[b]])) - (S (p, q, vec[hid[a]]));}

int bsrch (double (*_cmp) (int, int)) {
	int l = 0, r = hsz-1, m;
	double coef = _cmp (0, 1);

//	printf ("coef == %lf\n", coef);
	double c1, c2;
	while (l + 1 < r) {
		m = (l + r) / 2;
//		printf ("m == %d -- %lf %lf\n", m, _cmp (m, m + 1), _cmp (0, m));
		c1 = _cmp (m, m + 1); c2 = _cmp (0, m);
		if (coef > 0 && c1 > 0 && c2 > 0 || coef < 0 && c1 < 0 && c2 < 0 || coef < 0 && c1 > 0) {
//			printf ("l\n");
			l = m;
		} else {
//			printf ("r\n");
			r = m;
		}
	}

//	int ret;
//	printf ("between %d %d -- %lf(%d)\n", l, l + 1, _cmp (l, l + 1), (_cmp (l, l + 1) > 0 ? l + 1 : l));
	int ret = (_cmp (l, l + 1) > 0 ? l + 1 : l);
	if (_cmp (ret, 0) > 0) ret = 0;
	if (_cmp (ret, hsz-1) > 0) ret = hsz - 1;
//	printf ("ret %d\n", ret);
	return ret;
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i) scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	if (N >= 2) hull ();

	int min_id, max_id;
	while (scanf ("%lf %lf %lf %lf", &p.x, &p.y, &q.x, &q.y) == 4) {
		if (N < 2) {printf ("GOOD\n"); continue;}
		min_id = hid[bsrch (min)];
		max_id = hid[bsrch (max)];
//		printf ("for %lf %lf %lf %lf -- %d %d -- %lf * %lf\n", p.x, p.y, q.x, q.y, min_id, max_id, S (p, q, vec[min_id]), S (p, q, vec[max_id]));
		printf ("%s\n", S (p, q, vec[min_id]) * S (p, q, vec[max_id]) < 0 ? "BAD" : "GOOD");
		fflush (stdout);
	}

	return 0;
}
