/*
TASK:dwarfs
LANG:C++

FROM: CEOI 2002 day 2
PROB: dwarfs
KEYW: convex hull, binary search
NOTE: Velin's warmup : Theme 1 (convex hull, binary search)
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <algorithm>

const int MAXN = 1 << 17;
const double epsilon = 1e-6;

struct point {
	double x, y;
	point () {}
	point (double _x, double _y) : x (_x), y (_y) {}
};

int N;
point vec[MAXN];
point p, q;

inline double S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int hid[MAXN], hsz;
int fid, mid;
int mh;

bool cmp (int a, int b) {
	static double tmp;
	return	fabs (tmp = S (vec[fid], vec[a], vec[b])) > epsilon ?
				tmp > 0 :
				fabs (vec[a].y - vec[b].y) < epsilon ?
					vec[a].x < vec[b].x :
					vec[a].y < vec[b].y;
}

void hull () {
	int i;
	for (i = 1; i < N; ++i) {
		if (vec[i].y - vec[fid].y < -epsilon || fabs (vec[i].y - vec[fid].y) < epsilon && vec[i].x > vec[fid].x)
			fid = i;
		if (vec[i].y - vec[mid].y > epsilon || fabs (vec[i].y - vec[mid].y) < epsilon && vec[i].x < vec[mid].x)
			mid = i;
	}

	static int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	idx[fid] = 0;
	idx[0] = fid;

	std::sort (idx + 1, idx + N, cmp);
	idx[N] = idx[0];//copy the base point at the end
	for (i = 0; i <= N; ++i) {
		hid[hsz++] = idx[i];
		while (hsz > 2 && S (vec[hid[hsz-3]], vec[hid[hsz-2]], vec[hid[hsz-1]]) < epsilon) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}
	--hsz;//eat the base point at the end but it remains at hid[hsz]
	for (i = 0; i < hsz && hid[i] != mid; ++i);
	if ((mh = i) == hsz) exit (-1);
//	printf ("%d\n", mh);
//	for (i = 0; i < hsz; ++i) printf ("%d(%lf %lf) ", hid[i], vec[hid[i]].x, vec[hid[i]].y); printf ("\n");
}

double min (int a, int b) {return (S (p, q, vec[hid[a]])) - (S (p, q, vec[hid[b]]));}
//double max (int a, int b) {return (S (p, q, vec[hid[b]])) - (S (p, q, vec[hid[a]]));}
double (*_cmp) (int, int) = min;

int bsrch (int l, int r) {
	int m;
	double coef = _cmp (l, l + 1);
	while (l < r) {
		m = (l + r) / 2;
		if (_cmp (m, m + 1) * coef > 0)
			l = m + 1;
		else
			r = m;
	}

//	printf ("ret %d\n", l);
	return l;
}

bool what (int a, int b, int c, int d) {
	if (S (p, q, vec[hid[a]]) > 0) {
		if (S (p, q, vec[hid[b]]) < 0) return 1;
		if (S (p, q, vec[hid[c]]) < 0) return 1;
		if (S (p, q, vec[hid[d]]) < 0) return 1;
	} else {
		if (S (p, q, vec[hid[b]]) > 0) return 1;
		if (S (p, q, vec[hid[c]]) > 0) return 1;
		if (S (p, q, vec[hid[d]]) > 0) return 1;
	}
	return 0;
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i) scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	if (N >= 2) hull ();

	while (scanf ("%lf %lf %lf %lf", &p.x, &p.y, &q.x, &q.y) == 4) {
		if (N < 2) {printf ("GOOD\n"); continue;}
		printf ("%s\n", what (0, mh, bsrch (0, mh), bsrch (mh, hsz-1)) ? "BAD" : "GOOD");
		fflush (stdout);
	}

	return 0;
}
