#include <stdio.h>
#include <math.h>
#include <algorithm>

using namespace std;

struct point {
    int index;
    int x, y;

    bool operator< (const point& o) const {
        if (x == o.x) return y < o.y;
        return x < o.x;
    }

    bool operator==(const point& o) const {
        return x == o.x && y == o.y;
    }
};

int n;
int ans[10000];
point pts[10000];

int found(point& p) {
    int ffr, fto, fmid;
    ffr = 0; fto = n;
    do {
        fmid = (ffr + fto) / 2;
        if (p == pts[fmid]) return pts[fmid].index;
        if (p < pts[fmid]) {
            fto = fmid;
        } else {
            ffr = fmid + 1;
        }
    } while (ffr != fto);
    return -1;
}

double centerx, centery, vectorx, vectory;

int goodsymetry(point& p) {

    double scalar_product = vectorx * (centerx - p.x) +
        vectory * (centery - p.y);

    double rx = p.x + 2 * vectorx * scalar_product + 1e-6;
    double ry = p.y + 2 * vectory * scalar_product + 1e-6;

//    printf("%lf %lf %lf %lf :", centerx, centery, vectorx, vectory);
//    printf("%d %d %lf %lf\n", p.x, p.y, rx, ry);

    if ((rx - (int)rx > 2e-6) || (ry - (int)ry > 2e-6)) {
        return -1;
    }
    point t;
    t.x = (int)rx; t.y = (int)ry;
    return found(t);
}

void normv() {
    double nm = 1 / sqrt(vectorx * vectorx + vectory * vectory);
    vectorx *= nm;
    vectory *= nm;
}

bool solve() {
    int j,i;
    centerx = 0; centery = 0;
    for (j=0;j<n;j++) {
        centerx += pts[j].x;
        centery += pts[j].y;
    }
    centerx /= n; centery /= n;

    for (j=0;j<n;j++) {
        if (j == 0) {
            vectorx = pts[0].y - centery;
            vectory = centerx - pts[0].x;
        } else {
            vectorx = pts[j].x - pts[0].x;
            vectory = pts[j].y - pts[0].y;
        }
        normv();

        for (i=0;i<n;i++) {
            int t = goodsymetry(pts[i]);
            if (t == -1)
                break;
            ans[pts[i].index - 1] = t;
        }
        //printf("%lf %lf %lf %lf :", centerx, centery, vectorx, vectory);
        //for (int x=0;x<i;x++) {
        //    printf(" %d", ans[x]);
        //}
        //printf("\n");
        if (i == n)
            return true;
    }
    return false;
}

int main(void) {
    scanf("%d", &n);
    for (int i = 0; i < n; i++) {
        scanf("%d %d", &pts[i].x, &pts[i].y);
        pts[i].x += 10001; pts[i].y += 10001;
        pts[i].index = i+1;
    }
    sort(pts, pts+n);
    /* CHECK INPUT */
    for (int i = 1; i < n; i++) {
        if (pts[i] == pts[i-1]) {
            fprintf(stderr, "Error in input: point %d %d is found more than once", pts[i].x - 10001, pts[i].y - 10001);
            return -1;
        }
    }
    /* END INPUT CHECK */
    if (n==1) printf("1\n"); else
    if (solve()) {
        for (i=0;i<n;i++) {
            if (i > 0) printf(" ");
            printf("%d", ans[i]);
        }
        printf("\n");
    } else printf("0\n");
    return 0;
}