/*
TASK:garden
LANG:C++

FROM: NOI 1999 round 3
PROB: garden
KEYW: convex hull
NOTE: Velin's warmup : Theme 1 (convex hull, binary search)
*/

#include <cstdio>
#include <algorithm>
#include <cmath>

const int MAXN = 1 << 14;//16 000

struct point {
	int x, y;
	point () {}
	point (const point &a) : x (a.x), y (a.y) {}
	point (int _x, int _y) : x (_x), y (_y) {}
};

int N;
point vec[MAXN];

int fid;
int hid[MAXN], hsz;

inline int S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

inline bool cmp (int a, int b) {
	static int tmp;
	return (tmp = S (vec[fid], vec[a], vec[b])) ?
			tmp > 0 :
			vec[a].y != vec[b].y ?
				vec[a].y < vec[b].y :
				vec[a].x < vec[b].x;
}

void hull () {
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y < vec[fid].y || vec[i].y == vec[fid].y && vec[i].x > vec[fid].x)
			fid = i;

	int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	idx[fid] = 0;
	idx[0] = fid;

	std::sort (idx + 1, idx + N, cmp);
//	idx[N] = fid;//add the base point at the end to avoid 3 points on the bottom line
//	for (i = 0; i <= N; ++i) printf ("(%d %d) ", vec[idx[i]].x, vec[idx[i]].y); printf ("\n");

	hsz = 0;
	for (i = 0; i < N; ++i) {
		hid[hsz++] = idx[i];
		while (hsz > 2 && S (vec[hid[hsz-3]], vec[hid[hsz-2]], vec[hid[hsz-1]]) < 0) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}
//	if (!S (vec[hid[0]], vec[hid[hsz-1]], vec[hid[hsz-2]])) --hsz;
	hid[hsz] = hid[0];
//	--hsz;//eat the base point at the end -> but it stays at hid[hsz]
//	for (i = 0; i < hsz; ++i) printf ("%d(%d %d) ", hid[i], vec[hid[i]].x, vec[hid[i]].y); printf ("\n");
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &vec[i].x, &vec[i].y);

	hull ();
	double len = 0.;
	for (i = 0; i < hsz; ++i)//use i+1 which is at most hsz, which is (hid[hsz] ==) fid
		len += hypot (vec[hid[i]].x - vec[hid[i+1]].x, vec[hid[i]].y - vec[hid[i+1]].y);

	printf ("%d\n", (int)ceil (len));

	return 0;
}
