/*
TASK:palechko
LANG:C++

FROM: NOI 2004 k3
PROB: palechko
KEYW: geometry, binary search
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>

const int MAXN = 1 << 10;

struct point {
	int x, y;
	point () {}
	point (int _x, int _y) : x (_x), y (_y) {}
	point (const point &a) : x (a.x), y (a.y) {}

	point& operator += (const point &a) {x += a.x; y += a.y; return *this;}
	point& operator -= (const point &a) {x -= a.x; y -= a.y; return *this;}

	point operator + (const point &a) const {point ret (*this); ret += a; return ret;}
	point operator - (const point &a) const {point ret (*this); ret -= a; return ret;}

	int operator * (const point &a) const {return x * a.x + y * a.y;}

	int sq () {return (*this) * (*this);}
	double len () {return sqrt (sq ());}
};

int W, K;
point vec[2][MAXN];
int vecsz[2];

point d[2];
double _retdist;
int _retpos;

int S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int bsrch (const point& crnt, int k) {
	int l = 0, r = vecsz[k] - 1, m;

	while (l < r) {
		m = (l + r) / 2;
		if ((crnt - vec[k][m]).sq ()
		 >	(crnt - vec[k][m+1]).sq ())
		 	l = m + 1;
		else
			r = m;
	}

	assert (l == r);
	assert (l != 0 && l != vecsz[k]-1);
	return r;
}

double dist (int x, int k) {
	point crnt = point (x, 0) - d[k];
	int pos = bsrch (crnt, k);
	double d1 = (crnt - vec[k][pos]).len ();
	if ((crnt - vec[k][pos]) * (vec[k][pos+1] - vec[k][pos]) > 0)
		d1 = abs (S (crnt, vec[k][pos], vec[k][pos+1])) / (vec[k][pos+1] - vec[k][pos]).len ();
	if ((crnt - vec[k][pos]) * (vec[k][pos-1] - vec[k][pos]) > 0)
		d1 = abs (S (crnt, vec[k][pos], vec[k][pos-1])) / (vec[k][pos-1] - vec[k][pos]).len ();

	return d1;
}

void bsrch2 (int l, int r, int k) {
//	printf ("%d %d %d\n", l, r, k);
	int m;
	while (l + 1 < r) {
		m = (l + r) / 2;
		if ((dist (m, 0) > dist (m, 1)) ^ k)
			r = m;
		else
			l = m;
	}

	double dl = dist (l, 0) <? dist (l, 1);
	double dr = dist (r, 0) <? dist (r, 1);
	if (dl < dr) {
		_retpos = r;
		_retdist = dr;
	} else {
		_retpos = l;
		_retdist = dl;
	}
//	printf ("%lf %d\n", _retdist, _retpos);
}

int minYid[2][2] = {{0}};

void fast () {
	if (vec[1][minYid[1][1]].x + d[1].x < vec[0][minYid[0][0]].x + d[0].x)
		bsrch2 (vec[1][minYid[1][1]].x + d[1].x, vec[0][minYid[0][0]].x + d[0].x, 1);
	else if (vec[0][minYid[0][1]].x + d[0].x < vec[1][minYid[1][0]].x + d[1].x)
		bsrch2 (vec[0][minYid[0][1]].x + d[0].x, vec[1][minYid[1][0]].x + d[1].x, 0);
	else {
		_retdist = -1e99;
		_retpos = -100;
	}
}

int main () {
	scanf ("%d %*d %d", &W, &K);

	int k, i;
	for (k = 0; k < K; ++k) {
		scanf ("%d", vecsz + k);
		for (i = 1; i <= vecsz[k]; ++i)
			scanf ("%d %d", &vec[k][i].x, &vec[k][i].y);
		vec[k][0] = vec[k][1] + point (0, 1);
		vec[k][vecsz[k]+1] = vec[k][vecsz[k]] + point (0, 1);
		vecsz[k] += 2;//include the new points
	}
/*
	for (k = 0; k < K; ++k) {
		for (i = 0; i < vecsz[k]; ++i)
			printf ("%d %d\n", vec[k][i].x, vec[k][i].y);
		printf ("\n");
	}
*/
	if (K == 1) {//clone the 1st hand
		for (i = 0; i < vecsz[0]; ++i)
			vec[1][i] = vec[0][i];
		vecsz[1] = vecsz[0];
	}
	//now we have 2 hands

	for (k = 0; k < 2; ++k) {
		for (i = 1; i < vecsz[k]; ++i)
			if (vec[k][i].y < vec[k][minYid[k][0]].y) {
				minYid[k][0] = i;
				minYid[k][1] = i;
			} else if (vec[k][i].y == vec[k][minYid[k][0]].y)
				minYid[k][1] = i;
	}
//	printf ("--%d %d %d %d\n", minYid[0][0], minYid[0][1], minYid[1][0], minYid[1][1]);

	double d0, dw;
	d[0] = d[1] = point (0, 0);

	d0 = dist (0, 0) <? dist (0, 1);
	dw = dist (W, 0) <? dist (W, 1);
	fast ();//bsrch2 (vec[0][minYid[0]].x + d[0].x, vec[1][minYid[1]].x + d[1].x);
//	printf ("0 - %lf   mid (%d) - %lf   W - %lf\n", d0, _retpos, _retdist, dw);
	if (_retdist >= d0 && _retdist > dw) {
		printf ("%d\n", _retpos);
	} else if (d0 >= _retdist && d0 > dw) {
		printf ("%d\n", 0);
	} else
		printf ("%d\n", W);

	int moves;
	point _d[2];
	scanf ("%d", &moves);
	for (int m = 0; m < moves; ++m) {
		if (K == 2) {
			scanf ("%d %d %d %d", &_d[0].x, &_d[0].y, &_d[1].x, &_d[1].y);
			d[0] += _d[0];
			d[1] += _d[1];
		} else {
			scanf ("%d %d", &_d[0].x, &_d[0].y);
			d[0] += _d[0];
			d[1] += _d[0];
		}

		d0 = dist (0, 0) <? dist (0, 1);
		dw = dist (W, 0) <? dist (W, 1);
		fast ();//bsrch2 (vec[0][minYid[0]].x + d[0].x, vec[1][minYid[1]].x + d[1].x);
//		printf ("0 - %lf   mid (%d) - %lf   W - %lf\n", d0, _retpos, _retdist, dw);
		if (_retdist >= d0 && _retdist >= dw) {
			printf ("%d\n", _retpos);
		} else if (d0 >= _retdist && d0 >= dw) {
			printf ("%d\n", 0);
		} else
			printf ("%d\n", W);
	}

	return 0;
}
