/*
TASK: lights
LANG: C++

FROM: IOI 1999
PROB: lights
KEYW: dyjkstra with hand-made heap
*/

#include <cstdio>
#include <vector>

const int MAXN = 1 << 9;
const int MAXM = 1 << 14;

struct el {
	int to;
	int dist;
	int next;
	el () {}
	el (int _to, int _dist, int _next) : to (_to), dist (_dist), next (_next) {}
};

int N, M;
int vec[MAXN];
el buf[MAXM * 2];

int S, F;
int B[MAXN], P[MAXN], ST[MAXN];

//BEGIN heap
const int MAXHLEN = 1 << 10;

struct heap {
	int to;
	int dist;
	heap () {}
	heap (int _to, int _dist) : to (_to), dist (_dist) {}
};

heap h[MAXHLEN];
int hlen;
int idx[MAXN];
const int POPPED = -1, NOT_IN = -2;

void init () {
	int i;
	for (i = 1; i < MAXHLEN; ++i)
		h[i].dist = INT_MAX;
	h[0].dist = INT_MIN;
	hlen = 1;
	for (i = 0; i < N; ++i)
		idx[i] = NOT_IN;
}

heap pop () {
	heap ret = h[1]; idx[ret.to] = POPPED;
	heap tomove = h[--hlen];
	h[hlen].dist = INT_MAX;
	if (hlen == 1) return ret;

	int p1 = 1, p2 = 2;
	for (;;) {
		if (h[p2+1].dist < h[p2].dist)
			++p2;
		if (h[p2].dist < tomove.dist) {
			h[p1] = h[p2];
			idx[h[p2].to] = p1;

			p1 = p2;
			p2 *= 2;
		} else
			 break;
	}

	h[p1] = tomove;
	idx[tomove.to] = p1;

	return ret;
}

void siftup (int id) {
	heap tomove = h[idx[id]];
	int p1 = idx[id], p2 = p1 / 2;

	while (h[p2].dist > tomove.dist) {
		h[p1] = h[p2];
		idx[h[p2].to] = p1;

		p1 = p2;
		p2 /= 2;
	}

	h[p1] = tomove;
	idx[id] = p1;
}

bool add (int to, int dist) {
	if (idx[to] == NOT_IN) {
		h[hlen] = heap (to, dist);
		idx[to] = hlen++;
		siftup (to);
		return 1;
	} else if (idx[to] != POPPED && h[idx[to]].dist > dist) {
		h[idx[to]].dist = dist;
		siftup (to);
		return 1;
	}
	return 0;
}

//END heap

void _f (int a, int time, int &col, int &more, int &next) {
	int tmp = (time - ST[a]) % (B[a] + P[a]);
	if (tmp >= B[a]) {col = 2; more = B[a] + P[a] - tmp; next = B[a];}
	else {col = 1; more = B[a] - tmp; next = P[a];}
}

bool f (int a, int b, int time, int length) {
	int col1, col2, more1, more2, nxt1, nxt2;
	_f (a, time, col1, more1, nxt1);
	_f (b, time, col2, more2, nxt2);

	if (col1 == col2) return add (b, time + length);
	else if (more1 != more2) return add (b, time + (more1 <? more2) + length);
	else if (nxt1 != nxt2) return add (b, time + more1 + (nxt1 <? nxt2) + length);
	else return 0;//no way!
}

int prev[MAXN];

void dijkstra () {
	init ();
	add (S, 0);

	heap crnt;
	while (hlen > 1) {
		crnt = pop ();

//		printf ("popped %d %d\n", crnt.to, crnt.dist);
		if (crnt.to == F) goto sol;
		for (int i = vec[crnt.to]; i != -1; i = buf[i].next)
			if (f (crnt.to, buf[i].to, crnt.dist, buf[i].dist))
				prev[buf[i].to] = crnt.to;
	}
	printf ("0\n");
	return;
	sol:;
	printf ("%d\n", crnt.dist);
	std::vector <int> res;
	for (int a = F; a != S; a = prev[a]) res.push_back (a);
	printf ("%d", S + 1); for (int i = res.size () - 1; i >= 0; --i) printf (" %d", res[i] + 1); printf ("\n");
}

int main () {
	scanf ("%d %d\n", &S, &F);
	--S; --F;
	scanf ("%d %d\n", &N, &M);

	int i;
	char col;
	int r, b, p, a, d;
	for (i = 0; i < N; ++i) {
		scanf ("%c %d %d %d\n", &col, &r, &b, &p);
		B[i] = b;
		P[i] = p;
		if (col == 'B') ST[i] = r - b; else ST[i] = r - p - b;
	}

//	for (i = 0; i < N; ++i) printf ("%d %d %d\n", B[i], P[i], ST[i]);

	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d", &a, &b, &d);
		--a; --b;

		buf[i * 2] = el (b, d, vec[a]);
		vec[a] = i * 2;

		buf[i * 2 + 1] = el (a, d, vec[b]);
		vec[b] = i * 2 + 1;
	}
/*
	for (i = 0; i < N; ++i) {
		printf ("%d -> ", i);
		for (int j = vec[i]; j != -1; j = buf[j].next)
			printf ("(%d %d)", buf[j].to, buf[j].dist);
		printf ("\n");
	}
*/
	dijkstra ();

	return 0;
}
