/*
TASK: guards
LANG: C++

FROM: CEOI 2002 day 2
PROB: guards
KEYW: matching, dinitz max flow
*/

#include <cstdio>
#include <cstdlib>
#include <utility>

const int MAXn = 1 << 8;
const int MAXm = 1 << 8;
const int MAXN = 1 << 16;
const int MAXM = 1 << 16;

struct el {
	int to;
	bool rd;
	int next;
	el () {}
	el (int _to, bool _rd, int _next) : to (_to), rd (_rd), next (_next) {}
};

int N, M;
int board[MAXn][MAXm];
std::pair <int, int> map[MAXn][MAXm];

int rN;
int vec[MAXN];
el buf[MAXM];
int source, sink;

int D[MAXN];
bool used[MAXN];
int vl[MAXN], vp;

inline int op (int a) {return a ^ 1;}

bool bfs () {
	static int i, j, p3, crnt;
	static int queue[MAXN];
	for (i = 0; i < rN; ++i) {
		D[i] = -1;
		used[i] = 0;
	}
	used[source] = 1;
	D[sink] = 0;
	queue[p3 = 0, p3++] = sink;

	for (i = 0; i < p3; ++i)
		for (j = vec[crnt = queue[i]]; j != -1; j = buf[j].next)
			if (D[buf[j].to] == -1 && buf[op (j)].rd) {
				D[buf[j].to] = D[crnt] + 1;
				queue[p3++] = buf[j].to;
			}

	return D[source] != -1;
}

bool dfs (int v) {
	if (v == sink) return (used[sink] = 0, 1);

	for (int i = vec[v]; i != -1; i = buf[i].next)
		if (D[buf[i].to] == D[v] - 1 && !used[buf[i].to] && buf[i].rd) {
			vl[vp++] = i;
			used[buf[i].to] = 1;
			if (dfs (buf[i].to)) return 1;
			--vp;
		}
	return 0;
}

int dinitz () {
	int maxflow = 0;
	while (bfs ())
		while (vp = 0, dfs (source) && ++maxflow)
			for (int i = 0; i < vp; ++i) {
				buf[vl[i]].rd = 0;
				buf[op (vl[i])].rd = 1;
			}

	return maxflow;
}


int main () {
	scanf ("%d%d", &N, &M);
	int i, j;
	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j)
			scanf ("%d", &board[i][j]);

	int cntr = 0;
	bool utc = 0;
	for (i = 0; i < N; ++i) {
		for (j = 0; j < M; ++j) {
			if (board[i][j] != 2)
				map[i][j].first = (utc = 1, cntr);
			else if (utc) utc = 0, ++cntr;
		}
		if (utc) utc = 0, ++cntr;
	}
	int _ft = cntr;
	for (j = 0; j < M; ++j) {
		for (i = 0; i < N; ++i) {
			if (board[i][j] != 2)
				map[i][j].second = (utc = 1, cntr);
			else if (utc) utc = 0, ++cntr;
		}
		if (utc) utc = 0, ++cntr;
	}

	int bp = 0;
	source = cntr;
	sink = source + 1;
	rN = sink + 1;

	for (i = 0; i < rN; ++i) vec[i] = -1;
	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j)
			if (!board[i][j]) {
				buf[bp] = el (map[i][j].second, 1, vec[map[i][j].first]);
				vec[map[i][j].first] = bp++;

				buf[bp] = el (map[i][j].first, 0, vec[map[i][j].second]);
				vec[map[i][j].second] = bp++;
			}

	for (i = 0; i < _ft; ++i) {
		buf[bp] = el (i, 1, vec[source]);
		vec[source] = bp++;

		buf[bp] = el (source, 0, vec[i]);
		vec[i] = bp++;
	}
	for (i = _ft; i < source; ++i) {
		buf[bp] = el (sink, 1, vec[i]);
		vec[i] = bp++;

		buf[bp] = el (i, 0, vec[sink]);
		vec[sink] = bp++;
	}

	int maxflow = dinitz ();
	printf ("%d\n", maxflow);

	return 0;
}
