/*
TASK: kni
LANG: C++

FROM: BaOI 2001 day 2
PROB: kni (knights)
KEYW: matching, dinitz
*/

#include <cstdio>

const int MAXC = 1 << 8;
const int MAXN = 1 << 16;
const int MAXM = 1 << 20;

const int ds = 8;
const int dx[] = {-2, -2, -1, 1, 2, 2, 1, -1};
const int dy[] = {-1, 1, 2, 2, 1, -1, -2, -2};

struct el {
	int to;
	bool rd;
	int next;
	el () {}
	el (int _to, bool _rd, int _next) : to (_to), rd (_rd), next (_next) {}
};

int N;
bool board[MAXC][MAXC];

int rN;
int vec[MAXN];
el buf[MAXM];
int source, sink;

inline int op (int a) {return a ^ 1;}

int D[MAXN];
bool used[MAXN];

bool bfs () {
	static int i, j, p3, crnt;
	static int queue[MAXN];
	for (i = 0; i < rN; ++i) {
		D[i] = -1;
		used[i] = 0;
	}
	used[source] = 1;
	D[sink] = 0;
	queue[p3 = 0, p3++] = sink;

	for (i = 0; i < p3; ++i)
		for (j = vec[crnt = queue[i]]; j != -1; j = buf[j].next)
			if (D[buf[j].to] == -1 && buf[op (j)].rd) {
				D[buf[j].to] = D[crnt] + 1;
				queue[p3++] = buf[i].to;
			}

	return D[source] != -1;
}

int vl[MAXN], vp;

bool dfs (int v) {
	if (v == sink)
		return used[sink] = 0, 1;

	for (int i = vec[v]; i != -1; i = buf[i].next)
		if (D[buf[i].to] == D[v] - 1 && !used[buf[i].to] && buf[i].rd) {
			vl[vp++] = i;
			used[buf[i].to] = 1;
			if (dfs (buf[i].to)) return 1;
			--vp;
		}

	return 0;
}

int dinitz () {
	int maxflow = 0;
	while (bfs ())
		while (vp = 0, dfs (source) && ++maxflow)
			for (int i = 0; i < vp; ++i) {
				buf[vl[i]].rd = 0;
				buf[op (vl[i])].rd = 1;
			}

	return maxflow;
}


bool ok (int i, int j, int k) {
	return ((i += dx[k]) >= 0 && i < N && (j += dy[k]) >= 0 && j < N && !board[i][j]);
}

void build_graph () {
	int i, j, k, cid, nid;
	int bp = 0;

	for (i = 0; i < N * N + 2; ++i) vec[i] = -1;
	for (i = 0; i < N; ++i)
		for (j = i & 1; j < N; j += 2) {
			cid = i * N + j;
			if (board[i][j]) continue;
			for (k = 0; k < ds; ++k)
				if (ok (i, j, k)) {
					nid = (i + dx[k]) * N + j + dy[k];
					buf[bp] = el (nid, 1, vec[cid]);
					vec[cid] = bp++;

					buf[bp] = el (cid, 0, vec[nid]);
					vec[nid] = bp++;
				}
		}
	source = N * N;
	sink = source + 1;
	rN = sink + 1;
	for (i = 0; i < N; ++i)
		for (j = 0; j < N; ++j) {
			if (board[i][j]) continue;
			cid = i * N + j;
			if ((i + j) & 1) {
				buf[bp] = el (sink, 1, vec[cid]);
				vec[cid] = bp++;

				buf[bp] = el (cid, 0, vec[sink]);
				vec[sink] = bp++;
			} else {
				buf[bp] = el (cid, 1, vec[source]);
				vec[source] = bp++;

				buf[bp] = el (source, 0, vec[cid]);
				vec[cid] = bp++;
			}
		}
}

int main () {
	int bad;
	scanf ("%d%d", &N, &bad);
	int i;
	int a, b;
	for (i = 0; i < bad; ++i) {
		scanf ("%d %d", &a, &b);
		board[a-1][b-1] = 1;
	}

	build_graph ();
	int maxflow = dinitz ();
	printf ("%d\n", N * N - bad - maxflow);

	return 0;
}
