/*
TASK: maxflow
LANG: C++

NOTE: a maximum flow pure algorithm (dinitz implementation)
KEYW: dinitz max flow
*/

#include <cstdio>
#include <climits>

const int MAXN = 1 << 16;
const int MAXM = 1 << 20;

struct el {
	int to;
	int rd;
	int next;
	el () {}
	el (int _to, int _rd, int _next) : to (_to), rd (_rd), next (_next) {}
};

inline int op (int a) {return a ^ 1;}

int N, M;
int vec[MAXN];
el buf[MAXM*2];
int source, sink;

int D[MAXN];
bool used[MAXN];
int edgel[MAXN], edgelp;

bool bfs () {
	static int i, j, p3, crnt;
	static int queue[MAXN];
	for (i = 0; i < N; ++i) {
		D[i] = -1;
		used[i] = 0;
	}
	used[source] = 1;
	D[sink] = 0;
	queue[p3 = 0, p3++] = sink;

	for (i = 0; i < p3; ++i)
		for (j = vec[crnt = queue[i]]; j != -1; j = buf[j].next)
			if (D[buf[j].to] == -1 && buf[op (j)].rd) {
				queue[p3++] = buf[j].to;
				D[buf[j].to] = D[crnt] + 1;
			}

	return D[source] != -1;
}

int dfs (int v) {
	if (v == sink) return used[sink] = 0, INT_MAX;//max flow - it will be reduced

	int tmp;
	for (int i = vec[v]; i != -1; i = buf[i].next)
		if (D[buf[i].to] + 1 == D[v] && !used[buf[i].to] && buf[i].rd) {
			used[buf[i].to] = 1;
			edgel[edgelp++] = i;
			if ((tmp = dfs (buf[i].to))) return tmp <? buf[i].rd;
			--edgelp;
		}

	return 0;//no way found
}

int dinitz () {
	int cflow, maxflow = 0;
	while (bfs ())
		while (edgelp = 0, cflow = dfs (source) && maxflow += cflow)
			for (int i = 0; i < edgelp; ++i) {
				buf[edgel[i]].rd -= cflow;
				buf[op (edgel[i])].rd += cflow;
			}

	return maxflow;
}

void input () {
	scanf ("%d %d", &N, &M);
	scanf ("%d %d", &source, &sink);
	--source, --sink;

	int i;
	int a, b, c;
	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d", &a, &b, &c);
		--a; --b;

		buf[i * 2] = el (b, c, vec[a]);
		vec[a] = i * 2;

		buf[i*2+1] = el (a, c, vec[b]);
		vec[b] = i*2+1;
	}
}

int main () {
	input ();
	int maxflow = dinitz ();
	printf ("%d\n", maxflow);

	return 0;
}
