/*
TASK: aliens
LANG: C++

FROM: BOI 2002 day 2
PROB: aliens (zad4)
kEYW: computational geometry
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>

#include <algorithm>

typedef long long lli;
typedef long double ld;

const int MAXN = 1 << 17;
const ld epsilon = 1e-11;

struct pnt {
	ld x, y;
	pnt () {}
	pnt (const ld &_x, const ld &_y) : x (_x), y (_y) {}

	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
	ld operator * (const pnt &a) const {return a.x * x + a.y * y;}
	pnt operator * (const ld &a) const {return pnt (x * a, y * a);}
	ld sq () {return x * x + y * y;}
	ld len () {return sqrtl (sq ());}
	pnt rot1 () {return pnt (-y, x);}
	pnt rot2 () {return pnt (y, -x);}
};

int N;
pnt pnts[MAXN];
int hid[MAXN], hsz;

ld S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int lpid;
bool cmp (int a, int b) {
	static ld tmp;
	return fabsl (tmp = S (pnts[lpid], pnts[a], pnts[b])) > epsilon ?
			tmp > 0 :
			(pnts[a] - pnts[lpid]).sq () < (pnts[b] - pnts[lpid]).sq ();
}

void hull () {
	int i;
	for (i = 1; i < N; ++i)
		if (pnts[i].y - pnts[lpid].y < -epsilon || fabsl (pnts[i].y - pnts[lpid].y) < epsilon && pnts[i].x - pnts[lpid].x > epsilon)
			lpid = i;

	static int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	idx[0] = lpid;
	idx[lpid] = 0;

	std::sort (idx + 1, idx + N, cmp);

//	for (i = 0; i < N; ++i) printf (" (%Lf %Lf)", pnts[idx[i]].x, pnts[idx[i]].y); printf ("\n");

	for (i = 0; i < N; ++i) {
		hid[hsz++] = idx[i];
		while (hsz > 2 && S (pnts[hid[hsz-3]], pnts[hid[hsz-2]], pnts[hid[hsz-1]]) < epsilon) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}

//	for (i = 0; i < hsz; ++i) printf (" (%Lf %Lf)", pnts[hid[i]].x, pnts[hid[i]].y); printf ("\n");
}

void ansD (const pnt &a, const pnt &b) {
//	printf ("D %Lf %Lf  %Lf %Lf\n", a.x, a.y, b.x, b.y);
	pnt center = (b - a) * 0.5;
	ld radius = center.len ();
	center = center + a;

	printf ("%.2Lf\n%.2Lf %.2Lf\n", radius, center.x, center.y);
	exit (0);
}

void ansT (const pnt &a, const pnt &b, const pnt &c) {
//	printf ("T %Lf %Lf  %Lf %Lf  %Lf %Lf\n", a.x, a.y, b.x, b.y, c.x, c.y);

	ld al = (b - c).len (), bl = (a - c).len (), cl = (a - b).len ();
	ld R = fabsl (al * bl * cl / (2 * S (a, b, c)));

	pnt tmp1 (b - a);
	pnt tmpr;
	if (S (a, b, c) > 0) tmpr = tmp1.rot1 ();
	else tmpr = tmp1.rot2 ();

//	printf (">>%Lf %Lf  %Lf %Lf\n", tmp1.x, tmp1.y, tmpr.x, tmpr.y);
	tmpr = tmpr * (1 / tmpr.len ());
	tmp1 = tmp1 * 0.5;
	tmpr = tmpr * sqrtl (R * R - tmp1.sq ());
//	printf ("%Lf!!!\n", tmp1.sq ());
//	printf ("%Lf %Lf  %Lf %Lf\n", tmp1.x, tmp1.y, tmpr.x, tmpr.y);
	pnt center = a + tmp1 + tmpr;
	printf ("%Lf\n%Lf %Lf\n", R, center.x, center.y);
	exit (0);
}

ld ang (int _a, int _b, int _c) {
	static pnt a1, a2;
	a1 = pnts[hid[_c]] - pnts[hid[_a]], a2 = pnts[hid[_c]] - pnts[hid[_b]];

	return (a1 * a2) / (a1.len () * a2.len ());
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%Lf %Lf", &pnts[i].x, &pnts[i].y);

	hull ();
	if (hsz == 2) ansD (pnts[hid[0]], pnts[hid[1]]);
	pnts[N] = pnt (1e5, -1e5);
	hid[hsz] = N;

	int a = 0, b = 1, c = hsz;

	ld max;
	int maxi;
	ld SS;
	ld tmp;
	for (;;) {
//		printf ("%d %d %d\n", a, b, c);
		SS = S (pnts[hid[a]], pnts[hid[b]], pnts[hid[c]]);
		max = -1e99;
		maxi = -1;
		for (i = 0; i < hsz; ++i) {
//			printf ("%d -- %Lf  %Lf\n", i, S (pnts[hid[a]], pnts[hid[b]], pnts[hid[i]]), S (pnts[hid[a]], pnts[hid[b]], pnts[hid[i]]) * SS);
			if (S (pnts[hid[a]], pnts[hid[b]], pnts[hid[i]]) * SS > -epsilon) continue;
//			printf ("%d - stil here!\n", i);
			tmp = ang (a, b, i);
			if (max < tmp) {
				max = tmp;
				maxi = i;
			}
		}
//		printf ("-> %d %Lf\n", maxi, max);

		if (max < 0) ansD (pnts[hid[a]], pnts[hid[b]]);
		assert (maxi != -1);
		if (ang (b, maxi, a) < 0) {
			c = a;
			a = b;
			b = maxi;
		} else if (ang (a, maxi, b) < 0) {
			c = b;
			b = maxi;
			//a == a
		} else
			ansT (pnts[hid[a]], pnts[hid[b]], pnts[hid[maxi]]);
	}

	return 0;
}
