/*
TASK: nivi
LANG: C++

FROM: NOI 2001 k3
PROB: nivi
KEYW: double connected edge list, geometry
*/

#include <cstdio>
#include <cmath>

#include <vector>
#include <algorithm>

const int MAXN = 1 << 10;
const int MAXM = 1 << 13;
const int MAX_ZONE = 1 << 13;
const int MAX_PER_POINT = 1 << 3;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}
};

struct edge {
	int to_pnt;
	int next_star;

	int zone;
	int next_edge;
	edge () {}
	edge (int _to_pnt, int _next_star) : to_pnt (_to_pnt), next_star (_next_star), zone (-1) {}
};

inline int op (int a) {return a ^ 1;}

int N, M;
pnt pnts[MAXN];
int vec[MAXN];
edge buf[MAXM];
int fst[MAXN];

int ref[MAX_ZONE];
std::vector <int> pnts_in_zone[MAX_ZONE];
std::vector <int> nghbr_zones[MAX_ZONE];

int _base;
bool cmp_atan2 (int a, int b) {
	return	atan2 (pnts[buf[a].to_pnt].y - pnts[_base].y, pnts[buf[a].to_pnt].x - pnts[_base].x)
			<
			atan2 (pnts[buf[b].to_pnt].y - pnts[_base].y, pnts[buf[b].to_pnt].x - pnts[_base].x);
}

int main () {
	scanf ("%d %d", &N, &M);

	int i, j, k;
	for (i = 0; i < N; ++i) {
		scanf ("%lf %lf", &pnts[i].x, &pnts[i].y);
		vec[i] = -1;
	}

	int a, b;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &a, &b);
		--a; --b;

		buf[i * 2] = edge (b, vec[a]);
		vec[a] = i * 2;

		buf[i * 2 + 1] = edge (a, vec[b]);
		vec[b] = i * 2 + 1;
	}

	int cid[MAX_PER_POINT], cp;
	for (i = 0; i < N; ++i) {
		#warning careful with size of cid!!!
		cp = 0;
		for (j = vec[i]; j != -1; j = buf[j].next_star)
			cid[cp++] = j;

		_base = i;
		std::sort (cid, cid + cp, cmp_atan2);
		fst[i] = cid[0];
		for (j = 0; j < cp - 1; ++j)
			buf[op (cid[j])].next_edge = cid[j+1];
		buf[op (cid[cp - 1])].next_edge = cid[0];
	}
/*
	for (i = 0; i < N; ++i) {
		printf ("%d ->", i);
		for (j = vec[i]; j != -1; j = buf[j].next_star)
			printf (" <%d>(%d %d)", j, buf[j].to_pnt, buf[j].next_edge);
		printf ("\n");
	}
*/
	///now find the 'outher' zone and number it 0

	int lpid = 0;//lowest point id
	for (i = 1; i < N; ++i)
		if (pnts[i].y < pnts[lpid].y)
			lpid = i;

	buf[fst[lpid]].zone = 0;
//	printf (">>%d(%d)\n", vec[lpid], buf[fst[lpid]].to_pnt);
	for (j = buf[fst[lpid]].next_edge; j != fst[lpid]; j = buf[j].next_edge) {
		buf[j].zone = 0;
//		printf (">>%d(%d)\n", j, buf[j].to_pnt);
	}

	int cz = 1;
	for (i = 0; i < N; ++i) {
		for (j = vec[i]; j != -1; j = buf[j].next_star) {
			if (buf[j].zone != -1) continue;
//			printf ("___zone  %d__\n", cz);
			buf[j].zone = cz;
//			printf (" %d", j);
			for (k = buf[j].next_edge; k != j; k = buf[k].next_edge) {
				buf[k].zone = cz;
//				printf (" %d", k);
			}
//			printf ("\n");
			ref[cz] = j;
			++cz;
		}
	}

	for (i = 1; i < cz; ++i) {
//		printf ("__for zone %d\n", i);
		pnts_in_zone[i].push_back (buf[ref[i]].to_pnt);
		nghbr_zones[i].push_back (buf[op (ref[i])].zone);
//		printf ("push (%d %d)\n", buf[ref[i]].to_pnt, buf[op (ref[i])].zone);
		for (j = buf[ref[i]].next_edge; j != ref[i]; j = buf[j].next_edge) {
			pnts_in_zone[i].push_back (buf[j].to_pnt);
			nghbr_zones[i].push_back (buf[op (j)].zone);
//			printf ("push (%d %d)\n", buf[j].to_pnt, buf[op (j)].zone);
		}
		std::sort (pnts_in_zone[i].begin (), pnts_in_zone[i].end ());
		pnts_in_zone[i].resize (std::unique (pnts_in_zone[i].begin (), pnts_in_zone[i].end ()) - pnts_in_zone[i].begin ());

		std::sort (nghbr_zones[i].begin (), nghbr_zones[i].end ());
		nghbr_zones[i].resize (std::unique (nghbr_zones[i].begin (), nghbr_zones[i].end ()) - nghbr_zones[i].begin ());

/*		for (j = 0; j < pnts_in_zone[i].size (); ++j)
			printf ("__%d", pnts_in_zone[i][j]); printf ("\n");
		for (j = !nghbr_zones[i].front (); j < nghbr_zones[i].size (); ++j)
			printf ("__%d", nghbr_zones[i][j]); printf ("\n");
*/	}

//	printf ("----ans----\n");
	for (i = 1; i < cz; ++i) {
		printf ("%d", pnts_in_zone[i].front () + 1);
		for (j = 1; j < (int)pnts_in_zone[i].size (); ++j)
			printf (" %d", pnts_in_zone[i][j] + 1);
		printf ("\n");
		printf ("%d", nghbr_zones[i][!nghbr_zones[i].front ()]);
		for (j = !nghbr_zones[i].front () + 1; j < (int)nghbr_zones[i].size (); ++j)
			printf (" %d", nghbr_zones[i][j]);
		printf ("\n");
	}

	return 0;
}
