/*
TASK: chess
LANG: C++

FROM: NOI 2004 k3
PROB: chess
KEYW: cyclic game
*/

#include "chess.h"

#include <cstdio>
#include <cstdlib>
#include <cassert>

const int MAXCM = 1 << 6;
const int MAXCODE = 1 << 19;//exactly

int dkx[] = {-1, -1, -1, 0, 1, 1, 1, 0};
int dky[] = {-1, 0, 1, 1, 1, 0, -1, -1};
int M;
int dcx[MAXCM];
int dcy[MAXCM];

int code (int kx, int ky, int cx, int cy, int ex, int ey, bool w) {
	return (w << 18) | (kx << 15) | (ky << 12) | (cx << 9) | (cy << 6) | (ex << 3) | ey;
}

void decode (int id, int &kx, int &ky, int &cx, int &cy, int &ex, int &ey, bool &w) {
	ey = id & 7; id >>= 3; ex = id & 7; id >>= 3;
	cy = id & 7; id >>= 3; cx = id & 7; id >>= 3;
	ky = id & 7; id >>= 3; kx = id & 7; id >>= 3;
	w = id;
}

bool good_pos (int x, int y) {
	return x >= 0 && x < 8 && y >= 0 && y < 8;
}

bool invalid (int kx, int ky, int cx, int cy, int ex, int ey, bool w) {
	return kx == cx && ky == cy || w == 1 && kx == ex && ky == ey || w == 1 && cx == ex && cy == ey;
}

int prev[MAXCODE];
int in[MAXCODE];
int queue[MAXCODE];

int sstate;
void input () {
	FILE *in = fopen ("chess.in", "r");
	char skx, sky, scx, scy, sex, sey;
	fscanf (in, "%c%c %c%c %c%c", &skx, &sky, &scx, &scy, &sex, &sey);
	sstate = code ('8' - sky, skx - 'a', '8' - scy, scx - 'a', '8' - sey, sex - 'a', 1);

	fscanf (in, "%d", &M);
	for (int i = 0; i < M; ++i) {
		fscanf (in, "%d %d", dcy + i, dcx + i);
		dcx[i] = -dcx[i];
	}
	fclose (in);
}

void bfs () {
	bool w;
	int i, k;
	int kx, ky, cx, cy, ex, ey;
	int nx, ny, p3 = 0, c, go;
	for (i = 0; i < MAXCODE; ++i) {
		prev[i] = -2;
		decode (i, kx, ky, cx, cy, ex, ey, w);

		if (kx == cx && ky == cy) continue;//absolutely invalid
		if (w && cx == ex && cy == ey && abs (cx - kx) < 2 && abs (cy - ky) < 2) {
			queue[p3++] = i;
			prev[i] = -1;
		}
		if (!w) {
			if (cx == ex && cy == ey || kx == ex && ky == ey) {
				queue[p3++] = i;
				prev[i] = -1;
				continue;
			}
			for (k = 0; k < 8; ++k) {
				nx = ex + dkx[k];
				ny = ey + dky[k];
				if (good_pos (nx, ny)) ++in[i];
			}
		}
	}
	for (i = 0; i < p3; ++i) {
		c = queue[i];
		decode (c, kx, ky, cx, cy, ex, ey, w);
		if (w) {//my turn now so his previous turn
			for (k = 0; k < 8; ++k) {
				nx = ex - dkx[k];
				ny = ey - dky[k];
				if (!good_pos (nx, ny) || invalid (kx, ky, cx, cy, nx, ny, 0)) continue;
				go = code (kx, ky, cx, cy, nx, ny, 0);
				if (!--in[go]) {queue[p3++] = go; prev[go] = c;}
			}
		} else {//his turn so mine previous
			for (k = 0; k < 8; ++k) {
				nx = kx - dkx[k];
				ny = ky - dky[k];
				if (!good_pos (nx, ny) || invalid (nx, ny, cx, cy, ex, ey, 1)) continue;
				go = code (nx, ny, cx, cy, ex, ey, 1);
				if (prev[go] == -2) {queue[p3++] = go; prev[go] = c;}
			}
			for (k = 0; k < M; ++k) {
				nx = cx - dcx[k];
				ny = cy - dcy[k];
				if (!good_pos (nx, ny) || invalid (kx, ky, nx, ny, ex, ey, 1)) continue;
				go = code (kx, ky, nx, ny, ex, ey, 1);
				if (prev[go] == -2) {queue[p3++] = go; prev[go] = c;}
			}
		}
	}
}

void my_get_king (int &a, int &b) {char x; long y; getKing (&x, &y); b = x - 'a'; a = 8 - y;}

int main () {
	input ();
	bfs ();
	int kx, ky, cx, cy, ex, ey;
	bool w;
	int nkx, nky, ncx, ncy, nex, ney;
	bool nw;
	decode (sstate, kx, ky, cx, cy, ex, ey, w);
	for (;;) {
		sstate = prev[sstate];
		decode (sstate, nkx, nky, ncx, ncy, nex, ney, nw);
		if (nkx != kx || nky != ky)
			kx = nkx, ky = nky, moveKing ('a' + ky, 8 - kx);
		else
			cx = ncx, cy = ncy, moveColonel ('a' + cy, 8 - cx);
		if (prev[sstate] == -1) return 0;//end game;
		my_get_king (ex, ey);
		sstate = code (kx, ky, cx, cy, ex, ey, 1);
	}
}
