/*
TASK: chess
LANG: C++

FROM: NOI 2004 k3
PROB: chess
KEYW: cyclic game
*/

#include "chess.h"

#include <cstdio>
#include <cassert>
#include <vector>

unsigned _stklen = 1 << 25;//32 000 000

const int MAXCM = 1 << 6;//60
const int MAXCODE = 1 << 19;//exactly!!

const int kdx[] = {-1, -1, -1, 0, 1, 1,  1,  0};
const int kdy[] = {-1,  0,  1, 1, 1, 0, -1, -1};
int M;
int cdx[MAXCM];
int cdy[MAXCM];

inline bool okpos (int x, int y, const int *dx, const int *dy, int k) {
	return (x += dx[k]) >= 0 && x < 8 && (y += dy[k]) >= 0 && y < 8;
}

inline int code (int kx, int ky, int cx, int cy, int ex, int ey, bool w) {
	return (w << 18) | (ey << 15) | (ex << 12) | (cy << 9) | (cx << 6) | (ky << 3) | kx;
}

inline int code2 (int kx, int ky, int cx, int cy, int ex, int ey, bool w) {
	if (ex == cx && ey == cy)
		return code (kx, ky, kx, ky, ex, ey, w);
	else
		return code (kx, ky, cx, cy, ex, ey, w);
}

inline void decode (int id, int &kx, int &ky, int &cx, int &cy, int &ex, int &ey, bool &w) {
	kx = id & 7; id >>= 3; ky = id & 7; id >>= 3;
	cx = id & 7; id >>= 3; cy = id & 7; id >>= 3;
	ex = id & 7; id >>= 3; ey = id & 7; id >>= 3;
	w = id;
}

int opt[MAXCODE];
int prev[MAXCODE];
//int t[MAXCODE];

int queue[MAXCODE], p3;
int in[MAXCODE];

std::vector <int> vec[MAXCODE];//here is the reversed graph
//std::vector <int> vec2[MAXCODE];//here is the normal graph

void build_graph () {
	int i, k;
	int kx, ky, cx, cy, ex, ey;
	bool w;
	int nx, ny;//temporary
	int go;
	for (i = 0; i < MAXCODE; ++i) {
//		t[i] = -1;//undetermined
		decode (i, kx, ky, cx, cy, ex, ey, w);
		if (w == 1) {//my turn
			if (ex == kx && ey == ky) {opt[i] = 2; /*t=0*/queue[p3++] = i; continue;}
			if (ex == cx && ey == cy) {opt[i] = -1; continue;}//invalid situation

			if (kx == cx && ky == cy) {//we have king only
				for (k = 0; k < 8; ++k)  //move the king
					if (okpos (kx, ky, kdx, kdy, k)) {
						nx = kx + kdx[k]; ny = ky + kdy[k];
						go = code (nx, ny, nx, ny, ex, ey, 0);//move the K and C together (couse we dont have C)
						vec[go].push_back (i);
//						vec2[i].push_back (go);
						++in[i];
					}
			} else {//we have a king and a colonel
				for (k = 0; k < 8; ++k)  //move the king
					if (okpos (kx, ky, kdx, kdy, k)) {
						nx = kx + kdx[k]; ny = ky + kdy[k];
						if (nx == cx && ny == cy) continue;//can not go over the colonel
						go = code (nx, ny, cx, cy, ex, ey, 0);
						vec[go].push_back (i);
//						vec2[i].push_back (go);
						++in[i];
					}
				for (k = 0; k < M; ++k)  //move the colonel
					if (okpos (cx, cy, cdx, cdy, k)) {
						nx = cx + cdx[k]; ny = cy + cdy[k];
						if (nx == kx && ny == ky) continue;//can not go over the king
						go = code (kx, ky, nx, ny, ex, ey, 0);
						vec[go].push_back (i);
//						vec2[i].push_back (go);
						++in[i];
					}
			}
		} else {//opponents turn
			if ((ex == kx && ey == ky) || (ex == cx && ey == cy)) {opt[i] = 1; /*t[i] = 0;*/ queue[p3++] = i; continue;}//we win

			for (k = 0; k < 8; ++k)  //move the enemy king
				if (okpos (ex, ey, kdx, kdy, k)) {
					go = code2 (kx, ky, cx, cy, ex + kdx[k], ey + kdy[k], 1);//if taking the colonel -> make cx,xy = kx,ky
					vec[go].push_back (i);
//						vec2[i].push_back (go);
					++in[i];
				}
		}
	}
}

void bfs () {//only determines winning and losing
	int i, j;
	int crnt, go;
	bool w;
//	printf ("p3 in beggingin %d\n", p3);
	for (i = 0; i < p3; ++i) {
		crnt = queue[i];
		w = crnt & (1 << 18);//black/white
		for (j = 0; j < (int)vec[crnt].size (); ++j) {
			go = vec[crnt][j];
//			assert (opt[crnt] == 1 || opt[crnt] == 2);
//			assert ((go & (1 << 18)) != w);
			assert (opt[go] != -1);//it is not invalind
			if (opt[go]) continue;//already calculated
			if (w == 1) {
				if (opt[crnt] == 1) {
					if (!(--in[go])) {
						opt[go] = 1;//he doesnt have a chance -> we win (he loses)
						queue[p3++] = go;
						prev[go] = crnt;//to test in the begining
					}
				} else {
					opt[go] = 2;//he wins (we lose)
					queue[p3++] = go;
					prev[go] = crnt;//to test in the begining
				}
			} else {
				if (opt[crnt] == 1) {
					opt[go] = 1;//we win
					queue[p3++] = go;
					prev[go] = crnt;//to test in the begining
				} else {
					if (!(--in[go])) {
						opt[go] = 2;//we lose (dont have another chance)
						queue[p3++] = go;
						prev[go] = crnt;
					}
				}
			}
		}
	}
}

int skx, sky, scx, scy, sex, sey;//starting positions
int st;
void input () {
	FILE *in = fopen ("chess.in", "r");
//	FILE *in = stdin;
	char buf[4];
	fscanf (in, "%s", buf); skx = 8 - (buf[1] - '0'); sky = (buf[0] - 'a');// fprintf (stderr, "%s\n", buf);
	fscanf (in, "%s", buf); scx = 8 - (buf[1] - '0'); scy = (buf[0] - 'a');// fprintf (stderr, "%s\n", buf);
	fscanf (in, "%s", buf); sex = 8 - (buf[1] - '0'); sey = (buf[0] - 'a');// fprintf (stderr, "%s\n", buf);
	st = code (skx, sky, scx, scy, sex, sey, 1);
	fscanf (in, "%d", &M);
	for (int i = 0; i < M; ++i) fscanf (in, "%d %d", cdy + i, cdx + i);//inverted!
	for (int i = 0; i < M; ++i) cdx[i] = -cdx[i];//finish the inverting
	for (int i = 0; i < M; ++i) fprintf (stderr, "%d %d\n", cdx[i], cdy[i]);
}

void mymoveKing (int x, int y) {moveKing (y + 'a', (long)8 - x);}
void mymoveColonel (int x, int y) {moveColonel (y + 'a', (long)8 - x);}
void mygetKing (int &x, int &y) {char a; long b; getKing (&a, &b); x = 8 - b; y = a - 'a';}

int main () {
	input ();
	build_graph ();
	bfs ();

	int kx, ky, cx, cy, ex, ey;
	bool w;

	int kx1, ky1, cx1, cy1, ex1, ey1;
	bool w1;

	int go;
	int nx, ny;
	for (;;) {
//		if (t[st] == 0) return 0;//finish
		decode (st, kx, ky, cx, cy, ex, ey, w);
		go = prev[st];
		decode (go, kx1, ky1, cx1, cy1, ex1, ey1, w1);

		if (kx1 != kx || ky1 != ky)
			mymoveKing (kx1, ky1);
		else
			mymoveColonel (cx1, cy1);

//		if (t[go] == 0) return 0;//finish
		mygetKing (nx, ny);
		st = code2 (kx1, ky1, cx1, cy1, nx, ny, 1);//chechs if he has taken the colonel
	}

	return 0;
}
