/*
TASK: lgame
LANG: C++

FROM: BalticOI 2002 day	2
PROB: lgame
KEYW: cyclic game
*/

#include <cstdio>
#include <cassert>
#include <vector>
#include <algorithm>

const int MAXSTATE = 1 << 16;//very close

int Lp[8][4][2] =
{
	{
		{0, 0}, {0, 1}, {0, 2}, {1, 0}
	},{
		{0, 0}, {0, 1}, {1, 1}, {2, 1}
	},{
		{1, 0}, {1, 1}, {1, 2}, {0, 2}
	},{
		{0, 0}, {1, 0}, {2, 0}, {2, 1}
	},{
		{0, 0}, {1, 0}, {1, 1}, {1, 2}
	},{
		{2, 0}, {2, 1}, {1, 1}, {0, 1}
	},{
		{0, 0}, {0, 1}, {0, 2}, {1, 2}
	},{
		{0, 0}, {0, 1}, {1, 0}, {2, 0}
	}
};

void decodeLpos (int id, int &a, int &x, int &y) {
	a = id / 6; id %= 6;
	x = id / 3;
	y = id % 3;
	if (!(a & 1)) std::swap (x, y);
}

void decode_perm (int id, int &a, int &b) {
	for (int i = 7; i >= 1; --i)
		if ((id -= i) < 0) {
			id += i;
			a = 7 - i;
			b = a + id + 1;
			break;
		}
}

int code_perm (int a, int b) {
	int res = 0;
	if (a > b) std::swap (a, b);
	for (int i = 0; i < a; ++i)
		res += (7 - i);

	return res + b - a - 1;
}

char board[4][4];
char ib[4][4];

int coef[8] = {1, 8, 28, 1344, 64512};

void clear_board () {for (int i = 0; i < 4; ++i) for (int j = 0; j < 4; ++j) board[i][j] = '.';}

void putL (int c, char pp) {
	int id, x, y;
	decodeLpos (c, id, x, y);
	for (int i = 0; i < 4; ++i)
		board[Lp[id][i][0] + x][Lp[id][i][1] + y] = pp;
}

bool canput (int c, char pp) {
	int id, x, y;
	decodeLpos (c, id, x, y);
	for (int i = 0; i < 4; ++i)
		if (board[Lp[id][i][0] + x][Lp[id][i][1] + y] == pp
		 || board[Lp[id][i][0] + x][Lp[id][i][1] + y] == 'x')
			return 0;
	return 1;
}

int sx1, sy1, sx2, sy2;
void putx (int a, int b) {
	static int i, j;
	for (i = 0; i < 4; ++i)
		for (j = 0; j < 4; ++j)
			if (board[i][j] == '.') {
				if (!a--) {board[i][j] = 'x'; sx1 = i; sy1 = j;}
				if (!b--) {board[i][j] = 'x'; sx2 = i; sy2 = j;}
			}
}

void fnd (int &a, int &b) {
	int i, j, cntr = 0;
	for (i = 0; i < 4; ++i)
		for (j = 0; j < 4; ++j)
			if (board[i][j] == '.' || board[i][j] == 'x') {
				if (sx1 == i && sy1 == j) a = cntr;
				if (sx2 == i && sy2 == j) b = cntr;
				++cntr;
			}
}

bool decode (int id, int &code1, int &code2, int &code3, int &code4) {
	code2 = id / coef[3]; id %= coef[3];
	code1 = id / coef[2]; id %= coef[2];
	decode_perm (id, code3, code4);

	clear_board ();
	putL (code1, '#');
	if (!canput (code2, '#')) return 0;
	putL (code2, '*');
	putx (code3, code4);
	return 1;//everything is ok
}

void prnt (int x = 0) {
	for (int i = 0; i < 4; ++i) {
		for (int j = 0; j < 4; ++j)
			putchar (x ? board[i][j] == '#' ? '*' : board[i][j] == '*' ? '#' : board[i][j] : board[i][j]);
		putchar ('\n');
	}
}

void input () {
	int i, j;
	for (i = 0; i < 4; ++i) {
		for (j = 0; j < 4; ++j)
			ib[i][j] = getchar ();
		getchar ();
	}
}

std::vector <int> vec[MAXSTATE];
int in[MAXSTATE];

void putall (int id, int c1, int c2) {
	static int base;
	base = c1 * coef[2] + c2 * coef[3];
	static int i;

	static int c3, c4;
	fnd (c3, c4);
	in[id] += 13;//6 + 6 + 1
	for (i = 0; i < 8; ++i)
		if (i != c3 && i != c4) {
			vec[base + code_perm (c3, i)].push_back (id),
			vec[base + code_perm (i, c4)].push_back (id);
		}

	vec[base + code_perm (c3, c4)].push_back (id);
}

int start = -1;
int queue[MAXSTATE];
int p3;
int opt[MAXSTATE];
int prev[MAXSTATE];

bool cmp_input () {
	static int i, j;
	for (i = 0; i < 4; ++i)
		for (j = 0; j < 4; ++j)
			if (board[i][j] != ib[i][j]) goto end;
	end:;
	return j == 4;
}

void build_graph () {
	int i, id;
	int code1, code2, code3, code4;
	int stc = coef[4];
	for (id = 0; id < stc; ++id) {
		if (!decode (id, code1, code2, code3, code4)) {opt[id] = -1; continue;}
		if (cmp_input ()) start = id;

		putL (code1, '.');//erase
		for (i = 0; i < 48; ++i)
			if (i != code1 && canput (i, '*')) {
				putL (i, '#');//putnew
				putall (id, code2, i);
				putL (i, '.');//erase
			}

		if (!in[id]) {
			queue[p3++] = id;
			opt[id] = 2;//losing
		}
	}

	assert (start != -1);
}

void bfs () {
	int crnt;
	for (int i = 0; i < p3; ++i) {
		crnt = queue[i];
		for (int j = 0; j < (int)vec[crnt].size (); ++j) {
			if (opt[vec[crnt][j]] == 1) continue;
			assert (opt[vec[crnt][j]] != 2);
			if (opt[crnt] == 2) {
				queue[p3++] = vec[crnt][j];
				opt[vec[crnt][j]] = 1;
				prev[vec[crnt][j]] = crnt;
			} else if (!(--in[vec[crnt][j]])) {
				queue[p3++] = vec[crnt][j];
				opt[vec[crnt][j]] = 2;
				prev[vec[crnt][j]] = crnt;//not needed
			}
		}
	}
}

int main () {
/*	int a, b;
	scanf ("%d %d", &a, &b);
	int res = code_perm (a, b);
	printf ("%d - ", res);
	decode_perm (res, a, b);
	printf ("%d %d\n", a, b);
*/
/*	int t1, t2, t3, t4;
	int c1 = 33, c2 = 43, c3 = 5, c4 = 7;
	scanf ("%d %d %d %d", &c1, &c2, &c3, &c4);
	int base = c1 * coef[2] + c2 * coef[3];
	int i;
	for (i = 0; i < 8; ++i)
		if (i != c3 && i != c4) {
			printf ("-->%d %d --", c3, i);
			decode (base + code_perm (c3, i), t1, t2, t3, t4);
			printf ("%d %d %d %d\n", t1, t2, t3, t4);

			printf ("-->%d %d --", i, c4);
			decode (base + code_perm (i, c4), t1, t2, t3, t4);
			printf ("%d %d %d %d\n", t1, t2, t3, t4);
		}
*/
	input ();

	build_graph ();
	bfs ();
	if (opt[start] == 1) {
		int tmp1, tmp2, tmp3, tmp4;
		decode (prev[start], tmp1, tmp2, tmp3, tmp4);
		prnt (1);
	} else
		printf ("%s\n%s\n", "No winning move", opt[start] == 2 ? "Losing" : "Draw");

	return 0;

}
