/*
TASK: trade
LANG: C++

FROM: SPRING 2003 A
PROB: trade
KEYW: cyclic game
*/

#include "trade.h"

#include <cstdio>
#include <cassert>
#include <cstdlib>

const int MAXN = 1 << 5;//maximum 20
const int MAX = 1 << 20;

struct tr {
	int frt, frc;
	int tot, toc;
};

int N, P;
int K[MAXN];//capacity
int v[MAXN];//initial
tr trs[MAX];
int stc;

int coef[MAXN];

int code (int *v) {
	static int i, res;
	for (i = 0, res = 0; i < N; ++i) res += coef[i] * v[i];
	return res;
}

void decode (int a, int *v) {
	for (int i = N-1; i >= 0; --i) {v[i] = a / coef[i]; a %= coef[i];}
}

void undomove (int *v, int move) {
	v[trs[move].tot] -= trs[move].toc;
	v[trs[move].frt] += trs[move].frc;
}

void domove (int *v, int move) {
	v[trs[move].frt] -= trs[move].frc;
	v[trs[move].tot] += trs[move].toc;
}

int opt[MAX];
int prev[MAX];
int queue[MAX];
int in[MAX];

void bfs () {
	int p3 = 0;
	stc = coef[N];
	int i, j;
	int tmp[MAXN];
	int go;
	for (i = 0; i < stc; ++i) {
		decode (i, tmp);

		for (j = 0; j < P; ++j)
			if (tmp[trs[j].frt] >= trs[j].frc
			 && tmp[trs[j].tot] <= K[trs[j].tot] - trs[j].toc)
				++in[i];

		if (!in[i]) {
			queue[p3++] = i;
			opt[i] = 2;//losing
			prev[i] = -1;//we're done
			for (j = 0; j < N; ++j) printf ("%d ", tmp[j]); printf ("(losing)\n");
		}
	}

	for (i = 0; i < p3; ++i) {
		decode (queue[i], tmp);
		for (j = 0; j < P; ++j) {
			if (tmp[trs[j].tot] >= trs[j].toc
			 && tmp[trs[j].frt] <= K[trs[j].frt] - trs[j].frc) {
				undomove (tmp, j);
				go = code (tmp);
				assert (opt[go] != 2);//no way to be losing
				if (opt[go] == 1) {domove (tmp, j); continue;}//he is already winning

				if (opt[queue[i]] == 1) {//we win
					if (!(--in[go])) {
						opt[go] = 2;
						prev[go] = j;//for the module
						queue[p3++] = go;
					}
				} else {//we lose
					opt[go] = 1;
					prev[go] = j;
					queue[p3++] = go;
				}

				domove (tmp, j);
			}
		}
	}

	printf ("%d / %d\n", p3, stc);

	for (i = 0; i < stc; ++i) {//make prev for undetermined
		if (opt[i]) continue;

		decode (i, tmp);
		for (j = 0; j < P; ++j) {
			if (tmp[trs[j].frt] >= trs[j].frc
			 && tmp[trs[j].tot] <= K[trs[j].tot] - trs[j].toc) {
				domove (tmp, j);
				go = code (tmp);
				if (!opt[go]) {prev[i] = j; break;}
				undomove (tmp, j);
			}
		}

		if (j == P) {
			decode (i, tmp);
			for (int k = 0; k < N; ++k) printf ("%d ", tmp[k]); printf ("(%d %d)\n", opt[i], in[i]);
			for (j = 0; j < P; ++j) {
				if (tmp[trs[j].frt] >= trs[j].frc
				 && tmp[trs[j].tot] <= K[trs[j].tot] - trs[j].toc) {
					domove (tmp, j);
					for (int k = 0; k < N; ++k) printf ("%d ", tmp[k]); printf ("(%d)\n", opt[code (tmp)]);
					undomove (tmp, j);
				}
			}
		}

		assert (j != P);
	}
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", K + i, v + i);

	scanf ("%d", &P);
	for (i = 0; i < P; ++i) {
		scanf ("%d %d %d %d", &trs[i].frt, &trs[i].frc, &trs[i].tot, &trs[i].toc);
		--trs[i].frt;
		--trs[i].tot;
	}

	coef[0] = 1;
	for (i = 1; i <= N; ++i) coef[i] = coef[i-1] * (K[i-1] + 1);

	bfs ();

	int state = code (v);
	if (opt[state] == 2)
		say (2);
	else {
		say (1);
		say (prev[state] + 1);
		domove (v, prev[state]);
	}

	int move;
	for (;;) {
//		for (i = 0; i < N; ++i) printf ("%d ", v[i]); printf ("\n");
		move = ask () - 1;
		domove (v, move);
//		for (i = 0; i < N; ++i) printf ("%d ", v[i]); printf ("\n");
		state = code (v);
		assert (opt[state] != 2);//I am not losing
		say (prev[state] + 1);
		domove (v, prev[state]);
	}

	return 0;
}
