/*
TASK: race
LANG: C++

FROM: BOI 2004 day 2
PROB: race
KEYW: graph expansion, dijkstra with hand-made heap
*/

#include <cstdio>
#include <climits>

const int MAXN = 1 << 11;//2000
const int MAXM = 1 << 16;//50 000
const int MAXHEAP = MAXM * 2;

inline int min (int a, int b) {return a < b ? a : b;}

int N, M;
int vec[MAXN];
int buf[MAXM];

int len[MAXM];
int ee[MAXM][2];

int coor[MAXN][2];

inline int op (int a) {return a ^ 1;}//& 0xfffffffe;}

//BEGIN heap
struct heap {
	int id;
	int me;
	heap () {}
	heap (int _id, int _me) : id (_id), me (_me) {}
};

heap h[MAXHEAP];
int hlen;
int idx[MAXM];
const int NOT_IN = -1, POPPED = -2;

void init () {
	int i;
	for (i = 1; i < MAXHEAP; ++i) h[i].me = 0;
	h[0].me = INT_MAX;
	hlen = 1;
	for (i = 0; i < MAXM; ++i) idx[i] = NOT_IN;
}

void siftup (int id) {
//	printf ("in su!\n");
	heap tomove = h[idx[id]];

	int p1 = idx[id], p2 = p1 / 2;
	while (h[p2].me < tomove.me) {
		h[p1] = h[p2];
		idx[h[p2].id] = p1;

		p1 = p2;
		p2 /= 2;
	}

	h[p1] = tomove;
	idx[id] = p1;
}

heap pop () {
	heap ret = h[1]; idx[ret.id] = POPPED;
	heap tomove = h[--hlen];
	h[hlen].me = 0;
	if (hlen == 1)
		return ret;

	int p1 = 1, p2 = 2;

	for (;;) {
		if (h[p2+1].me > h[p2].me)
			++p2;
		if (h[p2].me > tomove.me) {
			h[p1] = h[p2];
			idx[h[p2].id] = p1;

			p1 = p2;
			p2 *= 2;
		} else
			break;
	}

	h[p1] = tomove;
	idx[tomove.id] = p1;
	return ret;
}

bool add (int id, int me) {
	if (idx[id] == NOT_IN) {
		h[hlen] = heap (id, me);
		idx[id] = hlen++;
		siftup (id);
		return 1;
	} else if (idx[id] != POPPED && h[idx[id]].me < me) {
		h[idx[id]].me = me;
		siftup (id);
		return 1;
	}

	return 0;
}

//END HEAP

inline int S (int ax, int ay, int bx, int by, int cx, int cy) {
	return (bx - ax) * (cy - ay) - (by - ay) * (cx - ax);
}

inline bool okturn (int a, int b, int c) {
	return S (coor[a][0], coor[a][1], coor[b][0], coor[b][1], coor[c][0], coor[c][1]) >= 0;
}

int Bme;
int Bl;
int Br[MAXM];
int prev[MAXM];

void dijkstra (int start) {
//	printf ("-----%d------\n", start);
	init ();
	int i;
	for (i = 0; i < MAXM; ++i) prev[i] = -1;

	add (start, len[start]);

	heap c;
	while (hlen > 1) {
		c = pop ();

//		printf ("popped %d %d\n", c.id, c.me);
		if (c.id == start) {
			if (prev[c.id] != -1)
				goto ok;
			idx[start] = NOT_IN;
		}
		for (i = vec[ee[c.id][1]]; i != -1; i = buf[i])
			if (i != op (c.id) //make a 180 degree turn
			 && okturn (ee[c.id][0], ee[c.id][1], ee[i][1])
			 && add (i, min (c.me, len[i]))) {
				prev[i] = c.id;
//				printf ("push %d %d\n", i, min (c.me, len[i]));
			}
	}

	return;
	ok:;
	int crnt = start;
	if (c.me > Bme) {
		Br[0] = crnt; crnt = prev[crnt];
		for (Bl = 1; crnt != start; crnt = prev[crnt], ++Bl)
			Br[Bl] = crnt;
	}
}

int dst (int ax, int ay, int bx, int by) {
	return (ax - bx) * (ax - bx) + (ay - by) * (ay - by);
}

int main () {
	scanf ("%d %d", &N, &M);

	int i;
	for (i = 0; i < N; ++i) {
		vec[i] = -1;
		scanf ("%d %d", &coor[i][0], &coor[i][1]);
	}

	int a, b;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &a, &b);
		--a; --b;

		ee[i*2][0] = a;
		ee[i*2][1] = b;
		ee[i*2+1][0] = b;
		ee[i*2+1][1] = a;

		buf[i*2] = vec[a];
		vec[a] = i*2;

		buf[i*2+1] = vec[b];
		vec[b] = i*2+1;

		len[i*2] = len[i*2+1] = dst (coor[a][0], coor[a][1], coor[b][0], coor[b][1]);
	}
/*
	for (i = 0; i < M * 2; ++i)
		printf ("%d %d\n", ee[i][0], ee[i][1]);
	for (i = 0; i < N; ++i) {
		printf ("%d ->", i);
		for (int j = vec[i]; j != -1; j = buf[j])
			printf (" %d", j);
		printf ("\n");
	}
	printf ("____\n");
*/
	Bme = 0;
	for (i = vec[0]; i != -1; i = buf[i])
		dijkstra (i);

	printf ("%d\n%d", Bl +  1, 1);
	for (i = Bl; i; --i) printf (" %d", ee[Br[i]][1] + 1); printf ("\n");

	return 0;
}
