/*
TASK: speed
LANG: C++

FROM: BaOI 2002 day 1
PROB: speed
KEYW: graph expansion with optimizations, dijkstra with stl heap
*/

#include <cstdio>
#include <cassert>
#include <cmath>

#include <vector>
#include <utility>
#include <queue>

const int MAXN = 1 << 8;//150
const int MAXM = MAXN * MAXN;
const int MAXV = 1 << 9;//500
const double epsilon = 1e-9;

struct el {
	int to;
	int v;
	int dist;
	int next;
	el () {}
	el (int _to, int _v, int _dist, int _next) : to (_to), v (_v), dist (_dist), next (_next) {}
};

struct heap {
	int to;
	int v;
	double time;
	int pto;//previous to
	int pv;//previous v
	heap () {}
	heap (int _to, int _v, double _time, int _pto, int _pv) : to (_to), v (_v), time (_time), pto (_pto), pv (_pv) {}
	bool operator < (const heap &a) const {return fabs (time - a.time) > epsilon ? time > a.time : v < a.v;}
};

int N, M, D;
int vec[MAXN];
el buf[MAXM];

std::pair <int, int> prev[MAXN][MAXV];
int maxV[MAXN];

std::priority_queue <heap> h;

int dijkstra () {
	h.push (heap (0, 70, 0, -1, -1));

	int newv;
	heap crnt;
	while (!h.empty ()) {
		crnt = h.top (); h.pop ();

//		printf ("%d %d %lf %d %d\n", crnt.to, crnt.v, crnt.time, crnt.pto, crnt.pv);
		if (crnt.v <= maxV[crnt.to]) continue;
//		printf ("cont!\n");
		maxV[crnt.to] = crnt.v;
		prev[crnt.to][crnt.v] = std::make_pair (crnt.pto, crnt.pv);
		if (crnt.to == D) return crnt.v;//to know where to start the search for the path

		for (int i = vec[crnt.to]; i != -1; i = buf[i].next) {
			newv = buf[i].v ? buf[i].v : crnt.v;
			if (newv > maxV[buf[i].to]) {
//				printf ("push ==> %d %d %lf %d %d\n", buf[i].to, newv, crnt.time + (double)buf[i].dist / newv, crnt.to, crnt.v);
				h.push (heap (buf[i].to, newv, crnt.time + (double)buf[i].dist / newv, crnt.to, crnt.v));
			}
		}
	}
	return -1;
}

int main () {
	scanf ("%d %d %d", &N, &M, &D);

	int i;
	int a, b, v, d;
	for (i = 0; i < N; ++i) vec[i] = -1;
	for (i = 0; i < M; ++i) {
		scanf ("%d %d %d %d", &a, &b, &v, &d);
		buf[i] = el (b, v, d, vec[a]);
		vec[a] = i;
	}
	int fv = dijkstra ();
	assert (fv != -1);
	std::vector <int> ans;
	for (std::pair <int, int> pos (D, fv); pos.first != -1; pos = prev[pos.first][pos.second])
		ans.push_back (pos.first);

	printf ("%d", ans.back ());
	for (i = ans.size () - 2; i >= 0; --i) printf (" %d", ans[i]); printf ("\n");

	return 0;
}
