/*
FROM: GCJ (Google Code Jam) Round 1B 2008
PROB: B Number Sets
KEYW: prime numbers, disjoint sets
NOTE: works for both cases (.5 min for the big one)

LANG: GNU C++ (g++ (GCC) 4.3.1 20080612 (Red Hat 4.3.1-2))
OPT: -lm -O2
*/

#include <cstdio>
#include <climits>
#include <cassert>
#include <ext/hash_set>

namespace std {
	using namespace __gnu_cxx;
}

typedef long long ll;

const int MAXPRC = 1 << 17;
const int MAXPR = 1 << 20;
const int MAXL = 1 << 20;

int prc;
int pr[MAXPRC];

void init_prime() {
	static char eseed[MAXPR];

	int i, j;
	for (i = 2; i < MAXPR; ++i) {
		if (eseed[i]) continue;
		assert(prc < MAXPRC);
		pr[prc++] = i;
		if ((ll)i * i > INT_MAX) continue;
		for (j = (ll)i * i; j < MAXPR; j += i)
			eseed[j] = 1;
	}
}

ll A, B, P;

int nlen;
int nxt[MAXL];
int top(int start) {
	assert(start >= 0 && start < nlen);
	for (; start != nxt[start]; start = nxt[start])
		nxt[start] = nxt[nxt[start]];
	return start;
}

void join(int s2, int jw) {
	s2 = top(s2);
	if (s2 != jw)
		nxt[s2] = jw;
}

void init_sets(int len) {
	nlen = len;
	for (int i = 0; i < nlen; ++i)
		nxt[i] = i;
}

int set_count() {
	std::hash_set<int> tops;
	for (int i = 0; i < nlen; ++i)
		tops.insert(top(i));
	return tops.size();
}

int main() {
	init_prime();
	fprintf(stderr, "inited primes!\n");

	int tc;
	scanf ("%d", &tc);

	for (int ctc = 1; ctc <= tc; ++ctc) {
		scanf ("%Ld %Ld %Ld", &A, &B, &P);
		fprintf(stderr, "%d\n", ctc);

		init_sets(B - A + 1);
		for (int i = 0; i < prc; ++i) {
			if (pr[i] < P) continue;

			ll lb, ub;
			lb = (A + (ll)pr[i] - 1ll) / (ll)pr[i];
			ub = (B + (ll)pr[i]) / (ll)pr[i];

			if (ub - lb < 2) continue;//nothing to join

			int join_with = top(lb * pr[i] - A);
			for (ll j = lb + 1; j != ub; ++j)
				join(j * pr[i] - A, join_with);
		}

		printf("Case #%d: %d\n", ctc, set_count());
	}

	return 0;
}