/*
FROM: GCJ (Google Code Jam) Round 3 2008
PROB: D Endless Knight
KEYW: pascal triangle, computing combinations modulus prime number, modulus division?

LANG: GNU C++ (g++ (GCC) 4.3.1 20080612 (Red Hat 4.3.1-2))
OPT: -lm -O2
*/

#include <cstdio>
#include <utility>
#include <cassert>
#include <algorithm>

using std::pair;
using std::make_pair;

struct pnt {
	int x, y;
	pnt() {}
	pnt(int _x, int _y) : x(_x), y(_y) {}

	pnt &operator -= (const pnt &p) {x -= p.x; y -= p.y; return *this;}
	pnt operator - (const pnt &p) const {pnt ret(*this); ret -= p; return ret;}

	bool operator < (const pnt &p) const {return x != p.x ? x < p.x : y < p.y;}

	bool operator == (const pnt &p) const {return x == p.x && y == p.y;}

	bool transform() {
		int row = (x + y) / 3;
		int col = row * 2 - x;
		if ((x + y) % 3 != 0 || col < 0 || col > row) {
			//printf("%d %d   %d %d\n", x, y, col, row);
			return false;
		}
		*this = pnt(row, col);
		return true;
	}

	bool is_proper() {
		return x > 0 && y >= 0 && y <= x;
	}
};

pnt ONE(1, 1);

const int MAXR = 16;
int R;
pnt rocks[MAXR];
int weight[MAXR];
pnt targ;

const int MOD = 10007;

int old_comb(pnt p) {
	long long res = 1;
	if (p.y * 2 > p.x)
		p.y = p.x - p.y;
	if (p.y == 0) return 1;
	for (int i = 1; i <= p.y; ++i) {
		res *= (p.x + 1 - i);
		res /= i;
	}
	return res % MOD;
}

int mul_to_tbl[MOD + 5] = {0, 1};

void init_mul_to() {
	for (int i = 2; i < MOD; ++i)
		mul_to_tbl[i] = (mul_to_tbl[i-1] * i) % MOD;
}

pair<int, int> ext_gcd(int a, int b) {
	static pair<int, int> res;
	return b ? (res = ext_gcd(b, a % b), make_pair(res.second, res.first - res.second * (a / b))): make_pair(1, 0);
}

int mul_inv(int x) {
	int mi = (ext_gcd(x, MOD).first + MOD) % MOD;
	assert((mi * x) % MOD == 1);
	return mi;
}

int div_mod(int p, int q) {
	if (!(p >= 0 && q > 0)) {
		fprintf(stderr, "%d %d\n", p, q);
	}
	assert(p >= 0 && q > 0);
	return (p * mul_inv(q)) % MOD;
}

inline int mul_to(int x) {
	return mul_to_tbl[x];
}

int combx(pnt p) {
	if (p.y < MOD && p.x % MOD > p.y) return 1;
	//fprintf(stderr, "in X %d %d\n", p.x, p.y);

	int res = div_mod(mul_to(p.x / MOD), (mul_to((p.x - p.y) / MOD) * mul_to(p.y / MOD)) % MOD);
	//fprintf(stderr, "out X\n");
	assert(res >= 0 && res < MOD);
	return res;
}

int comb(pnt p) {
	if (p.y * 2 > p.x)
		p.y = p.x - p.y;

	if (!(0 <= p.y) || !(p.y < p.x) || !(p.y * 2 <= p.x)) {
		fprintf(stderr, "%d %d\n", p.x, p.y);
	}

	assert(0 <= p.y);
	assert(p.y < p.x);
	assert(p.y * 2 <= p.x);

	if (p.y == 0) return 1;
	int k = p.y % MOD;
	int q = p.x % MOD;
	if (q == 0 || q < k) return 0;
	if (k == 0) {
		return combx(p);
	}
	int s = (p.x - p.y) % MOD;

	assert(s != 0);
	//fprintf(stderr, "%d %d\n", s - q, k);
	assert(q - s == k);
	//printf("%d %d %d\n", mul_to(q), mul_to(s), mul_to(k));
	int res = div_mod(mul_to(q), (mul_to(s) * mul_to(k)) % MOD);
	assert(res >= 0 && res < MOD);
	return (res * combx(p)) % MOD;
}

int main() {
	init_mul_to();
/*
	printf("%d\n", comb(pnt(25, 9)));
	return 0;
	*/
	int tc;
	scanf("%d", &tc);


	for (int ctc = 1; ctc <= tc; ++ctc) {
		printf("Case #%d:", ctc);
		int Rx;
		scanf("%d %d %d", &targ.x, &targ.y, &Rx);
		//printf("got %d %d\n", targ.x, targ.y);

		R = 0;
		for (int i = 0; i < Rx; ++i) {
			scanf("%d %d", &rocks[R].x, &rocks[R].y);
			//printf("\tgot rock %d %d\n", rocks[R].x, rocks[R].y);
			rocks[R] -= ONE;
			if (rocks[R].transform()) {
				assert(rocks[R].is_proper());
				++R;
			}
		}

		targ -= ONE;
		if (targ == pnt(0, 0)) {
			printf(" 1\n");
			continue;
		}
		//printf("%d %d\n", targ.x, targ.y);
		if (!targ.transform()) {
			printf(" 0\n");
			continue;
		}

		//fprintf(stderr, "initial!\n");
		//fprintf(stderr, "after initial!\n");

		std::sort(rocks, rocks + R);
		assert(R == 0 || rocks[R-1] < targ);
		rocks[R] = targ;

		//printf("stage 0\n");
		for (int i = 0; i <= R; ++i) {
			assert(rocks[i].is_proper());
			weight[i] = comb(rocks[i]);
		}

		//printf("stage 1\n");

		pnt nx;
		/*
		for (int i = 0; i <= R; ++i)
			fprintf(stderr, "\t%d %d\n", rocks[i].x, rocks[i].y);
		*/
		for (int i = 0; i < R; ++i) {
			for (int j = i+1; j <= R; ++j) {
				if ((nx = rocks[j] - rocks[i]).is_proper()) {
					//fprintf(stderr, "%d %d  %d %d\n", i, j, nx.x, nx.y);
					//printf("\t\tremoving from %d(%d)  %d %d : %d * %d\n", j, i, nx.x, nx.y, comb(nx), weight[i]);
					weight[j] -= (comb(nx) * weight[i]) % MOD;
					weight[j] = (weight[j] + MOD) % MOD;
				}
			}
		}

		printf(" %d\n", weight[R]);
	}

	return 0;
}
