/*
FROM: Croatia Final Competition in Informatics 2002 day 1
PROB: safe
KEYW: dinitz max flow
*/

#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <list>
#include <stack>

const int MAXN = 1 << 10;
const int MAXK = 1 << 7;
const int MAXNN = MAXN + MAXK;
const int MAXM = MAXN * MAXK * 2;
const int MAXB = 1 << 5;
const int INF = 1 << 20;

struct el {
	int to;
	int rd;
	int next;
	el () {}
	el (int _to, int _rd, int _next) : to (_to), rd (_rd), next (_next) {}
};

struct src {
	unsigned m[MAXB];
	int cntr;
	src () {memset (m, 0, sizeof (m)); cntr = 0;}
	src & operator = (const src &a) {
		memcpy (m, a.m, sizeof (m));
		return *this;
	}
	src & operator |= (const src &a) {
		for (int i = 0; i < MAXB; ++i)
			m[i] |= a.m[i];
		return *this;
	}
	bool get (int id) const {
		return (m[id >> 5] >> (id & 0x1f)) & 1;
	}
	void put (int id) {
		m[id / 32] |= 1 << id % 32;
	}
	void prnt (int N) const {
		for (int i = 0; i < N; ++i)
			printf (" %d", get (i));
		printf ("  __%d\n", cntr);
	}
};

int N, K;
src srcs[MAXN];
int gfdb[MAXN];
int used[MAXN];

std::stack <int> empty;

int NN, MM;
int vec[MAXN + MAXK];
el buf[MAXM];
int source, sink;

void add_edge (int fr, int to, int rd) {
//	printf ("AE %d %d %d\n", fr, to, rd);
	buf[MM] = el (to, rd, vec[fr]);
	vec[fr] = MM++;
	buf[MM] = el (fr, 0, vec[to]);
	vec[to] = MM++;
}

void build_edges (int to, src &mask) {
	int i;
	for (i = 0; i < N; ++i)
		if (mask.get (i))
			add_edge (i, to + N, INF);
}

int D[MAXNN];
int _bac_d_source;
bool bfs () {
	static int q[MAXNN];
	int p3, i, j;
	memset (D, -1, sizeof (D));

	q[p3 = 0, p3++] = sink;
	D[sink] = 0;
	for (i = 0; i < p3; ++i)
		for (j = vec[q[i]]; j != -1; j = buf[j].next)
			if (D[buf[j].to] == -1 && buf[j ^ 1].rd) {
				D[buf[j].to] = D[q[i]] + 1;
				q[p3++] = buf[j].to;
			}


	return (_bac_d_source = D[source]) != -1;
}

int edgel[MAXNN], ep;
int dfs (int v) {
	if (v == sink) {
		return INF;
	}

	int tmp;
	for (int i = vec[v]; i != -1; i = buf[i].next)
		if (D[buf[i].to] == D[v] - 1 && buf[i].rd) {
			edgel[ep++] = i;
			if ((tmp = dfs (buf[i].to))) {return tmp <? buf[i].rd;}
			--ep;
		}

	D[v] = -2;//unusable
	return 0;
}

int dinitz () {
	int cflow, maxflow = 0;
	while (bfs ())
		while (D[source] = _bac_d_source, ep = 0, cflow = dfs (source)) {
			maxflow += cflow;
			for (int i = 0; i < ep; ++i) {
				buf[edgel[i]].rd -= cflow;
				buf[edgel[i] ^ 1].rd += cflow;
			}
		}
	return maxflow;
}

int main () {
	scanf ("%d %d", &N, &K);
	source = N + K;
	sink = source + 1;
	NN = sink + 1;
	memset (vec, -1, sizeof (vec));

	for (int i = 0; i < N; ++i) {
		gfdb[i] = i;
		srcs[i].put (i);
		srcs[i].cntr = 1;
	}

	int i, j;
	int cap;
	for (i = 0; i < N; ++i) {
		scanf ("%d", &cap);
		add_edge (source, i, cap);
	}

	int pc, pid, sid, bm;
	for (i = 0; i < K; ++i) {
		scanf ("%d", &pc);
		if (pc == 0) {
			scanf ("%*d");
//			printf ("pc == 0\n");
			continue;//he cannot buy anything
		}
		scanf ("%d", &pid);
		--pid;
		sid = gfdb[pid];
		if (pc == 1) {
//			printf ("pc == 1\n");
			build_edges (i, srcs[sid]);

			scanf ("%d\n", &bm);
			add_edge (i + N, sink, bm);
			continue;
		}
//		printf ("bdt  %d -- %d\n", i, srcs[sid].cntr);
		if (srcs[sid].cntr > 1) {//detach
//			printf ("here!\n");
			--srcs[sid].cntr;
			sid = empty.top (); empty.pop ();
			srcs[sid] = srcs[gfdb[pid]];
//			printf ("copyed by %d -- ", gfdb[pid]); srcs[gfdb[pid]].prnt (N);
			gfdb[pid] = sid;
		}
		
		used[sid] = i + 1;
		srcs[sid].cntr = pc;

//		srcs[sid].cntr = pc; printf ("sid %d --> ", sid); srcs[sid].prnt (N);
//		printf ("ready to r&r  %d\n", i);
		for (j = 1; j < pc; ++j) {
			scanf ("%d", &pid);
			--pid;
			if (used[gfdb[pid]] != i + 1) {
				used[gfdb[pid]] = i + 1;
//				printf ("get -- ");
//				srcs[gfdb[pid]].prnt (N);//
				srcs[sid] |= srcs[gfdb[pid]];
			}
			if (!(--srcs[gfdb[pid]].cntr))//free
				empty.push (gfdb[pid]);
			gfdb[pid] = sid;
		}

//		printf ("build edges:\n");
		build_edges (i, srcs[sid]);
//		printf ("----------\n");
		scanf ("%d\n", &bm);
		add_edge (i + N, sink, bm);
//		for (j = 0; j < N; ++j) {printf ("%d -> %d ---- ", j, gfdb[j]); srcs[gfdb[j]].prnt (N);}
	}
/*
	for (i = 0; i < NN; ++i) {
		printf ("%d ->", i);
		for (j = vec[i]; j != -1; j = buf[j].next)
			printf ("(%d %d)", buf[j].to, buf[j].rd);
		puts ("");
	}
*/
	printf ("%d\n", dinitz ());

	return 0;
}
