/*
FROM: Croatia Final Competition in Informatics 2003 day 2
PROB: vikitoki
KEYW: bfs with graph expansion, point, point --> point, edge
NOTE: worked first time ;)
*/

#include <cstdio>
#include <cstring>

const int MAXN = 1 << 7;
const int MAXM = 1 << 12;
const int MAXNN = 1 << 22;
const int MAXQLEN = 1 << 21;//100 * 100 * 100 * 2 -- 2M

struct pos {
	int a, b, c;
	bool p;
	pos () {}
	pos (int _a, int _b, int _c, bool _p) : a (_a), b (_b), c (_c), p (_p) {}
	pos (int code) : a (code >> 15), b (code >> 8 & 0x7f), c (code >> 1 & 0x7f), p (code & 1) {}
	pos & operator = (const pos &pp) {a = pp.a, b = pp.b; c = pp.c; p = pp.p; return *this;}
	int code () {return a << 15 | b << 8 | c << 1 | p;}
};

struct coor {
	int x, y;
	coor () {}
	coor (int _x, int _y) : x (_x), y (_y) {}
	coor operator - (const coor &a) const {return coor (x - a.x, y - a.y);}
	int operator * (const coor &a) const {return x * a.x + y * a.y;}
};

struct el {
	int to;
	int next;
	el () {}
	el (int _to, int _next) : to (_to), next (_next) {}
};

int N, M;
bool used[MAXNN];
bool reach[MAXN];

long long D;
int vec[MAXN];
el buf[MAXM * 2];
coor loc[MAXN];

long long sq (int a) {return (long long)a * a;}

inline long long dist2 (int pid1, int pid2) {
	return sq (loc[pid1].x - loc[pid2].x) + sq (loc[pid1].y - loc[pid2].y);
}

inline bool ok (int pid1, int pid2) {
	return dist2 (pid1, pid2) * 10000 <= D;
}

inline int S (const coor &a, const coor &b, const coor &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool ok (int pid1, int pid2, int pid3) {
	if ((loc[pid3] - loc[pid2]) * (loc[pid1] - loc[pid2]) <= 0)
		return ok (pid1, pid2);
	if ((loc[pid2] - loc[pid3]) * (loc[pid1] - loc[pid3]) <= 0)
		return ok (pid1, pid3);
	return sq (S (loc[pid1], loc[pid2], loc[pid3])) * 10000 <= D * dist2 (pid2, pid3);
}

void bfs (int beg_code) {
	static int q[MAXQLEN], p3;
	int i, j, go;
	pos c, pgo;//crnt

	q[p3 = 0, p3++] = beg_code;
	used[beg_code] = 1;

	for (i = 0; i < p3; ++i) {
		c = pos (q[i]);
		if (c.p) {
			if (ok (c.a, c.b)) reach[c.b] = 1;
			if (ok (c.a, c.c)) reach[c.c] = 1;
		} else reach[c.a] = 1;
	
		for (j = vec[c.a]; j != -1; j = buf[j].next) {
			pgo = pos (buf[j].to, c.b, c.c, c.p);
			go = pgo.code ();
			if (ok (pgo.a, pgo.b, pgo.c)
			 && !used[go]) {
				used[go] = 1;
				q[p3++] = go;
			}
		
			pgo = pos (c.b, c.a, buf[j].to, !c.p);
			go = pgo.code ();
			if (ok (pgo.a, pgo.b, pgo.c)
			 && !used[go]) {
				used[go] = 1;
				q[p3++] = go;
			}
		}

		pgo = pos (c.a, c.c, c.b, c.p);
		go = pgo.code ();
		if (!used[go]) {
			used[go] = 1;
			q[p3++] = go;
		}

		if (!ok (c.a, c.b)) continue;
		for (j = vec[c.b]; j != -1; j = buf[j].next) {
			pgo = pos (c.a, c.b, buf[j].to, c.p);
			go = pgo.code ();
			if (!used[go]) {
				used[go] = 1;
				q[p3++] = go;
			}
		}
	}
}

int main () {
	double DD;
	scanf ("%d %d %lf", &N, &M, &DD);

	D = (int)(DD * 100);
	D *= D;

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &loc[i].x, &loc[i].y);

	int a, b;
	int bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < M; ++i) {
		scanf ("%d %d", &a, &b);
		--a; --b;

		buf[bp] = el (b, vec[a]);
		vec[a] = bp++;
		buf[bp] = el (a, vec[b]);
		vec[b] = bp++;
	}

	int s1, s2;
	scanf ("%d %d", &s1, &s2);
	--s1; --s2;
	reach[s2] = 1;

	if (vec[s1] != -1)
		bfs (pos (s2, s1, buf[vec[s1]].to, 0).code ());
	else if (vec[s2] != -1)
		bfs (pos (s1, s2, buf[vec[s2]].to, 1).code ());
	
	for (i = 0; i < N; ++i)
		if (reach[i])
			printf ("%d\n", i + 1);

	return 0;
}
