/*
FROM: Croatia Final Competition in Informatics 2004 day 1
PROB: mapa
KEYW: geometry, crossing a convex polygon with half plane
*/

#include <cstdio>
#include <algorithm>

const int MAXN = 1 << 13;
const int INF = 1 << 20;
const double EPS = 1e-6;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}
	pnt operator * (double d) const {return pnt (x * d, y * d);}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
};

int N;
pnt coor[MAXN];
pnt _poly1[MAXN], _poly2[MAXN], *cpoly = _poly1, *tpoly = _poly2;
int cpc, tpc;

pnt _a, _b;

inline double S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

pnt lintersect (const pnt &p, const pnt &q) {
	static double S1, S2, t;
	S1 = S (_a, _b, p);
	S2 = S (_b, _a, q);
	t = S1 / (S1 + S2);
	return (q - p) * t + p;
}

bool in (const pnt &p) {
	return S (_a, _b, p) > EPS;
}

void intersect (const pnt &a, const pnt &b, const pnt &) {
	cpoly[cpc] = cpoly[0];
	tpc = 0;
	_a = a; _b = b;
	bool cin, pin;
	int i;
	for (i = 1; i <= cpc; ++i) {
		cin = in (cpoly[i]);
		pin = in (cpoly[i-1]);
		if (cin ^ pin == 1) {
//			printf ("on i %d -- inter -- %.2lf %.2lf\n", i, lintersect (cpoly[i-1], cpoly[i]).x, lintersect (cpoly[i-1], cpoly[i]).y);
			tpoly[tpc++] = lintersect (cpoly[i-1], cpoly[i]);
		}
		if (cin) {
//			printf ("on i %d -- just add %.2lf %.2lf\n", i, cpoly[i].x, cpoly[i].y);
			tpoly[tpc++] = cpoly[i];
		}
	}
//	printf ("%lf %lf  %lf %lf\n", a.x, a.y, b.x, b.y);
//	for (i = 0; i < cpc; ++i) printf ("(%.2lf %.2lf)", cpoly[i].x, cpoly[i].y); puts ("");
//	for (i = 0; i < tpc; ++i) printf ("(%.2lf %.2lf)", tpoly[i].x, tpoly[i].y); puts ("");
//	puts ("");

	std::swap (cpoly, tpoly);
	std::swap (cpc, tpc);
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%lf %lf", &coor[i].x, &coor[i].y);

	cpoly[cpc++] = pnt (coor[0].x, -1);
	cpoly[cpc++] = pnt (coor[N-1].x, -1);
	cpoly[cpc++] = pnt (coor[N-1].x, INF);
	cpoly[cpc++] = pnt (coor[0].x, INF);

	for (i = 1; i < N; ++i)
		intersect (coor[i-1], coor[i]
		, coor[i].y < coor[i-1].y ?
		   pnt (coor[0].x, -1) 
		 : pnt (coor[N-1].x, -1));

	double res = INF;
	for (i = 0; i < cpc; ++i)
		res <?= cpoly[i].y;
	printf ("%.2lf\n", res);

	return 0;
}
