/*
FROM: Croatia 2006 Final exam day 2
PROB: lubenica
KEWY: LCA, RMQ, base 2 tree shortcuts (B2TS | TS)
*/

#include <cstdio>
#include <cassert>
#include <climits>
#include <cstring>

const int MAXN = 1 << 17;
const int LOGN = 20;

//BEGIN graph
struct el {
	int to, dist, next;
	el () {}
	el (int _to, int _dist, int _next) : to (_to), dist (_dist), next (_next) {}
};

int N;
int vec[MAXN];
el buf[MAXN * 2];
//END graph

//BEGIN shared b2ts <-> lca
int id[MAXN * 2];
int lvl[MAXN * 2];
int fo[MAXN];//first occurance
//END shared

//BEGIN B2TS
struct link {
	int min, max;
	int prev;
	link () : min (INT_MAX), max (-1), prev (-1) {};
	link (const link &a, const link &b) : min (a.min <? b.min), max (a.max >? b.max), prev (b.prev) {}
	link (int _min, int _max, int _prev) : min (_min), max (_max), prev (_prev) {}
};

link sc[MAXN][LOGN];
void b2ts_init (int pos =0) {
//	printf ("b2ts_init %d\n", pos);
	if (pos) {
		for (int i = 1; sc[sc[pos][i-1].prev][i-1].prev != -1; ++i)
			sc[pos][i] = link (sc[pos][i-1], sc[sc[pos][i-1].prev][i-1]);
/*		for (int i = 0; i < LOGN && sc[pos][i].prev != -1; ++i)
			printf ("%d %d %d\n", sc[pos][i].min, sc[pos][i].max, sc[pos][i].prev);*/
	}

	for (int i = vec[pos]; i != -1; i = buf[i].next) {
		if (buf[i].to == sc[pos][0].prev) continue;//this is our father
		sc[buf[i].to][0] = link (buf[i].dist, buf[i].dist, pos);
		b2ts_init (buf[i].to);
	}
}

void b2ts_query (int id1, int id2, int &min, int &max) {
	int tmp = lvl[fo[id1]] - lvl[fo[id2]];
//	printf ("b2ts query %d %d -- lvl diff - %d\n", id1, id2, tmp);
	int cpos = id1;
	for (int i = 0; cpos != id2; ++i) {
//		printf ("tmp, cpos, i  %x %d %d\n", tmp, cpos, i);
		if (!((tmp >> i) & 1)) continue;
//		printf ("min upd %d, max upd %d, goto %d\n", sc[cpos][i].min, sc[cpos][i].max, sc[cpos][i].prev);
		min <?= sc[cpos][i].min;
		max >?= sc[cpos][i].max;
		cpos = sc[cpos][i].prev;
	}
}
//END B2TS

//BEGIN LCA / RMQ
int NN;
int cpos;
int pre[MAXN * 2][LOGN];

void lca_init (int pos = 0) {
//	printf ("lca init %d -- %d   \n", pos, lvl[cpos]);

	fo[pos] = cpos;
	//the father gives the level
	id[cpos++] = pos;
	for (int i = vec[pos]; i != -1; i = buf[i].next) {
		if (sc[pos][0].prev == buf[i].to) {
//			printf ("cannot go %d\n", buf[i].to);
			continue;
		}

		//set the child level and recurse
		lvl[cpos] = lvl[fo[pos]] + 1;
		lca_init (buf[i].to);

		//we write ourselves
		id[cpos] = pos;
		lvl[cpos++] = lvl[fo[pos]];
	}

	if (pos == 0) {
		assert (cpos == N * 2 - 1);
		NN = cpos;
//		for (int i = 0; i < cpos; ++i) printf ("(%d %d)", id[i], lvl[i]); puts ("");
//		for (int i = 0; i < N; ++i) printf ("%d ", fo[i]); puts ("");
	
		for (int j = 0; j < NN; ++j) pre[j][0] = j;
		int ip2 = 1;
		for (int i = 1; i < LOGN; ++i) {
			for (int j = 0; j + ip2 * 2 <= NN; ++j) {
				pre[j][i] = lvl[pre[j][i-1]] < lvl[pre[j + ip2][i-1]] ? pre[j][i-1] : pre[j + ip2][i-1];
//				printf ("%d %d -- %d (%d %d  %d %d)\n", j, i, pre[j][i],\
				pre[j][i-1], pre[j + ip2][i-1], lvl[pre[j][i-1]], lvl[pre[j+ip2][i-1]]);
			}
			ip2 *= 2;
		}
	}
}

int lca_query (int id1, int id2) {
	int p1 = fo[id1], p2 = fo[id2];
	if (p1 > p2) {int t = p1; p1 = p2; p2 = t;}
	++p2;
	int p = 31 - __builtin_clz (p2 - p1);
	return lvl[pre[p1][p]] < lvl[pre[p2-(1 << p)][p]] ? id[pre[p1][p]] : id[pre[p2-(1 << p)][p]];
}
//END LCA / RMQ

int main () {
//	FILE *in = fopen ("lube.in", "r");
	FILE *in = stdin;

	fscanf (in, "%d", &N);	

	int i;
	int a, b, d;
	int bp = 0;
	memset (vec, -1, sizeof (vec));
	for (i = 0; i < N-1; ++i) {
		fscanf (in, "%d %d %d", &a, &b, &d);
		--a; --b;

		buf[bp] = el (b, d, vec[a]);
		vec[a] = bp++;

		buf[bp] = el (a, d, vec[b]);
		vec[b] = bp++;
	}

	b2ts_init ();
//	puts (""); puts ("");
	lca_init ();

	int Q;
	fscanf (in, "%d", &Q);
	int min, max;
	for (i = 0; i < Q; ++i) {
		fscanf (in, "%d %d", &a, &b);
		--a; --b;
		d = lca_query (a, b);
//		printf ("%d %d -- lca == %d\n",  a, b, d);

		min = INT_MAX;
		max = -1;
		if (d == a) b2ts_query (b, a, min, max);
		else if (d == b) b2ts_query (a, b, min, max);
		else {
			b2ts_query (a, d, min, max);
			b2ts_query (b, d, min, max);
		}
		printf ("%d %d\n", min, max);	
	}

	return 0;
}
