#include <cstdio>
#include <cstdlib>

const int MAXN = 1 << 5;
const double EPS = 1e-8;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	bool operator == (const pnt &a) const {return x == a.x && y == a.y;}
	int dd () const {return abs (x) + abs (y);}
};

struct line {
	pnt p1, p2;
	line () {}
	line (const pnt &a, const pnt &b) : p1 (a), p2 (b) {}
};

int N;
line vec[MAXN];

int S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int trf (int a) {
	return a > 0 ? 1 : a < 0 ? -1 : 0;
}
bool _inside (const pnt &a, const line &b) {//they are lying on the same line
	static pnt xx, yy;
	xx =    a - b.p1;
	yy = b.p2 - b.p1;
	return a == b.p1 || trf (xx.x) == trf (yy.x) && trf (xx.y) == trf (yy.y) && xx.dd () <= yy.dd ();
}

bool intersect (const line &a, const line &b) {
/*	printf ("inter %d %d  %d %d  %d %d  %d %d -- %d\n", a.p1.x, a.p1.y, a.p2.x, a.p2.y, b.p1.x, b.p1.y, b.p2.x, b.p2.y,
		a.p1 == b.p1 || a.p1 == b.p2 || a.p2 == b.p1 || a.p2 == b.p2
		|| inside (a.p1, b) || inside (a.p2, b) || inside (b.p1, a) || inside (b.p2, a)
		|| 	   trf (S (a.p1, a.p2, b.p1)) * trf (S (a.p1, a.p2, b.p2)) < 0
			&& trf (S (b.p1, b.p2, a.p1)) * trf (S (b.p1, b.p2, a.p2)) < 0);*/
	return
		   S (b.p1, b.p2, a.p1) == 0 && _inside (a.p1, b) 
		|| S (b.p1, b.p2, a.p2) == 0 && _inside (a.p2, b) 
		|| S (a.p1, a.p2, b.p1) == 0 && _inside (b.p1, a)
		|| S (a.p1, a.p2, b.p2) == 0 && _inside (b.p2, a)
		|| trf (S (a.p1, a.p2, b.p1)) * trf (S (a.p1, a.p2, b.p2)) < 0
		&& trf (S (b.p1, b.p2, a.p1)) * trf (S (b.p1, b.p2, a.p2)) < 0;
}

double find_inter (const line &a, const line &b) {
	int s1 = S (b.p1, b.p2, a.p1);
	int s2 = S (b.p1, a.p2, b.p2);
	return (double)s1 / (s1 + s2);
}

double myfabs (double a) {return a < 0 ? -a : a;}

bool nsp (const line &a, const line &b, const line &c) {
//	printf ("%lf %lf\n", find_inter (a, b), find_inter (a, c));
	return myfabs (find_inter (a, b) - find_inter (a, c)) > EPS;
}

line _extended;
bool can_extend (const line &a, const line &b) {
	static int blen, bi, bj, _tmp, i, j;
	static pnt _vec[4];
	if (S (a.p1, a.p2, b.p1) == 0 && S (a.p1, a.p2, b.p2) == 0
	 && (_inside (a.p1, b) || _inside (a.p2, b)
	  || _inside (b.p1, a) || _inside (b.p2, a))) {
		_vec[0] = a.p1; _vec[1] = a.p2;
		_vec[2] = b.p1; _vec[3] = b.p2;
		blen = -1;
		for (i = 0; i < 3; ++i)
			for (j = i + 1; j < 4; ++j)
				if (blen < (_tmp = (_vec[j] - _vec[i]).dd ())) {
					blen = _tmp;
					bi = i;
					bj = j;
				}
		_extended = line (_vec[bi], _vec[bj]);
		return 1;
	}
	return 0;
}

int main () {
	scanf ("%d", &N);

	int i, j, k;
	int x1, y1, x2, y2;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d %d %d", &x1, &y1, &x2, &y2);
		vec[i] = line (pnt (x1, y1), pnt (x2, y2));
	}

	for (int k = 0; k <= 20; ++k) {
		for (i = 0; i < N; ++i)
			for (j = i + 1; j < N; ++j)
				if (can_extend (vec[i], vec[j])) {
					vec[i] = _extended;
					vec[j] = vec[--N];
					goto nextk;
				}
		nextk:;
	}

	printf ("N = %d\n", N);
	for (i = 0; i < N; ++i)
		printf ("%d %d %d %d\n", vec[i].p1.x, vec[i].p1.y, vec[i].p2.x, vec[i].p2.y);

	int res = 0;
	for (i = 0; i < N; ++i)
		for (j = i + 1; j < N; ++j) {
			if (!intersect (vec[i], vec[j])) continue;
			for (k = j + 1; k < N; ++k) {
				res += intersect (vec[i], vec[k]) && intersect (vec[j], vec[k]) && nsp (vec[i], vec[j], vec[k]);
			}
		}

	printf ("%d\n", res);
			
	return 0;
}
