/*
FROM: COCI (Croatia Open Competition in Informatics) 2006 contest 4
PROB: ispiti
KEYW: 2d lowest bit index tree, buckets, binary search, coordinate compression
*/

#include <cstdio>
#include <vector>
#include <utility>
#include <algorithm>

//#define MP(A,B) std::make_pair (A, B)
using std::make_pair;

const int MAXN = 1 << 18;
const int MAXGC = 1 << 9;

int Atc, Btc;//total count
int allA[MAXN], allB[MAXN];
int Agc, Bgc;

//BEGIN index tree
int idt[MAXGC][MAXGC];

int lowest_bit (int a) {return a & -a;}

void add (int a, int b) {
	static int i, j;
	for (i = a; i >= 0; i -= lowest_bit (Agc - i))
		for (j = b; j >= 0; j -= lowest_bit (Bgc - j))
			++idt[i][j];//add a person
}

int srch (int a, int b) {
	static int i, j, res;
	for (i = a, res = 0; i != Agc; i += lowest_bit (Agc - i))
		for (j = b; j != Bgc; j += lowest_bit (Bgc - j))
			res += idt[i][j];
	return res;	
}
//END index tree

int PC;//people count
std::vector <int> bucket[MAXGC][MAXGC];
std::pair <int, int> allvec[MAXN];

int N;
int input[MAXN];//negative means add

int _rID, _cID;

int fndGC (int a) {
	int l = 0, r = 500, m;
	while (l + 1 < r) {
		m = (l + r) / 2;
		if (m * m < a)
			l = m;
		else
			r = m;
	}
	return r;
}

inline bool cmp1 (int id1, int id2) {
	return 	id1 != id2
		 && allvec[id1].first >= allvec[id2].first
		 && allvec[id1].second >= allvec[id2].second;
}

inline bool cmp2 (int id1, int id2) {
	return 	id2 == -1
		 || allvec[id1].second < allvec[id2].second
		 || allvec[id1].second == allvec[id2].second
		 && allvec[id1].first < allvec[id2].first;
}

void find_bucket (int x, int y) {
//	printf ("find in bucket %d %d\n", x, y);
	for (unsigned i = 0; i < bucket[x][y].size (); ++i)
		if (cmp1 (bucket[x][y][i], _cID)
		 && cmp2 (bucket[x][y][i], _rID))
			_rID = bucket[x][y][i];
}

void bsrch (int Ag, int Bg) {
	if (Ag == Agc || Bg == Bgc) return;//nothing to do
	int targ = srch (Ag, Bg);
	if (targ == 0) return;
	int l = Bg, r = Bgc, m;
	while (l + 1 < r) {
		m = (l + r) / 2;
		if (srch (Ag, m) == targ)
			l = m;
		else
			r = m;
	}

	for (int i = Ag; i < Agc; ++i) find_bucket (i, l);
}

void fndGrps (int id, int &ag, int &bg) {
	ag = (std::lower_bound (allA, allA + Atc, allvec[id].first) - allA) / Agc;
	bg = (std::lower_bound (allB, allB + Btc, allvec[id].second) - allB) / Bgc;
}

int main () {
	scanf ("%d\n", &N);

	int i, j;
	char type;
	int a, b;
	for (i = 0; i < N; ++i) {
		scanf ("%c %d", &type, &a);
		if (type == 'D') {//add
			scanf ("%d\n", &b);
//			printf ("input %d --- %d %d\n", i, a, b);
			input[i] = -PC;//the id of the current point. 0 means add
			allvec[PC] = make_pair (a, b);
			allA[PC] = a;
			allB[PC] = b;
			++PC;
		} else {//search
			scanf ("\n");
//			printf ("input %d --- %d\n", i, a-1);
			input[i] = a;//the id of the searched point plus 1
		}
	}

	Atc = Btc = PC;
	std::sort (allA, allA + Atc);
	std::sort (allB, allB + Btc);
	Atc = std::unique (allA, allA + Atc) - allA;
	Btc = std::unique (allB, allB + Btc) - allB;

	Agc = fndGC (Atc);
	Bgc = fndGC (Btc);

	int aig, big;
//BEGIN prnt
/*
	for (i = 0; i < Atc; ++i) printf ("%d ", allA[i]); puts ("");
	for (i = 0; i < Btc; ++i) printf ("%d ", allB[i]); puts ("");
	printf ("%d %d\n--------------\n", Agc, Bgc);

	int k;
	printf ("----------\n");
	for (i = 0; i < PC; ++i)
		printf ("%d %d\n", allvec[i].first, allvec[i].second);
	printf ("-----------\n");
	for (i = 0; i < Agc; ++i) {
		for (j = 0; j < Bgc; ++j)
			printf ("%d ", srch (i, j));
		printf ("\n");
	}
	printf ("---------\n");*/
//END prnt
	for (i = 0; i < N; ++i) {
		if (input[i] > 0) {//search
//			printf ("SRCH %d!!!!!!!!!!!!!!!\n", input[i].second.first);
/*			for (int ii = 0; ii < Agc; ++ii)
				for (j = 0; j < Bgc; ++j) {
					printf ("(%d %d) ", ii, j);
					for (unsigned k = 0; k < bucket[ii][j].size (); ++k)
						printf ("%d", bucket[ii][j][k]);
					printf ("\n");
				}
			printf (">--<\n");
			for (int jj = Bgc-1; jj >= 0; --jj) {
				for (int ii = 0; ii < Agc; ++ii)
					printf ("%d(%d %d) ", srch (ii, jj), ii, jj);
				printf ("\n");
			}
			printf (">--<\n");*/
/*			_rA = _rB = 2000000000;*/
			_rID = -1;
			_cID = input[i] - 1;
			fndGrps (_cID, aig, big);
//			printf ("SRCH %d %d (%d)\n", aig, big, _cID);
/*			a = allvec[input[i] - 1].first;
			b = allvec[input[i] - 1].second;
//			printf ("srch -- %d %d\n", _A, _B);
			ai = std::lower_bound (allA, allA + Atc, a) - allA;
			bi = std::lower_bound (allB, allB + Btc, b) - allB;
			aig = ai / Agc;
			big = bi / Bgc;*/
			for (j = aig; j < Agc; ++j) find_bucket (j, big);
			if (_rID != -1) {printf ("%d\n", _rID + 1); continue;}
			for (j = big + 1; j < Bgc; ++j) find_bucket (aig, j);
			bsrch (aig + 1, big + 1);
			if (_rID != -1) printf ("%d\n", _rID + 1);
			else printf ("NE\n");
		} else {//add
			fndGrps (-input[i], aig, big);
//			printf ("ADD!!!! %d %d(%d)\n", aig, big, -input[i]);
/*			a = allvec[input[i].second.first].first;
			b = allvec[input[i].second.first].second;
//			
			ai = std::lower_bound (allA, allA + Atc, a) - allA;
			bi = std::lower_bound (allB, allB + Btc, b) - allB;
			aig = ai / Agc;
			big = bi / Bgc;*/
			bucket[aig][big].push_back (-input[i]);
//			printf ("--< add %d %d\n", aig, big);
			add (aig, big);
		}
	}

	return 0;
}
