/*
FROM: Croatia Open Competition in Informatics (COCI) round 6
PROB: prostor
KEYW: 2D lowest bit index trees, complicated
*/

#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXC = 1 << 10;
const int MAXN = 1 << 17;

struct idt {
	int ma3x[MAXC][MAXC];
	void clear () {memset (ma3x, 0, sizeof (ma3x));}
	int srch (int X1, int Y1, int X2, int Y2) const {
		--X1; --Y1;
		return _srch (X2, Y2) + _srch (X1, Y1) - _srch (X1, Y2) - _srch (X2, Y1);
	}
	void add (int X, int Y, int val) {
		static int i, j;
		for (i = X; i < MAXC; i += i & -i)
			for (j = Y; j < MAXC; j += j & -j)
				ma3x[i][j] += val;
	}

	int _srch (int X, int Y) const {
		static int i, j, res;
		for (res = 0, i = X; i; i &= i - 1)
			for (j = Y; j; j &= j - 1)
				res += ma3x[i][j];
		return res;
	}
};

struct event {
	int X1, Y1, X2, Y2;
	int time;
	event () {}
	event (int _X1, int _Y1, int _X2, int _Y2, int _time) : X1 (_X1), Y1 (_Y1), X2 (_X2), Y2 (_Y2), time (_time) {}
	bool operator < (const event &a) const {return time < a.time;}
};

idt He, Le;
int N;
event typeXY[MAXN * 2], typeYZ[MAXN * 2], typeZX[MAXN * 2];
int xyp, yzp, zxp;

long long calc (event *events, int ec) {
	std::sort (events, events + ec);
	long long res = 0;
	He.clear (); Le.clear ();
	for (int i = 0; i < ec; ++i) {
//		printf ("%d %d  %d %d   %d (%d)\n", events[i].X1, events[i].Y1, events[i].X2, events[i].Y2, events[i].time / 3, events[i].time % 3);
		switch (events[i].time % 3) {
			case 0: res += He.srch (events[i].X1, events[i].Y1, events[i].X2, MAXC - 1)
						 - Le.srch (events[i].X1, events[i].Y2 + 1, events[i].X2, MAXC - 1);
					He.add (events[i].X2, events[i].Y2, 1);
					Le.add (events[i].X1, events[i].Y1, 1);
					break;
			case 1: res += He.srch (events[i].X1, events[i].Y1, events[i].X2, MAXC - 1)
						 - Le.srch (events[i].X1, events[i].Y2 + 1, events[i].X2, MAXC - 1);
					break;
			case 2: He.add (events[i].X2, events[i].Y2, -1);
					Le.add (events[i].X1, events[i].Y1, -1);
					break;
		}
	}
//	printf ("%d\n", res);
	return res;
}

void myswap (int &a, int &b) {a ^= b ^= a ^= b;}

int main () {
	scanf ("%d", &N);
	
	int i;
	int x1, y1, z1, x2, y2, z2;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d %d  %d %d %d", &x1, &y1, &z1, &x2, &y2, &z2);
		if (x1 > x2) myswap (x1, x2);
		if (y1 > y2) myswap (y1, y2);
		if (z1 > z2) myswap (z1, z2);
		if (x1 == x2) {
			typeXY[xyp++] = event (x1, z1, x1, z2, y1 * 3);
			typeZX[zxp++] = event (z1, y1, z2, y2, x1 * 3 + 1);
			typeXY[xyp++] = event (x1, z1, x1, z2, y2 * 3 + 2);
		}
		if (y1 == y2) {
			typeYZ[yzp++] = event (y1, x1, y1, x2, z1 * 3);
			typeXY[xyp++] = event (x1, z1, x2, z2, y1 * 3 + 1);
			typeYZ[yzp++] = event (y1, x1, y1, x2, z2 * 3 + 2);
		}
		if (z1 == z2) {
			typeZX[zxp++] = event (z1, y1, z1, y2, x1 * 3);
			typeYZ[yzp++] = event (y1, x1, y2, x2, z1 * 3 + 1);
			typeZX[zxp++] = event (z1, y1, z1, y2, x2 * 3 + 2);
		}
	}

	long long res = calc (typeXY, xyp) + calc (typeYZ, yzp) + calc (typeZX, zxp);

	printf ("%Ld\n", res);

	return 0;
}
