/*
FROM: IOI 2001 day 2
PROB: depot
KEYW: checker
*/

#include <cstdio>
#include <cassert>

#include <vector>
#include <algorithm>
#include <string>
#include <sstream>

unsigned N;
std::vector <std::vector <int> > target;
int perm_count;

bool simulate (std::vector <int> &perm) {
	static std::vector <std::vector <int> > depot;
	depot.clear ();

	unsigned i, j;
	for (i = 0; i < perm.size (); ++i) {
		int carry = perm[i];
		for (j = 0; j < depot.size (); ++j) {
			unsigned pos = std::lower_bound (depot[j].begin (), depot[j].end (), carry) - depot[j].begin ();
			if (pos == depot[j].size ()) {
				depot[j].push_back (carry);
				break;
			} else {
				std::swap (depot[j][pos], carry);
			}
		}
		if (j == depot.size ()) {
			depot.push_back (std::vector <int> (1, carry));
		}
	}
/*	for (unsigned i = 0; i < depot.size (); ++i) {
		for (unsigned j = 0; j < depot[i].size (); ++j)
			printf (" %d", depot[i][j]);
		puts ("");
	}
*/
	return depot == target;
}

bool get_perm (const char *row, std::vector <int> &perm) {
	perm.clear ();
	std::istringstream in (row);
	int a;
	while (in >> a) {
		perm.push_back (a);
	}
	if (perm.size () != N) {
		return 0;
	}

	std::string tmp;
	std::ostringstream out (tmp);
	for (unsigned i = 0; i < perm.size (); ++i) {
		if (i) out << ' ';
		out << perm[i];
	}

	#warning tova moje bi trqbva da se promeni za da raboti na windows
	out << '\n';
	return std::string (row) == out.str ();
}

int main (int argc, char *argv[]) {
	assert (argc == 4);

	FILE *in = fopen (argv[1], "r");
	FILE *out = fopen (argv[2], "r");
	FILE *sol = fopen (argv[3], "r");

	assert (in && out && sol);

	int sz;
	fscanf (in, "%d", &sz);
	target.resize (sz);
	for (unsigned i = 0; i < target.size (); ++i) {
		fscanf (in, "%d", &sz);
		target[i].resize (sz);
		for (unsigned j = 0; j < target[i].size (); ++j) {
			fscanf (in, "%d", &target[i][j]);
			++N;
		}
	}
	fclose (in);

	static char buf[1024];
	while (fgets (buf, 1024, sol)) {
		++perm_count;
	}

	fclose (sol);

	std::vector <int> cperm;
	std::vector <std::vector <int> > all_perms;
	int line_count = 0;
	int same_count = 0;
	while (fgets (buf, 1024, out)) {
		++line_count;
//		fprintf (stderr, "on line %d__%s__\n", line_count, buf);
		if (!get_perm (buf, cperm)) {
			fprintf (stderr, "0\nWront output format at line %d\n", line_count);
			return 0;
		}

		if (!simulate (cperm)) {
			fprintf (stderr, "0\nWrong permutation at line %d\n", line_count);
			return 0;
		}

		if (std::find (all_perms.begin (), all_perms.end (), cperm) != all_perms.end ())
			++same_count;
		else
			all_perms.push_back (cperm);
	}

	if (same_count == 0 && line_count == perm_count) {
		fprintf (stderr, "4\nCorrect solution (%d permutation(s))\n", perm_count);
		return 0;
	}
	if (same_count == 0 && line_count * 2 >= perm_count) {
		fprintf (stderr, "2\nNo duplicates, more than half permutations (%d permutation(s), %d total permutation(s))\n", line_count, perm_count);
		return 0;
	}
	fprintf (stderr, "1\nSome duplicates, or few than half (%d duplicate(s), %d unique, %d total)\n", same_count, line_count - same_count, perm_count);

	return 0;
}
