/*
FROM: International Olympiad in Informatics (IOI) 2006 day 2
PROB: points
KEYW: output checker
*/

#include <cstdio>
#include <cassert>
#include <vector>

const int MAXG = 1 << 16;
const int MAXR = 1 << 16;

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
	bool operator == (const pnt &a) const {return x == a.x && y == a.y;}
};

struct seg {
	pnt a, b;
	seg () {}
	seg (const pnt &_a, const pnt &_b) : a (_a), b (_b) {}
};

int G, R;
pnt gpnt[MAXG], rpnt[MAXR];
seg segm[MAXG + MAXR];

long long _S (const pnt &a, const pnt &b, const pnt &c) {
	return (long long)(b.x - a.x) * (c.y - a.y) - (long long)(b.y - a.y) * (c.x - a.x);
}

int S (const pnt &a, const pnt &b, const pnt &c) {
	static long long t;
	t = _S (a, b, c);
	assert (t || a == b || a == c || b == c);
	return (t > 0) - (t < 0);
}

int tr (long long x) {
	return (x > 0) - (x < 0);
}

bool inter (const seg &a, const seg &b) {
/*	return tr (S (a.a, a.b, b.a)) * tr (S (a.a, a.b, b.b)) < 0
		&& tr (S (b.a, b.b, a.a)) * tr (S (b.a, b.b, a.b)) < 0;*/
	return S (a.a, a.b, b.a) * S (a.a, a.b, b.b) < 0
		&& S (b.a, b.b, a.a) * S (b.a, b.b, a.b) < 0;
}

std::vector <std::vector <int> > ggr, rgr;

int bfs (const std::vector <std::vector <int> > &gr) {
	static int q[MAXG <? MAXR];
	static bool used[MAXG <? MAXR];
	memset (used, 0, sizeof (used));
	int p3 = 0;
	q[p3++] = 0;
	used[0] = 1;
	int i;
	size_t j;
	for (i = 0; i < p3; ++i) {
		for (j = 0; j < gr[q[i]].size (); ++j)
			if (!used[ gr[q[i]][j] ]) {
				used[ gr[q[i]][j] ] = 1;
				q[p3++] = gr[q[i]][j];
			}
	}
	return p3;
}

int main (int argc, char *argv[]) {
	assert (argc == 3);

	FILE *in = fopen (argv[1], "r");
	FILE *out = fopen (argv[2], "r");
	assert (in && out);

	int i, j;
	fscanf (in, "%d", &G);
	ggr.resize (G);
	for (i = 0; i < G; ++i) fscanf (in, "%d %d", &gpnt[i].x, &gpnt[i].y);
	fscanf (in, "%d", &R);
	rgr.resize (R);
	for (i = 0; i < R; ++i) fscanf (in, "%d %d", &rpnt[i].x, &rpnt[i].y);
	fclose (in);

//	printf ("%d %d\n", G, R);
//	printf ("red 282 -- %d %d\n", rpnt[282].x, rpnt[282].y);

	int a, b;
	char c;
	for (i = 0; i < G + R - 2; ++i) {
		assert (fscanf (out, "%d %d %c", &a, &b, &c) == 3);
		--a; --b;
//		printf ("scanned %d %d %c\n", a, b, c);
		if (c == 'g') {
			assert (a < G && b < G);
//			printf ("%d %d   %d %d <----\n", gpnt[a].x, gpnt[a].y, gpnt[b].x, gpnt[b].y);
			ggr[a].push_back (b);
			ggr[b].push_back (a);
			segm[i] = seg (gpnt[a], gpnt[b]);
			for (j = 0; j < i && !inter (segm[j], segm[i]); ++j);
			if (i != j) {
				printf ("%d %d-- %d %d  %d %d   %d %d  %d %d\n", i, j
				, segm[j].a.x, segm[j].a.y, segm[j].b.x, segm[j].b.y
				, segm[i].a.x, segm[i].a.y, segm[i].b.x, segm[i].b.y);
				for (j = 0; j <= i; ++j) {
					printf ("\t%d %d  %d %d\n", segm[j].a.x, segm[j].a.y, segm[j].b.x, segm[j].b.y);
				}
				assert (0);
			}
			assert (i == j);
		} else {
			assert (a < R && b < R);
//			printf ("%d %d   %d %d <----\n", rpnt[a].x, rpnt[a].y, rpnt[b].x, rpnt[b].y);
			rgr[a].push_back (b);
			rgr[b].push_back (a);
			segm[i] = seg (rpnt[a], rpnt[b]);
			for (j = 0; j < i && !inter (segm[j], segm[i]); ++j);
			if (i != j) {
				printf ("%d %d-- %d %d  %d %d   %d %d  %d %d\n", i, j
				, segm[j].a.x, segm[j].a.y, segm[j].b.x, segm[j].b.y
				, segm[i].a.x, segm[i].a.y, segm[i].b.x, segm[i].b.y);
				for (j = 0; j <= i; ++j) {
					printf ("\t%d %d  %d %d\n", segm[j].a.x, segm[j].a.y, segm[j].b.x, segm[j].b.y);
				}
				assert (0);
			}
			assert (i == j);
		}
	}

	assert (bfs (ggr) == G);
	assert (bfs (rgr) == R);

	printf ("correct!\n");

	return 0;
}
