/*
FROM: International Olympiad in Informatics (IOI) 2006 day 2
PROB: points
KEYW: divide & conquer
*/

#include <cstdio>
#include <cassert>
#include <algorithm>

const int MAXN = 1 << 17;//100 000

struct pnt {
	int x, y;
	pnt () {}
	pnt (int _x, int _y) : x (_x), y (_y) {}
};

long long S (const pnt &a, const pnt &b, const pnt &c) {
	return (long long)(b.x - a.x) * (c.y - a.y) - (long long)(b.y - a.y) * (c.x - a.x);
}

int N, G, R;//R + G == N
pnt vec[MAXN];
int idx[MAXN];

int buf1[MAXN], b1p;
int buf2[MAXN], b2p;

int tr (long long a) {
//	return (a > 0) - (a < 0);
	return a > 0 ? 1 : a < 0 ? -1 : 0;
}

bool same_col (int id1, int id2) {
	return id1 >= G && id2 >= G
	 	|| id1  < G && id2  < G;
}

int __cntr;
void prnt_line (int id1, int id2) {
//	printf ("%d %d\n", id1, id2);
//	if (++__cntr == 10) exit (0);

	assert (same_col (id1, id2));
	if (id1 >= G) {
		assert (id2 >= G);
		printf ("%d %d r\n", id1 - G + 1, id2 - G + 1);
	} else {
		assert (id2 < G);
		printf ("%d %d g\n", id1 + 1, id2 + 1);
	}
}

bool in_tri (int id1, int id2, int id3, int p) {
//	printf ("in tri %d %d %d %d -- %d\n", id1, id2, id3, p,\
			abs (tr (S (vec[id1], vec[id2], vec[p]))\
			   + tr (S (vec[id2], vec[id3], vec[p]))\
			   + tr (S (vec[id3], vec[id1], vec[p])))\
			== 3);
	return abs (tr (S (vec[id1], vec[id2], vec[p]))
			  + tr (S (vec[id2], vec[id3], vec[p]))
			  + tr (S (vec[id3], vec[id1], vec[p])))
			== 3;
}

bool inter (int id1, int id2, int id3, int id4) {
	return tr (S (vec[id1], vec[id2], vec[id3])) * tr (S (vec[id1], vec[id2], vec[id4])) < 0
		&& tr (S (vec[id3], vec[id4], vec[id1])) * tr (S (vec[id3], vec[id4], vec[id2])) < 0;
}

void rec (int lb, int ub, int id1, int id2, int id3) {
	assert (!same_col (id1, id3) && !same_col (id2, id3));
	int i;

//	printf ("rec %d %d  %d %d %d\n", lb, ub, id1, id2, id3);
//	for (i = lb; i < ub; ++i) printf (" %d", idx[i]); puts ("");

	for (i = lb; i < ub; ++i) assert (in_tri (id1, id2, id3, idx[i]));

	for (i = lb; i < ub && !same_col (idx[i], id3); ++i);
	if (i == ub) {
		for (i = lb; i < ub; ++i) {
			printf (" ");
			prnt_line (id1, idx[i]);
		}
		return;
	}
	std::swap (idx[lb], idx[i]);
	int mid = idx[lb];
	prnt_line (id3, mid);
	assert (in_tri (id1, id2, id3, mid));
	if (inter (id1, id2, id3, mid)) {
		printf ("%d %d  %d %d  %d %d  %d %d\n"
		, vec[id1].x, vec[id1].y
		, vec[id2].x, vec[id2].y
		, vec[id3].x, vec[id3].y
		, vec[mid].x, vec[mid].y);
	}
	assert (!inter (id1, id2, id3, mid));
	++lb;
	int ip = lb;
	b1p = b2p = 0;
	for (i = lb; i < ub; ++i) {
		if (in_tri (id1, id2, mid, idx[i]))
			idx[ip++] = idx[i];
		else if (in_tri (id1, mid, id3, idx[i]))
			buf1[b1p++] = idx[i];
		else {
			assert (in_tri (id2, mid, id3, idx[i]));
			buf2[b2p++] = idx[i];
		}
	}

	std::copy (buf1, buf1 + b1p, idx + ip);
	std::copy (buf2, buf2 + b2p, idx + ip + b1p);
	assert (ip + b1p + b2p == ub);
	int ip2 = ip + b1p;

	rec (lb, ip, id1, id2, mid);
	rec (ip, ip2, id3, mid, id1);
	rec (ip2, ub, id3, mid, id2);
}

int main () {
	scanf ("%d", &G);

	int i;
	for (i = 0; i < G; ++i)
		scanf ("%d %d", &vec[i].x, &vec[i].y);

	scanf ("%d", &R);
	N = G + R;

	for (i = G; i < N; ++i)
		scanf ("%d %d", &vec[i].x, &vec[i].y);

	assert (vec[1].x == vec[1].y);
	assert (vec[G].x == vec[G].y && vec[G].x == 0);
	assert (vec[0].x == 0 && vec[0].y == vec[1].y);
	assert (vec[G+1].x == vec[1].x && vec[G+1].y == 0);

/*
	for (i = 0; i < N; ++i)
		for (int j = i + 1; j < N; ++j)
			for (int k = j + 1; k < N; ++k)
				assert (S (vec[i], vec[j], vec[k]));
*/

	for (i = 0; i < N; ++i) idx[i] = i;
	std::swap (idx[2], idx[G]);
	std::swap (idx[3], idx[G+1]);

	int cp = 4, b1p = 0;
	for (i = 4; i < N; ++i) {
		if (in_tri (0, 1, G, idx[i])) {
			idx[cp++] = idx[i];
		} else {
			buf1[b1p++] = idx[i];
		}
	}

	std::copy (buf1, buf1 + b1p, idx + cp);
//	for (i = 0; i < N; ++i) printf (" %d", idx[i]); puts ("");
	printf ("1 2 r\n1 2 g\n");
	rec (4, cp, 0, 1, G);
	rec (cp, N, G, G + 1, 1);

	return 0;
}
