#include <cstdio>
#include <cassert>
#include <cmath>
#include <list>

//#warning add ficticious last bucket

const int MAXN = 1 << 7;
const double INF = 1e9 + 2;
const double BIG_INF = 1e99;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}

	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator * (double a) const {return pnt (x * a, y * a);}
};

double find_cap (int, int);
double init_wat (int, int);
struct hole {
	int lp, rp;
	double cap;
	double wat;
	bool left_over;
	bool right_over;
	hole () : lp (0), rp (0), cap (0), wat (0), left_over (0), right_over (0) {}
	hole (int _lp, int _rp) 
	: lp (_lp), rp (_rp)
	, cap (find_cap (lp, rp))
	, wat (init_wat (lp, rp)), left_over (0), right_over (0) {}
};

typedef std::list <hole> list_t;
typedef list_t :: iterator list_it_t;

int N;
pnt vec[MAXN];

double H;

list_t shole;
list_it_t first_non_touched;

bool find_slope (int id) {return vec[id].y - vec[id-1].y > 0;}

void do_it (list_it_t it) {
//	printf ("do it %d %d (%lf %lf)\n", it->lp, it->rp, it->cap, it->wat);
	if (it == first_non_touched) ++first_non_touched;	

	if (it->wat <= it->cap) return;//we are done
	double over = it->wat - it->cap;
	it->wat = it->cap;

	list_it_t new_it;
	if (vec[it->lp].y < vec[it->rp].y) {//overflow on the left
		new_it = it; --new_it;
		new_it->wat += over;
		it->left_over = 1;
		if (new_it->right_over) {//merge holes
			hole new_hole (new_it->lp, it->rp);
			new_hole.wat = new_it->wat + it->wat;
			new_hole.left_over = new_it->left_over;
			new_hole.right_over = it->right_over;
			list_it_t tmp = it; ++tmp;
			shole.erase (new_it);
			shole.erase (it);
			new_it = shole.insert (tmp, new_hole);
		}
	} else {//overflow on the right
		new_it = it; ++new_it;
		new_it->wat += over;
		it->right_over = 1;
		if (new_it->left_over) {//merge holes
			hole new_hole (it->lp, new_it->rp);
			new_hole.wat = new_it->wat + it->wat;
			new_hole.left_over = it->left_over;
			new_hole.right_over = new_it->right_over;
			list_it_t tmp = new_it; ++tmp;
			shole.erase (it);
			shole.erase (new_it);
			new_it = shole.insert (tmp, new_hole);
		}
	}

	return do_it (new_it);
}

double init_wat (int lp, int rp) {
//	printf ("init_wat %d %d--> %lf\n", lp, rp, (vec[rp].x - vec[lp].x) * H);
	return (vec[rp].x - vec[lp].x) * H;
}

double S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

pnt inter (const pnt &p1, const pnt &q1, const pnt &p2, const pnt &q2) {
//	printf ("inter %lf %lf  %lf %lf  %lf %lf  %lf %lf --"\
	, p1.x, p1.y\
	, q1.x, q1.y\
	, p2.x, p2.y\
	, q2.x, q2.y);

	double S1 = S (p1, q2, p2);
	double S2 = S (p2, q2, q1);
	double t = S1 / (S1 + S2);
//	printf (" %lf %lf (%lf)\n", ((q1 - p1) * t + p1).x, ((q1 - p1) * t + p1).y, t);
	return (q1 - p1) * t + p1;
}

double find_cap (int lp, int rp) {
	static double lvl;
	static int lb, rb;
	static pnt tp;

	if (vec[lp].y < vec[rp].y) {
//		printf ("case 1\n");
		lvl = vec[lp].y;
		lb = lp;
		for (rb = rp-1; vec[rb].y > lvl; --rb);
		tp = inter (pnt (0, lvl), pnt (1, lvl), vec[rb], vec[rb+1]);
	} else {
//		printf ("case 2\n");
		lvl = vec[rp].y;
		for (lb = lp+1; vec[lb].y > lvl; ++lb);
		rb = rp;
		tp = inter (pnt (0, lvl), pnt (1, lvl), vec[lb-1], vec[lb]);
	}

	double S = 0;
//	printf ("\t%lf %lf\n", vec[lb].x, vec[lb].y);
	for (int i = lb + 1; i <= rb; ++i) {
		S += vec[i-1].x * vec[i].y;
		S -= vec[i-1].y * vec[i].x;
//		printf ("\t%lf %lf\n", vec[i].x, vec[i].y);
	}
//	printf ("\t%lf %lf\n", tp.x, tp.y);
	S += vec[rb].x * tp.y;
	S -= vec[rb].y * tp.x;
	S += tp.x * vec[lb].y;
	S -= tp.y * vec[lb].x;
//	printf ("S ==== %lf\n", S / 2.);

	return S / 2;
}

double find_min_y (int lp, int rp) {
	int i;
	double miny = INF;
	for (i = lp; i <= rp; ++i) miny <?= vec[i].y;
	return miny;
}

double find_lower_bound (int lp, int rp) {
	double top = -1;
	double bot = INF;
	for (int i = lp + 1; i < rp; ++i)
		if (find_slope (i) == 1
		 && find_slope (i+1) == 0)
		 	top >?= vec[i].y;
		else
			bot <?= vec[i].y;

//	printf ("find_lower_bound %d %d --> %lf (%lf %lf)\n", lp, rp, top == -1 ? bot : top, top, bot);
	return top == -1 ? bot : top;
}

double find_lvl (int lp, int rp, double w) {
//	printf ("fnd lvl\n");
	int lb, rb;
	double l = find_lower_bound (lp, rp)
	, r = vec[lp].y <? vec[rp].y, m;
//	printf ("%lf %lf\n", l, r);
	for (int cc = 0; cc < 100; ++cc) {
		m = (l + r) / 2;
//		printf ("m == %lf\n", m);
		assert (vec[lp].y >= m && vec[rp].y >= m);
		for (lb = lp; vec[lb].y > m; ++lb);
		for (rb = rp; vec[rb].y > m; --rb);

		pnt p1 = inter (pnt (0, m), pnt (1, m), vec[rb], vec[rb+1]);
		pnt p2 = inter (pnt (0, m), pnt (1, m), vec[lb-1], vec[lb]);

		double S = 0;
//		printf ("\t%lf %lf\n", vec[lb].x, vec[lb].y);
		for (int i = lb; i <= rb + 2; ++i) {
			pnt _PA = (i-1 == lb-1 ? p2 : i-1 <= rb ? vec[i-1] : i-1 == rb+1 ? p1 : p2);
			pnt _PB = (i == lb-1 ? p2 : i  <= rb ? vec[ i ] :  i  == rb+1 ? p1 : p2);
			
			S += _PA.x * _PB.y;
			S -= _PA.y * _PB.x;
//			printf ("\t%lf %lf (%lf %lf)\n", _PA.x, _PA.y, _PB.x, _PB.y);
		}
//		printf ("m == %lf, S == %lf\n", m, S);
		S /= 2.;
		if (S > w)
			r = m;
		else
			l = m;
	}
//	printf ("fnd lvl %d %d --> %lf\n", lp, rp, m);
	return m;
}

int main () {
	scanf ("%d %lf", &N, &H);
	++N;

	int i;
	for (i = 1; i <= N; ++i)
		scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	vec[0].x = vec[1].x; vec[0].y = INF;
	vec[N+1].x = vec[N].x; vec[N+1].y = INF-1;
	N += 2;
	int fpid = 0;
	for (i = 1; i < N - 1; ++i) {
		int type = (find_slope (i) << 1) | find_slope (i + 1);
//		printf ("fs %d -> %d, fs %d -> %d\n", i, find_slope (i), i+1, find_slope (i+1));
		switch (type) {
//			case 0: /*\\*/ break;
//			case 1: /*\/*/ break;
			case 2: /*/\*/ shole.push_back (hole (fpid, i)); fpid = i;
//							printf ("%lf %lf\n", shole.back ().wat, shole.back ().cap);
							 break;
//			case 3: /*//*/ break;
		}
	}

	shole.push_back (hole (fpid, N-1));
//	printf ("%lf %lf\n", shole.back ().wat, shole.back ().cap);

//	shole.push_back (hole ());
//	shole.back ().cap = BIG_INF;

/*	for (list_it_t it = shole.begin (); it != shole.end (); ++it)
		printf ("%d %d -- %lf %lf\n", it->lp, it->rp, it->cap, it->wat);
*/
	first_non_touched = shole.begin ();
	while (first_non_touched != shole.end ())
		do_it (first_non_touched);

/*	for (list_it_t it = shole.begin (); it != shole.end (); ++it)
		printf ("%d %d -- %lf %lf (%d %d)\n", it->lp, it->rp, it->cap, it->wat, it->left_over, it->right_over);
*/
	double ans = 0;
	for (list_it_t it = shole.begin (); it != shole.end (); ++it)
		ans >?= find_lvl (it->lp, it->rp, it->wat) - find_min_y (it->lp, it->rp);

	printf ("%.10lf\n", ans);

	return 0;
}
