#include <cstdio>
#include <cmath>

struct pnti {
	int x, y;
	pnti () {}
	pnti (int _x, int _y) : x (_x), y (_y) {}
};

struct pntd {
	double x, y;
	pntd () {}
	pntd (double _x, double _y) : x (_x), y (_y) {}
	pntd operator - (const pntd &a) const {return pntd (x - a.x, y - a.y);}
	pntd operator * (double a) const {return pntd (x * a, y * a);}
	pntd operator + (const pntd &a) const {return pntd (x + a.x, y + a.y);}
};

typedef pntd pnt;

const int MAXN = 1 << 7;
const double INF = 1e5;

int N;
double H;
pnt vec[MAXN];
double bnd[MAXN];

bool fnd_slope (int id) {
	return vec[id].y - vec[id-1].y > 0;
}

double S (const pnt &a, const pnt &b, const pnt &c) {
	return fabs ((b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x)) / 2.;
}


pnt inter (const pnt &p1, const pnt &q1, const pnt &p2, const pnt &q2) {
//	printf ("inter %lf %lf  %lf %lf  %lf %lf  %lf %lf --"\
	, p1.x, p1.y\
	, q1.x, q1.y\
	, p2.x, p2.y\
	, q2.x, q2.y);

	double S1 = S (p1, q2, p2);
	double S2 = S (p2, q2, q1);
	double t = S1 / (S1 + S2);
//	printf (" %lf %lf (%lf)\n", ((q1 - p1) * t + p1).x, ((q1 - p1) * t + p1).y, t);
	return (q1 - p1) * t + p1;
}

double find_S (int f, int l, double m) {
	double S = 0;
	printf ("\t%lf %lf\n", vec[f].x, vec[f].y);
	for (int i = f + 1; i < l; ++i) {
		S += vec[i-1].x * vec[i].y;
		S -= vec[i-1].y * vec[i].x;
	
		printf ("\t%lf %lf\n", vec[i].x, vec[i].y);
	}
	pnt t2 = inter (pnt (0, m), pnt (1, m), vec[f-1], vec[f]);
	pnt t1 = inter (pnt (0, m), pnt (1, m), vec[l-1], vec[l]);
	printf ("\t%lf %lf\n\t%lf %lf\n-----", t1.x, t1.y, t2.x, t2.y);
	S += vec[l-1].x * t1.y;
	S -= vec[l-1].y * t1.x;
	S += t1.x * t2.y;
	S -= t1.y * t2.x;
	S += t2.x * vec[f].y;
	S -= t2.y * vec[f].x;
	printf ("%lf__\n", S);
	return S;
}

void bsrch (int lid, int rid) {
	double l = find_edge (lid, rid).y;
	, r = (vec[lid-1].y <? vec[rid].y)
	, m;

	double S;
	for (int cc = 0; cc < 50; ++cc) {
		m = (l + r) / 2;
		printf ("%lf %lf m == %lf-----------\n", l, r, m);
		fpid = -1;
		bool go_down = 0;
		for (i = lid; i <= rid; ++i) {
			if (fpid != -1 && vec[i].y > m) {
				S = find_S (fpid, i, m);
				printf ("%lf %lf (%lf)--> %lf\n", bnd[fpid], bnd[i], (bnd[i] - bnd[fpid]) * H, S);
				if (S > (bnd[i] - bnd[fpid]) * H)
					go_down = 1;
				fpid = -1;
			} else if (fpid == -1 && vec[i].y < m)
				fpid = i;
		}

		if (go_down)
			r = m;
		else
			l = m;
	}
	if (l < find_edge (lid, rid).y + EPS) {
		bsrch (lid, find_edge (lid, rid));
		bsrch (find_ednge (lid, rid) + 1);
	}
}

int main () {
	scanf ("%d %lf", &N, &H);
	++N;

	int i, j;
	for (i = 1; i <= N; ++i)
		scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	vec[0].x = vec[1].x; vec[0].y = INF;
	vec[N+1].x = vec[N].x, vec[N+1].y = INF+1;
	N += 2;

	bnd[1] = vec[1].x;
	int beg_id;
	double maxy = -INF;
	for (i = 2; i < N; ++i) {
		int type = (fnd_slope (i-1) << 1) | fnd_slope (i);
		printf ("i == %d, type == %d (%d %d) (%lf - %lf %lf)\n", i, type, fnd_slope (i-1), fnd_slope (i), vec[i].y, vec[i-1].y, vec[i].y - vec[i-1].y);
		switch (type) {
			case 0: /*\\*/ bnd[i] = bnd[i-1]; break;
			case 1: /*\/*/ beg_id = i; maxy >?= vec[i-1].y; break;
			case 2: /*/\*/ printf ("\ti == %d, beg_id == %d --> %lf\n", i, beg_id, vec[i-1].x);
							for (j = beg_id; j <= i; ++j) bnd[j] = vec[i-1].x; break;
			case 3: /*//*/ break;
		}
	}

	for (j = beg_id; j < N; ++j) bnd[j] = vec[N-1].x;

	for (i = 0; i < N; ++i) printf ("%2d - %lf %lf --> %lf\n", i, vec[i].x, vec[i].y, bnd[i]);

	int fpid;


	printf ("%lf\n", l);

	return 0;
}
