/*
FROM: Pol '99 round 1
TASK: cuboid
KEYW: data structures, set, multiset, sorting, geometry
*/

#include <cstdio>
#include <algorithm>
#include <ext/numeric>
#include <set>

const int MAXN = 1 << 19;
const int MAX = 1000000;
int N;
int data[MAXN][3];

long long bs;
int bc[3];

struct cmp {
	int sort_id;
	cmp (int _sort_id) : sort_id (_sort_id) {}
	bool operator () (int a, int b) const {return data[a][sort_id] < data[b][sort_id];}
};

struct pntx {
	int x, y;
	pntx () {}
	pntx (int _x, int _y) : x (_x), y (_y) {}
	bool operator < (const pntx &a) const {
		return x != a.x ? x < a.x : y < a.y;
	}
};

struct Scmp {
	bool operator () (const pntx &a, const pntx &b) const {
		return (long long)a.x * a.y < (long long)b.x * b.y;
	}
};

std::set <pntx, Scmp> S;
std::set <pntx> grid;

void init_db () {
	S = std::set <pntx, Scmp> ();
	grid = std::set <pntx> ();
	S.insert (pntx (MAX, MAX));
	grid.insert (pntx (0, MAX));
	grid.insert (pntx (MAX, 0));
}

void try_upd (int trd_coor, int srt_id, int f_id, int s_id) {
	static std::set <pntx, Scmp> :: iterator it;
	it = --S.end ();
	if (bs < (long long)it->x * it->y * trd_coor) {
		bs = (long long)it->x * it->y * trd_coor;
		bc[srt_id] = trd_coor;
		bc[f_id] = it->x;
		bc[s_id] = it->y;
	}
}

void add_point (const pntx &p) {
	static std::set <pntx> :: iterator it, tmp;
	static int prev_py, beg_py;
	it = grid.lower_bound (p);

	--it;
//	printf ("INIT at %d %d <%d %d>\n", it->x, it->y, p.x, p.y);
	if (it->y <= p.y) return;
//	printf ("we are at %d %d\n", p.x, p.y);

	prev_py = beg_py = it->y;
	++it;
	while (it->y >= p.y) {
//		printf ("looking at %d %d\n", it->x, it->y);
		S.erase (pntx (it->x, prev_py));
		prev_py = it->y;
		tmp = it++;
//		printf ("removing %d %d\n", tmp->x, tmp->y);
		grid.erase (tmp);
	}

//	printf ("insert %d %d\n", p.x, p.y);
	S.erase (pntx (it->x, prev_py));
	grid.insert (p);
	S.insert (pntx (p.x, beg_py));
	S.insert (pntx (it->x, p.y));
}

int idx[MAXN];
void do_job (int srt, int f, int s) {
	std::sort (idx, idx + N, cmp (srt));

	init_db ();
	for (int i = 0; i < N; ++i) {//if there are several points with common srt coordinate, the first gives the correct volume, and the rest are wrong (but there is one correct which is important)
		try_upd (data[idx[i]][srt], srt, f, s);//this is the third coordinate - the rest is from the set
		add_point (pntx (data[idx[i]][f], data[idx[i]][s]));//copes with S's and with points
	}
}

int main () {
	scanf ("%d", &N);

	for (int i = 0; i < N; ++i)
		scanf ("%d %d %d", &data[i][0], &data[i][1], &data[i][2]);

	if (N == 0) {
		printf ("%I64d\n%d %d %d\n", (long long)MAX * MAX * MAX, MAX, MAX, MAX);
		return 0;
	}
		
	__gnu_cxx::iota (idx, idx + N, 0);
	do_job (0, 1, 2);
	do_job (1, 0, 2);
	do_job (2, 0, 1);

	printf ("%I64d\n%d %d %d\n", bs, bc[0], bc[1], bc[2]);

	return 0;
}
