#include <cstdio>
#include <climits>
#include <cassert>
#include <vector>
#include <cstdlib>
#include <algorithm>

const int MAXF = 1 << 9;
const int MAXN = 1 << 4;
const int MAXL = 1 << 4;
const int BASE = 1000000000;
int F;
int fact[MAXF];

struct big_mul {
	int pow[MAXF];
	big_mul () {memset (pow, 0, sizeof (pow));}
	big_mul (int a) {
		static int i;
		for (i = 0; i < F; ++i) {
			pow[i] = 0;
			while (!(a % fact[i])) {
				a /= fact[i];
				++pow[i];
			}
		}
	}
	big_mul (const big_mul &a) {
		memcpy (pow, a.pow, sizeof (pow));
	}
	big_mul& operator *= (const big_mul &a) {
		static int i;
		for (i = 0; i < F; ++i)
			pow[i] += a.pow[i];
		return *this;
	}
	big_mul& operator /= (const big_mul &a) {
		static int i;
		for (i = 0; i < F; ++i) {
			pow[i] -= a.pow[i];
			assert (pow[i] >= 0);
		}

		return *this;
	}
	big_mul& gcd (const big_mul &a) {
		static int i;
		for (i = 0; i < F; ++i)
			pow[i] <?= a.pow[i];
		return *this;
	}
	big_mul& lcm (const big_mul &a) {
		static int i;
		for (i = 0; i < F; ++i)
			pow[i] >?= a.pow[i];
		return *this;
	}
	void prnt () const {
		static int i;
		for (i = 0; i < F; ++i)
			if (pow[i])	printf ("%d ^ %d  ", fact[i], pow[i]);
		puts ("");
	}
};

bool __very_bad;
struct big_add {
	int m[MAXL];
	big_add () {memset (m, 0, sizeof (m));}
	big_add (const big_mul &b) {
		memset (m, 0, sizeof (m));
		int i, j;
		m[0] = 1;
		long long buf = 1;
		for (i = 0; i < F; ++i)
			for (j = 0; j < b.pow[i]; ++j) {
				if (buf * fact[i] > INT_MAX) {
					assert (buf < INT_MAX);
					*this *= (int)buf;
					buf = 1;
				}
				buf *= fact[i];
			}
		*this *= buf;
	}

	big_add& operator = (const big_add &a) {
		memcpy (m, a.m, sizeof (m));
		return *this;
	}
	
	big_add& operator *= (int a) {
		int pr = 0;
		for (int i = 0; i < MAXL; ++i) {
			long long tmp (m[i]);
			tmp *= a;
			tmp += pr;
			pr = tmp / BASE;
			assert (i != MAXL - 1 || pr == 0);
			m[i] = tmp % BASE;
		}

		return *this;
	}

	big_add& operator += (const big_add &b) {
		for (int i = 0; i < MAXL; ++i) {
			m[i+1] += (m[i] += b.m[i]) / BASE;
			m[i] %= BASE;
		}
		return *this;
	}
	big_add& operator -= (const big_add &b) {
		for (int i = 0; i < MAXL; ++i) {
			m[i] -= b.m[i];
			if (m[i] < 0) {
				m[i] += BASE;
				--m[i+1];
			}
			assert (m[i] >= 0);
		}
		return *this;
	}
	big_add operator / (int d) const {
		big_add res;
		int cp = 0;
		long long c = 0;
		for (int i = MAXL - 1; i >= 0; --i) {
			c *= BASE;
			c += m[i];
			res.m[cp++] = c / d;
			c %= d;
		}

		if (c) {
			__very_bad = 1;
			return big_add ();
		}

		__very_bad = 0;

		std::reverse (res.m, res.m + cp);
		for (int i = 0; i < MAXL; ++i)
			assert (res.m[i] < BASE && res.m[i] >= 0);
//		printf ("divide to %d---VV\n", d); prnt (); 
//		res.prnt ();
		return res;
	}

	void prnt () const {
		static int i;
		for (i = MAXL-1; i && !m[i]; --i);
		printf ("%d", m[i]);
		for (--i; i >= 0; --i)
			printf ("%09d", m[i]);
		puts ("");
	}
};

int N;
int vec[MAXN];
big_mul bigs[MAXN];

int main () {
	scanf ("%d", &N);
	int i, j;
	int t;
	for (i = 0; i < N; ++i) {
		scanf ("%d", vec + i);
		t = vec[i];
		for (j = 2; j * j <= t; ++j) {
			if (t % j == 0) {
				fact[F++] = j;
				do
					t /= j;
				while (t % j == 0);
			}
		}
		if (t != 1) fact[F++] = t;
		std::sort (fact, fact + F);
		F = std::unique (fact, fact + F) - fact;
	}

//	for (i = 0; i < F; ++i) printf ("%d_", fact[i]); puts ("");

	big_mul lcm_all (1);
	for (i = 0; i < N; ++i) {
		bigs[i] = big_mul (vec[i]);
		lcm_all.lcm (bigs[i]);
//		lcm_all.prnt ();
	}
//	printf ("lcm all -- "); lcm_all.prnt ();
//	printf ("lcm all (big add) -- "); big_add (lcm_all).prnt ();
//	for (i = 0; i < N; ++i) bigs[i].prnt ();

	int ub = 1 << N;
//	printf ("are we here!\n");
	big_add nominator;
//	printf ("are we here!\n");
	for (i = 1; i < ub; ++i) {
//		printf ("i == %d\n", i);
		big_mul lcm_set (1);
		
		for (j = 0; j < N; ++j)
			if ((i >> j) & 1)
				lcm_set.lcm (bigs[j]);

		big_mul res (lcm_all);
		res /= lcm_set;
//		printf ("res -- "); res.prnt ();
//		printf ("res big add -- "); big_add (res).prnt ();
		
		if (__builtin_popcount (i) & 1)//add
			nominator += big_add (res);
		else//extract
			nominator -= big_add (res);
//		printf ("crnt nominator -- "); nominator.prnt ();
	}
//	nominator.prnt ();
//	big_add (lcm_all).prnt ();
	for (i = 0; i < F; ++i) {
		while (lcm_all.pow[i]) {
			big_add cres = nominator / fact[i];
			if (__very_bad)
				break;
			else {
				--lcm_all.pow[i];
				nominator = cres;
			}
		}
	}
	
	nominator.prnt ();
	big_add (lcm_all).prnt ();

/*	big_add num (1);
	num *= 19;
	num.prnt ();
	num *= 23;
	num.prnt ();
	num *= 101;
	num.prnt ();
	num *= 37;
	num.prnt ();
	num *= 13;
	num.prnt ();
	num *= 7;
	num.prnt ();
	num *= 97;
	num.prnt ();
	big_add res = num / 101;
	res.prnt ();*/
	return 0;
}
