/*
FROM: 2001 k2
PROB: light
KEYW: geometry, rotation, tangenta, intersection
*/

#include <cstdio>
#include <cmath>

#include <utility>
#include <algorithm>

const int MAXN = 1 << 9;
const double epsilon = 1e-9;

struct point {
	double x, y;
	point () {}
	point (const point &a) : x (a.x), y (a.y) {}
	point (double _x, double _y) : x (_x), y (_y) {}
	point& operator += (const point &a) {x += a.x; y += a.y; return *this;}
	point& operator -= (const point &a) {x -= a.x; y -= a.y; return *this;}
	point& operator *= (double a) {x *= a; y *= a; return *this;}

	point operator + (const point &a) const {point ret(*this); return ret += a;}
	point operator - (const point &a) const {point ret(*this); return ret -= a;}
	point operator * (double a) const {point ret(*this); return ret *= a;}

	point rot (double a) const {return point (cos (a) * x - sin (a) * y, sin (a) * x + cos (a) * y);}
	double operator * (const point &a) const {return x * a.x + y * a.y;}
	double sq () const {return x * x + y * y;}
};

int N;
point cir[MAXN];
double r[MAXN];
point L;

std::pair <double, double> segs[MAXN];

double S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

point intersect (const point &p1, const point &q1, const point &p2, const point &q2) {
	double S1 = S (p1, q2, p2);
	double S2 = S (p2, q2, q1);
	return (q1 - p1) * (S1 / (S1 + S2)) + p1;
}

inline double ang (double hyp2, double kat) {
	return atan (kat / sqrt (hyp2 - kat * kat));
}

inline double deg (double alpha) {return alpha / M_PI * 180.;}

int main () {
	scanf ("%d", &N);
	scanf ("%lf %lf", &L.x, &L.y);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%lf %lf %lf", &cir[i].x, &cir[i].y, &r[i]);

	point gr1 (1, 0), gr2 (2, 0);
	point bs, lf, rg;
	double alpha;
	for (i = 0; i < N; ++i) {
		bs = cir[i] - L;
		alpha = ang (bs.sq (), r[i]);
		lf = bs.rot (alpha) + L;
		rg = bs.rot (-alpha) + L;
		segs[i].first = intersect (gr1, gr2, L, rg).x;
		segs[i].second = intersect (gr1, gr2, L, lf).x;
	}
	std::sort (segs, segs + N);

	double cbeg (segs[0].first), cend (segs[0].second);
	for (i = 1; i < N; ++i)
		if (segs[i].first - cend < epsilon)
			cend >?= segs[i].second;
		else {
			printf ("%.2lf %.2lf\n", cbeg, cend);
			cbeg = segs[i].first;
			cend = segs[i].second;
		}

	printf ("%.2lf %.2lf\n", cbeg, cend);

	return 0;
}
