/*
FROM: 4th kontrolno 2002
PROB: hill
KEYW: arc dijkstra, heap
*/

#include <cstdio>

const int MAXN = 1024;
const int MAXM = 262144;

struct arc {
    int to;
    int dist;
};

struct heap {
    int n;
    double dist;
    heap (int nn =0, double dd =0.0):n(nn), dist(dd) {}
};

const int MAXHLEN = MAXM*2;

heap h[MAXHLEN];
int hlen;
const double _infinity = 1000000000.0;

int index[MAXM];
const int _NOTIN = -1;
const int _POPPED = -2;

void init () {
    int i;
    for (i = 0; i < MAXHLEN; ++i)
        h[i].dist = _infinity;

    h[0].dist = -_infinity;

    hlen = 1;

    for (i = 0; i < MAXM; ++i)
        index[i] = _NOTIN;
}

int N, M;
arc arcs[MAXM];
int buf[MAXM];
int vec[MAXN];

bool winning[MAXM];

double fit (double a) {
    if (a < 0.000000001)
        return 0.0;
    return a;
}

heap pop () {
    heap ret = h[1];
    index[ret.n] = _POPPED;

    heap tomove = h[--hlen];
    h[hlen].dist = _infinity;
    if (hlen == 1)
        return ret;

    int p1 =1, p2 =2;

    for (;;) {
        if (h[p2+1].dist < h[p2].dist)
            ++p2;
        if (h[p2].dist < tomove.dist) {
            h[p1] = h[p2];
            index[h[p2].n] = p1;
            p1 = p2;
            p2 *= 2;
        } else
            break;
    }

    h[p1] = tomove;
    index[tomove.n] = p1;
    return ret;
}

void siftup (int n) {
    heap tomove = h[index[n]];
    int p1 = index[n], p2 = p1/2;

    while (h[p2].dist > tomove.dist) {
        h[p1] = h[p2];
        index[h[p2].n] = p1;
        p1 = p2;
        p2 /= 2;
    }
    h[p1] = tomove;
    index[tomove.n] = p1;
}

void add (int n, double dist) {
    if (index[n] == _NOTIN) {
        index[n] = hlen;
        h[hlen++] = heap (n, dist);
        siftup (n);
    } else if (index[n] != _POPPED && h[index[n]].dist > dist) {
        h[index[n]].dist = dist;
        siftup (n);
    }
}

double dijkstra (int s) {
    init ();
    int i;
    for (i = vec[s]; i != -1; i = buf[i])
        add (i, arcs[i].dist / 2.0);

    heap crnt;
    while (hlen > 1) {
        crnt = pop ();
        if (winning[crnt.n])
            return crnt.dist;

        for (i = vec[arcs[crnt.n].to]; i != -1; i = buf[i])
            add (i, crnt.dist + fit (arcs[i].dist / 2.0 - arcs[crnt.n].dist / 4.0));
    }

    return 0.0;
}

double d[MAXM];
bool used[MAXM] ={0};

double _dijkstra (int s) {
    int i;
    for (i = 0; i < MAXM; ++i) d[i] = _infinity;

    for (i = vec[s]; i != -1; i = buf[i])
        d[i] = (d[i] < arcs[i].dist / 2.0 ?
                d[i] : arcs[i].dist / 2.0);

    int M2 =M*2;
    double min;
    int mini;
    for (int j=0; j < M2; ++j) {
        min = _infinity;
        for (i = 0; i < M2; ++i)
            if (!used[i] && d[i] < min) {
                min = d[i];
                mini = i;
            }

//        printf ("popped %d %lf\n", mini, min);
        if (min == _infinity)
            return 0;
        if (winning[mini])
            return min;

        used[mini] = 1;

        for (i = vec[arcs[mini].to]; i != -1; i = buf[i])
            d[i] = d[i] < min + fit (arcs[i].dist / 2.0 - arcs[mini].dist / 4.0) ?
                   d[i] : min + fit (arcs[i].dist / 2.0 - arcs[mini].dist / 4.0);
    }
    return 0;
}

int A, B;

int main () {
    scanf ("%d%d", &N, &M);
    int M2 = M*2;

    int i, a, b, l;
    for (i = 0; i < MAXN; ++i) vec[i] = -1;
    for (i = 0; i < M2; ++i) {
        scanf ("%d%d%d", &a, &b, &l);
        --a, --b;
        arcs[i].to = b;
        arcs[i].dist = l;
        buf[i] = vec[a];
        vec[a] = i++;

        arcs[i].to = a;
        arcs[i].dist = l;
        buf[i] = vec[b];
        vec[b] = i;
    }

    scanf ("%d%d", &A, &B);
    --A, --B;

    for (i = 0; i < M2; ++i)
        winning[i] = (arcs[i].to == B);

    double d;
    if ((d = dijkstra (A)) < 0.0000001)
        printf ("0\n");
    else
        printf ("%.2lf\n", d);

    return 0;
}

