/*
FROM: 2nd kontrolno 2004
PROB: convex
KEYW: dynamical programming with inner cycle optimization, geometry
*/

#include <cstdio>
#include <algorithm>
#include <cmath>

const int MAXN = 1 << 9;
const int MOD = 1048576;

struct point {
	int x;
	int y;
};

int N;

point pnts[MAXN];
int ysort[MAXN];
int tansort[MAXN][MAXN];

int opt[MAXN][MAXN][MAXN];
int cnt;

bool cmpy (int a, int b) {
	return pnts[a].y < pnts[b].y;
}

int cmptanbase;
bool cmptan (int a, int b) {
	return 	atan2 (pnts[a].y - pnts[cmptanbase].y, pnts[a].x - pnts[cmptanbase].x) <
			atan2 (pnts[b].y - pnts[cmptanbase].y, pnts[b].x - pnts[cmptanbase].x);
}

int S (int a, int b, int c) {
	return (pnts[b].x - pnts[a].x) * (pnts[c].y - pnts[a].y) - (pnts[b].y - pnts[a].y) * (pnts[c].x - pnts[a].x);
}

void inc_mod (int &a) {
	if ((++a) == N - 1) a = 0;
}

void doitL2 (int a, int b) {
	int i;
	int c1, c2;
	int stc1, stc2;

	for (i = 0; tansort[b][i] != a; ++i);
	c2 = stc1 = i;

	inc_mod (i);
	for (c1 = i; c1 != stc1 && S (a, b, tansort[b][c1]) < 0; inc_mod (c1));
	stc2 = c1;

	int csum = 0;
	while (c1 != stc1) {
		while (c1 != stc1 && pnts[tansort[b][c1]].y <= pnts[a].y) inc_mod (c1);
		if (c1 == stc1) break;

		while (c2 != stc2 && S (tansort[b][c2], b, tansort[b][c1]) > 0) {
			csum += opt[a][tansort[b][c2]][b];
			csum %= MOD;
			inc_mod (c2);
		}

		opt[a][b][tansort[b][c1]] = csum;
		cnt += csum;
		cnt %= MOD;
		inc_mod (c1);
	}
}

void doitL1 (int a) {
	int i;
	for (i = 0; i < N - 1 && pnts[tansort[a][i]].y < pnts[a].y; ++i);
	//every point now has y >= a.y;
	for (; i < N - 1; ++i) {
		opt[a][a][tansort[a][i]] = 1;
		doitL2 (a, tansort[a][i]);
	}
}

int main () {
	scanf ("%d", &N);

	int i, j;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &pnts[i].x, &pnts[i].y);

	for (i = 0; i < N; ++i) {
		ysort[i] = i;
		for (j = 0; j < N; ++j)
			if (j != i)
				tansort[i][j - (j > i)] = j;
		cmptanbase = i;
		std::sort (tansort[i], tansort[i] + N - 1, cmptan);
	}

	std::sort (ysort, ysort + N, cmpy);

	for (i = 0; i < N; ++i)
		doitL1 (ysort[i]);

	printf ("%d\n", cnt);

	return 0;
}
