#include <iostream>
#include <fstream>

using namespace std;

struct Point
{ double x,y;
  Point(double x1=0, double y1=0)
  { x=x1; y=y1; }
};

ostream & operator<<(ostream &  os, Point P)
{ os << "(" << P.x << "," << P.y << ")";
  return os;
}

struct Segment
{ Point A,B;
  Segment(Point P=Point(), Point Q=Point())
  { A=P; B=Q; }
};

int direction(Point A, Point B, Point C)
{ double xAB=B.x-A.x;
  double yAB=B.y-A.y;
  double xAC=C.x-A.x;
  double yAC=C.y-A.y;
  double p = xAB*yAC;
  double q = yAB*xAC;
  if(p>q) return 1;
  if(p<q) return -1;
  return 0;
}


struct Rect
{ Point A,B,C,D;
  Rect(Point P=Point(), Point Q=Point())
  { A=P; C=Q;
    B=Point(C.x,A.y);
    D=Point(A.x,C.y);
  }
};

bool onSegment(Segment S, Point P)
{ double x1=S.A.x, y1=S.A.y;
  double x2=S.B.x, y2=S.B.y;
  if(x1>x2) {x1=x2; x2=S.A.x;}
  if(y1>y2) {y1=y2; y2=S.A.y;}
  if(x1<=P.x && P.x<=x2 && y1<=P.y && P.y<=y2)
    return true;
  return false;
}    

bool intersect(Segment S, Segment T)
{ int d1 = direction(S.A,S.B,T.A);
  int d2 = direction(S.A,S.B,T.B);
  int d3 = direction(T.A,T.B,S.A);
  int d4 = direction(T.A,T.B,S.B);

  if(((d1>0 && d2<0) || (d1<0 && d2>0)) &&
     ((d3>0 && d4<0) || (d3<0 && d4>0)))
  { cout << S.A << "-" << S.B << " intersects " << T.A << "-" << T.B << endl;
    cout << d1 << " " << d2 << " " << d3 << " " << d4 << endl;
    return true;
  }

  if( d1==0 && onSegment(S,T.A)) return true;
  if( d2==0 && onSegment(S,T.B)) return true;
  if( d3==0 && onSegment(T,S.A)) return true;
  if( d4==0 && onSegment(T,S.B)) return true;
  return false;
}

bool intersect(Segment S, Rect R)
{ return  intersect(S,Segment(R.A,R.B))
       || intersect(S,Segment(R.B,R.C))
       || intersect(S,Segment(R.C,R.D))
       || intersect(S,Segment(R.D,R.A));
}

Rect    R[512];
Point   P[2048];
Segment S[2048];

int main(int argc, char *argv[])
{  int i,j,K,L,M,N;
   double md,nd;

   if (argc != 4)
   { cout << "Argument error \n";
     return 0;
   }

   ifstream fin(argv[1]);    // input file
   if(fin.fail())
   { cout << 0 << endl;
     cout << "Cannot open input file " << argv[1] << endl;
     return 0;
   }

   ifstream fout(argv[2]);    // output file
   if(fout.fail())
   { cout << 0 << endl;
     cout << "Cannot open output file " << argv[2] << endl;
     return 0;
   }

   ifstream fsol(argv[3]);    // solution file
   if(fsol.fail())
   { cout << 0 << endl;
     cout << "Cannot open solution file " << argv[3] << endl;
     return 0;
   }

   fin >> N >> M >> K;
   for(i=1; i<=K; i++)
   { Point P, Q;
     fin >> P.x >> P.y >> Q.x >> Q.y;
     R[i]=Rect(P,Q);
   }
   fin.close();

   int sol;
   fsol >> sol;
   fsol.close();

   fout >> L;
   if(sol==-1 && L==-1)
   { cout << 10 << endl;
     cout << "Correct solution \n";
     fout.close();
     return 0;
   }

   if(sol==-1 && L!=-1)
   { cout << 0 << endl;
     cout << "L=" << L << " (must be -1)" << endl;
     fout.close();
     return 0;
   }

   if(sol!=-1 && L==-1)
   { cout << 0 << endl;
     cout << "L=" << L << " (must be nonnegative)" << endl;
     fout.close();
     return 0;
   }

   if(L > 4*K)
   { cout << 0 << endl;
     cout << "Too long path" << endl;
     cout << "K=" << K << "  L=" << L << endl;
     return 0;
   }

   for(i=1; i<=L; i++)
   { fout >> P[i].x >> P[i].y; }
   fout.close();

   md=M; nd=N;
   for(i=1; i<=L; i++)
     if( !(0<P[i].x && P[i].x<nd && 0<P[i].y && P[i].y<md))
          { cout << 0 << endl;
            cout << "P[" << i << "]=" << P[i] << " is on the border or outside" << endl;
            return 0;
          }

   P[0]=Point(0,0);
   P[L+1]=Point(nd,md);

   for(i=0; i<=L; i++)
     S[i]=Segment(P[i],P[i+1]);

   for(i=0; i<=L; i++)
     for(j=1; j<=K; j++)
       if (intersect(S[i],R[j]))
       { cout << 0 << endl;
         cout << "Segment " << i << " - " << i+1 << " intersects rectangle " << j << endl;
         cout << P[i] << " - " << P[i+1] << endl;
         cout << R[j].A << " " << R[j].B << " " << R[j].C << " " << R[j].D << endl;
         return 0;
       }

   cout << 10 << endl;
   cout << "Correct solution \n";
   return 0;
}




