/*
FROM: 2006 k1
PROB: skymap
KEYW: mars index tree, 3D
*/

#include <cstdio>
#include <cassert>

#include <algorithm>

using std::swap;

const int MAXN = 1 << 9;

struct rec {
	int x[2];
	int y[2];
	int z[2];
};

struct el {
	int y;
	int id;
	el () {}
	el (int _y, int _id) : y (_y), id (_id) {}
	bool operator < (const el &a) const {return y < a.y;}
};

struct node {
	long long cov;
	int all;
};

int N;
rec data[MAXN];
int X[MAXN * 2], Y[MAXN * 2], Z[MAXN * 2];
int xp, yp, zp;

int vec[MAXN], vp;

node idt[MAXN * 4];

long long _get (int id, int xx, int yy) {
	if (idt[id].all)
		return X[yy] - X[xx];
	else
		return idt[id].cov;
}

long long get () {return _get (0, 0, xp);}

void add (int x, int y, int xx, int yy, int p, int val) {
//	printf ("%d %d  %d %d  %d  %d\n", x, y, xx, yy, p, val);
	if (x >= yy || y <= xx) {/*printf ("<-\n");*/ return;}
	x >?= xx; y <?= yy;
	if (x == xx && y == yy) {
		idt[p].all += val;
//		printf ("--< %d(%Ld)\n", idt[p].all, _get (p, xx, yy));
		return;
	}

	int m = (xx + yy) / 2;
	add (x, y, xx, m, p * 2 + 1, val);
	add (x, y, m, yy, p * 2 + 2, val);

	idt[p].cov = _get (p * 2 + 1, xx, m) + _get (p * 2 + 2, m, yy);
//	printf ("ret %d %d -- %Ld\n", xx, yy, _get (p, xx, yy));
}

long long doit () {
	static el wo[MAXN * 2];
	static int wp;
	int i, k;
	if (vp == 0) return 0ll;
	for (wp = i = 0; i < vp; ++i)
		for (k = 0; k < 2; ++k)
			wo[wp++] = el (data[vec[i]].y[k], vec[i]);

	std::sort (wo, wo + wp);

	long long res = 0;
	add (data[wo[0].id].x[0], data[wo[0].id].x[1], 0, xp, 0, 1);
	for (i = 1; i < wp; ++i) {
		if (wo[i].y != wo[i-1].y) res += get () * (Y[wo[i].y] - Y[wo[i-1].y]);
		add (data[wo[i].id].x[0], data[wo[i].id].x[1], 0, xp, 0, (wo[i].y == data[wo[i].id].y[0] ? 1 : -1));
	}
//	printf ("doit -- ret -- %Ld\n", res);
	return res;
}

int main () {
	scanf ("%d", &N);
	if (!N) {printf ("0\n"); return 0;}

	int i, k;
	for (i = 0; i < N; ++i) {
		for (k = 0; k < 2; ++k) {
			scanf ("%d %d %d", &data[i].x[k], &data[i].y[k], &data[i].z[k]);
			X[xp++] = data[i].x[k];
			Y[yp++] = data[i].y[k];
			Z[zp++] = data[i].z[k];
		}

		if (data[i].x[0] > data[i].x[1]) swap (data[i].x[0], data[i].x[1]);
		if (data[i].y[0] > data[i].y[1]) swap (data[i].y[0], data[i].y[1]);
		if (data[i].z[0] > data[i].z[1]) swap (data[i].z[0], data[i].z[1]);
	}

	std::sort (X, X + xp); xp = std::unique (X, X + xp) - X;
	std::sort (Y, Y + yp); yp = std::unique (Y, Y + yp) - Y;
	std::sort (Z, Z + zp); zp = std::unique (Z, Z + zp) - Z;

	for (i = 0; i < N; ++i)
		for (k = 0; k < 2; ++k) {
			data[i].x[k] = std::lower_bound (X, X + xp, data[i].x[k]) - X;
			data[i].y[k] = std::lower_bound (Y, Y + yp, data[i].y[k]) - Y;
			data[i].z[k] = std::lower_bound (Z, Z + zp, data[i].z[k]) - Z;
		}

	long long res = 0, S;
	for (i = 1; i < zp; ++i) {
		for (vp = k = 0; k < N; ++k)
			if (data[k].z[0] <= (i-1) && i <= data[k].z[1])
				vec[vp++] = k;

		S = doit ();
		res += S * (Z[i] - Z[i-1]);
	}

	printf ("%Ld\n", res);

	return 0;
}
