/*
FROM: NOI 2006 round 3 day 1
PROB: brkclk
KEYW: binary operations, bitmasks, full exhaustion
NOTE: for every 2 hours and every 2 minutes calculate the time when they will be distinguishable, then iterate through all different time-minute pairs and see which pair is the "worst" case
*/

#include <cstdio>
#include <cassert>

typedef unsigned uint;

const uint LINES = 5;
const uint CHAR_PER_LINE = 32;
const uint MHOURS = 32;
const uint HOURS = 24;
const uint MMIN = 64;
const uint MIN = 60;
const uint DIG_COUNT = 4;
const uint BIT_COUNT = 7;
const uint SHIFT = 8;
const uint INF = 0xffffffff;

//				0		1	2		3	4		5	6		7	8		9
uint norm[] = {0x77, 0x24, 0x5D, 0x6D, 0x2E, 0x6B, 0x7B, 0x25, 0x7F, 0x6F, 0x00};
//			 0  1  2  3  4  5  6  -- positions of the bits in the string representation (which is in the input)
uint dx[] = {0, 1, 1, 2, 3, 3, 4};
uint dy[] =	{1, 0, 2, 1, 0, 2, 1};
uint doy[] = {0, 5, 10, 15};//digit offset Y - where is the begining Y of the digit

uint work_mask[DIG_COUNT];//1 if the specified diode is working
uint work_mask_hm[2];//concatanates work_mask[0] && work_mask[1] and work_mask[2] && work_mask[3]
uint see_h[MHOURS];//see_h[i] -- what are we going to see if the hour is 'i'
uint see_m[MMIN];//see_m[i] -- whar are we going to see if the minute is 'i'

char inp[LINES][CHAR_PER_LINE];
uint csee[DIG_COUNT];//what are we currently able to see
uint csee_hm[2];//what are we currently seing grouped by hours and minutes

int fshow_he[MHOURS][MHOURS];//after how many 'changes' will h1 and h2 be different if they change together (-1 if never)
int fshow_h[MHOURS][MHOURS];//after how many 'changes' will h1 and h2 be different if h1 is changing before h2 (-1 if never)
int fshow_m[MMIN][MMIN];//after how many 'changes' will m1 and m2 be different (-1 if never)

uint poss_h[MHOURS], php;//possible hours, possible hours pointer
uint poss_m[MMIN], pmp;//possible minutes, possible minutes pointer

int main () {
	for (uint l = 0; l < LINES; ++l)
		gets (inp[l]);

	uint d, b;//digit, bit
	for (d = 0; d < DIG_COUNT; ++d) {
		for (b = 0; b < BIT_COUNT; ++b) {
			if (inp[dx[b]][doy[d] + dy[b]] != '.') {
				work_mask[d] |= 1 << b;
			}
			if (inp[dx[b]][doy[d] + dy[b]] == '='
			 || inp[dx[b]][doy[d] + dy[b]] == '#') {//we are seing it right now
				csee[d] |= 1 << b;
			}
		}
		if (d & 1) {
			work_mask_hm[d>>1] = (work_mask[d-1] << SHIFT) | (work_mask[d]);
			csee_hm[d>>1] = (csee[d-1] << SHIFT) | (csee[d]);
		}
	}

	uint norm_see;//what are we going to see if everything works fine (grouped 1st with 2nd digit)
	uint h, h1, h2;//the current hour and its 2 digits
	for (h = 0; h < HOURS; ++h) {
		h1 = h / 10; h2 = h % 10;
		if (h1 == 0) h1 = 10;//we dont have leading 0 -> horm[10] is 0 (everything off)
		norm_see = (norm[h1] << SHIFT) | norm[h2];
		see_h[h] = norm_see & work_mask_hm[0];//work_mask_hm[0] is for the hours
		if (see_h[h] == csee_hm[0]) {
			poss_h[php++] = h;
		}
	}

	uint m, m1, m2;//the current minute and its 2 digits
	for (m = 0; m < MIN; ++m) {
		m1 = m / 10; m2 = m % 10;
		norm_see = (norm[m1] << SHIFT) | norm[m2];
		see_m[m] = norm_see & work_mask_hm[1];//work_mask_hm[1] is for the minutes;
		if (see_m[m] == csee_hm[1]) {
			poss_m[pmp++] = m;
		}
	}

	//h1 and h2 are now showing the 2 hours that we are tracing to see when they'll show difference
	//h1 changes BEFORE h2
	//d is the number of changes
	//fill fshow_h[][]
	uint ch1, ch2;//h1 and h2 in an intermediate moment after d changes (moved ahead)
	for (h1 = 0; h1 < HOURS; ++h1)
		for (h2 = 0; h2 < HOURS; ++h2) {
			ch1 = h1, ch2 = h2;
			if (see_h[h1] != see_h[h2]) fshow_h[h1][h2] = 0;//they are already different
			for (d = 1; d < MHOURS * 2; ++d) {
				if (d & 1) {//h1 is moving
					ch1 = ch1 + 1 == HOURS ? 0 : ch1 + 1;
					if (see_h[ch1] != see_h[ch2]) {fshow_h[h1][h2] = d; break;}
				} else {//h2 is moving
					ch2 = ch2 + 1 == HOURS ? 0 : ch2 + 1;
					if (see_h[ch1] != see_h[ch2]) {fshow_h[h1][h2] = d; break;}
				}
			}
			if (d == MHOURS * 2)
				fshow_h[h1][h2] = -1;//they are never going to be the same (h1 moves before h2)
		}

	//h1 and h2 move simultaneously -> fill fshow_he[][];
	for (h1 = 0; h1 < HOURS; ++h1)
		for (h2 = 0; h2 < HOURS; ++h2) {
			for (d = 0; d < MHOURS; ++d)
				if (see_h[(h1 + d) % HOURS] != see_h[(h2 + d) % HOURS]) {
					fshow_he[h1][h2] = d;
					break;
				}
			if (d == MHOURS) fshow_he[h1][h2] = -1;//they are never going to be the same (h1 and h2 move simultaneously)
		}

	for (m1 = 0; m1 < MIN; ++m1)
		for (m2 = 0; m2 < MIN; ++m2) {
			for (d = 0; d < MMIN; ++d)
				if (see_m[(m1 + d) % MIN] != see_m[(m2 + d) % MIN]) {
					fshow_m[m1][m2] = d;
					break;
				}
			if (d == MMIN) fshow_m[m1][m2] = -1;//they are never going to be different
		}

	uint res = 0;
	uint _h1, _h2, _m1, _m2;//_h1 and _h2 are indexes in poss_h, _m1 and _m2 are indexes in poss_m
	for (_h1 = 0; _h1 < php; ++_h1) for (_h2 = 0; _h2 < php; ++_h2)
		for (_m1 = 0; _m1 < pmp; ++_m1) for (_m2 = 0; _m2 < pmp; ++_m2) {
			h1 = poss_h[_h1]; m1 = poss_m[_m1];
			h2 = poss_h[_h2]; m2 = poss_m[_m2];
			if (h1 == h2 && m1 == m2) continue;//we havent chosen 2 different hour-minute pairs
			if (m1 == m2) {//the hours move simultaneously
				res >?= fshow_he[h1][h2] != -1 ? fshow_he[h1][h2] * MIN - m1 : INF;
			} else if (m1 > m2) {//h1 moves before h2
				res >?= (fshow_h[h1][h2] != -1 ? ((fshow_h[h1][h2] + 1) / 2 * MIN - (fshow_h[h1][h2] & 1 ? m1 : m2)) : INF)
							<?	//or when the minutes get different
						(fshow_m[m1][m2] != -1 ? fshow_m[m1][m2] : INF);
			}//if m1 < m2 we will have afterwards (or we already had) h2 h1 m2 m1 which is the same but m1' < m2'
		}

	printf ("%d\n", (int)res);//INF is converted to -1

	return 0;
}
