/*
FROM: NOI 2006
PROB: lab101
KEYW: coding, decoding, bfs, cyclic game
*/

#include <cstdio>
#include <utility>

#include <queue>

const int MAXN = 1 << 4;
const int MAXM = 1 << 4;
const int MAXK = 1 << 4;
const int MAXNN = 1 << 24;

struct state {
	int x1, y1;
	int x2, y2;
	int keys;
	state () {}
	state (int _x1, int _y1, int _x2, int _y2, int _keys) : x1 (_x1), y1 (_y1), x2 (_x2), y2 (_y2), keys (_keys) {}
};

void prnt (state s) {
	printf ("%d %d  %d %d  %d\n", s.x1, s.y1, s.x2, s.y2, s.keys);
}

const int dx[] = {0, 1, 0, -1, 0};
const int dy[] = {1, 0, -1, 0, 0};

int N, M, K, P;
bool map[MAXN][MAXM];
int key[MAXN][MAXM];
int X1, Y1, X2, Y2;
int FX, FY;


std::pair <int, int> keys[MAXK];

int __bk;

int getid (int x, int y) {
	std::pair <int, int> add (x, y);
	int i;
	for (i = 0; i < K && keys[i] != add; ++i);
	if (i == K) {
		keys[K++] = add;
		__bk <<= 1; __bk |= map[x][y];
		map[x][y] = 0;
	}

	return i;
}

int maxNN;
int opt[MAXNN];

int _T1, _T2, _T3;
int code (state s) {
	int res = 0;
	res += s.x1 * _T1 + s.x2 * _T2 + s.y1 * _T3 + s.y2;
	res <<= K;
	res |= s.keys;
	return res;
}

state decode (int a) {
	state res;
	res.keys = a & ((1 << K) - 1); a >>= K;
	res.x1 = a / _T1; a %= _T1;
	res.x2 = a / _T2; a %= _T2;
	res.y1 = a / _T3; a %= _T3;
	res.y2 = a;
	for (int i = 0; i < K; ++i) map[keys[i].first][keys[i].second] = res.keys & (1 << (K - i - 1));
	return res;
}

int in[MAXNN];
void add (int toadd, int i, std::queue <int> &q) {
	if (opt[toadd] != -1) return;
	if (opt[i]) {
		if (!(--in[toadd])) {
//			printf (">(0)"); prnt (decode (toadd));
			opt[toadd] = 0;
			q.push (toadd);
		}
	} else {
//		printf (">(1)"); prnt (decode (toadd));
		opt[toadd] = 1;
		q.push (toadd);
	}
}

void fill_in () {
	static int i, k;
	static int nx, ny;
	static int kid;
	for (i = 0; i < maxNN; ++i) {
		state crnt = decode (i);

		for (k = 0; k < 5; ++k) {
			nx = crnt.x1 + dx[k];
			ny = crnt.y1 + dy[k];
			if (0 <= nx && nx < N
			 && 0 <= ny && ny < M
			 && !map[nx][ny])

				++in[i];
		}

		//try to change key
		if (key[crnt.x1][crnt.y1] != -1) {
			kid = key[crnt.x1][crnt.y1];
			if (!(keys[kid].first == crnt.x1 && keys[kid].second == crnt.y1
			   || keys[kid].first == crnt.x2 && keys[kid].second == crnt.y2)) {

				++in[i];
			}
		}
//		printf ("%d %d\n", i, in[i]);
	}
}

int bfs () {
	for (int i = 0; i < maxNN; ++i) opt[i] = -1;//undetermined
	std::queue <int> q;

	state crnt;
	int targ = code (state (X1, Y1, X2, Y2, __bk));
//	printf ("targ == "); prnt (state (X1, Y1, X2, Y2, __bk));

	int i, k;
	for (i = 0; i < maxNN; ++i) {
		crnt = decode (i);
		if (map[crnt.x1][crnt.y1]
		 || map[crnt.x2][crnt.y2]) {opt[i] = 3; continue;}

		if (crnt.x1 == FX && crnt.y1 == FY) {opt[i] = 3; continue;}

		if (crnt.x2 == FX && crnt.y2 == FY) {
			opt[i] = 0;//already lost
			q.push (i);
		}
	}

	int ci;
	int nx, ny;
	int toadd;
	int kid;
	while (!q.empty ()) {
		ci = q.front (); q.pop ();
//		printf ("popped(%d):", opt[ci]); prnt (decode (ci));
		if (ci == targ) return 2 - opt[ci];
		crnt = decode (ci);
		//try to move (or stay in the same place)
		for (k = 0; k < 5; ++k) {
			nx = crnt.x2 + dx[k];
			ny = crnt.y2 + dy[k];
			if (0 <= nx && nx < N
			 && 0 <= ny && ny < M
			 && !map[nx][ny]) {
				toadd = code (state (nx, ny, crnt.x1, crnt.y1, crnt.keys));
				add (toadd, ci, q);
			}
		}

		//try to change key
		if (key[crnt.x2][crnt.y2] != -1) {
			kid = key[crnt.x2][crnt.y2];
			if (!(keys[kid].first == crnt.x1 && keys[kid].second == crnt.y1
			   || keys[kid].first == crnt.x2 && keys[kid].second == crnt.y2)) {

				crnt.keys ^= 1 << (K - 1 - kid);//switch
				toadd = code (state (crnt.x2, crnt.y2, crnt.x1, crnt.y1, crnt.keys));
				add (toadd, ci, q);
			}
		}
	}

	return 0;//no one wins
}

int main () {
	scanf ("%d %d", &N, &M);

	int i, j = 0;
	int tmp;
	for (i = 0; i < N; ++i)
		for (j = 0; j < M; ++j) {
			scanf ("%d", &tmp);
			map[i][j] = tmp;
			key[i][j] = -1;
		}

	scanf ("%d", &P);

	int x, y, a, b;
	for (i = 0; i < P; ++i) {
		scanf ("%d %d %d %d", &x, &y, &a, &b);
		--x; --y; --a; --b;
		key[x][y] = getid (a, b);
	}
	scanf ("%d %d", &X1, &Y1); --X1; --Y1;
	scanf ("%d %d", &X2, &Y2); --X2; --Y2;
	scanf ("%d %d", &FX, &FY); --FX; --FY;


	maxNN = N * N * M * M * (1 << K);
	_T3 = M; _T2 = _T3 * M; _T1 = _T2 * N;

	fill_in ();
	int res = bfs ();
	printf ("%d\n", res);

	return 0;
}
