/*
FROM: NOI 2006 round 3 day 2
PROB: sym
KEYW: convex hull, symetricity
NOTE: very careful with the hull - SHULD NOT change places of points in vec
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <algorithm>

const int MAXN = 1 << 14;
const double epsilon = 1e-9;

bool OK (double &a, double &b) {
	if (fabs (a - nearbyint (a)) < epsilon
	 && fabs (b - nearbyint (b)) < epsilon) {
		a = nearbyint (a);
		b = nearbyint (b);
		return 1;
	}
	return 0;
}

struct point {
	int x, y;
	point () {}
	point (int _x, int _y) : x (_x), y (_y) {}
	point operator - (const point &a) const {return point (x - a.x, y - a.y);}
	int sq () const {return x * x + y * y;}
	point rot90 () const {return point (y, -x);}
	point symetr (int s, int len, point par) const {
		static double xx, yy;
		xx = (double)par.x * ((double)s * 2. / (double)len);
		yy = (double)par.y * ((double)s * 2. / (double)len);
//		printf ("in simetr %lf %lf (%d %d (%lf) %d %d)\n", xx, yy, s, len, (double)s / len, par.x, par.y);
		if (OK (xx, yy))
			return point (x + (int)xx, y + (int)yy);
		else
			return point (100000, 100000);//can't be :)
	}
	int operator * (const point &a) {return x * a.x + y * a.y;}
	bool operator != (const point &a) {return x != a.x || y != a.y;}
};

int N;
point vec[MAXN];

int h[MAXN];
int hc;

inline int S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

int _bi;
inline bool cmp1 (int a, int b) {
	static int tmp;
	return (tmp = S (vec[_bi], vec[a], vec[b])) ?
			tmp > 0 :
			(vec[a] - vec[0]).sq () < (vec[b] - vec[0]).sq ();
}

inline bool ok () {
	return S (vec[h[hc-3]], vec[h[hc-2]], vec[h[hc-1]]) > 0;
}

void hull () {
	point best = vec[0];
	int bi = 0;
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y < best.y || vec[i].y == best.y && vec[i].x > best.x) {
			best = vec[i];
			bi = i;
		}
	_bi = bi;
/*
	vec[bi] = vec[0];
	vec[0] = best;
*/
	int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
//	std::swap (idx[0], idx[bi]);
	idx[bi] = 0; idx[0] = bi;

	std::sort (idx + 1, idx + N, cmp1);

	h[hc++] = idx[0];
	h[hc++] = idx[1];

	for (i = 2; i < N; ++i) {
		h[hc++] = idx[i];

		while (hc > 2 && !ok ()) {
			h[hc-2] = h[hc-1];
			--hc;
		}
	}
	h[hc] = h[0];
//	for (i = 0; i < hc; ++i) printf ("%d %d\n", vec[h[i]].x, vec[h[i]].y);
	if (hc == 2) {//everything is on the same line
		printf ("1"); for (i = 1; i < N; ++i) printf (" %d", i + 1); printf ("\n");
		exit (0);
	}
}

inline point mid (const point &a, const point &b) {
	return point ((a.x + b.x) / 2, (a.y + b.y) / 2);
}

int indx[MAXN];
bool cmp2 (int a, int b) {
	return vec[a].x != vec[b].x ?
			vec[a].x < vec[b].x :
			vec[a].y < vec[b].y;
}

int bsrch (point xx) {
	int l = -1, r = N, m;
	vec[N+1] = xx;
	while (l + 1 < r) {
		m = (l + r) / 2;
		if (cmp2 (indx[m], N+1))
			l = m;
		else
			r = m;
	}
//	printf ("srch %d %d -- %d(%d)\n", xx.x, xx.y, r, indx[r]);
	if (r == N || vec[indx[r]] != xx) return -1;
	return indx[r];
}

int cor[MAXN];

void _test () {
	point vv[MAXN];
	int vvp = 0;
	point tmp;
	for (int i = 0; i < N; ++i) {
		if (i == cor[i]) continue;
		tmp = (vec[i] - vec[cor[i]]).rot90 ();
		vv[vvp++] = mid (vec[i], vec[cor[i]]);
//		printf ("%lf\n", fabs (tmp.x / tmp.y));
	}
	for (int i = 0; i + 2 < vvp; ++i)
		assert (S (vv[i], vv[i+1], vv[i+2]) == 0);
	if (vvp >= 2)
		for (int i = 0; i < N; ++i)
			assert ((vv[1] - vv[0]) * (vec[i] - vec[cor[i]]) == 0);
}

void _try (const point &p, const point &q) {
//	printf ("--try %d %d  %d %d\n", p.x, p.y, q.x, q.y);
	point par = (q - p).rot90 ();

	int i;
	int s;
	int len = (p - q).sq ();
	point ns;
	for (i = 0; i < N; ++i) {
		s = S (p, q, vec[i]);
		if (s == 0) {cor[i] = i; continue;}
		ns = vec[i].symetr (s, len, par);
//		printf ("\t%d %d --> %d %d\n", vec[i].x, vec[i].y, ns.x, ns.y);
		if ((cor[i] = bsrch (ns)) == -1) return;
	}

	printf ("%d", cor[0] + 1); for (i = 1; i < N; ++i) printf (" %d", cor[i] + 1); printf ("\n");// exit (0);

	_test ();
}

int main () {
	scanf ("%d", &N);
	if (N == 1) {printf ("1\n"); return 0;}

	int i;
	for (i = 0; i < N; ++i) {
		scanf ("%d %d", &vec[i].x, &vec[i].y);
		vec[i].x *= 2;
		vec[i].y *= 2;
	}

	hull ();

//	for (i = 0; i < N; ++i) printf ("%d %d\n", vec[i].x, vec[i].y); printf ("----\n");

	for (i = 0; i < N; ++i) indx[i] = i;
	std::sort (indx, indx + N, cmp2);
//	for (i = 0; i < N; ++i) printf ("%d %d\n", vec[indx[i]].x, vec[indx[i]].y); printf ("-----\n");

	int ii;
	if (hc & 1)
		for (i = 0, ii = i + hc / 2; i < hc; ++i, ii = (ii + 1) % hc)
			_try (vec[h[i]], mid (vec[h[ii]], vec[h[ii+1]]));
	else
		for (i = 0, ii = i + hc / 2; i < hc / 2; ++i, ii = (ii + 1) % hc)
			_try (vec[h[i]], vec[h[ii]]),
			_try (mid (vec[h[i]], vec[h[i+1]]), mid (vec[h[ii]], vec[h[ii+1]]));

//	printf ("0\n");

	return 0;
}
