/*
FROM: SPRING 2004 A
PROB: wireless
KEYW: dijkstra
*/

#include <cstdio>
#include <cassert>
#include <cstdlib>
#include <vector>
#include <climits>
#include <queue>
#include <utility>

using std::make_pair;

const int MAXN = 1 << 12;
const int _infinity = 1 << 29;

struct el {
	int to;
	int dist;
	el () {}
	el (int _to, int _dist) : to (_to), dist (_dist) {}
	bool operator < (const el &a) const {return dist > a.dist;}//inversed
};

int N;
int A, B, C;
std::vector <el> vec[MAXN];
std::vector <el> rvec[MAXN];
int dA[MAXN], dB[MAXN], dC[MAXN];

void dijkstra (int st, std::vector <el> *gr, int *d) {
//	printf ("st == %d\n", st);
	std::priority_queue <el> q;
	bool used[MAXN] = {0};
	q.push (el (st, 0));

	int i;
	el crnt;
	while (!q.empty ()) {
		crnt = q.top (); q.pop ();
//		printf ("%d %d\n", crnt.to, crnt.dist);
		if (used[crnt.to]) continue;
		used[crnt.to] = 1;
		d[crnt.to] = crnt.dist;

		for (i = 0; i < (int)gr[crnt.to].size (); ++i)
			if (!used[gr[crnt.to][i].to])
				q.push (el (gr[crnt.to][i].to, crnt.dist + gr[crnt.to][i].dist));
	}
}

int fnd (int *d, int f) {
	for (int i = 0; i < (int)vec[f].size (); ++i)
		if (vec[f][i].dist == abs (d[vec[f][i].to] - d[f])) return i;
	assert (0);
}

std::vector <std::pair <int, int> > ans;

void fprnt (int crnt, int targ, int *d) {
	int id;
	while (crnt != targ) {
		id = fnd (d, crnt);
		ans.push_back (make_pair (crnt, vec[crnt][id].dist));
		crnt = vec[crnt][id].to;
	}
}

int main () {
	scanf ("%d %d %d %d", &N, &A, &B, &C);
	--A; --B; --C;

	int i, j;
	int k;
	int a, d;
	for (i = 0; i < N; ++i) {
		scanf ("%d", &k);
		vec[i].reserve (k);
		for (j = 0; j < k; ++j) {
			scanf ("%d %d", &a, &d);
//			printf ("(%d) %d %d\n", i, a, d);
			--a;
			vec[i].push_back (el (a, d));
			rvec[a].push_back (el (i, d));
		}
	}
/*
	for (i = 0; i < N; ++i) {
		printf ("%d ->", i);
		for (j = 0; j < vec[i].size (); ++j)
			printf (" (%d %d)", vec[i][j].to, vec[i][j].dist);
		printf ("\n");
	}
*/
	for (i = 0; i < N; ++i) dA[i] = dB[i] = dC[i] = _infinity;
	dijkstra (A, vec, dA);
	dijkstra (B, rvec, dB);
	dijkstra (C, rvec, dC);
/*
	for (i = 0; i < N; ++i) printf ("%d ", dA[i]); printf ("\n");
	for (i = 0; i < N; ++i) printf ("%d ", dB[i]); printf ("\n");
	for (i = 0; i < N; ++i) printf ("%d ", dC[i]); printf ("\n");
*/
	int ACB = dA[C] + dB[C];
	int ABC = dA[B] + dC[B];

	int A_BC = _infinity;
	int toB, toC, toBi, toCi;
	int mid, toBbi, toCbi;
	int tmp;
	for (i = 0; i < N; ++i) {
		if (!vec[i].size ()) continue;
		toB = dB[vec[i][0].to]; toBi = 0;
		toC = dC[vec[i][0].to]; toCi = 0;

		for (j = 1; j < (int)vec[i].size (); ++j) {
			if (toB > dB[vec[i][j].to]) {
				toB = dB[vec[i][j].to];
				toBi = j;
			}
			if (toC > dC[vec[i][j].to]) {
				toC = dC[vec[i][j].to];
				toCi = j;
			}
			if (A_BC > (tmp = dA[i] + vec[i][j].dist + toB + toC)) {
				A_BC = tmp;
				mid = i;
				toBbi = toBi;
				toCbi = toCi;
			}
		}
	}
	int crnt;
	int id;
	int best;
	if (ABC <= (ACB <? A_BC)) {
		best = ABC;
		crnt = A;

		fprnt (A, B, dA);
		fprnt (B, C, dC);
	} else if (ACB <= (ABC <? A_BC)) {
		best = ACB;
		crnt = A;
		fprnt (A, C, dA);
		fprnt (C, B, dB);
	} else {//A_BC - the hard way :)
		best = A_BC;
		crnt = A;
		fprnt (A, mid, dA);
		crnt = mid;
		ans.push_back (make_pair (crnt, toBbi > toCbi ? vec[crnt][toBbi].dist : vec[crnt][toCbi].dist));
		fprnt (vec[mid][toBbi].to, B, dB);
		fprnt (vec[mid][toCbi].to, C, dC);
	}

	printf ("%d %d\n", ans.size (), best);
	for (i = 0; i < ans.size (); ++i)
		printf ("%d %d\n", ans[i].first + 1, ans[i].second);

	return 0;
}
