/*
FROM: SPRING 2006 A
PROB: atom
KEYW: binary search, geometry
*/

#include <cstdio>
#include <cmath>

#include <algorithm>

const int MAXN = 1 << 7;
const double epsilon = 1e-6;

template <class T> struct point {
	T x, y;
	point () {}
	point (T _x, T _y) : x (_x), y (_y) {}
	point (const point<T> &a) : x (a.x), y (a.y) {}

	point& operator += (const point &a) {x += a.x; y += a.y; return *this;}
	point& operator -= (const point &a) {x -= a.x; y -= a.y; return *this;}
	point& operator *= (T a) {x *= a; y *= a; return *this;}
	point& operator /= (T a) {x /= a; y /= a; return *this;}

	point operator + (const point &a) const {point <T> res (*this); res += a; return res;}
	point operator - (const point &a) const {point <T> res (*this); res -= a; return res;}
	point operator * (T a) const {point <T> res (*this); res *= a; return res;}
	point operator / (T a) const {point <T> res (*this); res /= a; return res;}

	T sq () {return x * x + y * y;}
	double len () {return sqrt (fabs (sq ()));}
	point rot () const {return point (-y, x);}
};

point <double> tod (const point <int> &a) {
	return point <double> (a.x, a.y);
}

int N;
point <int> pnts[MAXN];

double d22[MAXN][MAXN];
point <double> mid[MAXN][MAXN];
point <double> e1[MAXN][MAXN];

int lpid;
int hid[MAXN], hsz;

template <class T> T S (const point <T> &a, const point <T> &b, const point <T> &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool cmp (int a, int b) {
	static int tmp;
	return (tmp = S (pnts[lpid], pnts[a], pnts[b])) ?
			tmp > 0 :
			(pnts[a] - pnts[lpid]).sq () < (pnts[b] - pnts[lpid]).sq ();
}

void hull () {
	lpid = 0;
	int i;
	for (i = 1; i < N; ++i)
		if (pnts[i].y < pnts[lpid].y || pnts[i].y == pnts[lpid].y && pnts[i].x > pnts[lpid].x)
			lpid = i;

	int idx[MAXN];
	for (i = 0; i < N; ++i) idx[i] = i;
	idx[lpid] = 0;
	idx[0] = lpid;

	std::sort (idx + 1, idx + N, cmp);

	hid[0] = idx[0];
	hid[1] = idx[1];
	hsz = 2;

	for (i = 2; i < N; ++i) {
		hid[hsz++] = idx[i];
		while (hsz > 2 && S (pnts[hid[hsz-3]], pnts[hid[hsz-2]], pnts[hid[hsz-1]]) <= 0) {
			hid[hsz-2] = hid[hsz-1];
			--hsz;
		}
	}
//	for (i = 0; i < hsz; ++i) printf ("%d(%d %d) ", hid[i], pnts[hid[i]].x, pnts[hid[i]].y); printf ("\n");
	hid[hsz] = hid[0];
}

point <double> xxx;

bool test (double R) {
	static int i, j, k;
	static point <double> p;
	static double R2;
	static bool f1;
	R2 = R * R;
//	printf ("test -- %lf\n", R);

	for (i = 0; i < N; ++i)
		for (j = 0; j < i; ++j) {
			f1 = (R2 - d22[i][j] < 0.);

			p = f1 ? mid[i][j] : mid[i][j] + e1[i][j] * sqrt (R2 - d22[i][j]);
//			printf ("(%.1lf %.1lf) ", p.x, p.y);
			for (k = 0; k < hsz; ++k) if (S (tod (pnts[hid[k]]), tod (pnts[hid[k+1]]), p) < -epsilon) break;
			if (k < hsz) {/*printf ("<S %d>", k);*/ goto nxt;}
			for (k = 0; k < N && (p - tod (pnts[k])).len () - R > -epsilon; ++k);
			if (k == N) {xxx = p; return 1;} else {/*printf ("<L %d>", k)*/;}

			nxt:;
			if (f1) continue;
			p = f1 ? mid[i][j] : mid[i][j] - e1[i][j] * sqrt (R2 - d22[i][j]);
//			printf ("(%.1lf %.1lf) ", p.x, p.y);
			for (k = 0; k < hsz; ++k) if (S (tod (pnts[hid[k]]), tod (pnts[hid[k+1]]), p) < -epsilon) break;
			if (k < hsz) {/*printf ("<S %d>", k); */continue;}
			for (k = 0; k < N && (p - tod (pnts[k])).len () - R > -epsilon; ++k);
			if (k == N) {xxx = p; return 1;} else {/*printf ("<L %d>", k);*/}
		}

//	printf ("NOP!\n");
	return 0;
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%d %d", &pnts[i].x, &pnts[i].y);

	hull ();

	int j;
	for (i = 0; i < N; ++i)
		for (j = 0; j < i; ++j) {
			d22[i][j] = (pnts[j] - pnts[i]).sq () / 4.;
			mid[i][j] = tod (pnts[j] - pnts[i]) / 2. + tod (pnts[i]);
			e1[i][j] = tod ((pnts[j] - pnts[i]).rot ()) / (pnts[j] - pnts[i]).len ();
//			printf ("%d %d --- %lf __ %lf %lf __ %lf %lf\n", i, j, d22[i][j], mid[i][j].x, mid[i][j].y, e1[i][j].x, e1[i][j].y);
		}

	double lb = 0, ub = 20000, m = 0.;
	while (lb - ub < -epsilon) {
		m = (lb + ub) / 2.;
		if (test (m))
			lb = m;
		else
			ub = m;
	}

	test (m);
	printf ("%.2lf\n%.2lf %.2lf\n", m, xxx.x, xxx.y);

	return 0;
}
