#include <cstdio>
#include <cstdarg>
#include <cstring>
#include <cctype>
#include <string>
#include <iostream>
#include <fstream>
#include <cmath>

using namespace std;

typedef long double real;
const int MAXN = 128;

// printf(...)-style function
void report(int score, const char *fmt, ...)
{
	va_list arg;
	static char buff[1024];
	printf("%d\n", score);
	va_start(arg, fmt);
	vsnprintf(buff, 1024, fmt, arg);
	va_end(arg);
	printf("%s", buff);
}

/*
	Judgefile Format:

	<Max Radius>
	<Hull size> <Hull pt 0> <Hull pt 1> ... <Hull pt n>
	<Hull area>
*/

int hull[MAXN];
int hs, n;
real area, varea;
real pt[MAXN][2];
real jans;
//
real uans, ux, uy;

real sqr(real x) { return x*x; }
real dist(real x1, real y1, real x2, real y2)
{
	return sqrt(sqr(x1-x2) + sqr(y1-y2));
}

real face(real x1, real y1, real x2, real y2, real x3, real y3)
{
	return x1 * y2 + x2 * y3 + x3 * y1 - x3 * y2 - x2 * y1 - x1 * y3;
}

bool in_hull(void)
{
	varea = 0.0;
	for (int i = 0; i < hs; i++) {
		real x1 = pt[hull[i]][0];
		real y1 = pt[hull[i]][1];
		real x2 = pt[hull[(i+1)%hs]][0];
		real y2 = pt[hull[(i+1)%hs]][1];
		real t = face(ux, uy, x1, y1, x2, y2);
		if (fabs(t) < 1e-7 && fabs(dist(ux, uy, x1, y1) + dist(ux, uy, x2, y2) - dist(x1, y1, x2, y2)) < 1e-7) return true;
		real h = t / dist(x1,y1,x2,y2);
		if (h < -0.015) return false;
		varea += fabs(t);
	}
	return true;
}


int main(int argc, char **argv)
{
	if (argc != 4) {
		printf("Usage: %s <input_file> <output_file> <judge_file>\n", argv[0]);
		return 1;
	}
	ifstream in(argv[1]);
	ifstream out(argv[2]);
	ifstream judge(argv[3]);
	//
	if (!in) {
		report(0, "Failed to open input file `%s',\nusually meaning that something mysterious has happened\n", argv[1]);
		return 2;
	}
	if (!out) {
		report(0, "Failed to open output file `%s',\nusually meaning that something mysterious has happened\n", argv[2]);
		return 3;
	}
	if (!judge) {
		report(0, "Failed to open judge file `%s',\nusually meaning that something mysterious has happened\n", argv[3]);
		return 4;
	}
	//
	// DO THE ACTUAL TESTING HERE...
	in >> n;
	for (int i = 0; i < n; i++)
		in >> pt[i][0] >> pt[i][1];
	//
	judge >> jans;
	judge >> hs;
	for (int i = 0; i < hs; i++)
		judge >> hull[i];
	judge >> area;
	if (!judge) {
		report(0, "Mysterious judge fail-to-read error\n");
		return -1;
	}

	//
	out >> uans >> ux >> uy;
	if (!out.good()) {
		report(0, "The output file is not of the correct format!\n");
		return 0;
	}
	if (fabs(uans-jans) > 0.005) {
		if (uans < jans) {
			report(0, "The supplied answer is smaller than judge's(%Lf %Lf)\n", uans, jans);
			return 0;
		}
	}
	if (!in_hull()) {
		report(0, "The specified answer point is not in the hull (%.6Lf vs %.6Lf)\n", area, varea);
		return 0;
	}

	real mdist = 1e99;
	for (int i = 0; i < n; i++) {
		real t = dist(ux, uy, pt[i][0], pt[i][1]);
		if(t < mdist) mdist = t;
	}
	if (fabs(mdist - uans) > 0.005) {
		report(0, "The specified answer point is not placed at the specified distance to the closest point\n"
		          "Reported by us is %.3Lf, reported by the competitor is %.3Lf\n", mdist, uans);
		return 0;

	}
	if (fabs(uans - jans) > 0.005) {
		report(0, "Judge solution is wrong. :(\n");
		return -1;
	}
	report(10, "OK\n");
	return 0;
}
