/*
FROM: Spring 2007 A
PROB: names
KEYW: logarithm hash comparison of 2 strings, smallest lexicographical rotation of a string, full exhaustion
*/

#include <cstdio>
#include <cassert>
#include <vector>
#include <utility>
#include <algorithm>

typedef std::pair <int, int> PI;
typedef std::pair <long long, long long> PLL;

const int MAXL = 1 << 21;

const PI MOD (456231569, 978496649);
const PI BASE (29, 31);
PI H[MAXL];
PI B[MAXL];

PLL operator + (const PLL &a, const PLL &b) {
	return PLL (a.first + b.first, a.second + b.second);
}
PLL operator - (const PLL &a, const PLL &b) {
	return PLL (a.first - b.first, a.second - b.second);
}
PLL operator * (const PLL &a, const PLL &b) {
	return PLL (a.first * b.first, a.second * b.second);
}
PI operator % (const PLL &a, const PI &b) {
	return PI (a.first % b.first, a.second % b.second);
}

const PLL MOD_SQ = MOD * MOD;
int N;
char s[MAXL];

PLL to_pair (int x) {
	return PLL ((long long)x, (long long)x);
}

void preprocess () {
	static int i;
	H[0] = to_pair (s[0] - 'a') % MOD;
	B[0] = to_pair (1);

	for (i = 1; s[i]; ++i) {
		H[i] = (H[i-1] * BASE + to_pair (s[i] - 'a')) % MOD;
		B[i] = (B[i-1] * BASE) % MOD;
	}
	N = i;
/*
	for (i = 0; i < N; ++i)
		printf ("%d %d  %d %d\n", H[i].first, B[i].first, H[i].second, B[i].second);
*/
}

PI hash (int b, int e) {
	--b; --e;
	if (b == -1) return H[e];
	return (H[e] - H[b] * B[e-b] + MOD_SQ) % MOD;
}
PI hash (const PI &x) {return hash (x.first, x.second);}
int min (int a, int b) {return a < b ? a : b;}

int cmp (const PI &a, const PI &b) {
	static int l, r, m;
	if (a.second - a.first == 0
	 || b.second - b.first == 0) return 0;//equal
	l = 0, r = min (a.second - a.first, b.second - b.first) + 1;
	while (l + 1 < r) {
		m = (l + r) / 2;
		if (hash (a.first, a.first + m) == hash (b.first, b.first + m))
			l = m;
		else
			r = m;
	}
	if (l == min (a.second - a.first, b.second - b.first)) return 0;
	return s[a.first + l] - s[b.first + l];
}

int cmp (const std::vector <PI> &a, const std::vector <PI> &b) {
	static size_t p1, p2;
	static int b1, b2, l1, l2, cres;
/*
	for (p1 = 0; p1 < a.size (); ++p1) printf (" (%d %d)", a[p1].first, a[p1].second); puts ("  a");
	for (p1 = 0; p1 < b.size (); ++p1) printf (" (%d %d)", b[p1].first, b[p1].second); puts ("  b");
*/
	p1 = p2 = 0;
	b1 = a[p1].first;
	b2 = b[p2].first;

	while (p1 != a.size ()) {
		cres = cmp (PI (b1, a[p1].second), PI (b2, b[p2].second));
		if (cres == 0) {
			l1 = a[p1].second - b1;
			l2 = b[p2].second - b2;
			if (l1 < l2) {
				b1 = a[++p1].first;
				b2 += l1;
			} else if (l1 > l2) {
				b2 = b[++p2].first;
				b1 += l2;
			} else {
				++p1; b1 = a[p1].first;
				++p2; b2 = b[p2].first;
			}
		} else {
//			printf ("%u %d %u %d  %d\n", p1, b1, p2, b2, cres);
			return cres;//inequality
		}
	}
//	printf ("%u %d %u %d Xx\n", p1, b1, p2, b2);
	assert (p2 == b.size ());
//	printf ("eq!\n");
	return 0;//equal
}

int main () {
	std::vector <PI> va, vb;
	static char min_char[MAXL];
	int i, j, beg;
	while (gets (s)) {
//		puts (s);
		preprocess ();
//		printf ("N == %d\n", N);

		va.clear ();
		va.push_back (PI (0, N));
/*		vb.resize (2);
		for (i = 1; i < N; ++i) {
			vb[0] = PI (i, N);
			vb[1] = PI (0, i);
			if (cmp (va, vb) > 0)
				va = vb;
		}*/
		min_char[N] = 'z' + 1;
		for (i = N-1; i >= 0; --i)
			min_char[i] = min_char[i+1] <? s[i];
		min_char[N] = 'a' - 1;//make it very small so that the next cycle can stop
		for (i = 0; min_char[i+1] >= s[i]; ++i);
		beg = i;
//		printf ("beg -- %d\n", beg);
		vb.resize (2 + !!beg);
		if (beg) vb[0] = PI (0, beg);
		for (++i; i < N; ++i) {
			vb[!!beg] = PI (i, N);
			vb[!!beg + 1] = PI (beg, i);
			if (cmp (va, vb) > 0)
				va = vb;
		}
		vb.resize (3);
		for (i = 1; i < N; ++i)
			for (j = i + 1; j < N; ++j) {
				vb[0] = PI (i, j);
				vb[1] = PI (0, i);
				vb[2] = PI (j, N);
				if (cmp (va, vb) > 0)
					va = vb;
			}

/*		for (size_t ii = 0; ii != va.size (); ++ii) {
			printf (" (%d %d)", va[ii].first, va[ii].second);
		}
		puts ("");*/
		for (size_t ii = 0; ii != va.size (); ++ii) {
			printf ("%.*s", va[ii].second - va[ii].first, s + va[ii].first);
		}
		puts ("");
	}

/*
	gets (s);
	preprocess ();

	int a, b;
	std::vector <PI> va, vb;
	for (;;) {
		scanf ("%d %d", &a, &b);
		va.clear ();
		va.push_back (PI (0, a));
		va.push_back (PI (a, b));
		va.push_back (PI (b, N));
		vb = va;
		do
			if (cmp (va, vb) > 0) {
				printf ("yep!\n");
				va = vb;
			}
		while (std::next_permutation (vb.begin (), vb.end ()));
		printf ("%d %d  %d %d  %d %d\n", va[0].first, va[0].second, va[1].first, va[1].second, va[2].first, va[2].second);
		//find s' smallest rotation
		va.clear ();
		va.push_back (PI (0, N));
		vb.resize (2);
		for (int i = 1; i < N; ++i) {
			vb[0] = PI (i, N);
			vb[1] = PI (0, i);
			if (cmp (va, vb) > 0)
				va = vb;
		}
		printf ("SR %d %d  %d %d  %d %d\n", va[0].first, va[0].second, va[1].first, va[1].second, va[2].first, va[2].second);
	}
*/
	return 0;
}
