/*
FROM: USACO 2002 JANUARY GREEN
PROB: party
KEYW: max flow, dinitz
*/

#include <cstdio>

const int MAXrN = 1 << 9;//512
const int MAXM = 1 << 16;//60 000
const int MAXD = 1 << 7;//128
const int _infinity = 1 << 10;

struct el {
	int to;
	int cap;
	int next;
	el () {}
	el (int _to, int _cap, int _next) : to (_to), cap (_cap), next (_next) {}
};

int N, D, K;
int rN;//real N -> number of vertices in the graph

int vec[MAXrN];
el buf[MAXM];

int source, sink;

int Dist[MAXrN];
int vis[MAXrN], vp;
bool used[MAXrN];

inline int op (int a) {
	return a + (a & 1 ? -1 : 1);
}

bool bfs () {
	int i, j;
	for (i = 0; i < rN; ++i) {
		used[i] = 0;
		Dist[i] = -1;
	}
	used[source] = 1;

	int p1 =0, p2 =1, p3 =0, lvl =0;
	static int queue[MAXrN];
	queue[p3++] = sink;
	Dist[sink] = lvl++;

	while (p1 != p2) {
		for (i = p1; i < p2; ++i) {
			if (queue[i] == source) return 1;

			for (j = vec[queue[i]]; j != -1; j = buf[j].next) {
				if (Dist[buf[j].to] == -1 && buf[op (j)].cap) {
//					printf ("Dist[%d] = %d\n", buf[j].to, lvl);
					Dist[buf[j].to] = lvl;
					queue[p3++] = buf[j].to;
				}
			}
		}
		p1 = p2;
		p2 = p3;
		++lvl;
	}

	return 0;
}

int dfs (int v) {
//	printf ("dfs %d\n", v);
	if (v == sink) {
//		printf ("ret %d\n", _infinity);
		return _infinity;
	}

	int tmp;
	for (int i = vec[v]; i != -1; i = buf[i].next) {
		if (Dist[buf[i].to] == Dist[v] - 1 && !used[buf[i].to] && buf[i].cap) {
			used[buf[i].to] = 1;
			vis[vp++] = i;
			if ((tmp = dfs (buf[i].to))) {
//				printf ("%d returned %d\n", buf[i].to, tmp);
//				printf ("%d ret %d(%d)\n", v, tmp < buf[i].cap ? tmp : buf[i].cap, tmp);
				return (tmp < buf[i].cap ? tmp : buf[i].cap);
			}
			--vp;
		}
	}
//	printf ("<- %d\n", v);
	return 0;//did'n find a path to the sink
}

int dinitz () {
	int cflow, sflow =0;

	while (bfs ())
		while (vp = 0, (cflow = dfs (source))) {
			sflow += cflow;
//			printf ("---%d\n", cflow);
			for (int i = 0; i < vp; ++i) {
				buf[vis[i]].cap -= cflow;
				buf[op (vis[i])].cap += cflow;
			}
			used[sink] = 0;
		}

	return sflow;
}

int main () {
//	FILE *in = fopen ("party.in", "r");
	FILE *in = stdin;

	fscanf (in, "%d %d %d", &N, &K, &D);
	source = N + D;
	sink = source + 1;

	int i, j;
	rN = sink + 1;
	int bp =0;
	int a;

	for (i = 0; i < rN; ++i) vec[i] = -1;
	for (i = 0; i < D; ++i) {
		fscanf (in, "%d", &a);
		buf[bp] = el (sink, a, vec[N + i]);
		vec[N + i] = bp++;

		buf[bp] = el (N + i, 0, vec[sink]);
		vec[sink] = bp++;
	}

	int z;
	for (i = 0; i < N; ++i) {
		fscanf (in, "%d", &z);

		for (j = 0; j < z; ++j) {
			fscanf (in, "%d", &a);
			--a;

			buf[bp] = el (N + a, 1, vec[i]);
			vec[i] = bp++;

			buf[bp] = el (i, 0, vec[N + a]);
			vec[N + a] = bp++;
		}
	}
	fclose (in);

	for (i = 0; i < N; ++i) {
		buf[bp] = el (i, K, vec[source]);
		vec[source] = bp++;

		buf[bp] = el (source, 0, vec[i]);
		vec[i] = bp++;
	}
/*
	for (i = 0; i < rN; ++i) {
		printf ("%d ->", i);
		for (j = vec[i]; j != -1; j = buf[j].next)
			printf (" (%d %d)", buf[j].to, buf[j].cap);
		printf ("\n");
	}
*/
	int mflow = dinitz ();

//	FILE *out = fopen ("party.out", "w");
	FILE *out = stdout;
	fprintf (out, "%d\n", mflow);
	fclose (out);

	return 0;
}
