/*
ID: iskren81
PROB: roping
LANG: C++
KEYW: computational geometry
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>

const int MAXN = 1 << 8;//150
const int MAXG = 1 << 7;//100
const long double epsilon = 1e-12l;

struct point {
	long long x, y;
	point () {}
	point (int xx, int yy) : x (xx), y (yy) {}
	point operator - (const point &a) {return point (x - a.x, y - a.y);}
	long long operator * (const point &a) {return  x * a.x + y * a.y;}
};

int N, G;

point vec[MAXN];
point c[MAXG];
int R;

bool ma3x[MAXN][MAXN];
int opt[MAXN][MAXN];

inline int max (int a, int b) {
	return (a > b ? a : b);
}

long long S (point a, point b, point c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

long double dist (point a, point b) {
	return hypotl (a.x - b.x, a.y - b.y);
}

bool intersect (point p, point q, point o) {
	return ((long double)(llabs (S (p, q, o))) - (long double)(R) * dist (p, q) < epsilon &&
	(
	 dist (o, p) - R < epsilon ||
	 dist (o, q) - R < epsilon ||
	 ((p - q) * (o - q) > 0 &&
	  (q - p) * (o - p) > 0
	 )
	));
}

int main () {
	FILE *in = fopen ("roping.in", "r");

	fscanf (in, "%d %d %d", &N, &G, &R);

	int i, j, k;
	for (i = 0; i < N; ++i)
		fscanf (in, "%Ld %Ld", &vec[i].x, &vec[i].y);
	for (i = 0; i < G; ++i)
		fscanf (in, "%Ld %Ld", &c[i].x, &c[i].y);
	fclose (in);

	int N1 = N-1;
	int cnt =0;
	for (i = 0; i < N1; ++i)
		for (j = i + 2; j < N; ++j) {
			for (k = 0; k < G; ++k)
				if (intersect (vec[i], vec[j], c[k]))
					break;
			if (k == G)
				ma3x[i][j] = ma3x[j][i] = 1;
		}

	ma3x[0][N-1] = ma3x[N-1][0] = 0;//because we may have added this previously

	int _tmp;
	for (k = 3; k < N; ++k)
		for (i = 0; i < N; ++i) {
			_tmp = (i + k) % N;
			for (j = (i + 1) % N; j != _tmp; ++j, (j == N ? j = 0 : 0)) {
				opt[i][_tmp] = max (opt[i][_tmp], opt[i][j] + opt[j][_tmp] + ma3x[i][j] + ma3x[j][_tmp]);
			}
		}

	for (i = 1; i < N; ++i)
		cnt = max (cnt, opt[i][i-1]);
	cnt = max (cnt, opt[0][N-1]);

	FILE *out = fopen ("roping.out", "w");
	fprintf (out, "%d\n", cnt);
	fclose (out);

	return 0;
}
