/*
TASK: mobile
LANG: C++
KEYW: dijkstra + computational geometry
*/

#include <cstdio>
#include <cmath>
#include <vector>
#include <queue>
#include <algorithm>

const int MAXN = 1 << 7;
const double epsilon = 1e-8;

struct pnt {
    double x, y;
    pnt () {}
    pnt (double _x, double _y) : x (_x), y (_y) {}
    pnt &operator -= (const pnt &a) {x -= a.x; y -= a.y; return *this;}
    pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
    double operator * (const pnt &a) const {return x * a.x + y * a.y;}
    pnt &operator *= (double a) {x *= a; y *= a; return *this;}
    double sq () const {return x * x + y * y;}
    double len () const {return sqrt (sq ());}
    pnt rotl () const {return pnt (-y, x);}
    pnt rotr () const {return pnt (y, -x);}
    void mod () {double k = len (); x /= k; y /= k;}
};

int N1, N2;
int N[2];
std::vector <pnt> buf[2][MAXN];
std::vector <pnt> vec[2];

double S (const pnt &a, const pnt &b, const pnt &c) {
    return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

pnt _base;
bool cmp (const pnt &a, const pnt &b) {
    return (a - _base).sq () < (b - _base).sq ();
}

bool can (const pnt &x, const pnt &a, const pnt &b, pnt &ret) {
//    printf (">>can %lf %lf   %lf %lf  %lf %lf\n", x.x, x.y, a.x, a.y, b.x, b.y);
    if ((b - a) * (x - a) < epsilon || (a - b) * (x - b) < epsilon) {
//        printf (">>%lf %lf NO!\n", (b - a) * (x - a), (a - b) * (x - b));
        return 0;
    }
    pnt tmp;
    double _tS;
    if ((_tS = S (a, b, x)) > 0)
        tmp = (b - a).rotr ();
    else
        tmp = (b - a).rotl ();
    _tS /= (a - b).len ();
    tmp.mod ();
//    printf ("tomult %lf,   %lf %lf\n", _tS, tmp.x, tmp.y);
    tmp *= _tS;
//    printf ("!!!%lf %lf\n", tmp.x, tmp.y);
    tmp.x += x.x; tmp.y += x.y;
//    printf ("!!!%lf %lf\n", tmp.x, tmp.y);
    ret = tmp;
//    printf ("<<<<%lf %lf\n", ret.x, ret.y);
    return 1;
}

struct heap {
    int k1, k2;
    double dist;
    heap () {}
    heap (int _k1, int _k2, double _dist) : k1 (_k1), k2 (_k2), dist (_dist) {}
    bool operator < (const heap &a) const {return dist > a.dist;}
};

std::priority_queue <heap> h;

char *XXX;
int _XX, __XX;
void init (int a, int b) {
    _XX = a; __XX = b;
    XXX = new char [a * b / 8 + 3];
}

bool not_used (int a, int b) {
    int id = a * __XX + b;
    return !(XXX[id >> 3] & (1 << (id & 7)));
}

void make_used (int a, int b) {
    int id = a * __XX + b;
    XXX[id >> 3] |= 1 << (id & 7);
}

double dijkstra () {
    h.push (heap (0, 0, (vec[1][0] - vec[0][0]).sq ()));
//    printf ("%lf %lf  %lf %lf  %lf\n", vec[0][0].x, vec[0][0].y, vec[1][0].x, vec[1][0].y, (vec[0][0] - vec[1][0]).sq ());
    make_used (0, 0);

    heap crnt;
    int k1, k2;
    while (!h.empty ()) {
        crnt = h.top (); h.pop ();

//        printf ("%d %d  %.2lf\n", crnt.k1, crnt.k2, crnt.dist);
        if (crnt.k1 == vec[0].size () - 1 && crnt.k2 == vec[1].size () - 1) return crnt.dist;
        make_used (crnt.k1, crnt.k2);
        for (k1 = -1; k1 <= 1; ++k1)
            for (k2 = -1; k2 <= 1; ++k2)
                if (crnt.k1 + k1 >= 0 && crnt.k1 + k1 < vec[0].size ()
                 && crnt.k2 + k2 >= 0 && crnt.k2 + k2 < vec[1].size ()
                 && not_used (crnt.k1 + k1, crnt.k2 + k2))
                    h.push (heap (crnt.k1 + k1, crnt.k2 + k2,
                    crnt.dist >? (vec[0][crnt.k1 + k1] - vec[1][crnt.k2 + k2]).sq ()));
    }
    return 100000000;
}

int main () {
    scanf ("%d %d", &N1, &N2);
    N[0] = N1; N[1] = N2;

    int i, k;
    pnt X;
    for (k = 0; k < 2; ++k) {
        for (i = 0; i < N1; ++i) {
            scanf ("%lf %lf", &X.x, &X.y);
            buf[k][i].push_back (X);
        }
    }

    int j;
    for (k = 0; k < 2; ++k)
        for (i = 0; i < N[k]; ++i)
            for (j = 0; j < N[!k] - 1; ++j)
                if (can (buf[k][i][0], buf[!k][j][0], buf[!k][j+1][0], X)) {
                    buf[!k][j].push_back (X);
//                    printf ("push_back at %d %d --(%u)\n", !k, j, buf[!k][j].size ());
                }
    
    for (k = 0; k < 2; ++k) {
        for (i = 0; i < N[k]-1; ++i) {
            _base = buf[k][i][0];
            std::sort (buf[k][i].begin () + 1, buf[k][i].end (), cmp);
        }
    }

    for (k = 0; k < 2; ++k)
        for (i = 0; i < N[k]; ++i)
            for (j = 0; j < buf[k][i].size (); ++j) {
//                printf ("%d %d %d -- %.2lf %.2lf\n", k, i, j, buf[k][i][j].x, buf[k][i][j].y);
                vec[k].push_back (buf[k][i][j]);
            }
/*
    for (k = 0; k < 2; ++k) {
        for (i = 0; i < vec[k].size (); ++i)
            printf ("(%.3lf %.3lf)", vec[k][i].x, vec[k][i].y);
        printf ("\n");
    }
*/
    init (vec[0].size (), vec[1].size ());

    double res = dijkstra ();
    printf ("%.4lf\n", sqrt (res));

    return 0;
}

