/*
ID: iskren81
PROB: cowtour
LANG: C++
KEYW: dijkstra, graph diameter
*/

#include <cstdio>
#include <cstdlib>
#include <cmath>

const int MAXN = 1 << 8;
const double _infinity = 1e+9;

struct point {
	int x;
	int y;
	point () {}
	point (int _x, int _y) : x (_x), y (_y) {}
};

int N;
bool ma3x[MAXN][MAXN];
double ma3xD[MAXN][MAXN];
point vec[MAXN];
double maxD[MAXN];

int group[MAXN];
double groupD[MAXN];
bool ready_group[MAXN];

void dfs (int v, int g) {
	group[v] = g;

	for (int i = 0; i < N; ++i)
		if (ma3x[v][i] && group[i] == -1)
			dfs (i, g);
}

int dijkstra (int v) {
	static bool used[MAXN];
	static double D[MAXN];

	int i;
	for (i = 0; i < N; ++i) {
		used[i] = 0;
		D[i] = _infinity;
	}

	D[v] = 0;

	int mini;
	double min;
	for (;;) {
		min = _infinity;
		for (i = 0; i < N; ++i)
			if (!used[i] && D[i] < min) {
				min = D[i];
				mini = i;
			}

		if (min == _infinity) break;
		used[mini] = 1;

		if (maxD[mini] < D[mini])
			maxD[mini] = D[mini];

		for (i = 0; i < N; ++i)
			if (ma3x[mini][i] &&
				D[i] > min + ma3xD[mini][i])
				D[i] = min + ma3xD[mini][i];
	}

	return mini;//the last mini was not changed
}

double maxGD = 0;

void fill_gr (int v) {
	int a = dijkstra (v);
	int b = dijkstra (a);
	dijkstra (b);
//	if (group[b] != group[a] || group[a] != group[v]) printf ("group problem!\n");
	groupD[group[b]] = maxD[b];
	if (maxGD < maxD[b])
		maxGD = maxD[b];
}

inline double max (double a, double b) {
	return (a > b ? a : b);
}

inline double max4 (double a, double b, double c, double d) {
//	return (a > b ? a > c ? a : c : b > c ? b : c);
	return max (max (a, b), max (c, d));
}

inline double tellD (int a, int b) {
	return max4 (groupD[group[a]], groupD[group[b]], maxD[a] + maxD[b] + ma3xD[a][b], maxGD);
}

int main () {
	FILE *in = fopen ("cowtour.in", "r");
	fscanf (in, "%d\n", &N);

	int i, j;
	for (i = 0; i < N; ++i)
		fscanf (in, "%d %d\n", &vec[i].x, &vec[i].y);

	char tmp;
	for (i = 0; i < N; ++i) {
		for (j = 0; j < N; ++j) {
			fscanf (in, "%c", &tmp);
			ma3x[i][j] = (tmp == '1');
		}
		fscanf (in, "\n");
	}
	fclose (in);

	for (i = 0; i < N; ++i) group[i] = -1;

	int nG = 0;
	for (i = 0; i < N; ++i)
		if (group[i] == -1)
			dfs (i, nG++);

	for (i = 0; i < N; ++i)
		for (j = i + 1; j < N; ++j)
			ma3xD[i][j] = ma3xD[j][i] = hypot (vec[i].x - vec[j].x, vec[i].y - vec[j].y);

	for (i = 0; i < N; ++i)
		if (!ready_group[group[i]] && (ready_group[group[i]] = 1))
			fill_gr (i);

	double minD = _infinity;
	for (i = 0; i < N; ++i)
		for (j = i + 1; j < N; ++j)
			if (group[i] != group[j] &&
				minD > tellD (i, j))
				minD = tellD (i, j);

	printf ("%lf\n", maxGD);

	FILE *out = fopen ("cowtour.out", "w");
	fprintf (out, "%.6lf\n", minD);
	fclose (out);

	return 0;
}
