/*
ID: iskren81
PROB: fence4
LANG: C++
KEYW: computational geometry
*/

#include <cstdio>
#include <cmath>
#include <algorithm>
#include <limits>

const int MAXN = 1 << 8;

int nod (int, int);

struct point {
	int x;
	int y;
	point () {}
	point (int xx, int yy) : x (xx), y (yy) {}
	point& operator += (const point &a) {x += a.x; y += a.y; return *this;}
	point& operator -= (const point &a) {x -= a.x; y -= a.y; return *this;}
	point operator + (const point &a) const {return point (x + a.x, y + a.y);}
	point operator - (const point &a) const {return point (x - a.x, y - a.y);}
	point& operator *= (int a) {x *= a; y *= a; return *this;}
	point operator * (int a) const {return point (x * a, y * a);}
	point& div () {int k = nod (abs (x), abs (y)); x /= k; y /= k; return *this;};
	double len () const {return sqrt (x * x + y * y);}
	bool operator == (const point &a) const {return x == a.x && y == a.y;}
};

int N;
point vec[MAXN];
point rv[MAXN];
int rvp;

bool seen[MAXN];

point base;

int _nod (int a, int b) {
	return (b ? _nod (b, a % b) : a);
}

int nod (int a, int b) {
	return (a > b ? _nod (a, b) : _nod (b, a));
}

int S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool inter_line (const point &p1, const point &q1, const point &p2, const point &q2) {
//	printf ("/*/");
	return (p2 - p1).len () + (p2 - q1).len () == (p1 - q1).len () || (q2 - p1).len () + (q2 - q1).len () == (p1 - q1).len ();
}

bool intersect (const point &p1, const point &q1, const point &p2, const point &q2) {
	long long a1 = (long long)(S (p1, q1, p2)) * S (p1, q1, q2);
	long long a2 = (long long)(S (p2, q2, p1)) * S (p2, q2, q1);
	
	if (a1 || a2)
		return (a1 <= 0 && a2 <= 0);
	else
		return inter_line (p1, q1, p2, q2);
}

bool cmp1 (const point &a, const point &b) {
	return (a.x != b.x ? a.x < b.x : a.y < b.y);
}

bool cmp2 (const point &a, const point &b) {
	return atan2 (a.y, a.x) < atan2 (b.y, b.x);
}

point enlarge (const point &a) {
//	return a;
//	printf ("%d %d ->", a.x, a.y);
	point ret = a * ((1000 / std::max (abs (a.x), abs (a.y))) + 1);
//	printf ("%d %d(%d)\n", ret.x, ret.y, ((1000 / std::max (abs (a.x), abs (a.y))) + 1));
	return ret;
}

double find_t (const point &p1, const point &q1, const point &p2, const point &q2) {
	if (!intersect (p1, enlarge (q1 - p1) + p1, p2, q2)) return -1;
//	printf ("\there %d %d  %d %d   %d %d  %d %d\n", p1.x, p1.y, q1.x, q1.y, p2.x, p2.y, q2.x, q2.y);
//	if (q1.x == -5 && q1.y == 0) printf ("*%d %d*\n",enlarge (q1 - p1).x, enlarge (q1 - p1).y);
	int S1 = S (p1, p2, q2);
	int S2 = S (q2, p2, q1);
	return (double)(S1) / (double)(S1 + S2);
}

void test (const point &a) {
//	printf ("test -> %d %d\n", a.x, a.y);
	double mint = std::numeric_limits<double>::max ();
	int mini = -1;
	for (int i = 0; i < N; ++i) {
		double ct = find_t (base, base + a, vec[i], vec[i + 1]);
		if (0 < ct && ct < mint) {
			mint = ct;
			mini = i;
		}
	}
//	printf ("%d\n", mini);
	if (mini != -1)
		seen[mini] = 1;
}

void output () {
	int i, cnt =0;
	for (i = 0; i < N; ++i) cnt += seen[i];
	FILE *out = fopen ("fence4.out", "w");
	fprintf (out, "%d\n", cnt);
	
	for (i = 0; i < N - 2; ++i)
		if (seen[i])
			fprintf (out, "%d %d %d %d\n", vec[i].x, vec[i].y, vec[i+1].x, vec[i+1].y);
	if (seen[N-1])
		fprintf (out, "%d %d %d %d\n", vec[0].x, vec[0].y, vec[N-1].x, vec[N-1].y);
	if (seen[i = (N-2)])
		fprintf (out, "%d %d %d %d\n", vec[i].x, vec[i].y, vec[i+1].x, vec[i+1].y);
	fclose (out);
}

int main () {
	FILE *in = fopen ("fence4.in", "r");
	fscanf (in, "%d", &N);
	
	fscanf (in, "%d %d", &base.x, &base.y);

	int i, j;
	for (i = 0; i < N; ++i)
		fscanf (in, "%d %d", &vec[i].x, &vec[i].y);
	fclose (in);
	vec[N] = vec[0];

	for (i = 0; i < N; ++i)
		for (j = 0; j < N; ++j) {
			if (j == i || j == (i + N - 1) % N || j == (i + 1) % N) continue;//j is
			if (vec[i] == vec[j]) goto end_for1;
		}	
	
	for (i = 0; i < N; ++i)
		for (j = 0; j < N; ++j) {
			if (j == i || j == (i + N - 1) % N || j == (i + 1) % N) continue;//j is
			if (intersect (vec[i], vec[i+1], vec[j], vec[j+1])) goto end_for1;
		}

end_for1:;
	if (i != N) {
		printf ("%d %d", i, j);
		FILE *out = fopen ("fence4.out", "w");
		fprintf (out, "NOFENCE\n");
		fclose (out);
		return 0;//exit main
	}

	for (i = 0; i < N; ++i) {
		rv[i] = vec[i] - base;
//		printf ("%d %d ->",  rv[i].x, rv[i].y);
		rv[i].div ();
//		printf (" %d %d\n",  rv[i].x, rv[i].y);
	}
	rvp = N;
//	printf ("***\n");

	std::sort (rv, rv + rvp, cmp1);
	rvp = std::unique (rv, rv + rvp) - rv;
/*	
	for (i = 0; i < rvp; ++i)
		printf ("%d %d\n", rv[i].x, rv[i].y);
	printf ("**\n");
*/
	std::sort (rv, rv + rvp, cmp2);
	rv[rvp] = rv[0];
/*
	for (i = 0; i < rvp; ++i)
		printf ("%d %d\n", rv[i].x, rv[i].y);
	printf ("**\n");
*/
	for (i = 0; i < rvp; ++i) {
//		printf ("%d -> ", i);
		test (rv[i] + rv[i+1]);
	}
	output ();

	return 0;
}
