/*
FROM: WINTER 2005 A
PROB: dist
KEYW: computational geometry
*/
#include <cstdio>
#include <queue>
#include <cmath>

const int MAXN = 1 << 10;
const int MAXM = MAXN << 2;

struct point {
	double x;
	double y;
	point () {}
	point (double xx, double yy) : x (xx), y (yy) {}
	point operator - (const point &a) const {return point (x - a.x, y - a.y);}
	point operator + (const point &a) const {return point (x + a.x, y + a.y);}
};

struct el {
	int to;
	int next;
	el () {}
	el (int tt, int nn) : to (tt), next (nn) {}
};

struct el2 {
	int base1, base2, op, fnd;
	el2 (int a, int b, int c, int d) : base1 (a), base2 (b), op (c), fnd (d) {}
};

int N;
int S1, S2;

int lnks[MAXN];

point coor[MAXN];
bool found[MAXN];

int vec[MAXN];
el buf[MAXM];
int bp;

double ma3x[MAXN][MAXN];

std::queue <el2> q;

double costh (double a, double b, double c) {
	return (a * a + b * b - c * c) / (2 * a * b);
}

double togr (double a) {
	return a * 180 / M_PI;
}


point rot (point base, double ang) {
	return point (cos (ang) * base.x - sin (ang) * base.y, sin (ang) * base.x + cos (ang) * base.y);
}

double S (point a, point b, point c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool dhp (point a, point b, point c, point d) {
	return ((long double)S (a, b, c) * S (a, b, d) < 0);
}

void find (el2 a) {
	double baseAng = atan2 (coor[a.base2].y - coor[a.base1].y, coor[a.base2].x - coor[a.base1].x);
	double scndAng = acos (costh (ma3x[a.base1][a.base2], ma3x[a.base1][a.fnd], ma3x[a.base2][a.fnd]));

	point test = rot (point (ma3x[a.base1][a.fnd], 0), baseAng + scndAng) + coor[a.base1];
	if (dhp (coor[a.base1], coor[a.base2], coor[a.op], test))
		coor[a.fnd] = test;
	else
		coor[a.fnd] = rot (point (ma3x[a.base1][a.fnd], 0), baseAng - scndAng) + coor[a.base1];
}

int _vec[4];
int opposite (int a, int b) {
	for (int i = 0; i < 3; ++i)
		if (_vec[i] != a && _vec[i] != b) {
			return _vec[i];
		}
	return -1;
}

void upload (int a) {
	for (int i = vec[a]; i != -1; i = buf[i].next) {
		if (!found[buf[i].to])
			if (lnks[buf[i].to] == -1) {
				lnks[buf[i].to] = a;//first one
			} else {
				q.push (el2 (lnks[buf[i].to], a, opposite (a, lnks[buf[i].to]), buf[i].to));
				found[buf[i].to] = 1;
			}
	}
}

int main () {
	scanf ("%d", &N);
	scanf ("%d %d", &S1, &S2);
	--S1; --S2;
	int a, b;
	double d;

	int i;
	for (i = 0; i < N; ++i) vec[i] = -1;
	while (scanf ("%d %d %lf", &a, &b, &d) != EOF) {
		--a, --b;
		buf[bp] = el (b, vec[a]);
		vec[a] = bp++;
		
		buf[bp] = el (a, vec[b]);
		vec[b] = bp++;

		ma3x[a][b] = ma3x[b][a] = d;
	}
	
	coor[S1] = point (0, 0);
	coor[S2] = point (ma3x[S1][S2], 0);
	coor[N] = point (0, -1);//tmp -> used only in the points connected with s1 && s2

	for (i = 0; i < N; ++i) {
		lnks[i] = -1;
		found[i] = 0;
	}
	
	_vec[0] = S1; _vec[1] = S2; _vec[2] = N;
	
	found[S1] = 1;
	found[S2] = 1;
	
	upload (S1);
	upload (S2);

	el2 crnt (0,0,0,0);
	
	while (!q.empty ()) {
		crnt = q.front ();
//		printf ("ha!\n");
		q.pop ();
		find (crnt);
		upload (crnt.fnd);
	}
	
	for (i = 0; i < N; ++i) {
		printf ("%.2lf\n", hypot (coor[i].x, coor[i].y));
		if (!found[i])
			printf ("wowowo!\n");
	}

	return 0;
}
